;;; bug-numbered-tests.el --- run single tests according to bug number

;; Copyright (C) 2011 Andreas Roehler

;; Author: Andreas Roehler <andreas.roehler@online.de>
;; Keywords: languages

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; 

;;; Code:

(require 'thingatpt-utils-base)
(require 'thing-at-point-utils)
(require 'beg-end)
(require 'ar-comment-lor)

(setq bug-numbered-tests (list
                          
                          'py-previous-statement-637955-test
                          'py-302834-test
                          'py-fill-paragraph-problems-710373))

(defun py-run-bug-numbered-tests (&optional arg)
  (interactive "p")
  (dolist (ele bug-numbered-tests)
    (funcall ele arg)))

(defun py-fill-paragraph-problems-710373 (&optional load-branch-function)
  "If no `load-branch-function' is specified, make sure the appropriate branch is loaded. Otherwise default python-mode will be checked. "
  (interactive)
  ;; this var holds the function which loads the branch, edit it
  (let ((tmp-dir "/tmp/")
        (python-branch (or load-branch-function
                           'paragraph-fill-warts))
        (fpp-exec-buffer "fill-paragraph-problems-710373")
        (diff-buffer "fpp-710373-old")
        (fpp-teststring "
    \"\"\"
    triple-quoted string containing \"quotation\" marks.
    triple-quoted string containing \"quotation\" marks.
    triple-quoted string containing \"quotation\" marks.
    triple-quoted string containing \"quotation\" marks.
    triple-quoted string containing \"quotation\" marks.
    \"\"\"
")
        erg)
    (set-buffer (get-buffer-create diff-buffer))
    (erase-buffer)
    (insert fpp-teststring)
    (write-file (concat tmp-dir diff-buffer))
    (set-buffer (get-buffer-create fpp-exec-buffer))
    (when (interactive-p) (switch-to-buffer (current-buffer)))
    (erase-buffer)
    (python-mode)
    (insert fpp-teststring)
    (when (functionp python-branch) (funcall python-branch))
    (set-buffer fpp-exec-buffer)
    (font-lock-mode 1)
    (font-lock-fontify-buffer)
    (goto-char (point-min))
    (forward-line 3)
    (message "I'm here: %s" (point))
    (set-buffer-modified-p nil)
    ;;     (describe-function 'py-fill-paragraph)
    (set-fill-column 55)
    (py-fill-paragraph)
    (write-file (concat tmp-dir fpp-exec-buffer))
    (setq erg (diff (concat tmp-dir fpp-exec-buffer) (concat tmp-dir diff-buffer) "-u"))
    (if (featurep 'xemacs)
        (progn
          (set-buffer "*Diff Output*")
          (switch-to-buffer (current-buffer)))
      (set-buffer erg)
      (sit-for 1)
      (assert (numberp (progn (goto-char (point-min))(search-forward "no differences" nil t 1))) t))
    ;; another bug reported with the nr 
    (assert (functionp 'py-in-statement-p) nil "py-fill-paragraph should not change this")
    (message "%s" "py-fill-paragraph-problems-710373 passed")))

(defun py-302834-test (&optional arg)
  (interactive "p") 
  (with-temp-buffer
    (insert "class OrderedDict1(dict):
    \"\"\"
    This implementation of a dictionary keeps track of the order
    in which keys were inserted.
    \"\"\"")
    (when arg (switch-to-buffer (current-buffer)))
    (python-mode)
    (font-lock-mode 1)
    (font-lock-fontify-buffer)
    (goto-char 78)
    (let ((erg (face-at-point)))
      (insert "\"")
      (assert (ar-in-triplequoted-dq-p-atpt) nil "In triplequoted string not recognised!")
      (font-lock-fontify-buffer)
      (assert (eq erg (face-at-point)) "Being stuck insside triple-quoted-string. Did not reach beginning of class."))
    (when arg (message "%s" "py-302834-test passed"))))

(defun py-previous-statement-637955-test (&optional arg)
  (interactive "p") 
  (with-temp-buffer
    (insert "class OrderedDict1(dict):
    \"\"\"
    This implementation of a dictionary keeps track of the order
    in which keys were inserted.
    \"\"\"")
    (when arg (switch-to-buffer (current-buffer)))
    (beginning-of-line)
    (py-previous-statement)
    (assert (eq 1 (point)) t "Being stuck insside triple-quoted-string. Did not reach beginning of class.")
    (when arg (message "%s" "py-previous-statement-637955-test passed"))))

(provide 'bug-numbered-tests)
;;; bug-numbered-tests.el ends here
