;;; thing-at-point-utils.el --- more th-at-point edit functions

;; Copyright (C) 2010 Andreas Roehler, unless
;; indicated otherwise

;; Author: Andreas Roehler <andreas.roehler@easy-emacs.de>, unless
;; indicated otherwise

;; Keywords: convenience

;; This file is free software; you can redistribute it
;; and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2, or (at your option) any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Information is given with thingatpt-utils-base.el

(require 'thingatpt-utils-base)

;; ar-thing-at-point-utils-core: ar-atpt-classes start

;;;###autoload
(defun ar-alnum-atpt (&optional arg no-delimiters) 
  "Returns alnum at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'alnum arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-alnum-atpt 'ar-alnum-bounds-atpt)
;;;###autoload
(defun ar-alnum-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of alnum if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'alnum no-delimiters (interactive-p)))

;;;###autoload
(defun ar-alnum-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position alnum at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'alnum no-delimiters (interactive-p)))

;;;###autoload
(defun ar-alnum-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of alnum at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'alnum no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-alnum-atpt 'ar-alnum-beginning-atpt)
;;;###autoload
(defun ar-alnum-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class alnum at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'alnum no-delimiters (interactive-p)))

(defalias 'ar-end-of-alnum-atpt 'ar-alnum-end-atpt)
;;;###autoload
(defun ar-alnum-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class alnum at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'alnum no-delimiters (interactive-p)))

(defalias 'ar-in-alnum-p-atpt 'ar-alnum-in-p-atpt)
;;;###autoload
(defun ar-alnum-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of alnum at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'alnum no-delimiters (interactive-p)))

(defalias 'ar-length-of-alnum-atpt 'ar-alnum-length-atpt)
;;;###autoload
(defun ar-alnum-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class alnum at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'alnum no-delimiters (interactive-p)))

(defalias 'ar-copy-alnum-atpt 'ar-alnum-copy-atpt)
;;;###autoload
(defun ar-alnum-copy-atpt (&optional no-delimiters) 
  "Returns a copy of alnum at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'alnum no-delimiters (interactive-p)))

(defalias 'ar-delete-alnum-in-region 'ar-alnum-delete-in-region)
;;;###autoload
(defun ar-alnum-delete-in-region (beg end) 
  "Deletes alnum at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'alnum beg end (interactive-p)))

;;;###autoload
(defun ar-blok-alnum-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around alnum.
  Returns blok or nil if no alnum at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'alnum no-delimiters (interactive-p)))

(defalias 'ar-escape-alnum-atpt 'ar-alnum-escape-atpt)
;;;###autoload
(defun ar-alnum-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted alnum at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'alnum no-delimiters))

(defalias 'ar-doublequote-alnum-atpt 'ar-alnum-doublequote-atpt)
;;;###autoload
(defun ar-alnum-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'alnum no-delimiters (interactive-p)))

(defalias 'ar-slash-alnum-atpt 'ar-alnum-slash-atpt)
;;;###autoload
(defun ar-alnum-slash-atpt (&optional no-delimiters) 
  "Doublequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-slash 'alnum no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-alnum-atpt 'ar-alnum-double-backslash-atpt)
;;;###autoload
(defun ar-alnum-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around alnum at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'alnum no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-alnum-atpt 'ar-alnum-doubleslash-atpt)
;;;###autoload
(defun ar-alnum-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around alnum at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'alnum no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-alnum-atpt 'ar-alnum-doubleslashparen-atpt)
;;;###autoload
(defun ar-alnum-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around alnum at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'alnum no-delimiters (interactive-p)))

(defalias 'ar-slashparen-alnum-atpt 'ar-alnum-slashparen-atpt)
;;;###autoload
(defun ar-alnum-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around alnum at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'alnum no-delimiters (interactive-p)))

(defalias 'ar-dollar-alnum-atpt 'ar-alnum-dollar-atpt)
;;;###autoload
(defun ar-alnum-dollar-atpt (&optional no-delimiters) 
  "Doublequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-dollar 'alnum no-delimiters (interactive-p)))

(defalias 'ar-equalize-alnum-atpt 'ar-alnum-equalize-atpt)
;;;###autoload
(defun ar-alnum-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around alnum at point if any. "
  (interactive "*p")
  (ar-th-equalize 'alnum no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-alnum-atpt 'ar-alnum-greater-angle-atpt)
;;;###autoload
(defun ar-alnum-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for alnum after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'alnum no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-alnum-atpt 'ar-alnum-lesser-angle-atpt)
;;;###autoload
(defun ar-alnum-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for alnum after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'alnum no-delimiters (interactive-p)))

(defalias 'ar-backslash-alnum-atpt 'ar-alnum-backslash-atpt)
;;;###autoload
(defun ar-alnum-backslash-atpt (&optional no-delimiters) 
  "Backslash alnum at point if any. "
  (interactive "*p")
  (ar-th-backslash 'alnum no-delimiters (interactive-p))) 

(defalias 'ar-brace-alnum-atpt 'ar-alnum-brace-atpt)
;;;###autoload
(defun ar-alnum-brace-atpt (&optional no-delimiters) 
  "Braces alnum at point if any. "
  (interactive "*p")
  (ar-th-brace 'alnum no-delimiters (interactive-p)))

(defalias 'ar-bracket-alnum-atpt 'ar-alnum-bracket-atpt)
;;;###autoload
(defun ar-alnum-bracket-atpt (&optional no-delimiters) 
  "Brackets alnum after point if any. "
  (interactive "*p")
  (ar-th-bracket 'alnum no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-alnum-atpt (&optional no-delimiters) 
  "Comments alnum at point if any. "
  (interactive "*p")
  (ar-th-comment 'alnum no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-alnum-atpt (&optional no-delimiters) 
  "Put a comma after alnum at point if any. "
  (interactive "*p")
  (ar-th-commatize 'alnum no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-alnum-atpt (&optional no-delimiters) 
  "Put a singlequote before alnum at point if any. "
  (interactive "*p")
  (ar-th-quote 'alnum no-delimiters (interactive-p)))

(defalias 'ar-hyphen-alnum-atpt 'ar-alnum-hyphen-atpt)
;;;###autoload
(defun ar-alnum-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around alnum at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'alnum no-delimiters (interactive-p)))

(defalias 'ar-mark-alnum-atpt 'ar-alnum-mark-atpt)
;;;###autoload
(defun ar-alnum-mark-atpt () 
  "Marks alnum at point if any. "
  (interactive)
  (ar-th-mark 'alnum))

(defalias 'ar-hide-alnum-atpt 'ar-alnum-hide-atpt)
;;;###autoload
(defun ar-alnum-hide-atpt () 
  "Hides alnum at point. "
  (interactive)
  (ar-th-hide 'alnum))

(defalias 'ar-show-alnum-atpt 'ar-alnum-show-atpt)
;;;###autoload
(defun ar-alnum-show-atpt () 
  "Shows hidden alnum at point. "
  (interactive)
  (ar-th-show 'alnum))

(defalias 'ar-hide-show-alnum-atpt 'ar-alnum-hide-show-atpt)
;;;###autoload
(defun ar-alnum-hide-show-atpt () 
  "Alternatively hides or shows alnum at point. "
  (interactive)
  (ar-th-hide-show 'alnum))

(defalias 'ar-highlight-alnum-atpt-mode 'ar-alnum-highlight-atpt-mode)

(defun ar-alnum-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles alnum-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'alnum no-delimiters (interactive-p)))

(defalias 'ar-kill-alnum-atpt 'ar-alnum-kill-atpt)
;;;###autoload
(defun ar-alnum-kill-atpt (&optional no-delimiters) 
  "Kills alnum at point if any. "
  (interactive "*P")
  (ar-th-kill 'alnum no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-alnum-atpt 'ar-alnum-left-right-singlequote-atpt)
;;;###autoload
(defun ar-alnum-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'alnum no-delimiters (interactive-p)))

(defalias 'ar-parentize-alnum-atpt 'ar-alnum-parentize-atpt)
;;;###autoload
(defun ar-alnum-parentize-atpt (&optional no-delimiters) 
  "Parentizes alnum at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'alnum no-delimiters (interactive-p)))

(defalias 'ar-separate-alnum-atpt 'ar-alnum-separate-atpt)
;;;###autoload
(defun ar-alnum-separate-atpt (&optional no-delimiters) 
  "Separates alnum at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'alnum no-delimiters (interactive-p)))

(defalias 'ar-singlequote-alnum-atpt 'ar-alnum-singlequote-atpt)
;;;###autoload
(defun ar-alnum-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'alnum no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-alnum-atpt 'ar-alnum-triplequote-dq-atpt)
;;;###autoload
(defun ar-alnum-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around alnum. "
  (interactive "*p")
  (ar-th-triplequote-dq 'alnum no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-alnum-atpt 'ar-alnum-triplequote-sq-atpt)
;;;###autoload
(defun ar-alnum-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around alnum. "
  (interactive "*p")
  (ar-th-triplequote-sq 'alnum no-delimiters (interactive-p)))

(defalias 'ar-trim-alnum-atpt 'ar-alnum-trim-atpt)
;;;###autoload
(defun ar-alnum-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alnum t t)) 
    (ar-th-trim 'alnum t t)))

(defalias 'ar-trim-left-alnum-atpt 'ar-alnum-left-trim-atpt)
;;;###autoload
(defun ar-alnum-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alnum t nil))
    (ar-th-trim 'alnum t nil)))

(defalias 'ar-trim-right-alnum-atpt 'ar-alnum-right-trim-atpt)
;;;###autoload
(defun ar-alnum-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alnum nil t))
    (ar-th-trim 'alnum nil t)))

(defalias 'ar-alnum-underscore-atpt 'ar-underscore-alnum-atpt)
;;;###autoload
(defun ar-underscore-alnum-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'alnum no-delimiters (interactive-p)))

(defalias 'ar-alnum-whitespace-atpt 'ar-whitespace-alnum-atpt)
;;;###autoload
(defun ar-whitespace-alnum-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'alnum nil t))

(defalias 'ar-forward-alnum-atpt 'ar-alnum-forward-atpt)
;;;###autoload
(defun ar-alnum-forward-atpt (&optional arg) 
  "Moves forward over alnum at point if any, does nothing otherwise.
Returns end position of alnum "
  (interactive "p")
  (ar-th-forward 'alnum arg (interactive-p)))

(defalias 'ar-backward-alnum-atpt 'ar-alnum-backward-atpt)
;;;###autoload
(defun ar-alnum-backward-atpt (&optional arg) 
  "Moves backward over alnum before point if any, does nothing otherwise.
Returns beginning position of alnum "
  (interactive "p")
  (ar-th-backward 'alnum arg (interactive-p)))

(defalias 'ar-transpose-alnum-atpt 'ar-alnum-transpose-atpt)
;;;###autoload
(defun ar-alnum-transpose-atpt (&optional arg) 
  "Transposes alnum with alnum before point if any. "
  (interactive "*p")
  (ar-th-transpose 'alnum arg (interactive-p)))

(defalias 'ar-sort-alnum-atpt 'ar-alnum-sort-atpt)
;;;###autoload
(defun ar-alnum-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts alnums in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'alnum reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-alnum-atpt 'ar-alnum-check-atpt)
;;;###autoload
(defun ar-alnum-check-atpt () 
  "Return t if a alnum at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-alnum-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-alnum-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-alpha-atpt (&optional arg no-delimiters) 
  "Returns alpha at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'alpha arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-alpha-atpt 'ar-alpha-bounds-atpt)
;;;###autoload
(defun ar-alpha-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of alpha if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'alpha no-delimiters (interactive-p)))

;;;###autoload
(defun ar-alpha-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position alpha at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'alpha no-delimiters (interactive-p)))

;;;###autoload
(defun ar-alpha-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of alpha at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'alpha no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-alpha-atpt 'ar-alpha-beginning-atpt)
;;;###autoload
(defun ar-alpha-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class alpha at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'alpha no-delimiters (interactive-p)))

(defalias 'ar-end-of-alpha-atpt 'ar-alpha-end-atpt)
;;;###autoload
(defun ar-alpha-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class alpha at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'alpha no-delimiters (interactive-p)))

(defalias 'ar-in-alpha-p-atpt 'ar-alpha-in-p-atpt)
;;;###autoload
(defun ar-alpha-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of alpha at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'alpha no-delimiters (interactive-p)))

(defalias 'ar-length-of-alpha-atpt 'ar-alpha-length-atpt)
;;;###autoload
(defun ar-alpha-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class alpha at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'alpha no-delimiters (interactive-p)))

(defalias 'ar-copy-alpha-atpt 'ar-alpha-copy-atpt)
;;;###autoload
(defun ar-alpha-copy-atpt (&optional no-delimiters) 
  "Returns a copy of alpha at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'alpha no-delimiters (interactive-p)))

(defalias 'ar-delete-alpha-in-region 'ar-alpha-delete-in-region)
;;;###autoload
(defun ar-alpha-delete-in-region (beg end) 
  "Deletes alpha at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'alpha beg end (interactive-p)))

;;;###autoload
(defun ar-blok-alpha-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around alpha.
  Returns blok or nil if no alpha at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'alpha no-delimiters (interactive-p)))

(defalias 'ar-escape-alpha-atpt 'ar-alpha-escape-atpt)
;;;###autoload
(defun ar-alpha-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted alpha at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'alpha no-delimiters))

(defalias 'ar-doublequote-alpha-atpt 'ar-alpha-doublequote-atpt)
;;;###autoload
(defun ar-alpha-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes alpha at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'alpha no-delimiters (interactive-p)))

(defalias 'ar-slash-alpha-atpt 'ar-alpha-slash-atpt)
;;;###autoload
(defun ar-alpha-slash-atpt (&optional no-delimiters) 
  "Doublequotes alpha at point if any. "
  (interactive "*p")
  (ar-th-slash 'alpha no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-alpha-atpt 'ar-alpha-double-backslash-atpt)
;;;###autoload
(defun ar-alpha-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around alpha at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'alpha no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-alpha-atpt 'ar-alpha-doubleslash-atpt)
;;;###autoload
(defun ar-alpha-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around alpha at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'alpha no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-alpha-atpt 'ar-alpha-doubleslashparen-atpt)
;;;###autoload
(defun ar-alpha-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around alpha at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'alpha no-delimiters (interactive-p)))

(defalias 'ar-slashparen-alpha-atpt 'ar-alpha-slashparen-atpt)
;;;###autoload
(defun ar-alpha-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around alpha at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'alpha no-delimiters (interactive-p)))

(defalias 'ar-dollar-alpha-atpt 'ar-alpha-dollar-atpt)
;;;###autoload
(defun ar-alpha-dollar-atpt (&optional no-delimiters) 
  "Doublequotes alpha at point if any. "
  (interactive "*p")
  (ar-th-dollar 'alpha no-delimiters (interactive-p)))

(defalias 'ar-equalize-alpha-atpt 'ar-alpha-equalize-atpt)
;;;###autoload
(defun ar-alpha-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around alpha at point if any. "
  (interactive "*p")
  (ar-th-equalize 'alpha no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-alpha-atpt 'ar-alpha-greater-angle-atpt)
;;;###autoload
(defun ar-alpha-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for alpha after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'alpha no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-alpha-atpt 'ar-alpha-lesser-angle-atpt)
;;;###autoload
(defun ar-alpha-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for alpha after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'alpha no-delimiters (interactive-p)))

(defalias 'ar-backslash-alpha-atpt 'ar-alpha-backslash-atpt)
;;;###autoload
(defun ar-alpha-backslash-atpt (&optional no-delimiters) 
  "Backslash alpha at point if any. "
  (interactive "*p")
  (ar-th-backslash 'alpha no-delimiters (interactive-p))) 

(defalias 'ar-brace-alpha-atpt 'ar-alpha-brace-atpt)
;;;###autoload
(defun ar-alpha-brace-atpt (&optional no-delimiters) 
  "Braces alpha at point if any. "
  (interactive "*p")
  (ar-th-brace 'alpha no-delimiters (interactive-p)))

(defalias 'ar-bracket-alpha-atpt 'ar-alpha-bracket-atpt)
;;;###autoload
(defun ar-alpha-bracket-atpt (&optional no-delimiters) 
  "Brackets alpha after point if any. "
  (interactive "*p")
  (ar-th-bracket 'alpha no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-alpha-atpt (&optional no-delimiters) 
  "Comments alpha at point if any. "
  (interactive "*p")
  (ar-th-comment 'alpha no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-alpha-atpt (&optional no-delimiters) 
  "Put a comma after alpha at point if any. "
  (interactive "*p")
  (ar-th-commatize 'alpha no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-alpha-atpt (&optional no-delimiters) 
  "Put a singlequote before alpha at point if any. "
  (interactive "*p")
  (ar-th-quote 'alpha no-delimiters (interactive-p)))

(defalias 'ar-hyphen-alpha-atpt 'ar-alpha-hyphen-atpt)
;;;###autoload
(defun ar-alpha-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around alpha at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'alpha no-delimiters (interactive-p)))

(defalias 'ar-mark-alpha-atpt 'ar-alpha-mark-atpt)
;;;###autoload
(defun ar-alpha-mark-atpt () 
  "Marks alpha at point if any. "
  (interactive)
  (ar-th-mark 'alpha))

(defalias 'ar-hide-alpha-atpt 'ar-alpha-hide-atpt)
;;;###autoload
(defun ar-alpha-hide-atpt () 
  "Hides alpha at point. "
  (interactive)
  (ar-th-hide 'alpha))

(defalias 'ar-show-alpha-atpt 'ar-alpha-show-atpt)
;;;###autoload
(defun ar-alpha-show-atpt () 
  "Shows hidden alpha at point. "
  (interactive)
  (ar-th-show 'alpha))

(defalias 'ar-hide-show-alpha-atpt 'ar-alpha-hide-show-atpt)
;;;###autoload
(defun ar-alpha-hide-show-atpt () 
  "Alternatively hides or shows alpha at point. "
  (interactive)
  (ar-th-hide-show 'alpha))

(defalias 'ar-highlight-alpha-atpt-mode 'ar-alpha-highlight-atpt-mode)

(defun ar-alpha-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles alpha-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'alpha no-delimiters (interactive-p)))

(defalias 'ar-kill-alpha-atpt 'ar-alpha-kill-atpt)
;;;###autoload
(defun ar-alpha-kill-atpt (&optional no-delimiters) 
  "Kills alpha at point if any. "
  (interactive "*P")
  (ar-th-kill 'alpha no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-alpha-atpt 'ar-alpha-left-right-singlequote-atpt)
;;;###autoload
(defun ar-alpha-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'alpha no-delimiters (interactive-p)))

(defalias 'ar-parentize-alpha-atpt 'ar-alpha-parentize-atpt)
;;;###autoload
(defun ar-alpha-parentize-atpt (&optional no-delimiters) 
  "Parentizes alpha at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'alpha no-delimiters (interactive-p)))

(defalias 'ar-separate-alpha-atpt 'ar-alpha-separate-atpt)
;;;###autoload
(defun ar-alpha-separate-atpt (&optional no-delimiters) 
  "Separates alpha at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'alpha no-delimiters (interactive-p)))

(defalias 'ar-singlequote-alpha-atpt 'ar-alpha-singlequote-atpt)
;;;###autoload
(defun ar-alpha-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alpha at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'alpha no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-alpha-atpt 'ar-alpha-triplequote-dq-atpt)
;;;###autoload
(defun ar-alpha-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around alpha. "
  (interactive "*p")
  (ar-th-triplequote-dq 'alpha no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-alpha-atpt 'ar-alpha-triplequote-sq-atpt)
;;;###autoload
(defun ar-alpha-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around alpha. "
  (interactive "*p")
  (ar-th-triplequote-sq 'alpha no-delimiters (interactive-p)))

(defalias 'ar-trim-alpha-atpt 'ar-alpha-trim-atpt)
;;;###autoload
(defun ar-alpha-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alpha t t)) 
    (ar-th-trim 'alpha t t)))

(defalias 'ar-trim-left-alpha-atpt 'ar-alpha-left-trim-atpt)
;;;###autoload
(defun ar-alpha-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alpha t nil))
    (ar-th-trim 'alpha t nil)))

(defalias 'ar-trim-right-alpha-atpt 'ar-alpha-right-trim-atpt)
;;;###autoload
(defun ar-alpha-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'alpha nil t))
    (ar-th-trim 'alpha nil t)))

(defalias 'ar-alpha-underscore-atpt 'ar-underscore-alpha-atpt)
;;;###autoload
(defun ar-underscore-alpha-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'alpha no-delimiters (interactive-p)))

(defalias 'ar-alpha-whitespace-atpt 'ar-whitespace-alpha-atpt)
;;;###autoload
(defun ar-whitespace-alpha-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'alpha nil t))

(defalias 'ar-forward-alpha-atpt 'ar-alpha-forward-atpt)
;;;###autoload
(defun ar-alpha-forward-atpt (&optional arg) 
  "Moves forward over alpha at point if any, does nothing otherwise.
Returns end position of alpha "
  (interactive "p")
  (ar-th-forward 'alpha arg (interactive-p)))

(defalias 'ar-backward-alpha-atpt 'ar-alpha-backward-atpt)
;;;###autoload
(defun ar-alpha-backward-atpt (&optional arg) 
  "Moves backward over alpha before point if any, does nothing otherwise.
Returns beginning position of alpha "
  (interactive "p")
  (ar-th-backward 'alpha arg (interactive-p)))

(defalias 'ar-transpose-alpha-atpt 'ar-alpha-transpose-atpt)
;;;###autoload
(defun ar-alpha-transpose-atpt (&optional arg) 
  "Transposes alpha with alpha before point if any. "
  (interactive "*p")
  (ar-th-transpose 'alpha arg (interactive-p)))

(defalias 'ar-sort-alpha-atpt 'ar-alpha-sort-atpt)
;;;###autoload
(defun ar-alpha-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts alphas in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'alpha reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-alpha-atpt 'ar-alpha-check-atpt)
;;;###autoload
(defun ar-alpha-check-atpt () 
  "Return t if a alpha at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-alpha-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-alpha-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-ascii-atpt (&optional arg no-delimiters) 
  "Returns ascii at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'ascii arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-ascii-atpt 'ar-ascii-bounds-atpt)
;;;###autoload
(defun ar-ascii-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of ascii if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'ascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-ascii-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position ascii at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'ascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-ascii-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of ascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'ascii no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-ascii-atpt 'ar-ascii-beginning-atpt)
;;;###autoload
(defun ar-ascii-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class ascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'ascii no-delimiters (interactive-p)))

(defalias 'ar-end-of-ascii-atpt 'ar-ascii-end-atpt)
;;;###autoload
(defun ar-ascii-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class ascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'ascii no-delimiters (interactive-p)))

(defalias 'ar-in-ascii-p-atpt 'ar-ascii-in-p-atpt)
;;;###autoload
(defun ar-ascii-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of ascii at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'ascii no-delimiters (interactive-p)))

(defalias 'ar-length-of-ascii-atpt 'ar-ascii-length-atpt)
;;;###autoload
(defun ar-ascii-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class ascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'ascii no-delimiters (interactive-p)))

(defalias 'ar-copy-ascii-atpt 'ar-ascii-copy-atpt)
;;;###autoload
(defun ar-ascii-copy-atpt (&optional no-delimiters) 
  "Returns a copy of ascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'ascii no-delimiters (interactive-p)))

(defalias 'ar-delete-ascii-in-region 'ar-ascii-delete-in-region)
;;;###autoload
(defun ar-ascii-delete-in-region (beg end) 
  "Deletes ascii at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'ascii beg end (interactive-p)))

;;;###autoload
(defun ar-blok-ascii-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around ascii.
  Returns blok or nil if no ascii at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'ascii no-delimiters (interactive-p)))

(defalias 'ar-escape-ascii-atpt 'ar-ascii-escape-atpt)
;;;###autoload
(defun ar-ascii-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted ascii at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'ascii no-delimiters))

(defalias 'ar-doublequote-ascii-atpt 'ar-ascii-doublequote-atpt)
;;;###autoload
(defun ar-ascii-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes ascii at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'ascii no-delimiters (interactive-p)))

(defalias 'ar-slash-ascii-atpt 'ar-ascii-slash-atpt)
;;;###autoload
(defun ar-ascii-slash-atpt (&optional no-delimiters) 
  "Doublequotes ascii at point if any. "
  (interactive "*p")
  (ar-th-slash 'ascii no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-ascii-atpt 'ar-ascii-double-backslash-atpt)
;;;###autoload
(defun ar-ascii-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around ascii at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'ascii no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-ascii-atpt 'ar-ascii-doubleslash-atpt)
;;;###autoload
(defun ar-ascii-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around ascii at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'ascii no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-ascii-atpt 'ar-ascii-doubleslashparen-atpt)
;;;###autoload
(defun ar-ascii-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around ascii at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'ascii no-delimiters (interactive-p)))

(defalias 'ar-slashparen-ascii-atpt 'ar-ascii-slashparen-atpt)
;;;###autoload
(defun ar-ascii-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around ascii at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'ascii no-delimiters (interactive-p)))

(defalias 'ar-dollar-ascii-atpt 'ar-ascii-dollar-atpt)
;;;###autoload
(defun ar-ascii-dollar-atpt (&optional no-delimiters) 
  "Doublequotes ascii at point if any. "
  (interactive "*p")
  (ar-th-dollar 'ascii no-delimiters (interactive-p)))

(defalias 'ar-equalize-ascii-atpt 'ar-ascii-equalize-atpt)
;;;###autoload
(defun ar-ascii-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around ascii at point if any. "
  (interactive "*p")
  (ar-th-equalize 'ascii no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-ascii-atpt 'ar-ascii-greater-angle-atpt)
;;;###autoload
(defun ar-ascii-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for ascii after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'ascii no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-ascii-atpt 'ar-ascii-lesser-angle-atpt)
;;;###autoload
(defun ar-ascii-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for ascii after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'ascii no-delimiters (interactive-p)))

(defalias 'ar-backslash-ascii-atpt 'ar-ascii-backslash-atpt)
;;;###autoload
(defun ar-ascii-backslash-atpt (&optional no-delimiters) 
  "Backslash ascii at point if any. "
  (interactive "*p")
  (ar-th-backslash 'ascii no-delimiters (interactive-p))) 

(defalias 'ar-brace-ascii-atpt 'ar-ascii-brace-atpt)
;;;###autoload
(defun ar-ascii-brace-atpt (&optional no-delimiters) 
  "Braces ascii at point if any. "
  (interactive "*p")
  (ar-th-brace 'ascii no-delimiters (interactive-p)))

(defalias 'ar-bracket-ascii-atpt 'ar-ascii-bracket-atpt)
;;;###autoload
(defun ar-ascii-bracket-atpt (&optional no-delimiters) 
  "Brackets ascii after point if any. "
  (interactive "*p")
  (ar-th-bracket 'ascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-ascii-atpt (&optional no-delimiters) 
  "Comments ascii at point if any. "
  (interactive "*p")
  (ar-th-comment 'ascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-ascii-atpt (&optional no-delimiters) 
  "Put a comma after ascii at point if any. "
  (interactive "*p")
  (ar-th-commatize 'ascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-ascii-atpt (&optional no-delimiters) 
  "Put a singlequote before ascii at point if any. "
  (interactive "*p")
  (ar-th-quote 'ascii no-delimiters (interactive-p)))

(defalias 'ar-hyphen-ascii-atpt 'ar-ascii-hyphen-atpt)
;;;###autoload
(defun ar-ascii-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around ascii at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'ascii no-delimiters (interactive-p)))

(defalias 'ar-mark-ascii-atpt 'ar-ascii-mark-atpt)
;;;###autoload
(defun ar-ascii-mark-atpt () 
  "Marks ascii at point if any. "
  (interactive)
  (ar-th-mark 'ascii))

(defalias 'ar-hide-ascii-atpt 'ar-ascii-hide-atpt)
;;;###autoload
(defun ar-ascii-hide-atpt () 
  "Hides ascii at point. "
  (interactive)
  (ar-th-hide 'ascii))

(defalias 'ar-show-ascii-atpt 'ar-ascii-show-atpt)
;;;###autoload
(defun ar-ascii-show-atpt () 
  "Shows hidden ascii at point. "
  (interactive)
  (ar-th-show 'ascii))

(defalias 'ar-hide-show-ascii-atpt 'ar-ascii-hide-show-atpt)
;;;###autoload
(defun ar-ascii-hide-show-atpt () 
  "Alternatively hides or shows ascii at point. "
  (interactive)
  (ar-th-hide-show 'ascii))

(defalias 'ar-highlight-ascii-atpt-mode 'ar-ascii-highlight-atpt-mode)

(defun ar-ascii-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles ascii-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'ascii no-delimiters (interactive-p)))

(defalias 'ar-kill-ascii-atpt 'ar-ascii-kill-atpt)
;;;###autoload
(defun ar-ascii-kill-atpt (&optional no-delimiters) 
  "Kills ascii at point if any. "
  (interactive "*P")
  (ar-th-kill 'ascii no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-ascii-atpt 'ar-ascii-left-right-singlequote-atpt)
;;;###autoload
(defun ar-ascii-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'ascii no-delimiters (interactive-p)))

(defalias 'ar-parentize-ascii-atpt 'ar-ascii-parentize-atpt)
;;;###autoload
(defun ar-ascii-parentize-atpt (&optional no-delimiters) 
  "Parentizes ascii at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'ascii no-delimiters (interactive-p)))

(defalias 'ar-separate-ascii-atpt 'ar-ascii-separate-atpt)
;;;###autoload
(defun ar-ascii-separate-atpt (&optional no-delimiters) 
  "Separates ascii at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'ascii no-delimiters (interactive-p)))

(defalias 'ar-singlequote-ascii-atpt 'ar-ascii-singlequote-atpt)
;;;###autoload
(defun ar-ascii-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes ascii at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'ascii no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-ascii-atpt 'ar-ascii-triplequote-dq-atpt)
;;;###autoload
(defun ar-ascii-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around ascii. "
  (interactive "*p")
  (ar-th-triplequote-dq 'ascii no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-ascii-atpt 'ar-ascii-triplequote-sq-atpt)
;;;###autoload
(defun ar-ascii-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around ascii. "
  (interactive "*p")
  (ar-th-triplequote-sq 'ascii no-delimiters (interactive-p)))

(defalias 'ar-trim-ascii-atpt 'ar-ascii-trim-atpt)
;;;###autoload
(defun ar-ascii-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ascii t t)) 
    (ar-th-trim 'ascii t t)))

(defalias 'ar-trim-left-ascii-atpt 'ar-ascii-left-trim-atpt)
;;;###autoload
(defun ar-ascii-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ascii t nil))
    (ar-th-trim 'ascii t nil)))

(defalias 'ar-trim-right-ascii-atpt 'ar-ascii-right-trim-atpt)
;;;###autoload
(defun ar-ascii-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ascii nil t))
    (ar-th-trim 'ascii nil t)))

(defalias 'ar-ascii-underscore-atpt 'ar-underscore-ascii-atpt)
;;;###autoload
(defun ar-underscore-ascii-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'ascii no-delimiters (interactive-p)))

(defalias 'ar-ascii-whitespace-atpt 'ar-whitespace-ascii-atpt)
;;;###autoload
(defun ar-whitespace-ascii-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'ascii nil t))

(defalias 'ar-forward-ascii-atpt 'ar-ascii-forward-atpt)
;;;###autoload
(defun ar-ascii-forward-atpt (&optional arg) 
  "Moves forward over ascii at point if any, does nothing otherwise.
Returns end position of ascii "
  (interactive "p")
  (ar-th-forward 'ascii arg (interactive-p)))

(defalias 'ar-backward-ascii-atpt 'ar-ascii-backward-atpt)
;;;###autoload
(defun ar-ascii-backward-atpt (&optional arg) 
  "Moves backward over ascii before point if any, does nothing otherwise.
Returns beginning position of ascii "
  (interactive "p")
  (ar-th-backward 'ascii arg (interactive-p)))

(defalias 'ar-transpose-ascii-atpt 'ar-ascii-transpose-atpt)
;;;###autoload
(defun ar-ascii-transpose-atpt (&optional arg) 
  "Transposes ascii with ascii before point if any. "
  (interactive "*p")
  (ar-th-transpose 'ascii arg (interactive-p)))

(defalias 'ar-sort-ascii-atpt 'ar-ascii-sort-atpt)
;;;###autoload
(defun ar-ascii-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts asciis in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'ascii reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-ascii-atpt 'ar-ascii-check-atpt)
;;;###autoload
(defun ar-ascii-check-atpt () 
  "Return t if a ascii at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-ascii-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-ascii-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-blank-atpt (&optional arg no-delimiters) 
  "Returns blank at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'blank arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-blank-atpt 'ar-blank-bounds-atpt)
;;;###autoload
(defun ar-blank-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of blank if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'blank no-delimiters (interactive-p)))

;;;###autoload
(defun ar-blank-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position blank at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'blank no-delimiters (interactive-p)))

;;;###autoload
(defun ar-blank-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of blank at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'blank no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-blank-atpt 'ar-blank-beginning-atpt)
;;;###autoload
(defun ar-blank-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class blank at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'blank no-delimiters (interactive-p)))

(defalias 'ar-end-of-blank-atpt 'ar-blank-end-atpt)
;;;###autoload
(defun ar-blank-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class blank at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'blank no-delimiters (interactive-p)))

(defalias 'ar-in-blank-p-atpt 'ar-blank-in-p-atpt)
;;;###autoload
(defun ar-blank-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of blank at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'blank no-delimiters (interactive-p)))

(defalias 'ar-length-of-blank-atpt 'ar-blank-length-atpt)
;;;###autoload
(defun ar-blank-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class blank at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'blank no-delimiters (interactive-p)))

(defalias 'ar-copy-blank-atpt 'ar-blank-copy-atpt)
;;;###autoload
(defun ar-blank-copy-atpt (&optional no-delimiters) 
  "Returns a copy of blank at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'blank no-delimiters (interactive-p)))

(defalias 'ar-delete-blank-in-region 'ar-blank-delete-in-region)
;;;###autoload
(defun ar-blank-delete-in-region (beg end) 
  "Deletes blank at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'blank beg end (interactive-p)))

;;;###autoload
(defun ar-blok-blank-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around blank.
  Returns blok or nil if no blank at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'blank no-delimiters (interactive-p)))

(defalias 'ar-escape-blank-atpt 'ar-blank-escape-atpt)
;;;###autoload
(defun ar-blank-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted blank at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'blank no-delimiters))

(defalias 'ar-doublequote-blank-atpt 'ar-blank-doublequote-atpt)
;;;###autoload
(defun ar-blank-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes blank at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'blank no-delimiters (interactive-p)))

(defalias 'ar-slash-blank-atpt 'ar-blank-slash-atpt)
;;;###autoload
(defun ar-blank-slash-atpt (&optional no-delimiters) 
  "Doublequotes blank at point if any. "
  (interactive "*p")
  (ar-th-slash 'blank no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-blank-atpt 'ar-blank-double-backslash-atpt)
;;;###autoload
(defun ar-blank-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around blank at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'blank no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-blank-atpt 'ar-blank-doubleslash-atpt)
;;;###autoload
(defun ar-blank-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around blank at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'blank no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-blank-atpt 'ar-blank-doubleslashparen-atpt)
;;;###autoload
(defun ar-blank-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around blank at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'blank no-delimiters (interactive-p)))

(defalias 'ar-slashparen-blank-atpt 'ar-blank-slashparen-atpt)
;;;###autoload
(defun ar-blank-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around blank at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'blank no-delimiters (interactive-p)))

(defalias 'ar-dollar-blank-atpt 'ar-blank-dollar-atpt)
;;;###autoload
(defun ar-blank-dollar-atpt (&optional no-delimiters) 
  "Doublequotes blank at point if any. "
  (interactive "*p")
  (ar-th-dollar 'blank no-delimiters (interactive-p)))

(defalias 'ar-equalize-blank-atpt 'ar-blank-equalize-atpt)
;;;###autoload
(defun ar-blank-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around blank at point if any. "
  (interactive "*p")
  (ar-th-equalize 'blank no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-blank-atpt 'ar-blank-greater-angle-atpt)
;;;###autoload
(defun ar-blank-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for blank after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'blank no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-blank-atpt 'ar-blank-lesser-angle-atpt)
;;;###autoload
(defun ar-blank-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for blank after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'blank no-delimiters (interactive-p)))

(defalias 'ar-backslash-blank-atpt 'ar-blank-backslash-atpt)
;;;###autoload
(defun ar-blank-backslash-atpt (&optional no-delimiters) 
  "Backslash blank at point if any. "
  (interactive "*p")
  (ar-th-backslash 'blank no-delimiters (interactive-p))) 

(defalias 'ar-brace-blank-atpt 'ar-blank-brace-atpt)
;;;###autoload
(defun ar-blank-brace-atpt (&optional no-delimiters) 
  "Braces blank at point if any. "
  (interactive "*p")
  (ar-th-brace 'blank no-delimiters (interactive-p)))

(defalias 'ar-bracket-blank-atpt 'ar-blank-bracket-atpt)
;;;###autoload
(defun ar-blank-bracket-atpt (&optional no-delimiters) 
  "Brackets blank after point if any. "
  (interactive "*p")
  (ar-th-bracket 'blank no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-blank-atpt (&optional no-delimiters) 
  "Comments blank at point if any. "
  (interactive "*p")
  (ar-th-comment 'blank no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-blank-atpt (&optional no-delimiters) 
  "Put a comma after blank at point if any. "
  (interactive "*p")
  (ar-th-commatize 'blank no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-blank-atpt (&optional no-delimiters) 
  "Put a singlequote before blank at point if any. "
  (interactive "*p")
  (ar-th-quote 'blank no-delimiters (interactive-p)))

(defalias 'ar-hyphen-blank-atpt 'ar-blank-hyphen-atpt)
;;;###autoload
(defun ar-blank-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around blank at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'blank no-delimiters (interactive-p)))

(defalias 'ar-mark-blank-atpt 'ar-blank-mark-atpt)
;;;###autoload
(defun ar-blank-mark-atpt () 
  "Marks blank at point if any. "
  (interactive)
  (ar-th-mark 'blank))

(defalias 'ar-hide-blank-atpt 'ar-blank-hide-atpt)
;;;###autoload
(defun ar-blank-hide-atpt () 
  "Hides blank at point. "
  (interactive)
  (ar-th-hide 'blank))

(defalias 'ar-show-blank-atpt 'ar-blank-show-atpt)
;;;###autoload
(defun ar-blank-show-atpt () 
  "Shows hidden blank at point. "
  (interactive)
  (ar-th-show 'blank))

(defalias 'ar-hide-show-blank-atpt 'ar-blank-hide-show-atpt)
;;;###autoload
(defun ar-blank-hide-show-atpt () 
  "Alternatively hides or shows blank at point. "
  (interactive)
  (ar-th-hide-show 'blank))

(defalias 'ar-highlight-blank-atpt-mode 'ar-blank-highlight-atpt-mode)

(defun ar-blank-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles blank-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'blank no-delimiters (interactive-p)))

(defalias 'ar-kill-blank-atpt 'ar-blank-kill-atpt)
;;;###autoload
(defun ar-blank-kill-atpt (&optional no-delimiters) 
  "Kills blank at point if any. "
  (interactive "*P")
  (ar-th-kill 'blank no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-blank-atpt 'ar-blank-left-right-singlequote-atpt)
;;;###autoload
(defun ar-blank-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'blank no-delimiters (interactive-p)))

(defalias 'ar-parentize-blank-atpt 'ar-blank-parentize-atpt)
;;;###autoload
(defun ar-blank-parentize-atpt (&optional no-delimiters) 
  "Parentizes blank at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'blank no-delimiters (interactive-p)))

(defalias 'ar-separate-blank-atpt 'ar-blank-separate-atpt)
;;;###autoload
(defun ar-blank-separate-atpt (&optional no-delimiters) 
  "Separates blank at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'blank no-delimiters (interactive-p)))

(defalias 'ar-singlequote-blank-atpt 'ar-blank-singlequote-atpt)
;;;###autoload
(defun ar-blank-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes blank at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'blank no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-blank-atpt 'ar-blank-triplequote-dq-atpt)
;;;###autoload
(defun ar-blank-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around blank. "
  (interactive "*p")
  (ar-th-triplequote-dq 'blank no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-blank-atpt 'ar-blank-triplequote-sq-atpt)
;;;###autoload
(defun ar-blank-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around blank. "
  (interactive "*p")
  (ar-th-triplequote-sq 'blank no-delimiters (interactive-p)))

(defalias 'ar-trim-blank-atpt 'ar-blank-trim-atpt)
;;;###autoload
(defun ar-blank-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'blank t t)) 
    (ar-th-trim 'blank t t)))

(defalias 'ar-trim-left-blank-atpt 'ar-blank-left-trim-atpt)
;;;###autoload
(defun ar-blank-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'blank t nil))
    (ar-th-trim 'blank t nil)))

(defalias 'ar-trim-right-blank-atpt 'ar-blank-right-trim-atpt)
;;;###autoload
(defun ar-blank-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'blank nil t))
    (ar-th-trim 'blank nil t)))

(defalias 'ar-blank-underscore-atpt 'ar-underscore-blank-atpt)
;;;###autoload
(defun ar-underscore-blank-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'blank no-delimiters (interactive-p)))

(defalias 'ar-blank-whitespace-atpt 'ar-whitespace-blank-atpt)
;;;###autoload
(defun ar-whitespace-blank-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'blank nil t))

(defalias 'ar-forward-blank-atpt 'ar-blank-forward-atpt)
;;;###autoload
(defun ar-blank-forward-atpt (&optional arg) 
  "Moves forward over blank at point if any, does nothing otherwise.
Returns end position of blank "
  (interactive "p")
  (ar-th-forward 'blank arg (interactive-p)))

(defalias 'ar-backward-blank-atpt 'ar-blank-backward-atpt)
;;;###autoload
(defun ar-blank-backward-atpt (&optional arg) 
  "Moves backward over blank before point if any, does nothing otherwise.
Returns beginning position of blank "
  (interactive "p")
  (ar-th-backward 'blank arg (interactive-p)))

(defalias 'ar-transpose-blank-atpt 'ar-blank-transpose-atpt)
;;;###autoload
(defun ar-blank-transpose-atpt (&optional arg) 
  "Transposes blank with blank before point if any. "
  (interactive "*p")
  (ar-th-transpose 'blank arg (interactive-p)))

(defalias 'ar-sort-blank-atpt 'ar-blank-sort-atpt)
;;;###autoload
(defun ar-blank-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts blanks in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'blank reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-blank-atpt 'ar-blank-check-atpt)
;;;###autoload
(defun ar-blank-check-atpt () 
  "Return t if a blank at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-blank-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-blank-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-cntrl-atpt (&optional arg no-delimiters) 
  "Returns cntrl at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'cntrl arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-cntrl-atpt 'ar-cntrl-bounds-atpt)
;;;###autoload
(defun ar-cntrl-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of cntrl if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'cntrl no-delimiters (interactive-p)))

;;;###autoload
(defun ar-cntrl-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position cntrl at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'cntrl no-delimiters (interactive-p)))

;;;###autoload
(defun ar-cntrl-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of cntrl at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-cntrl-atpt 'ar-cntrl-beginning-atpt)
;;;###autoload
(defun ar-cntrl-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class cntrl at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-end-of-cntrl-atpt 'ar-cntrl-end-atpt)
;;;###autoload
(defun ar-cntrl-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class cntrl at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-in-cntrl-p-atpt 'ar-cntrl-in-p-atpt)
;;;###autoload
(defun ar-cntrl-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of cntrl at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-length-of-cntrl-atpt 'ar-cntrl-length-atpt)
;;;###autoload
(defun ar-cntrl-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class cntrl at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-copy-cntrl-atpt 'ar-cntrl-copy-atpt)
;;;###autoload
(defun ar-cntrl-copy-atpt (&optional no-delimiters) 
  "Returns a copy of cntrl at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-delete-cntrl-in-region 'ar-cntrl-delete-in-region)
;;;###autoload
(defun ar-cntrl-delete-in-region (beg end) 
  "Deletes cntrl at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'cntrl beg end (interactive-p)))

;;;###autoload
(defun ar-blok-cntrl-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around cntrl.
  Returns blok or nil if no cntrl at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-escape-cntrl-atpt 'ar-cntrl-escape-atpt)
;;;###autoload
(defun ar-cntrl-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted cntrl at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'cntrl no-delimiters))

(defalias 'ar-doublequote-cntrl-atpt 'ar-cntrl-doublequote-atpt)
;;;###autoload
(defun ar-cntrl-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes cntrl at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-slash-cntrl-atpt 'ar-cntrl-slash-atpt)
;;;###autoload
(defun ar-cntrl-slash-atpt (&optional no-delimiters) 
  "Doublequotes cntrl at point if any. "
  (interactive "*p")
  (ar-th-slash 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-cntrl-atpt 'ar-cntrl-double-backslash-atpt)
;;;###autoload
(defun ar-cntrl-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around cntrl at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-cntrl-atpt 'ar-cntrl-doubleslash-atpt)
;;;###autoload
(defun ar-cntrl-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around cntrl at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-cntrl-atpt 'ar-cntrl-doubleslashparen-atpt)
;;;###autoload
(defun ar-cntrl-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around cntrl at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-slashparen-cntrl-atpt 'ar-cntrl-slashparen-atpt)
;;;###autoload
(defun ar-cntrl-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around cntrl at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-dollar-cntrl-atpt 'ar-cntrl-dollar-atpt)
;;;###autoload
(defun ar-cntrl-dollar-atpt (&optional no-delimiters) 
  "Doublequotes cntrl at point if any. "
  (interactive "*p")
  (ar-th-dollar 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-equalize-cntrl-atpt 'ar-cntrl-equalize-atpt)
;;;###autoload
(defun ar-cntrl-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around cntrl at point if any. "
  (interactive "*p")
  (ar-th-equalize 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-cntrl-atpt 'ar-cntrl-greater-angle-atpt)
;;;###autoload
(defun ar-cntrl-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for cntrl after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-cntrl-atpt 'ar-cntrl-lesser-angle-atpt)
;;;###autoload
(defun ar-cntrl-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for cntrl after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-backslash-cntrl-atpt 'ar-cntrl-backslash-atpt)
;;;###autoload
(defun ar-cntrl-backslash-atpt (&optional no-delimiters) 
  "Backslash cntrl at point if any. "
  (interactive "*p")
  (ar-th-backslash 'cntrl no-delimiters (interactive-p))) 

(defalias 'ar-brace-cntrl-atpt 'ar-cntrl-brace-atpt)
;;;###autoload
(defun ar-cntrl-brace-atpt (&optional no-delimiters) 
  "Braces cntrl at point if any. "
  (interactive "*p")
  (ar-th-brace 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-bracket-cntrl-atpt 'ar-cntrl-bracket-atpt)
;;;###autoload
(defun ar-cntrl-bracket-atpt (&optional no-delimiters) 
  "Brackets cntrl after point if any. "
  (interactive "*p")
  (ar-th-bracket 'cntrl no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-cntrl-atpt (&optional no-delimiters) 
  "Comments cntrl at point if any. "
  (interactive "*p")
  (ar-th-comment 'cntrl no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-cntrl-atpt (&optional no-delimiters) 
  "Put a comma after cntrl at point if any. "
  (interactive "*p")
  (ar-th-commatize 'cntrl no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-cntrl-atpt (&optional no-delimiters) 
  "Put a singlequote before cntrl at point if any. "
  (interactive "*p")
  (ar-th-quote 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-hyphen-cntrl-atpt 'ar-cntrl-hyphen-atpt)
;;;###autoload
(defun ar-cntrl-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around cntrl at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-mark-cntrl-atpt 'ar-cntrl-mark-atpt)
;;;###autoload
(defun ar-cntrl-mark-atpt () 
  "Marks cntrl at point if any. "
  (interactive)
  (ar-th-mark 'cntrl))

(defalias 'ar-hide-cntrl-atpt 'ar-cntrl-hide-atpt)
;;;###autoload
(defun ar-cntrl-hide-atpt () 
  "Hides cntrl at point. "
  (interactive)
  (ar-th-hide 'cntrl))

(defalias 'ar-show-cntrl-atpt 'ar-cntrl-show-atpt)
;;;###autoload
(defun ar-cntrl-show-atpt () 
  "Shows hidden cntrl at point. "
  (interactive)
  (ar-th-show 'cntrl))

(defalias 'ar-hide-show-cntrl-atpt 'ar-cntrl-hide-show-atpt)
;;;###autoload
(defun ar-cntrl-hide-show-atpt () 
  "Alternatively hides or shows cntrl at point. "
  (interactive)
  (ar-th-hide-show 'cntrl))

(defalias 'ar-highlight-cntrl-atpt-mode 'ar-cntrl-highlight-atpt-mode)

(defun ar-cntrl-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles cntrl-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-kill-cntrl-atpt 'ar-cntrl-kill-atpt)
;;;###autoload
(defun ar-cntrl-kill-atpt (&optional no-delimiters) 
  "Kills cntrl at point if any. "
  (interactive "*P")
  (ar-th-kill 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-cntrl-atpt 'ar-cntrl-left-right-singlequote-atpt)
;;;###autoload
(defun ar-cntrl-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-parentize-cntrl-atpt 'ar-cntrl-parentize-atpt)
;;;###autoload
(defun ar-cntrl-parentize-atpt (&optional no-delimiters) 
  "Parentizes cntrl at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-separate-cntrl-atpt 'ar-cntrl-separate-atpt)
;;;###autoload
(defun ar-cntrl-separate-atpt (&optional no-delimiters) 
  "Separates cntrl at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-singlequote-cntrl-atpt 'ar-cntrl-singlequote-atpt)
;;;###autoload
(defun ar-cntrl-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes cntrl at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-cntrl-atpt 'ar-cntrl-triplequote-dq-atpt)
;;;###autoload
(defun ar-cntrl-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around cntrl. "
  (interactive "*p")
  (ar-th-triplequote-dq 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-cntrl-atpt 'ar-cntrl-triplequote-sq-atpt)
;;;###autoload
(defun ar-cntrl-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around cntrl. "
  (interactive "*p")
  (ar-th-triplequote-sq 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-trim-cntrl-atpt 'ar-cntrl-trim-atpt)
;;;###autoload
(defun ar-cntrl-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'cntrl t t)) 
    (ar-th-trim 'cntrl t t)))

(defalias 'ar-trim-left-cntrl-atpt 'ar-cntrl-left-trim-atpt)
;;;###autoload
(defun ar-cntrl-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'cntrl t nil))
    (ar-th-trim 'cntrl t nil)))

(defalias 'ar-trim-right-cntrl-atpt 'ar-cntrl-right-trim-atpt)
;;;###autoload
(defun ar-cntrl-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'cntrl nil t))
    (ar-th-trim 'cntrl nil t)))

(defalias 'ar-cntrl-underscore-atpt 'ar-underscore-cntrl-atpt)
;;;###autoload
(defun ar-underscore-cntrl-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'cntrl no-delimiters (interactive-p)))

(defalias 'ar-cntrl-whitespace-atpt 'ar-whitespace-cntrl-atpt)
;;;###autoload
(defun ar-whitespace-cntrl-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'cntrl nil t))

(defalias 'ar-forward-cntrl-atpt 'ar-cntrl-forward-atpt)
;;;###autoload
(defun ar-cntrl-forward-atpt (&optional arg) 
  "Moves forward over cntrl at point if any, does nothing otherwise.
Returns end position of cntrl "
  (interactive "p")
  (ar-th-forward 'cntrl arg (interactive-p)))

(defalias 'ar-backward-cntrl-atpt 'ar-cntrl-backward-atpt)
;;;###autoload
(defun ar-cntrl-backward-atpt (&optional arg) 
  "Moves backward over cntrl before point if any, does nothing otherwise.
Returns beginning position of cntrl "
  (interactive "p")
  (ar-th-backward 'cntrl arg (interactive-p)))

(defalias 'ar-transpose-cntrl-atpt 'ar-cntrl-transpose-atpt)
;;;###autoload
(defun ar-cntrl-transpose-atpt (&optional arg) 
  "Transposes cntrl with cntrl before point if any. "
  (interactive "*p")
  (ar-th-transpose 'cntrl arg (interactive-p)))

(defalias 'ar-sort-cntrl-atpt 'ar-cntrl-sort-atpt)
;;;###autoload
(defun ar-cntrl-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts cntrls in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'cntrl reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-cntrl-atpt 'ar-cntrl-check-atpt)
;;;###autoload
(defun ar-cntrl-check-atpt () 
  "Return t if a cntrl at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-cntrl-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-cntrl-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-digit-atpt (&optional arg no-delimiters) 
  "Returns digit at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'digit arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-digit-atpt 'ar-digit-bounds-atpt)
;;;###autoload
(defun ar-digit-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of digit if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'digit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-digit-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position digit at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'digit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-digit-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of digit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'digit no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-digit-atpt 'ar-digit-beginning-atpt)
;;;###autoload
(defun ar-digit-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class digit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'digit no-delimiters (interactive-p)))

(defalias 'ar-end-of-digit-atpt 'ar-digit-end-atpt)
;;;###autoload
(defun ar-digit-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class digit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'digit no-delimiters (interactive-p)))

(defalias 'ar-in-digit-p-atpt 'ar-digit-in-p-atpt)
;;;###autoload
(defun ar-digit-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of digit at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'digit no-delimiters (interactive-p)))

(defalias 'ar-length-of-digit-atpt 'ar-digit-length-atpt)
;;;###autoload
(defun ar-digit-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class digit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'digit no-delimiters (interactive-p)))

(defalias 'ar-copy-digit-atpt 'ar-digit-copy-atpt)
;;;###autoload
(defun ar-digit-copy-atpt (&optional no-delimiters) 
  "Returns a copy of digit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'digit no-delimiters (interactive-p)))

(defalias 'ar-delete-digit-in-region 'ar-digit-delete-in-region)
;;;###autoload
(defun ar-digit-delete-in-region (beg end) 
  "Deletes digit at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'digit beg end (interactive-p)))

;;;###autoload
(defun ar-blok-digit-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around digit.
  Returns blok or nil if no digit at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'digit no-delimiters (interactive-p)))

(defalias 'ar-escape-digit-atpt 'ar-digit-escape-atpt)
;;;###autoload
(defun ar-digit-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted digit at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'digit no-delimiters))

(defalias 'ar-doublequote-digit-atpt 'ar-digit-doublequote-atpt)
;;;###autoload
(defun ar-digit-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes digit at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'digit no-delimiters (interactive-p)))

(defalias 'ar-slash-digit-atpt 'ar-digit-slash-atpt)
;;;###autoload
(defun ar-digit-slash-atpt (&optional no-delimiters) 
  "Doublequotes digit at point if any. "
  (interactive "*p")
  (ar-th-slash 'digit no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-digit-atpt 'ar-digit-double-backslash-atpt)
;;;###autoload
(defun ar-digit-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around digit at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'digit no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-digit-atpt 'ar-digit-doubleslash-atpt)
;;;###autoload
(defun ar-digit-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around digit at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'digit no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-digit-atpt 'ar-digit-doubleslashparen-atpt)
;;;###autoload
(defun ar-digit-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around digit at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'digit no-delimiters (interactive-p)))

(defalias 'ar-slashparen-digit-atpt 'ar-digit-slashparen-atpt)
;;;###autoload
(defun ar-digit-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around digit at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'digit no-delimiters (interactive-p)))

(defalias 'ar-dollar-digit-atpt 'ar-digit-dollar-atpt)
;;;###autoload
(defun ar-digit-dollar-atpt (&optional no-delimiters) 
  "Doublequotes digit at point if any. "
  (interactive "*p")
  (ar-th-dollar 'digit no-delimiters (interactive-p)))

(defalias 'ar-equalize-digit-atpt 'ar-digit-equalize-atpt)
;;;###autoload
(defun ar-digit-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around digit at point if any. "
  (interactive "*p")
  (ar-th-equalize 'digit no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-digit-atpt 'ar-digit-greater-angle-atpt)
;;;###autoload
(defun ar-digit-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for digit after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'digit no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-digit-atpt 'ar-digit-lesser-angle-atpt)
;;;###autoload
(defun ar-digit-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for digit after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'digit no-delimiters (interactive-p)))

(defalias 'ar-backslash-digit-atpt 'ar-digit-backslash-atpt)
;;;###autoload
(defun ar-digit-backslash-atpt (&optional no-delimiters) 
  "Backslash digit at point if any. "
  (interactive "*p")
  (ar-th-backslash 'digit no-delimiters (interactive-p))) 

(defalias 'ar-brace-digit-atpt 'ar-digit-brace-atpt)
;;;###autoload
(defun ar-digit-brace-atpt (&optional no-delimiters) 
  "Braces digit at point if any. "
  (interactive "*p")
  (ar-th-brace 'digit no-delimiters (interactive-p)))

(defalias 'ar-bracket-digit-atpt 'ar-digit-bracket-atpt)
;;;###autoload
(defun ar-digit-bracket-atpt (&optional no-delimiters) 
  "Brackets digit after point if any. "
  (interactive "*p")
  (ar-th-bracket 'digit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-digit-atpt (&optional no-delimiters) 
  "Comments digit at point if any. "
  (interactive "*p")
  (ar-th-comment 'digit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-digit-atpt (&optional no-delimiters) 
  "Put a comma after digit at point if any. "
  (interactive "*p")
  (ar-th-commatize 'digit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-digit-atpt (&optional no-delimiters) 
  "Put a singlequote before digit at point if any. "
  (interactive "*p")
  (ar-th-quote 'digit no-delimiters (interactive-p)))

(defalias 'ar-hyphen-digit-atpt 'ar-digit-hyphen-atpt)
;;;###autoload
(defun ar-digit-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around digit at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'digit no-delimiters (interactive-p)))

(defalias 'ar-mark-digit-atpt 'ar-digit-mark-atpt)
;;;###autoload
(defun ar-digit-mark-atpt () 
  "Marks digit at point if any. "
  (interactive)
  (ar-th-mark 'digit))

(defalias 'ar-hide-digit-atpt 'ar-digit-hide-atpt)
;;;###autoload
(defun ar-digit-hide-atpt () 
  "Hides digit at point. "
  (interactive)
  (ar-th-hide 'digit))

(defalias 'ar-show-digit-atpt 'ar-digit-show-atpt)
;;;###autoload
(defun ar-digit-show-atpt () 
  "Shows hidden digit at point. "
  (interactive)
  (ar-th-show 'digit))

(defalias 'ar-hide-show-digit-atpt 'ar-digit-hide-show-atpt)
;;;###autoload
(defun ar-digit-hide-show-atpt () 
  "Alternatively hides or shows digit at point. "
  (interactive)
  (ar-th-hide-show 'digit))

(defalias 'ar-highlight-digit-atpt-mode 'ar-digit-highlight-atpt-mode)

(defun ar-digit-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles digit-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'digit no-delimiters (interactive-p)))

(defalias 'ar-kill-digit-atpt 'ar-digit-kill-atpt)
;;;###autoload
(defun ar-digit-kill-atpt (&optional no-delimiters) 
  "Kills digit at point if any. "
  (interactive "*P")
  (ar-th-kill 'digit no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-digit-atpt 'ar-digit-left-right-singlequote-atpt)
;;;###autoload
(defun ar-digit-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'digit no-delimiters (interactive-p)))

(defalias 'ar-parentize-digit-atpt 'ar-digit-parentize-atpt)
;;;###autoload
(defun ar-digit-parentize-atpt (&optional no-delimiters) 
  "Parentizes digit at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'digit no-delimiters (interactive-p)))

(defalias 'ar-separate-digit-atpt 'ar-digit-separate-atpt)
;;;###autoload
(defun ar-digit-separate-atpt (&optional no-delimiters) 
  "Separates digit at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'digit no-delimiters (interactive-p)))

(defalias 'ar-singlequote-digit-atpt 'ar-digit-singlequote-atpt)
;;;###autoload
(defun ar-digit-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes digit at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'digit no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-digit-atpt 'ar-digit-triplequote-dq-atpt)
;;;###autoload
(defun ar-digit-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around digit. "
  (interactive "*p")
  (ar-th-triplequote-dq 'digit no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-digit-atpt 'ar-digit-triplequote-sq-atpt)
;;;###autoload
(defun ar-digit-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around digit. "
  (interactive "*p")
  (ar-th-triplequote-sq 'digit no-delimiters (interactive-p)))

(defalias 'ar-trim-digit-atpt 'ar-digit-trim-atpt)
;;;###autoload
(defun ar-digit-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'digit t t)) 
    (ar-th-trim 'digit t t)))

(defalias 'ar-trim-left-digit-atpt 'ar-digit-left-trim-atpt)
;;;###autoload
(defun ar-digit-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'digit t nil))
    (ar-th-trim 'digit t nil)))

(defalias 'ar-trim-right-digit-atpt 'ar-digit-right-trim-atpt)
;;;###autoload
(defun ar-digit-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'digit nil t))
    (ar-th-trim 'digit nil t)))

(defalias 'ar-digit-underscore-atpt 'ar-underscore-digit-atpt)
;;;###autoload
(defun ar-underscore-digit-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'digit no-delimiters (interactive-p)))

(defalias 'ar-digit-whitespace-atpt 'ar-whitespace-digit-atpt)
;;;###autoload
(defun ar-whitespace-digit-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'digit nil t))

(defalias 'ar-forward-digit-atpt 'ar-digit-forward-atpt)
;;;###autoload
(defun ar-digit-forward-atpt (&optional arg) 
  "Moves forward over digit at point if any, does nothing otherwise.
Returns end position of digit "
  (interactive "p")
  (ar-th-forward 'digit arg (interactive-p)))

(defalias 'ar-backward-digit-atpt 'ar-digit-backward-atpt)
;;;###autoload
(defun ar-digit-backward-atpt (&optional arg) 
  "Moves backward over digit before point if any, does nothing otherwise.
Returns beginning position of digit "
  (interactive "p")
  (ar-th-backward 'digit arg (interactive-p)))

(defalias 'ar-transpose-digit-atpt 'ar-digit-transpose-atpt)
;;;###autoload
(defun ar-digit-transpose-atpt (&optional arg) 
  "Transposes digit with digit before point if any. "
  (interactive "*p")
  (ar-th-transpose 'digit arg (interactive-p)))

(defalias 'ar-sort-digit-atpt 'ar-digit-sort-atpt)
;;;###autoload
(defun ar-digit-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts digits in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'digit reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-digit-atpt 'ar-digit-check-atpt)
;;;###autoload
(defun ar-digit-check-atpt () 
  "Return t if a digit at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-digit-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-digit-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-graph-atpt (&optional arg no-delimiters) 
  "Returns graph at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'graph arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-graph-atpt 'ar-graph-bounds-atpt)
;;;###autoload
(defun ar-graph-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of graph if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'graph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-graph-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position graph at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'graph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-graph-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of graph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'graph no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-graph-atpt 'ar-graph-beginning-atpt)
;;;###autoload
(defun ar-graph-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class graph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'graph no-delimiters (interactive-p)))

(defalias 'ar-end-of-graph-atpt 'ar-graph-end-atpt)
;;;###autoload
(defun ar-graph-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class graph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'graph no-delimiters (interactive-p)))

(defalias 'ar-in-graph-p-atpt 'ar-graph-in-p-atpt)
;;;###autoload
(defun ar-graph-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of graph at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'graph no-delimiters (interactive-p)))

(defalias 'ar-length-of-graph-atpt 'ar-graph-length-atpt)
;;;###autoload
(defun ar-graph-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class graph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'graph no-delimiters (interactive-p)))

(defalias 'ar-copy-graph-atpt 'ar-graph-copy-atpt)
;;;###autoload
(defun ar-graph-copy-atpt (&optional no-delimiters) 
  "Returns a copy of graph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'graph no-delimiters (interactive-p)))

(defalias 'ar-delete-graph-in-region 'ar-graph-delete-in-region)
;;;###autoload
(defun ar-graph-delete-in-region (beg end) 
  "Deletes graph at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'graph beg end (interactive-p)))

;;;###autoload
(defun ar-blok-graph-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around graph.
  Returns blok or nil if no graph at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'graph no-delimiters (interactive-p)))

(defalias 'ar-escape-graph-atpt 'ar-graph-escape-atpt)
;;;###autoload
(defun ar-graph-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted graph at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'graph no-delimiters))

(defalias 'ar-doublequote-graph-atpt 'ar-graph-doublequote-atpt)
;;;###autoload
(defun ar-graph-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes graph at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'graph no-delimiters (interactive-p)))

(defalias 'ar-slash-graph-atpt 'ar-graph-slash-atpt)
;;;###autoload
(defun ar-graph-slash-atpt (&optional no-delimiters) 
  "Doublequotes graph at point if any. "
  (interactive "*p")
  (ar-th-slash 'graph no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-graph-atpt 'ar-graph-double-backslash-atpt)
;;;###autoload
(defun ar-graph-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around graph at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'graph no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-graph-atpt 'ar-graph-doubleslash-atpt)
;;;###autoload
(defun ar-graph-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around graph at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'graph no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-graph-atpt 'ar-graph-doubleslashparen-atpt)
;;;###autoload
(defun ar-graph-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around graph at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'graph no-delimiters (interactive-p)))

(defalias 'ar-slashparen-graph-atpt 'ar-graph-slashparen-atpt)
;;;###autoload
(defun ar-graph-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around graph at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'graph no-delimiters (interactive-p)))

(defalias 'ar-dollar-graph-atpt 'ar-graph-dollar-atpt)
;;;###autoload
(defun ar-graph-dollar-atpt (&optional no-delimiters) 
  "Doublequotes graph at point if any. "
  (interactive "*p")
  (ar-th-dollar 'graph no-delimiters (interactive-p)))

(defalias 'ar-equalize-graph-atpt 'ar-graph-equalize-atpt)
;;;###autoload
(defun ar-graph-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around graph at point if any. "
  (interactive "*p")
  (ar-th-equalize 'graph no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-graph-atpt 'ar-graph-greater-angle-atpt)
;;;###autoload
(defun ar-graph-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for graph after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'graph no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-graph-atpt 'ar-graph-lesser-angle-atpt)
;;;###autoload
(defun ar-graph-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for graph after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'graph no-delimiters (interactive-p)))

(defalias 'ar-backslash-graph-atpt 'ar-graph-backslash-atpt)
;;;###autoload
(defun ar-graph-backslash-atpt (&optional no-delimiters) 
  "Backslash graph at point if any. "
  (interactive "*p")
  (ar-th-backslash 'graph no-delimiters (interactive-p))) 

(defalias 'ar-brace-graph-atpt 'ar-graph-brace-atpt)
;;;###autoload
(defun ar-graph-brace-atpt (&optional no-delimiters) 
  "Braces graph at point if any. "
  (interactive "*p")
  (ar-th-brace 'graph no-delimiters (interactive-p)))

(defalias 'ar-bracket-graph-atpt 'ar-graph-bracket-atpt)
;;;###autoload
(defun ar-graph-bracket-atpt (&optional no-delimiters) 
  "Brackets graph after point if any. "
  (interactive "*p")
  (ar-th-bracket 'graph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-graph-atpt (&optional no-delimiters) 
  "Comments graph at point if any. "
  (interactive "*p")
  (ar-th-comment 'graph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-graph-atpt (&optional no-delimiters) 
  "Put a comma after graph at point if any. "
  (interactive "*p")
  (ar-th-commatize 'graph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-graph-atpt (&optional no-delimiters) 
  "Put a singlequote before graph at point if any. "
  (interactive "*p")
  (ar-th-quote 'graph no-delimiters (interactive-p)))

(defalias 'ar-hyphen-graph-atpt 'ar-graph-hyphen-atpt)
;;;###autoload
(defun ar-graph-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around graph at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'graph no-delimiters (interactive-p)))

(defalias 'ar-mark-graph-atpt 'ar-graph-mark-atpt)
;;;###autoload
(defun ar-graph-mark-atpt () 
  "Marks graph at point if any. "
  (interactive)
  (ar-th-mark 'graph))

(defalias 'ar-hide-graph-atpt 'ar-graph-hide-atpt)
;;;###autoload
(defun ar-graph-hide-atpt () 
  "Hides graph at point. "
  (interactive)
  (ar-th-hide 'graph))

(defalias 'ar-show-graph-atpt 'ar-graph-show-atpt)
;;;###autoload
(defun ar-graph-show-atpt () 
  "Shows hidden graph at point. "
  (interactive)
  (ar-th-show 'graph))

(defalias 'ar-hide-show-graph-atpt 'ar-graph-hide-show-atpt)
;;;###autoload
(defun ar-graph-hide-show-atpt () 
  "Alternatively hides or shows graph at point. "
  (interactive)
  (ar-th-hide-show 'graph))

(defalias 'ar-highlight-graph-atpt-mode 'ar-graph-highlight-atpt-mode)

(defun ar-graph-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles graph-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'graph no-delimiters (interactive-p)))

(defalias 'ar-kill-graph-atpt 'ar-graph-kill-atpt)
;;;###autoload
(defun ar-graph-kill-atpt (&optional no-delimiters) 
  "Kills graph at point if any. "
  (interactive "*P")
  (ar-th-kill 'graph no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-graph-atpt 'ar-graph-left-right-singlequote-atpt)
;;;###autoload
(defun ar-graph-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'graph no-delimiters (interactive-p)))

(defalias 'ar-parentize-graph-atpt 'ar-graph-parentize-atpt)
;;;###autoload
(defun ar-graph-parentize-atpt (&optional no-delimiters) 
  "Parentizes graph at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'graph no-delimiters (interactive-p)))

(defalias 'ar-separate-graph-atpt 'ar-graph-separate-atpt)
;;;###autoload
(defun ar-graph-separate-atpt (&optional no-delimiters) 
  "Separates graph at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'graph no-delimiters (interactive-p)))

(defalias 'ar-singlequote-graph-atpt 'ar-graph-singlequote-atpt)
;;;###autoload
(defun ar-graph-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes graph at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'graph no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-graph-atpt 'ar-graph-triplequote-dq-atpt)
;;;###autoload
(defun ar-graph-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around graph. "
  (interactive "*p")
  (ar-th-triplequote-dq 'graph no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-graph-atpt 'ar-graph-triplequote-sq-atpt)
;;;###autoload
(defun ar-graph-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around graph. "
  (interactive "*p")
  (ar-th-triplequote-sq 'graph no-delimiters (interactive-p)))

(defalias 'ar-trim-graph-atpt 'ar-graph-trim-atpt)
;;;###autoload
(defun ar-graph-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'graph t t)) 
    (ar-th-trim 'graph t t)))

(defalias 'ar-trim-left-graph-atpt 'ar-graph-left-trim-atpt)
;;;###autoload
(defun ar-graph-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'graph t nil))
    (ar-th-trim 'graph t nil)))

(defalias 'ar-trim-right-graph-atpt 'ar-graph-right-trim-atpt)
;;;###autoload
(defun ar-graph-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'graph nil t))
    (ar-th-trim 'graph nil t)))

(defalias 'ar-graph-underscore-atpt 'ar-underscore-graph-atpt)
;;;###autoload
(defun ar-underscore-graph-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'graph no-delimiters (interactive-p)))

(defalias 'ar-graph-whitespace-atpt 'ar-whitespace-graph-atpt)
;;;###autoload
(defun ar-whitespace-graph-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'graph nil t))

(defalias 'ar-forward-graph-atpt 'ar-graph-forward-atpt)
;;;###autoload
(defun ar-graph-forward-atpt (&optional arg) 
  "Moves forward over graph at point if any, does nothing otherwise.
Returns end position of graph "
  (interactive "p")
  (ar-th-forward 'graph arg (interactive-p)))

(defalias 'ar-backward-graph-atpt 'ar-graph-backward-atpt)
;;;###autoload
(defun ar-graph-backward-atpt (&optional arg) 
  "Moves backward over graph before point if any, does nothing otherwise.
Returns beginning position of graph "
  (interactive "p")
  (ar-th-backward 'graph arg (interactive-p)))

(defalias 'ar-transpose-graph-atpt 'ar-graph-transpose-atpt)
;;;###autoload
(defun ar-graph-transpose-atpt (&optional arg) 
  "Transposes graph with graph before point if any. "
  (interactive "*p")
  (ar-th-transpose 'graph arg (interactive-p)))

(defalias 'ar-sort-graph-atpt 'ar-graph-sort-atpt)
;;;###autoload
(defun ar-graph-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts graphs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'graph reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-graph-atpt 'ar-graph-check-atpt)
;;;###autoload
(defun ar-graph-check-atpt () 
  "Return t if a graph at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-graph-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-graph-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-lower-atpt (&optional arg no-delimiters) 
  "Returns lower at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'lower arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-lower-atpt 'ar-lower-bounds-atpt)
;;;###autoload
(defun ar-lower-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of lower if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'lower no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lower-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position lower at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'lower no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lower-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of lower at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'lower no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-lower-atpt 'ar-lower-beginning-atpt)
;;;###autoload
(defun ar-lower-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class lower at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'lower no-delimiters (interactive-p)))

(defalias 'ar-end-of-lower-atpt 'ar-lower-end-atpt)
;;;###autoload
(defun ar-lower-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class lower at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'lower no-delimiters (interactive-p)))

(defalias 'ar-in-lower-p-atpt 'ar-lower-in-p-atpt)
;;;###autoload
(defun ar-lower-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of lower at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'lower no-delimiters (interactive-p)))

(defalias 'ar-length-of-lower-atpt 'ar-lower-length-atpt)
;;;###autoload
(defun ar-lower-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class lower at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'lower no-delimiters (interactive-p)))

(defalias 'ar-copy-lower-atpt 'ar-lower-copy-atpt)
;;;###autoload
(defun ar-lower-copy-atpt (&optional no-delimiters) 
  "Returns a copy of lower at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'lower no-delimiters (interactive-p)))

(defalias 'ar-delete-lower-in-region 'ar-lower-delete-in-region)
;;;###autoload
(defun ar-lower-delete-in-region (beg end) 
  "Deletes lower at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'lower beg end (interactive-p)))

;;;###autoload
(defun ar-blok-lower-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around lower.
  Returns blok or nil if no lower at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'lower no-delimiters (interactive-p)))

(defalias 'ar-escape-lower-atpt 'ar-lower-escape-atpt)
;;;###autoload
(defun ar-lower-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted lower at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'lower no-delimiters))

(defalias 'ar-doublequote-lower-atpt 'ar-lower-doublequote-atpt)
;;;###autoload
(defun ar-lower-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes lower at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'lower no-delimiters (interactive-p)))

(defalias 'ar-slash-lower-atpt 'ar-lower-slash-atpt)
;;;###autoload
(defun ar-lower-slash-atpt (&optional no-delimiters) 
  "Doublequotes lower at point if any. "
  (interactive "*p")
  (ar-th-slash 'lower no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-lower-atpt 'ar-lower-double-backslash-atpt)
;;;###autoload
(defun ar-lower-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around lower at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'lower no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-lower-atpt 'ar-lower-doubleslash-atpt)
;;;###autoload
(defun ar-lower-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around lower at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'lower no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-lower-atpt 'ar-lower-doubleslashparen-atpt)
;;;###autoload
(defun ar-lower-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around lower at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'lower no-delimiters (interactive-p)))

(defalias 'ar-slashparen-lower-atpt 'ar-lower-slashparen-atpt)
;;;###autoload
(defun ar-lower-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around lower at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'lower no-delimiters (interactive-p)))

(defalias 'ar-dollar-lower-atpt 'ar-lower-dollar-atpt)
;;;###autoload
(defun ar-lower-dollar-atpt (&optional no-delimiters) 
  "Doublequotes lower at point if any. "
  (interactive "*p")
  (ar-th-dollar 'lower no-delimiters (interactive-p)))

(defalias 'ar-equalize-lower-atpt 'ar-lower-equalize-atpt)
;;;###autoload
(defun ar-lower-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around lower at point if any. "
  (interactive "*p")
  (ar-th-equalize 'lower no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-lower-atpt 'ar-lower-greater-angle-atpt)
;;;###autoload
(defun ar-lower-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for lower after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'lower no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-lower-atpt 'ar-lower-lesser-angle-atpt)
;;;###autoload
(defun ar-lower-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for lower after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'lower no-delimiters (interactive-p)))

(defalias 'ar-backslash-lower-atpt 'ar-lower-backslash-atpt)
;;;###autoload
(defun ar-lower-backslash-atpt (&optional no-delimiters) 
  "Backslash lower at point if any. "
  (interactive "*p")
  (ar-th-backslash 'lower no-delimiters (interactive-p))) 

(defalias 'ar-brace-lower-atpt 'ar-lower-brace-atpt)
;;;###autoload
(defun ar-lower-brace-atpt (&optional no-delimiters) 
  "Braces lower at point if any. "
  (interactive "*p")
  (ar-th-brace 'lower no-delimiters (interactive-p)))

(defalias 'ar-bracket-lower-atpt 'ar-lower-bracket-atpt)
;;;###autoload
(defun ar-lower-bracket-atpt (&optional no-delimiters) 
  "Brackets lower after point if any. "
  (interactive "*p")
  (ar-th-bracket 'lower no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-lower-atpt (&optional no-delimiters) 
  "Comments lower at point if any. "
  (interactive "*p")
  (ar-th-comment 'lower no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-lower-atpt (&optional no-delimiters) 
  "Put a comma after lower at point if any. "
  (interactive "*p")
  (ar-th-commatize 'lower no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-lower-atpt (&optional no-delimiters) 
  "Put a singlequote before lower at point if any. "
  (interactive "*p")
  (ar-th-quote 'lower no-delimiters (interactive-p)))

(defalias 'ar-hyphen-lower-atpt 'ar-lower-hyphen-atpt)
;;;###autoload
(defun ar-lower-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around lower at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'lower no-delimiters (interactive-p)))

(defalias 'ar-mark-lower-atpt 'ar-lower-mark-atpt)
;;;###autoload
(defun ar-lower-mark-atpt () 
  "Marks lower at point if any. "
  (interactive)
  (ar-th-mark 'lower))

(defalias 'ar-hide-lower-atpt 'ar-lower-hide-atpt)
;;;###autoload
(defun ar-lower-hide-atpt () 
  "Hides lower at point. "
  (interactive)
  (ar-th-hide 'lower))

(defalias 'ar-show-lower-atpt 'ar-lower-show-atpt)
;;;###autoload
(defun ar-lower-show-atpt () 
  "Shows hidden lower at point. "
  (interactive)
  (ar-th-show 'lower))

(defalias 'ar-hide-show-lower-atpt 'ar-lower-hide-show-atpt)
;;;###autoload
(defun ar-lower-hide-show-atpt () 
  "Alternatively hides or shows lower at point. "
  (interactive)
  (ar-th-hide-show 'lower))

(defalias 'ar-highlight-lower-atpt-mode 'ar-lower-highlight-atpt-mode)

(defun ar-lower-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles lower-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'lower no-delimiters (interactive-p)))

(defalias 'ar-kill-lower-atpt 'ar-lower-kill-atpt)
;;;###autoload
(defun ar-lower-kill-atpt (&optional no-delimiters) 
  "Kills lower at point if any. "
  (interactive "*P")
  (ar-th-kill 'lower no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-lower-atpt 'ar-lower-left-right-singlequote-atpt)
;;;###autoload
(defun ar-lower-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'lower no-delimiters (interactive-p)))

(defalias 'ar-parentize-lower-atpt 'ar-lower-parentize-atpt)
;;;###autoload
(defun ar-lower-parentize-atpt (&optional no-delimiters) 
  "Parentizes lower at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'lower no-delimiters (interactive-p)))

(defalias 'ar-separate-lower-atpt 'ar-lower-separate-atpt)
;;;###autoload
(defun ar-lower-separate-atpt (&optional no-delimiters) 
  "Separates lower at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'lower no-delimiters (interactive-p)))

(defalias 'ar-singlequote-lower-atpt 'ar-lower-singlequote-atpt)
;;;###autoload
(defun ar-lower-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes lower at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'lower no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-lower-atpt 'ar-lower-triplequote-dq-atpt)
;;;###autoload
(defun ar-lower-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around lower. "
  (interactive "*p")
  (ar-th-triplequote-dq 'lower no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-lower-atpt 'ar-lower-triplequote-sq-atpt)
;;;###autoload
(defun ar-lower-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around lower. "
  (interactive "*p")
  (ar-th-triplequote-sq 'lower no-delimiters (interactive-p)))

(defalias 'ar-trim-lower-atpt 'ar-lower-trim-atpt)
;;;###autoload
(defun ar-lower-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lower t t)) 
    (ar-th-trim 'lower t t)))

(defalias 'ar-trim-left-lower-atpt 'ar-lower-left-trim-atpt)
;;;###autoload
(defun ar-lower-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lower t nil))
    (ar-th-trim 'lower t nil)))

(defalias 'ar-trim-right-lower-atpt 'ar-lower-right-trim-atpt)
;;;###autoload
(defun ar-lower-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lower nil t))
    (ar-th-trim 'lower nil t)))

(defalias 'ar-lower-underscore-atpt 'ar-underscore-lower-atpt)
;;;###autoload
(defun ar-underscore-lower-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'lower no-delimiters (interactive-p)))

(defalias 'ar-lower-whitespace-atpt 'ar-whitespace-lower-atpt)
;;;###autoload
(defun ar-whitespace-lower-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'lower nil t))

(defalias 'ar-forward-lower-atpt 'ar-lower-forward-atpt)
;;;###autoload
(defun ar-lower-forward-atpt (&optional arg) 
  "Moves forward over lower at point if any, does nothing otherwise.
Returns end position of lower "
  (interactive "p")
  (ar-th-forward 'lower arg (interactive-p)))

(defalias 'ar-backward-lower-atpt 'ar-lower-backward-atpt)
;;;###autoload
(defun ar-lower-backward-atpt (&optional arg) 
  "Moves backward over lower before point if any, does nothing otherwise.
Returns beginning position of lower "
  (interactive "p")
  (ar-th-backward 'lower arg (interactive-p)))

(defalias 'ar-transpose-lower-atpt 'ar-lower-transpose-atpt)
;;;###autoload
(defun ar-lower-transpose-atpt (&optional arg) 
  "Transposes lower with lower before point if any. "
  (interactive "*p")
  (ar-th-transpose 'lower arg (interactive-p)))

(defalias 'ar-sort-lower-atpt 'ar-lower-sort-atpt)
;;;###autoload
(defun ar-lower-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts lowers in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'lower reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-lower-atpt 'ar-lower-check-atpt)
;;;###autoload
(defun ar-lower-check-atpt () 
  "Return t if a lower at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-lower-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-lower-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-nonascii-atpt (&optional arg no-delimiters) 
  "Returns nonascii at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'nonascii arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-nonascii-atpt 'ar-nonascii-bounds-atpt)
;;;###autoload
(defun ar-nonascii-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of nonascii if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'nonascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-nonascii-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position nonascii at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'nonascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-nonascii-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of nonascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-nonascii-atpt 'ar-nonascii-beginning-atpt)
;;;###autoload
(defun ar-nonascii-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class nonascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-end-of-nonascii-atpt 'ar-nonascii-end-atpt)
;;;###autoload
(defun ar-nonascii-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class nonascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-in-nonascii-p-atpt 'ar-nonascii-in-p-atpt)
;;;###autoload
(defun ar-nonascii-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of nonascii at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-length-of-nonascii-atpt 'ar-nonascii-length-atpt)
;;;###autoload
(defun ar-nonascii-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class nonascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-copy-nonascii-atpt 'ar-nonascii-copy-atpt)
;;;###autoload
(defun ar-nonascii-copy-atpt (&optional no-delimiters) 
  "Returns a copy of nonascii at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-delete-nonascii-in-region 'ar-nonascii-delete-in-region)
;;;###autoload
(defun ar-nonascii-delete-in-region (beg end) 
  "Deletes nonascii at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'nonascii beg end (interactive-p)))

;;;###autoload
(defun ar-blok-nonascii-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around nonascii.
  Returns blok or nil if no nonascii at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-escape-nonascii-atpt 'ar-nonascii-escape-atpt)
;;;###autoload
(defun ar-nonascii-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted nonascii at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'nonascii no-delimiters))

(defalias 'ar-doublequote-nonascii-atpt 'ar-nonascii-doublequote-atpt)
;;;###autoload
(defun ar-nonascii-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes nonascii at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-slash-nonascii-atpt 'ar-nonascii-slash-atpt)
;;;###autoload
(defun ar-nonascii-slash-atpt (&optional no-delimiters) 
  "Doublequotes nonascii at point if any. "
  (interactive "*p")
  (ar-th-slash 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-nonascii-atpt 'ar-nonascii-double-backslash-atpt)
;;;###autoload
(defun ar-nonascii-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around nonascii at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-nonascii-atpt 'ar-nonascii-doubleslash-atpt)
;;;###autoload
(defun ar-nonascii-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around nonascii at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-nonascii-atpt 'ar-nonascii-doubleslashparen-atpt)
;;;###autoload
(defun ar-nonascii-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around nonascii at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-slashparen-nonascii-atpt 'ar-nonascii-slashparen-atpt)
;;;###autoload
(defun ar-nonascii-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around nonascii at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-dollar-nonascii-atpt 'ar-nonascii-dollar-atpt)
;;;###autoload
(defun ar-nonascii-dollar-atpt (&optional no-delimiters) 
  "Doublequotes nonascii at point if any. "
  (interactive "*p")
  (ar-th-dollar 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-equalize-nonascii-atpt 'ar-nonascii-equalize-atpt)
;;;###autoload
(defun ar-nonascii-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around nonascii at point if any. "
  (interactive "*p")
  (ar-th-equalize 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-nonascii-atpt 'ar-nonascii-greater-angle-atpt)
;;;###autoload
(defun ar-nonascii-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for nonascii after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-nonascii-atpt 'ar-nonascii-lesser-angle-atpt)
;;;###autoload
(defun ar-nonascii-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for nonascii after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-backslash-nonascii-atpt 'ar-nonascii-backslash-atpt)
;;;###autoload
(defun ar-nonascii-backslash-atpt (&optional no-delimiters) 
  "Backslash nonascii at point if any. "
  (interactive "*p")
  (ar-th-backslash 'nonascii no-delimiters (interactive-p))) 

(defalias 'ar-brace-nonascii-atpt 'ar-nonascii-brace-atpt)
;;;###autoload
(defun ar-nonascii-brace-atpt (&optional no-delimiters) 
  "Braces nonascii at point if any. "
  (interactive "*p")
  (ar-th-brace 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-bracket-nonascii-atpt 'ar-nonascii-bracket-atpt)
;;;###autoload
(defun ar-nonascii-bracket-atpt (&optional no-delimiters) 
  "Brackets nonascii after point if any. "
  (interactive "*p")
  (ar-th-bracket 'nonascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-nonascii-atpt (&optional no-delimiters) 
  "Comments nonascii at point if any. "
  (interactive "*p")
  (ar-th-comment 'nonascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-nonascii-atpt (&optional no-delimiters) 
  "Put a comma after nonascii at point if any. "
  (interactive "*p")
  (ar-th-commatize 'nonascii no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-nonascii-atpt (&optional no-delimiters) 
  "Put a singlequote before nonascii at point if any. "
  (interactive "*p")
  (ar-th-quote 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-hyphen-nonascii-atpt 'ar-nonascii-hyphen-atpt)
;;;###autoload
(defun ar-nonascii-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around nonascii at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-mark-nonascii-atpt 'ar-nonascii-mark-atpt)
;;;###autoload
(defun ar-nonascii-mark-atpt () 
  "Marks nonascii at point if any. "
  (interactive)
  (ar-th-mark 'nonascii))

(defalias 'ar-hide-nonascii-atpt 'ar-nonascii-hide-atpt)
;;;###autoload
(defun ar-nonascii-hide-atpt () 
  "Hides nonascii at point. "
  (interactive)
  (ar-th-hide 'nonascii))

(defalias 'ar-show-nonascii-atpt 'ar-nonascii-show-atpt)
;;;###autoload
(defun ar-nonascii-show-atpt () 
  "Shows hidden nonascii at point. "
  (interactive)
  (ar-th-show 'nonascii))

(defalias 'ar-hide-show-nonascii-atpt 'ar-nonascii-hide-show-atpt)
;;;###autoload
(defun ar-nonascii-hide-show-atpt () 
  "Alternatively hides or shows nonascii at point. "
  (interactive)
  (ar-th-hide-show 'nonascii))

(defalias 'ar-highlight-nonascii-atpt-mode 'ar-nonascii-highlight-atpt-mode)

(defun ar-nonascii-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles nonascii-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-kill-nonascii-atpt 'ar-nonascii-kill-atpt)
;;;###autoload
(defun ar-nonascii-kill-atpt (&optional no-delimiters) 
  "Kills nonascii at point if any. "
  (interactive "*P")
  (ar-th-kill 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-nonascii-atpt 'ar-nonascii-left-right-singlequote-atpt)
;;;###autoload
(defun ar-nonascii-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-parentize-nonascii-atpt 'ar-nonascii-parentize-atpt)
;;;###autoload
(defun ar-nonascii-parentize-atpt (&optional no-delimiters) 
  "Parentizes nonascii at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-separate-nonascii-atpt 'ar-nonascii-separate-atpt)
;;;###autoload
(defun ar-nonascii-separate-atpt (&optional no-delimiters) 
  "Separates nonascii at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-singlequote-nonascii-atpt 'ar-nonascii-singlequote-atpt)
;;;###autoload
(defun ar-nonascii-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes nonascii at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-nonascii-atpt 'ar-nonascii-triplequote-dq-atpt)
;;;###autoload
(defun ar-nonascii-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around nonascii. "
  (interactive "*p")
  (ar-th-triplequote-dq 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-nonascii-atpt 'ar-nonascii-triplequote-sq-atpt)
;;;###autoload
(defun ar-nonascii-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around nonascii. "
  (interactive "*p")
  (ar-th-triplequote-sq 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-trim-nonascii-atpt 'ar-nonascii-trim-atpt)
;;;###autoload
(defun ar-nonascii-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'nonascii t t)) 
    (ar-th-trim 'nonascii t t)))

(defalias 'ar-trim-left-nonascii-atpt 'ar-nonascii-left-trim-atpt)
;;;###autoload
(defun ar-nonascii-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'nonascii t nil))
    (ar-th-trim 'nonascii t nil)))

(defalias 'ar-trim-right-nonascii-atpt 'ar-nonascii-right-trim-atpt)
;;;###autoload
(defun ar-nonascii-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'nonascii nil t))
    (ar-th-trim 'nonascii nil t)))

(defalias 'ar-nonascii-underscore-atpt 'ar-underscore-nonascii-atpt)
;;;###autoload
(defun ar-underscore-nonascii-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'nonascii no-delimiters (interactive-p)))

(defalias 'ar-nonascii-whitespace-atpt 'ar-whitespace-nonascii-atpt)
;;;###autoload
(defun ar-whitespace-nonascii-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'nonascii nil t))

(defalias 'ar-forward-nonascii-atpt 'ar-nonascii-forward-atpt)
;;;###autoload
(defun ar-nonascii-forward-atpt (&optional arg) 
  "Moves forward over nonascii at point if any, does nothing otherwise.
Returns end position of nonascii "
  (interactive "p")
  (ar-th-forward 'nonascii arg (interactive-p)))

(defalias 'ar-backward-nonascii-atpt 'ar-nonascii-backward-atpt)
;;;###autoload
(defun ar-nonascii-backward-atpt (&optional arg) 
  "Moves backward over nonascii before point if any, does nothing otherwise.
Returns beginning position of nonascii "
  (interactive "p")
  (ar-th-backward 'nonascii arg (interactive-p)))

(defalias 'ar-transpose-nonascii-atpt 'ar-nonascii-transpose-atpt)
;;;###autoload
(defun ar-nonascii-transpose-atpt (&optional arg) 
  "Transposes nonascii with nonascii before point if any. "
  (interactive "*p")
  (ar-th-transpose 'nonascii arg (interactive-p)))

(defalias 'ar-sort-nonascii-atpt 'ar-nonascii-sort-atpt)
;;;###autoload
(defun ar-nonascii-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts nonasciis in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'nonascii reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-nonascii-atpt 'ar-nonascii-check-atpt)
;;;###autoload
(defun ar-nonascii-check-atpt () 
  "Return t if a nonascii at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-nonascii-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-nonascii-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-print-atpt (&optional arg no-delimiters) 
  "Returns print at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'print arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-print-atpt 'ar-print-bounds-atpt)
;;;###autoload
(defun ar-print-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of print if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'print no-delimiters (interactive-p)))

;;;###autoload
(defun ar-print-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position print at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'print no-delimiters (interactive-p)))

;;;###autoload
(defun ar-print-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of print at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'print no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-print-atpt 'ar-print-beginning-atpt)
;;;###autoload
(defun ar-print-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class print at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'print no-delimiters (interactive-p)))

(defalias 'ar-end-of-print-atpt 'ar-print-end-atpt)
;;;###autoload
(defun ar-print-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class print at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'print no-delimiters (interactive-p)))

(defalias 'ar-in-print-p-atpt 'ar-print-in-p-atpt)
;;;###autoload
(defun ar-print-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of print at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'print no-delimiters (interactive-p)))

(defalias 'ar-length-of-print-atpt 'ar-print-length-atpt)
;;;###autoload
(defun ar-print-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class print at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'print no-delimiters (interactive-p)))

(defalias 'ar-copy-print-atpt 'ar-print-copy-atpt)
;;;###autoload
(defun ar-print-copy-atpt (&optional no-delimiters) 
  "Returns a copy of print at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'print no-delimiters (interactive-p)))

(defalias 'ar-delete-print-in-region 'ar-print-delete-in-region)
;;;###autoload
(defun ar-print-delete-in-region (beg end) 
  "Deletes print at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'print beg end (interactive-p)))

;;;###autoload
(defun ar-blok-print-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around print.
  Returns blok or nil if no print at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'print no-delimiters (interactive-p)))

(defalias 'ar-escape-print-atpt 'ar-print-escape-atpt)
;;;###autoload
(defun ar-print-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted print at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'print no-delimiters))

(defalias 'ar-doublequote-print-atpt 'ar-print-doublequote-atpt)
;;;###autoload
(defun ar-print-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes print at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'print no-delimiters (interactive-p)))

(defalias 'ar-slash-print-atpt 'ar-print-slash-atpt)
;;;###autoload
(defun ar-print-slash-atpt (&optional no-delimiters) 
  "Doublequotes print at point if any. "
  (interactive "*p")
  (ar-th-slash 'print no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-print-atpt 'ar-print-double-backslash-atpt)
;;;###autoload
(defun ar-print-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around print at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'print no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-print-atpt 'ar-print-doubleslash-atpt)
;;;###autoload
(defun ar-print-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around print at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'print no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-print-atpt 'ar-print-doubleslashparen-atpt)
;;;###autoload
(defun ar-print-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around print at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'print no-delimiters (interactive-p)))

(defalias 'ar-slashparen-print-atpt 'ar-print-slashparen-atpt)
;;;###autoload
(defun ar-print-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around print at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'print no-delimiters (interactive-p)))

(defalias 'ar-dollar-print-atpt 'ar-print-dollar-atpt)
;;;###autoload
(defun ar-print-dollar-atpt (&optional no-delimiters) 
  "Doublequotes print at point if any. "
  (interactive "*p")
  (ar-th-dollar 'print no-delimiters (interactive-p)))

(defalias 'ar-equalize-print-atpt 'ar-print-equalize-atpt)
;;;###autoload
(defun ar-print-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around print at point if any. "
  (interactive "*p")
  (ar-th-equalize 'print no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-print-atpt 'ar-print-greater-angle-atpt)
;;;###autoload
(defun ar-print-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for print after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'print no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-print-atpt 'ar-print-lesser-angle-atpt)
;;;###autoload
(defun ar-print-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for print after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'print no-delimiters (interactive-p)))

(defalias 'ar-backslash-print-atpt 'ar-print-backslash-atpt)
;;;###autoload
(defun ar-print-backslash-atpt (&optional no-delimiters) 
  "Backslash print at point if any. "
  (interactive "*p")
  (ar-th-backslash 'print no-delimiters (interactive-p))) 

(defalias 'ar-brace-print-atpt 'ar-print-brace-atpt)
;;;###autoload
(defun ar-print-brace-atpt (&optional no-delimiters) 
  "Braces print at point if any. "
  (interactive "*p")
  (ar-th-brace 'print no-delimiters (interactive-p)))

(defalias 'ar-bracket-print-atpt 'ar-print-bracket-atpt)
;;;###autoload
(defun ar-print-bracket-atpt (&optional no-delimiters) 
  "Brackets print after point if any. "
  (interactive "*p")
  (ar-th-bracket 'print no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-print-atpt (&optional no-delimiters) 
  "Comments print at point if any. "
  (interactive "*p")
  (ar-th-comment 'print no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-print-atpt (&optional no-delimiters) 
  "Put a comma after print at point if any. "
  (interactive "*p")
  (ar-th-commatize 'print no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-print-atpt (&optional no-delimiters) 
  "Put a singlequote before print at point if any. "
  (interactive "*p")
  (ar-th-quote 'print no-delimiters (interactive-p)))

(defalias 'ar-hyphen-print-atpt 'ar-print-hyphen-atpt)
;;;###autoload
(defun ar-print-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around print at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'print no-delimiters (interactive-p)))

(defalias 'ar-mark-print-atpt 'ar-print-mark-atpt)
;;;###autoload
(defun ar-print-mark-atpt () 
  "Marks print at point if any. "
  (interactive)
  (ar-th-mark 'print))

(defalias 'ar-hide-print-atpt 'ar-print-hide-atpt)
;;;###autoload
(defun ar-print-hide-atpt () 
  "Hides print at point. "
  (interactive)
  (ar-th-hide 'print))

(defalias 'ar-show-print-atpt 'ar-print-show-atpt)
;;;###autoload
(defun ar-print-show-atpt () 
  "Shows hidden print at point. "
  (interactive)
  (ar-th-show 'print))

(defalias 'ar-hide-show-print-atpt 'ar-print-hide-show-atpt)
;;;###autoload
(defun ar-print-hide-show-atpt () 
  "Alternatively hides or shows print at point. "
  (interactive)
  (ar-th-hide-show 'print))

(defalias 'ar-highlight-print-atpt-mode 'ar-print-highlight-atpt-mode)

(defun ar-print-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles print-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'print no-delimiters (interactive-p)))

(defalias 'ar-kill-print-atpt 'ar-print-kill-atpt)
;;;###autoload
(defun ar-print-kill-atpt (&optional no-delimiters) 
  "Kills print at point if any. "
  (interactive "*P")
  (ar-th-kill 'print no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-print-atpt 'ar-print-left-right-singlequote-atpt)
;;;###autoload
(defun ar-print-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'print no-delimiters (interactive-p)))

(defalias 'ar-parentize-print-atpt 'ar-print-parentize-atpt)
;;;###autoload
(defun ar-print-parentize-atpt (&optional no-delimiters) 
  "Parentizes print at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'print no-delimiters (interactive-p)))

(defalias 'ar-separate-print-atpt 'ar-print-separate-atpt)
;;;###autoload
(defun ar-print-separate-atpt (&optional no-delimiters) 
  "Separates print at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'print no-delimiters (interactive-p)))

(defalias 'ar-singlequote-print-atpt 'ar-print-singlequote-atpt)
;;;###autoload
(defun ar-print-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes print at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'print no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-print-atpt 'ar-print-triplequote-dq-atpt)
;;;###autoload
(defun ar-print-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around print. "
  (interactive "*p")
  (ar-th-triplequote-dq 'print no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-print-atpt 'ar-print-triplequote-sq-atpt)
;;;###autoload
(defun ar-print-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around print. "
  (interactive "*p")
  (ar-th-triplequote-sq 'print no-delimiters (interactive-p)))

(defalias 'ar-trim-print-atpt 'ar-print-trim-atpt)
;;;###autoload
(defun ar-print-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'print t t)) 
    (ar-th-trim 'print t t)))

(defalias 'ar-trim-left-print-atpt 'ar-print-left-trim-atpt)
;;;###autoload
(defun ar-print-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'print t nil))
    (ar-th-trim 'print t nil)))

(defalias 'ar-trim-right-print-atpt 'ar-print-right-trim-atpt)
;;;###autoload
(defun ar-print-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'print nil t))
    (ar-th-trim 'print nil t)))

(defalias 'ar-print-underscore-atpt 'ar-underscore-print-atpt)
;;;###autoload
(defun ar-underscore-print-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'print no-delimiters (interactive-p)))

(defalias 'ar-print-whitespace-atpt 'ar-whitespace-print-atpt)
;;;###autoload
(defun ar-whitespace-print-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'print nil t))

(defalias 'ar-forward-print-atpt 'ar-print-forward-atpt)
;;;###autoload
(defun ar-print-forward-atpt (&optional arg) 
  "Moves forward over print at point if any, does nothing otherwise.
Returns end position of print "
  (interactive "p")
  (ar-th-forward 'print arg (interactive-p)))

(defalias 'ar-backward-print-atpt 'ar-print-backward-atpt)
;;;###autoload
(defun ar-print-backward-atpt (&optional arg) 
  "Moves backward over print before point if any, does nothing otherwise.
Returns beginning position of print "
  (interactive "p")
  (ar-th-backward 'print arg (interactive-p)))

(defalias 'ar-transpose-print-atpt 'ar-print-transpose-atpt)
;;;###autoload
(defun ar-print-transpose-atpt (&optional arg) 
  "Transposes print with print before point if any. "
  (interactive "*p")
  (ar-th-transpose 'print arg (interactive-p)))

(defalias 'ar-sort-print-atpt 'ar-print-sort-atpt)
;;;###autoload
(defun ar-print-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts prints in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'print reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-print-atpt 'ar-print-check-atpt)
;;;###autoload
(defun ar-print-check-atpt () 
  "Return t if a print at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-print-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-print-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-punct-atpt (&optional arg no-delimiters) 
  "Returns punct at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'punct arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-punct-atpt 'ar-punct-bounds-atpt)
;;;###autoload
(defun ar-punct-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of punct if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'punct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-punct-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position punct at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'punct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-punct-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of punct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'punct no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-punct-atpt 'ar-punct-beginning-atpt)
;;;###autoload
(defun ar-punct-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class punct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'punct no-delimiters (interactive-p)))

(defalias 'ar-end-of-punct-atpt 'ar-punct-end-atpt)
;;;###autoload
(defun ar-punct-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class punct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'punct no-delimiters (interactive-p)))

(defalias 'ar-in-punct-p-atpt 'ar-punct-in-p-atpt)
;;;###autoload
(defun ar-punct-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of punct at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'punct no-delimiters (interactive-p)))

(defalias 'ar-length-of-punct-atpt 'ar-punct-length-atpt)
;;;###autoload
(defun ar-punct-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class punct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'punct no-delimiters (interactive-p)))

(defalias 'ar-copy-punct-atpt 'ar-punct-copy-atpt)
;;;###autoload
(defun ar-punct-copy-atpt (&optional no-delimiters) 
  "Returns a copy of punct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'punct no-delimiters (interactive-p)))

(defalias 'ar-delete-punct-in-region 'ar-punct-delete-in-region)
;;;###autoload
(defun ar-punct-delete-in-region (beg end) 
  "Deletes punct at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'punct beg end (interactive-p)))

;;;###autoload
(defun ar-blok-punct-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around punct.
  Returns blok or nil if no punct at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'punct no-delimiters (interactive-p)))

(defalias 'ar-escape-punct-atpt 'ar-punct-escape-atpt)
;;;###autoload
(defun ar-punct-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted punct at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'punct no-delimiters))

(defalias 'ar-doublequote-punct-atpt 'ar-punct-doublequote-atpt)
;;;###autoload
(defun ar-punct-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes punct at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'punct no-delimiters (interactive-p)))

(defalias 'ar-slash-punct-atpt 'ar-punct-slash-atpt)
;;;###autoload
(defun ar-punct-slash-atpt (&optional no-delimiters) 
  "Doublequotes punct at point if any. "
  (interactive "*p")
  (ar-th-slash 'punct no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-punct-atpt 'ar-punct-double-backslash-atpt)
;;;###autoload
(defun ar-punct-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around punct at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'punct no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-punct-atpt 'ar-punct-doubleslash-atpt)
;;;###autoload
(defun ar-punct-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around punct at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'punct no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-punct-atpt 'ar-punct-doubleslashparen-atpt)
;;;###autoload
(defun ar-punct-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around punct at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'punct no-delimiters (interactive-p)))

(defalias 'ar-slashparen-punct-atpt 'ar-punct-slashparen-atpt)
;;;###autoload
(defun ar-punct-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around punct at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'punct no-delimiters (interactive-p)))

(defalias 'ar-dollar-punct-atpt 'ar-punct-dollar-atpt)
;;;###autoload
(defun ar-punct-dollar-atpt (&optional no-delimiters) 
  "Doublequotes punct at point if any. "
  (interactive "*p")
  (ar-th-dollar 'punct no-delimiters (interactive-p)))

(defalias 'ar-equalize-punct-atpt 'ar-punct-equalize-atpt)
;;;###autoload
(defun ar-punct-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around punct at point if any. "
  (interactive "*p")
  (ar-th-equalize 'punct no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-punct-atpt 'ar-punct-greater-angle-atpt)
;;;###autoload
(defun ar-punct-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for punct after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'punct no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-punct-atpt 'ar-punct-lesser-angle-atpt)
;;;###autoload
(defun ar-punct-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for punct after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'punct no-delimiters (interactive-p)))

(defalias 'ar-backslash-punct-atpt 'ar-punct-backslash-atpt)
;;;###autoload
(defun ar-punct-backslash-atpt (&optional no-delimiters) 
  "Backslash punct at point if any. "
  (interactive "*p")
  (ar-th-backslash 'punct no-delimiters (interactive-p))) 

(defalias 'ar-brace-punct-atpt 'ar-punct-brace-atpt)
;;;###autoload
(defun ar-punct-brace-atpt (&optional no-delimiters) 
  "Braces punct at point if any. "
  (interactive "*p")
  (ar-th-brace 'punct no-delimiters (interactive-p)))

(defalias 'ar-bracket-punct-atpt 'ar-punct-bracket-atpt)
;;;###autoload
(defun ar-punct-bracket-atpt (&optional no-delimiters) 
  "Brackets punct after point if any. "
  (interactive "*p")
  (ar-th-bracket 'punct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-punct-atpt (&optional no-delimiters) 
  "Comments punct at point if any. "
  (interactive "*p")
  (ar-th-comment 'punct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-punct-atpt (&optional no-delimiters) 
  "Put a comma after punct at point if any. "
  (interactive "*p")
  (ar-th-commatize 'punct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-punct-atpt (&optional no-delimiters) 
  "Put a singlequote before punct at point if any. "
  (interactive "*p")
  (ar-th-quote 'punct no-delimiters (interactive-p)))

(defalias 'ar-hyphen-punct-atpt 'ar-punct-hyphen-atpt)
;;;###autoload
(defun ar-punct-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around punct at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'punct no-delimiters (interactive-p)))

(defalias 'ar-mark-punct-atpt 'ar-punct-mark-atpt)
;;;###autoload
(defun ar-punct-mark-atpt () 
  "Marks punct at point if any. "
  (interactive)
  (ar-th-mark 'punct))

(defalias 'ar-hide-punct-atpt 'ar-punct-hide-atpt)
;;;###autoload
(defun ar-punct-hide-atpt () 
  "Hides punct at point. "
  (interactive)
  (ar-th-hide 'punct))

(defalias 'ar-show-punct-atpt 'ar-punct-show-atpt)
;;;###autoload
(defun ar-punct-show-atpt () 
  "Shows hidden punct at point. "
  (interactive)
  (ar-th-show 'punct))

(defalias 'ar-hide-show-punct-atpt 'ar-punct-hide-show-atpt)
;;;###autoload
(defun ar-punct-hide-show-atpt () 
  "Alternatively hides or shows punct at point. "
  (interactive)
  (ar-th-hide-show 'punct))

(defalias 'ar-highlight-punct-atpt-mode 'ar-punct-highlight-atpt-mode)

(defun ar-punct-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles punct-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'punct no-delimiters (interactive-p)))

(defalias 'ar-kill-punct-atpt 'ar-punct-kill-atpt)
;;;###autoload
(defun ar-punct-kill-atpt (&optional no-delimiters) 
  "Kills punct at point if any. "
  (interactive "*P")
  (ar-th-kill 'punct no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-punct-atpt 'ar-punct-left-right-singlequote-atpt)
;;;###autoload
(defun ar-punct-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'punct no-delimiters (interactive-p)))

(defalias 'ar-parentize-punct-atpt 'ar-punct-parentize-atpt)
;;;###autoload
(defun ar-punct-parentize-atpt (&optional no-delimiters) 
  "Parentizes punct at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'punct no-delimiters (interactive-p)))

(defalias 'ar-separate-punct-atpt 'ar-punct-separate-atpt)
;;;###autoload
(defun ar-punct-separate-atpt (&optional no-delimiters) 
  "Separates punct at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'punct no-delimiters (interactive-p)))

(defalias 'ar-singlequote-punct-atpt 'ar-punct-singlequote-atpt)
;;;###autoload
(defun ar-punct-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes punct at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'punct no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-punct-atpt 'ar-punct-triplequote-dq-atpt)
;;;###autoload
(defun ar-punct-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around punct. "
  (interactive "*p")
  (ar-th-triplequote-dq 'punct no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-punct-atpt 'ar-punct-triplequote-sq-atpt)
;;;###autoload
(defun ar-punct-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around punct. "
  (interactive "*p")
  (ar-th-triplequote-sq 'punct no-delimiters (interactive-p)))

(defalias 'ar-trim-punct-atpt 'ar-punct-trim-atpt)
;;;###autoload
(defun ar-punct-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'punct t t)) 
    (ar-th-trim 'punct t t)))

(defalias 'ar-trim-left-punct-atpt 'ar-punct-left-trim-atpt)
;;;###autoload
(defun ar-punct-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'punct t nil))
    (ar-th-trim 'punct t nil)))

(defalias 'ar-trim-right-punct-atpt 'ar-punct-right-trim-atpt)
;;;###autoload
(defun ar-punct-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'punct nil t))
    (ar-th-trim 'punct nil t)))

(defalias 'ar-punct-underscore-atpt 'ar-underscore-punct-atpt)
;;;###autoload
(defun ar-underscore-punct-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'punct no-delimiters (interactive-p)))

(defalias 'ar-punct-whitespace-atpt 'ar-whitespace-punct-atpt)
;;;###autoload
(defun ar-whitespace-punct-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'punct nil t))

(defalias 'ar-forward-punct-atpt 'ar-punct-forward-atpt)
;;;###autoload
(defun ar-punct-forward-atpt (&optional arg) 
  "Moves forward over punct at point if any, does nothing otherwise.
Returns end position of punct "
  (interactive "p")
  (ar-th-forward 'punct arg (interactive-p)))

(defalias 'ar-backward-punct-atpt 'ar-punct-backward-atpt)
;;;###autoload
(defun ar-punct-backward-atpt (&optional arg) 
  "Moves backward over punct before point if any, does nothing otherwise.
Returns beginning position of punct "
  (interactive "p")
  (ar-th-backward 'punct arg (interactive-p)))

(defalias 'ar-transpose-punct-atpt 'ar-punct-transpose-atpt)
;;;###autoload
(defun ar-punct-transpose-atpt (&optional arg) 
  "Transposes punct with punct before point if any. "
  (interactive "*p")
  (ar-th-transpose 'punct arg (interactive-p)))

(defalias 'ar-sort-punct-atpt 'ar-punct-sort-atpt)
;;;###autoload
(defun ar-punct-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts puncts in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'punct reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-punct-atpt 'ar-punct-check-atpt)
;;;###autoload
(defun ar-punct-check-atpt () 
  "Return t if a punct at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-punct-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-punct-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-space-atpt (&optional arg no-delimiters) 
  "Returns space at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'space arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-space-atpt 'ar-space-bounds-atpt)
;;;###autoload
(defun ar-space-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of space if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'space no-delimiters (interactive-p)))

;;;###autoload
(defun ar-space-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position space at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'space no-delimiters (interactive-p)))

;;;###autoload
(defun ar-space-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of space at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'space no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-space-atpt 'ar-space-beginning-atpt)
;;;###autoload
(defun ar-space-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class space at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'space no-delimiters (interactive-p)))

(defalias 'ar-end-of-space-atpt 'ar-space-end-atpt)
;;;###autoload
(defun ar-space-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class space at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'space no-delimiters (interactive-p)))

(defalias 'ar-in-space-p-atpt 'ar-space-in-p-atpt)
;;;###autoload
(defun ar-space-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of space at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'space no-delimiters (interactive-p)))

(defalias 'ar-length-of-space-atpt 'ar-space-length-atpt)
;;;###autoload
(defun ar-space-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class space at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'space no-delimiters (interactive-p)))

(defalias 'ar-copy-space-atpt 'ar-space-copy-atpt)
;;;###autoload
(defun ar-space-copy-atpt (&optional no-delimiters) 
  "Returns a copy of space at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'space no-delimiters (interactive-p)))

(defalias 'ar-delete-space-in-region 'ar-space-delete-in-region)
;;;###autoload
(defun ar-space-delete-in-region (beg end) 
  "Deletes space at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'space beg end (interactive-p)))

;;;###autoload
(defun ar-blok-space-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around space.
  Returns blok or nil if no space at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'space no-delimiters (interactive-p)))

(defalias 'ar-escape-space-atpt 'ar-space-escape-atpt)
;;;###autoload
(defun ar-space-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted space at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'space no-delimiters))

(defalias 'ar-doublequote-space-atpt 'ar-space-doublequote-atpt)
;;;###autoload
(defun ar-space-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes space at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'space no-delimiters (interactive-p)))

(defalias 'ar-slash-space-atpt 'ar-space-slash-atpt)
;;;###autoload
(defun ar-space-slash-atpt (&optional no-delimiters) 
  "Doublequotes space at point if any. "
  (interactive "*p")
  (ar-th-slash 'space no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-space-atpt 'ar-space-double-backslash-atpt)
;;;###autoload
(defun ar-space-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around space at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'space no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-space-atpt 'ar-space-doubleslash-atpt)
;;;###autoload
(defun ar-space-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around space at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'space no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-space-atpt 'ar-space-doubleslashparen-atpt)
;;;###autoload
(defun ar-space-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around space at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'space no-delimiters (interactive-p)))

(defalias 'ar-slashparen-space-atpt 'ar-space-slashparen-atpt)
;;;###autoload
(defun ar-space-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around space at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'space no-delimiters (interactive-p)))

(defalias 'ar-dollar-space-atpt 'ar-space-dollar-atpt)
;;;###autoload
(defun ar-space-dollar-atpt (&optional no-delimiters) 
  "Doublequotes space at point if any. "
  (interactive "*p")
  (ar-th-dollar 'space no-delimiters (interactive-p)))

(defalias 'ar-equalize-space-atpt 'ar-space-equalize-atpt)
;;;###autoload
(defun ar-space-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around space at point if any. "
  (interactive "*p")
  (ar-th-equalize 'space no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-space-atpt 'ar-space-greater-angle-atpt)
;;;###autoload
(defun ar-space-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for space after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'space no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-space-atpt 'ar-space-lesser-angle-atpt)
;;;###autoload
(defun ar-space-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for space after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'space no-delimiters (interactive-p)))

(defalias 'ar-backslash-space-atpt 'ar-space-backslash-atpt)
;;;###autoload
(defun ar-space-backslash-atpt (&optional no-delimiters) 
  "Backslash space at point if any. "
  (interactive "*p")
  (ar-th-backslash 'space no-delimiters (interactive-p))) 

(defalias 'ar-brace-space-atpt 'ar-space-brace-atpt)
;;;###autoload
(defun ar-space-brace-atpt (&optional no-delimiters) 
  "Braces space at point if any. "
  (interactive "*p")
  (ar-th-brace 'space no-delimiters (interactive-p)))

(defalias 'ar-bracket-space-atpt 'ar-space-bracket-atpt)
;;;###autoload
(defun ar-space-bracket-atpt (&optional no-delimiters) 
  "Brackets space after point if any. "
  (interactive "*p")
  (ar-th-bracket 'space no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-space-atpt (&optional no-delimiters) 
  "Comments space at point if any. "
  (interactive "*p")
  (ar-th-comment 'space no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-space-atpt (&optional no-delimiters) 
  "Put a comma after space at point if any. "
  (interactive "*p")
  (ar-th-commatize 'space no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-space-atpt (&optional no-delimiters) 
  "Put a singlequote before space at point if any. "
  (interactive "*p")
  (ar-th-quote 'space no-delimiters (interactive-p)))

(defalias 'ar-hyphen-space-atpt 'ar-space-hyphen-atpt)
;;;###autoload
(defun ar-space-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around space at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'space no-delimiters (interactive-p)))

(defalias 'ar-mark-space-atpt 'ar-space-mark-atpt)
;;;###autoload
(defun ar-space-mark-atpt () 
  "Marks space at point if any. "
  (interactive)
  (ar-th-mark 'space))

(defalias 'ar-hide-space-atpt 'ar-space-hide-atpt)
;;;###autoload
(defun ar-space-hide-atpt () 
  "Hides space at point. "
  (interactive)
  (ar-th-hide 'space))

(defalias 'ar-show-space-atpt 'ar-space-show-atpt)
;;;###autoload
(defun ar-space-show-atpt () 
  "Shows hidden space at point. "
  (interactive)
  (ar-th-show 'space))

(defalias 'ar-hide-show-space-atpt 'ar-space-hide-show-atpt)
;;;###autoload
(defun ar-space-hide-show-atpt () 
  "Alternatively hides or shows space at point. "
  (interactive)
  (ar-th-hide-show 'space))

(defalias 'ar-highlight-space-atpt-mode 'ar-space-highlight-atpt-mode)

(defun ar-space-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles space-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'space no-delimiters (interactive-p)))

(defalias 'ar-kill-space-atpt 'ar-space-kill-atpt)
;;;###autoload
(defun ar-space-kill-atpt (&optional no-delimiters) 
  "Kills space at point if any. "
  (interactive "*P")
  (ar-th-kill 'space no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-space-atpt 'ar-space-left-right-singlequote-atpt)
;;;###autoload
(defun ar-space-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'space no-delimiters (interactive-p)))

(defalias 'ar-parentize-space-atpt 'ar-space-parentize-atpt)
;;;###autoload
(defun ar-space-parentize-atpt (&optional no-delimiters) 
  "Parentizes space at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'space no-delimiters (interactive-p)))

(defalias 'ar-separate-space-atpt 'ar-space-separate-atpt)
;;;###autoload
(defun ar-space-separate-atpt (&optional no-delimiters) 
  "Separates space at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'space no-delimiters (interactive-p)))

(defalias 'ar-singlequote-space-atpt 'ar-space-singlequote-atpt)
;;;###autoload
(defun ar-space-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes space at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'space no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-space-atpt 'ar-space-triplequote-dq-atpt)
;;;###autoload
(defun ar-space-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around space. "
  (interactive "*p")
  (ar-th-triplequote-dq 'space no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-space-atpt 'ar-space-triplequote-sq-atpt)
;;;###autoload
(defun ar-space-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around space. "
  (interactive "*p")
  (ar-th-triplequote-sq 'space no-delimiters (interactive-p)))

(defalias 'ar-trim-space-atpt 'ar-space-trim-atpt)
;;;###autoload
(defun ar-space-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'space t t)) 
    (ar-th-trim 'space t t)))

(defalias 'ar-trim-left-space-atpt 'ar-space-left-trim-atpt)
;;;###autoload
(defun ar-space-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'space t nil))
    (ar-th-trim 'space t nil)))

(defalias 'ar-trim-right-space-atpt 'ar-space-right-trim-atpt)
;;;###autoload
(defun ar-space-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'space nil t))
    (ar-th-trim 'space nil t)))

(defalias 'ar-space-underscore-atpt 'ar-underscore-space-atpt)
;;;###autoload
(defun ar-underscore-space-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'space no-delimiters (interactive-p)))

(defalias 'ar-space-whitespace-atpt 'ar-whitespace-space-atpt)
;;;###autoload
(defun ar-whitespace-space-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'space nil t))

(defalias 'ar-forward-space-atpt 'ar-space-forward-atpt)
;;;###autoload
(defun ar-space-forward-atpt (&optional arg) 
  "Moves forward over space at point if any, does nothing otherwise.
Returns end position of space "
  (interactive "p")
  (ar-th-forward 'space arg (interactive-p)))

(defalias 'ar-backward-space-atpt 'ar-space-backward-atpt)
;;;###autoload
(defun ar-space-backward-atpt (&optional arg) 
  "Moves backward over space before point if any, does nothing otherwise.
Returns beginning position of space "
  (interactive "p")
  (ar-th-backward 'space arg (interactive-p)))

(defalias 'ar-transpose-space-atpt 'ar-space-transpose-atpt)
;;;###autoload
(defun ar-space-transpose-atpt (&optional arg) 
  "Transposes space with space before point if any. "
  (interactive "*p")
  (ar-th-transpose 'space arg (interactive-p)))

(defalias 'ar-sort-space-atpt 'ar-space-sort-atpt)
;;;###autoload
(defun ar-space-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts spaces in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'space reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-space-atpt 'ar-space-check-atpt)
;;;###autoload
(defun ar-space-check-atpt () 
  "Return t if a space at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-space-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-space-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-upper-atpt (&optional arg no-delimiters) 
  "Returns upper at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'upper arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-upper-atpt 'ar-upper-bounds-atpt)
;;;###autoload
(defun ar-upper-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of upper if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'upper no-delimiters (interactive-p)))

;;;###autoload
(defun ar-upper-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position upper at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'upper no-delimiters (interactive-p)))

;;;###autoload
(defun ar-upper-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of upper at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'upper no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-upper-atpt 'ar-upper-beginning-atpt)
;;;###autoload
(defun ar-upper-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class upper at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'upper no-delimiters (interactive-p)))

(defalias 'ar-end-of-upper-atpt 'ar-upper-end-atpt)
;;;###autoload
(defun ar-upper-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class upper at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'upper no-delimiters (interactive-p)))

(defalias 'ar-in-upper-p-atpt 'ar-upper-in-p-atpt)
;;;###autoload
(defun ar-upper-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of upper at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'upper no-delimiters (interactive-p)))

(defalias 'ar-length-of-upper-atpt 'ar-upper-length-atpt)
;;;###autoload
(defun ar-upper-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class upper at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'upper no-delimiters (interactive-p)))

(defalias 'ar-copy-upper-atpt 'ar-upper-copy-atpt)
;;;###autoload
(defun ar-upper-copy-atpt (&optional no-delimiters) 
  "Returns a copy of upper at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'upper no-delimiters (interactive-p)))

(defalias 'ar-delete-upper-in-region 'ar-upper-delete-in-region)
;;;###autoload
(defun ar-upper-delete-in-region (beg end) 
  "Deletes upper at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'upper beg end (interactive-p)))

;;;###autoload
(defun ar-blok-upper-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around upper.
  Returns blok or nil if no upper at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'upper no-delimiters (interactive-p)))

(defalias 'ar-escape-upper-atpt 'ar-upper-escape-atpt)
;;;###autoload
(defun ar-upper-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted upper at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'upper no-delimiters))

(defalias 'ar-doublequote-upper-atpt 'ar-upper-doublequote-atpt)
;;;###autoload
(defun ar-upper-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes upper at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'upper no-delimiters (interactive-p)))

(defalias 'ar-slash-upper-atpt 'ar-upper-slash-atpt)
;;;###autoload
(defun ar-upper-slash-atpt (&optional no-delimiters) 
  "Doublequotes upper at point if any. "
  (interactive "*p")
  (ar-th-slash 'upper no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-upper-atpt 'ar-upper-double-backslash-atpt)
;;;###autoload
(defun ar-upper-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around upper at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'upper no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-upper-atpt 'ar-upper-doubleslash-atpt)
;;;###autoload
(defun ar-upper-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around upper at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'upper no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-upper-atpt 'ar-upper-doubleslashparen-atpt)
;;;###autoload
(defun ar-upper-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around upper at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'upper no-delimiters (interactive-p)))

(defalias 'ar-slashparen-upper-atpt 'ar-upper-slashparen-atpt)
;;;###autoload
(defun ar-upper-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around upper at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'upper no-delimiters (interactive-p)))

(defalias 'ar-dollar-upper-atpt 'ar-upper-dollar-atpt)
;;;###autoload
(defun ar-upper-dollar-atpt (&optional no-delimiters) 
  "Doublequotes upper at point if any. "
  (interactive "*p")
  (ar-th-dollar 'upper no-delimiters (interactive-p)))

(defalias 'ar-equalize-upper-atpt 'ar-upper-equalize-atpt)
;;;###autoload
(defun ar-upper-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around upper at point if any. "
  (interactive "*p")
  (ar-th-equalize 'upper no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-upper-atpt 'ar-upper-greater-angle-atpt)
;;;###autoload
(defun ar-upper-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for upper after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'upper no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-upper-atpt 'ar-upper-lesser-angle-atpt)
;;;###autoload
(defun ar-upper-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for upper after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'upper no-delimiters (interactive-p)))

(defalias 'ar-backslash-upper-atpt 'ar-upper-backslash-atpt)
;;;###autoload
(defun ar-upper-backslash-atpt (&optional no-delimiters) 
  "Backslash upper at point if any. "
  (interactive "*p")
  (ar-th-backslash 'upper no-delimiters (interactive-p))) 

(defalias 'ar-brace-upper-atpt 'ar-upper-brace-atpt)
;;;###autoload
(defun ar-upper-brace-atpt (&optional no-delimiters) 
  "Braces upper at point if any. "
  (interactive "*p")
  (ar-th-brace 'upper no-delimiters (interactive-p)))

(defalias 'ar-bracket-upper-atpt 'ar-upper-bracket-atpt)
;;;###autoload
(defun ar-upper-bracket-atpt (&optional no-delimiters) 
  "Brackets upper after point if any. "
  (interactive "*p")
  (ar-th-bracket 'upper no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-upper-atpt (&optional no-delimiters) 
  "Comments upper at point if any. "
  (interactive "*p")
  (ar-th-comment 'upper no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-upper-atpt (&optional no-delimiters) 
  "Put a comma after upper at point if any. "
  (interactive "*p")
  (ar-th-commatize 'upper no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-upper-atpt (&optional no-delimiters) 
  "Put a singlequote before upper at point if any. "
  (interactive "*p")
  (ar-th-quote 'upper no-delimiters (interactive-p)))

(defalias 'ar-hyphen-upper-atpt 'ar-upper-hyphen-atpt)
;;;###autoload
(defun ar-upper-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around upper at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'upper no-delimiters (interactive-p)))

(defalias 'ar-mark-upper-atpt 'ar-upper-mark-atpt)
;;;###autoload
(defun ar-upper-mark-atpt () 
  "Marks upper at point if any. "
  (interactive)
  (ar-th-mark 'upper))

(defalias 'ar-hide-upper-atpt 'ar-upper-hide-atpt)
;;;###autoload
(defun ar-upper-hide-atpt () 
  "Hides upper at point. "
  (interactive)
  (ar-th-hide 'upper))

(defalias 'ar-show-upper-atpt 'ar-upper-show-atpt)
;;;###autoload
(defun ar-upper-show-atpt () 
  "Shows hidden upper at point. "
  (interactive)
  (ar-th-show 'upper))

(defalias 'ar-hide-show-upper-atpt 'ar-upper-hide-show-atpt)
;;;###autoload
(defun ar-upper-hide-show-atpt () 
  "Alternatively hides or shows upper at point. "
  (interactive)
  (ar-th-hide-show 'upper))

(defalias 'ar-highlight-upper-atpt-mode 'ar-upper-highlight-atpt-mode)

(defun ar-upper-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles upper-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'upper no-delimiters (interactive-p)))

(defalias 'ar-kill-upper-atpt 'ar-upper-kill-atpt)
;;;###autoload
(defun ar-upper-kill-atpt (&optional no-delimiters) 
  "Kills upper at point if any. "
  (interactive "*P")
  (ar-th-kill 'upper no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-upper-atpt 'ar-upper-left-right-singlequote-atpt)
;;;###autoload
(defun ar-upper-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'upper no-delimiters (interactive-p)))

(defalias 'ar-parentize-upper-atpt 'ar-upper-parentize-atpt)
;;;###autoload
(defun ar-upper-parentize-atpt (&optional no-delimiters) 
  "Parentizes upper at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'upper no-delimiters (interactive-p)))

(defalias 'ar-separate-upper-atpt 'ar-upper-separate-atpt)
;;;###autoload
(defun ar-upper-separate-atpt (&optional no-delimiters) 
  "Separates upper at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'upper no-delimiters (interactive-p)))

(defalias 'ar-singlequote-upper-atpt 'ar-upper-singlequote-atpt)
;;;###autoload
(defun ar-upper-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes upper at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'upper no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-upper-atpt 'ar-upper-triplequote-dq-atpt)
;;;###autoload
(defun ar-upper-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around upper. "
  (interactive "*p")
  (ar-th-triplequote-dq 'upper no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-upper-atpt 'ar-upper-triplequote-sq-atpt)
;;;###autoload
(defun ar-upper-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around upper. "
  (interactive "*p")
  (ar-th-triplequote-sq 'upper no-delimiters (interactive-p)))

(defalias 'ar-trim-upper-atpt 'ar-upper-trim-atpt)
;;;###autoload
(defun ar-upper-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'upper t t)) 
    (ar-th-trim 'upper t t)))

(defalias 'ar-trim-left-upper-atpt 'ar-upper-left-trim-atpt)
;;;###autoload
(defun ar-upper-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'upper t nil))
    (ar-th-trim 'upper t nil)))

(defalias 'ar-trim-right-upper-atpt 'ar-upper-right-trim-atpt)
;;;###autoload
(defun ar-upper-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'upper nil t))
    (ar-th-trim 'upper nil t)))

(defalias 'ar-upper-underscore-atpt 'ar-underscore-upper-atpt)
;;;###autoload
(defun ar-underscore-upper-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'upper no-delimiters (interactive-p)))

(defalias 'ar-upper-whitespace-atpt 'ar-whitespace-upper-atpt)
;;;###autoload
(defun ar-whitespace-upper-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'upper nil t))

(defalias 'ar-forward-upper-atpt 'ar-upper-forward-atpt)
;;;###autoload
(defun ar-upper-forward-atpt (&optional arg) 
  "Moves forward over upper at point if any, does nothing otherwise.
Returns end position of upper "
  (interactive "p")
  (ar-th-forward 'upper arg (interactive-p)))

(defalias 'ar-backward-upper-atpt 'ar-upper-backward-atpt)
;;;###autoload
(defun ar-upper-backward-atpt (&optional arg) 
  "Moves backward over upper before point if any, does nothing otherwise.
Returns beginning position of upper "
  (interactive "p")
  (ar-th-backward 'upper arg (interactive-p)))

(defalias 'ar-transpose-upper-atpt 'ar-upper-transpose-atpt)
;;;###autoload
(defun ar-upper-transpose-atpt (&optional arg) 
  "Transposes upper with upper before point if any. "
  (interactive "*p")
  (ar-th-transpose 'upper arg (interactive-p)))

(defalias 'ar-sort-upper-atpt 'ar-upper-sort-atpt)
;;;###autoload
(defun ar-upper-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts uppers in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'upper reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-upper-atpt 'ar-upper-check-atpt)
;;;###autoload
(defun ar-upper-check-atpt () 
  "Return t if a upper at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-upper-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-upper-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-xdigit-atpt (&optional arg no-delimiters) 
  "Returns xdigit at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'xdigit arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-xdigit-atpt 'ar-xdigit-bounds-atpt)
;;;###autoload
(defun ar-xdigit-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of xdigit if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'xdigit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-xdigit-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position xdigit at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'xdigit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-xdigit-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of xdigit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-xdigit-atpt 'ar-xdigit-beginning-atpt)
;;;###autoload
(defun ar-xdigit-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class xdigit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-end-of-xdigit-atpt 'ar-xdigit-end-atpt)
;;;###autoload
(defun ar-xdigit-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class xdigit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-in-xdigit-p-atpt 'ar-xdigit-in-p-atpt)
;;;###autoload
(defun ar-xdigit-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of xdigit at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-length-of-xdigit-atpt 'ar-xdigit-length-atpt)
;;;###autoload
(defun ar-xdigit-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class xdigit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-copy-xdigit-atpt 'ar-xdigit-copy-atpt)
;;;###autoload
(defun ar-xdigit-copy-atpt (&optional no-delimiters) 
  "Returns a copy of xdigit at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-delete-xdigit-in-region 'ar-xdigit-delete-in-region)
;;;###autoload
(defun ar-xdigit-delete-in-region (beg end) 
  "Deletes xdigit at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'xdigit beg end (interactive-p)))

;;;###autoload
(defun ar-blok-xdigit-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around xdigit.
  Returns blok or nil if no xdigit at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-escape-xdigit-atpt 'ar-xdigit-escape-atpt)
;;;###autoload
(defun ar-xdigit-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted xdigit at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'xdigit no-delimiters))

(defalias 'ar-doublequote-xdigit-atpt 'ar-xdigit-doublequote-atpt)
;;;###autoload
(defun ar-xdigit-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes xdigit at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-slash-xdigit-atpt 'ar-xdigit-slash-atpt)
;;;###autoload
(defun ar-xdigit-slash-atpt (&optional no-delimiters) 
  "Doublequotes xdigit at point if any. "
  (interactive "*p")
  (ar-th-slash 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-xdigit-atpt 'ar-xdigit-double-backslash-atpt)
;;;###autoload
(defun ar-xdigit-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around xdigit at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-xdigit-atpt 'ar-xdigit-doubleslash-atpt)
;;;###autoload
(defun ar-xdigit-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around xdigit at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-xdigit-atpt 'ar-xdigit-doubleslashparen-atpt)
;;;###autoload
(defun ar-xdigit-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around xdigit at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-slashparen-xdigit-atpt 'ar-xdigit-slashparen-atpt)
;;;###autoload
(defun ar-xdigit-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around xdigit at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-dollar-xdigit-atpt 'ar-xdigit-dollar-atpt)
;;;###autoload
(defun ar-xdigit-dollar-atpt (&optional no-delimiters) 
  "Doublequotes xdigit at point if any. "
  (interactive "*p")
  (ar-th-dollar 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-equalize-xdigit-atpt 'ar-xdigit-equalize-atpt)
;;;###autoload
(defun ar-xdigit-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around xdigit at point if any. "
  (interactive "*p")
  (ar-th-equalize 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-xdigit-atpt 'ar-xdigit-greater-angle-atpt)
;;;###autoload
(defun ar-xdigit-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for xdigit after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-xdigit-atpt 'ar-xdigit-lesser-angle-atpt)
;;;###autoload
(defun ar-xdigit-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for xdigit after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-backslash-xdigit-atpt 'ar-xdigit-backslash-atpt)
;;;###autoload
(defun ar-xdigit-backslash-atpt (&optional no-delimiters) 
  "Backslash xdigit at point if any. "
  (interactive "*p")
  (ar-th-backslash 'xdigit no-delimiters (interactive-p))) 

(defalias 'ar-brace-xdigit-atpt 'ar-xdigit-brace-atpt)
;;;###autoload
(defun ar-xdigit-brace-atpt (&optional no-delimiters) 
  "Braces xdigit at point if any. "
  (interactive "*p")
  (ar-th-brace 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-bracket-xdigit-atpt 'ar-xdigit-bracket-atpt)
;;;###autoload
(defun ar-xdigit-bracket-atpt (&optional no-delimiters) 
  "Brackets xdigit after point if any. "
  (interactive "*p")
  (ar-th-bracket 'xdigit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-xdigit-atpt (&optional no-delimiters) 
  "Comments xdigit at point if any. "
  (interactive "*p")
  (ar-th-comment 'xdigit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-xdigit-atpt (&optional no-delimiters) 
  "Put a comma after xdigit at point if any. "
  (interactive "*p")
  (ar-th-commatize 'xdigit no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-xdigit-atpt (&optional no-delimiters) 
  "Put a singlequote before xdigit at point if any. "
  (interactive "*p")
  (ar-th-quote 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-hyphen-xdigit-atpt 'ar-xdigit-hyphen-atpt)
;;;###autoload
(defun ar-xdigit-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around xdigit at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-mark-xdigit-atpt 'ar-xdigit-mark-atpt)
;;;###autoload
(defun ar-xdigit-mark-atpt () 
  "Marks xdigit at point if any. "
  (interactive)
  (ar-th-mark 'xdigit))

(defalias 'ar-hide-xdigit-atpt 'ar-xdigit-hide-atpt)
;;;###autoload
(defun ar-xdigit-hide-atpt () 
  "Hides xdigit at point. "
  (interactive)
  (ar-th-hide 'xdigit))

(defalias 'ar-show-xdigit-atpt 'ar-xdigit-show-atpt)
;;;###autoload
(defun ar-xdigit-show-atpt () 
  "Shows hidden xdigit at point. "
  (interactive)
  (ar-th-show 'xdigit))

(defalias 'ar-hide-show-xdigit-atpt 'ar-xdigit-hide-show-atpt)
;;;###autoload
(defun ar-xdigit-hide-show-atpt () 
  "Alternatively hides or shows xdigit at point. "
  (interactive)
  (ar-th-hide-show 'xdigit))

(defalias 'ar-highlight-xdigit-atpt-mode 'ar-xdigit-highlight-atpt-mode)

(defun ar-xdigit-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles xdigit-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-kill-xdigit-atpt 'ar-xdigit-kill-atpt)
;;;###autoload
(defun ar-xdigit-kill-atpt (&optional no-delimiters) 
  "Kills xdigit at point if any. "
  (interactive "*P")
  (ar-th-kill 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-xdigit-atpt 'ar-xdigit-left-right-singlequote-atpt)
;;;###autoload
(defun ar-xdigit-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-parentize-xdigit-atpt 'ar-xdigit-parentize-atpt)
;;;###autoload
(defun ar-xdigit-parentize-atpt (&optional no-delimiters) 
  "Parentizes xdigit at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-separate-xdigit-atpt 'ar-xdigit-separate-atpt)
;;;###autoload
(defun ar-xdigit-separate-atpt (&optional no-delimiters) 
  "Separates xdigit at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-singlequote-xdigit-atpt 'ar-xdigit-singlequote-atpt)
;;;###autoload
(defun ar-xdigit-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes xdigit at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-xdigit-atpt 'ar-xdigit-triplequote-dq-atpt)
;;;###autoload
(defun ar-xdigit-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around xdigit. "
  (interactive "*p")
  (ar-th-triplequote-dq 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-xdigit-atpt 'ar-xdigit-triplequote-sq-atpt)
;;;###autoload
(defun ar-xdigit-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around xdigit. "
  (interactive "*p")
  (ar-th-triplequote-sq 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-trim-xdigit-atpt 'ar-xdigit-trim-atpt)
;;;###autoload
(defun ar-xdigit-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'xdigit t t)) 
    (ar-th-trim 'xdigit t t)))

(defalias 'ar-trim-left-xdigit-atpt 'ar-xdigit-left-trim-atpt)
;;;###autoload
(defun ar-xdigit-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'xdigit t nil))
    (ar-th-trim 'xdigit t nil)))

(defalias 'ar-trim-right-xdigit-atpt 'ar-xdigit-right-trim-atpt)
;;;###autoload
(defun ar-xdigit-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'xdigit nil t))
    (ar-th-trim 'xdigit nil t)))

(defalias 'ar-xdigit-underscore-atpt 'ar-underscore-xdigit-atpt)
;;;###autoload
(defun ar-underscore-xdigit-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'xdigit no-delimiters (interactive-p)))

(defalias 'ar-xdigit-whitespace-atpt 'ar-whitespace-xdigit-atpt)
;;;###autoload
(defun ar-whitespace-xdigit-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'xdigit nil t))

(defalias 'ar-forward-xdigit-atpt 'ar-xdigit-forward-atpt)
;;;###autoload
(defun ar-xdigit-forward-atpt (&optional arg) 
  "Moves forward over xdigit at point if any, does nothing otherwise.
Returns end position of xdigit "
  (interactive "p")
  (ar-th-forward 'xdigit arg (interactive-p)))

(defalias 'ar-backward-xdigit-atpt 'ar-xdigit-backward-atpt)
;;;###autoload
(defun ar-xdigit-backward-atpt (&optional arg) 
  "Moves backward over xdigit before point if any, does nothing otherwise.
Returns beginning position of xdigit "
  (interactive "p")
  (ar-th-backward 'xdigit arg (interactive-p)))

(defalias 'ar-transpose-xdigit-atpt 'ar-xdigit-transpose-atpt)
;;;###autoload
(defun ar-xdigit-transpose-atpt (&optional arg) 
  "Transposes xdigit with xdigit before point if any. "
  (interactive "*p")
  (ar-th-transpose 'xdigit arg (interactive-p)))

(defalias 'ar-sort-xdigit-atpt 'ar-xdigit-sort-atpt)
;;;###autoload
(defun ar-xdigit-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts xdigits in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'xdigit reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-xdigit-atpt 'ar-xdigit-check-atpt)
;;;###autoload
(defun ar-xdigit-check-atpt () 
  "Return t if a xdigit at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-xdigit-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-xdigit-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))
;; ar-thing-at-point-utils-core: ar-atpt-classes end

;; ar-thing-at-point-utils-delimited-in-anlegen: ar-atpt-unpaired-delimited-list-roh start

(defalias 'ar-in-backslashed-p-atpt 'ar-backslashed-in-p-atpt)
;;;###autoload
(defun ar-backslashed-in-p-atpt () 
  "Returns `t' if inside backslashed, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "\\" "\\")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-dollared-p-atpt 'ar-dollared-in-p-atpt)
;;;###autoload
(defun ar-dollared-in-p-atpt () 
  "Returns `t' if inside dollared, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "\\$" "\\$")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-doublequoted-p-atpt 'ar-doublequoted-in-p-atpt)
;;;###autoload
(defun ar-doublequoted-in-p-atpt () 
  "Returns `t' if inside doublequoted, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "\"" "\"")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-equalized-p-atpt 'ar-equalized-in-p-atpt)
;;;###autoload
(defun ar-equalized-in-p-atpt () 
  "Returns `t' if inside equalized, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "=" "=")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-hyphened-p-atpt 'ar-hyphened-in-p-atpt)
;;;###autoload
(defun ar-hyphened-in-p-atpt () 
  "Returns `t' if inside hyphened, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "-" "-")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-quoted-p-atpt 'ar-quoted-in-p-atpt)
;;;###autoload
(defun ar-quoted-in-p-atpt () 
  "Returns `t' if inside quoted, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "\"\\|'" "\"\\|'")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-singlequoted-p-atpt 'ar-singlequoted-in-p-atpt)
;;;###autoload
(defun ar-singlequoted-in-p-atpt () 
  "Returns `t' if inside singlequoted, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "'" "'")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-slashed-p-atpt 'ar-slashed-in-p-atpt)
;;;###autoload
(defun ar-slashed-in-p-atpt () 
  "Returns `t' if inside slashed, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "/" "/")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-triplequoted-p-atpt 'ar-triplequoted-in-p-atpt)
;;;###autoload
(defun ar-triplequoted-in-p-atpt () 
  "Returns `t' if inside triplequoted, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "[^\\]\"\"\"\\|\`\"\"\"\\|[^\\]'''\\|\`'''" "[^\\]\"\"\"\\|\`\"\"\"\\|[^\\]'''\\|\`'''")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-triplequoted-dq-p-atpt 'ar-triplequoted-dq-in-p-atpt)
;;;###autoload
(defun ar-triplequoted-dq-in-p-atpt () 
  "Returns `t' if inside triplequoted-dq, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "[^\\]\"\"\"\\|\`\"\"\"" "[^\\]\"\"\"\\|\`\"\"\"")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-triplequoted-sq-p-atpt 'ar-triplequoted-sq-in-p-atpt)
;;;###autoload
(defun ar-triplequoted-sq-in-p-atpt () 
  "Returns `t' if inside triplequoted-sq, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "[^\\]'''\\|\`'''" "[^\\]'''\\|\`'''")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-underscored-p-atpt 'ar-underscored-in-p-atpt)
;;;###autoload
(defun ar-underscored-in-p-atpt () 
  "Returns `t' if inside underscored, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base "_" "_")))))
    (when (interactive-p) (message "%s" erg))
    erg))

(defalias 'ar-in-whitespaced-p-atpt 'ar-whitespaced-in-p-atpt)
;;;###autoload
(defun ar-whitespaced-in-p-atpt () 
  "Returns `t' if inside whitespaced, nil otherwise. "
  (interactive)
  (let ((erg (ignore-errors (eq 1 (in-form-base " " " ")))))
    (when (interactive-p) (message "%s" erg))
    erg))

;; ar-thing-at-point-utils-delimited-in-anlegen: ar-atpt-unpaired-delimited-list-roh end

;; ar-thing-at-point-utils-delimited-intern: ar-atpt-unpaired-delimited-list-roh start

;;;###autoload
(defun ar-backslashed-atpt (&optional arg no-delimiters) 
  "Returns backslashed at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'backslashed arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-backslashed-atpt 'ar-backslashed-bounds-atpt)
;;;###autoload
(defun ar-backslashed-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of backslashed if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'backslashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-backslashed-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position backslashed at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'backslashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-backslashed-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of backslashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-backslashed-atpt 'ar-backslashed-beginning-atpt)
;;;###autoload
(defun ar-backslashed-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class backslashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-end-of-backslashed-atpt 'ar-backslashed-end-atpt)
;;;###autoload
(defun ar-backslashed-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class backslashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-length-of-backslashed-atpt 'ar-backslashed-length-atpt)
;;;###autoload
(defun ar-backslashed-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class backslashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-copy-backslashed-atpt 'ar-backslashed-copy-atpt)
;;;###autoload
(defun ar-backslashed-copy-atpt (&optional no-delimiters) 
  "Returns a copy of backslashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-delete-backslashed-in-region 'ar-backslashed-delete-in-region)
;;;###autoload
(defun ar-backslashed-delete-in-region (beg end) 
  "Deletes backslashed at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'backslashed beg end (interactive-p)))

;;;###autoload
(defun ar-blok-backslashed-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around backslashed.
  Returns blok or nil if no backslashed at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-escape-backslashed-atpt 'ar-backslashed-escape-atpt)
;;;###autoload
(defun ar-backslashed-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted backslashed at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'backslashed no-delimiters))

(defalias 'ar-doublequote-backslashed-atpt 'ar-backslashed-doublequote-atpt)
;;;###autoload
(defun ar-backslashed-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes backslashed at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-slash-backslashed-atpt 'ar-backslashed-slash-atpt)
;;;###autoload
(defun ar-backslashed-slash-atpt (&optional no-delimiters) 
  "Doublequotes backslashed at point if any. "
  (interactive "*p")
  (ar-th-slash 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-backslashed-atpt 'ar-backslashed-double-backslash-atpt)
;;;###autoload
(defun ar-backslashed-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around backslashed at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-backslashed-atpt 'ar-backslashed-doubleslash-atpt)
;;;###autoload
(defun ar-backslashed-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around backslashed at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-backslashed-atpt 'ar-backslashed-doubleslashparen-atpt)
;;;###autoload
(defun ar-backslashed-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around backslashed at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-slashparen-backslashed-atpt 'ar-backslashed-slashparen-atpt)
;;;###autoload
(defun ar-backslashed-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around backslashed at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-dollar-backslashed-atpt 'ar-backslashed-dollar-atpt)
;;;###autoload
(defun ar-backslashed-dollar-atpt (&optional no-delimiters) 
  "Doublequotes backslashed at point if any. "
  (interactive "*p")
  (ar-th-dollar 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-equalize-backslashed-atpt 'ar-backslashed-equalize-atpt)
;;;###autoload
(defun ar-backslashed-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around backslashed at point if any. "
  (interactive "*p")
  (ar-th-equalize 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-backslashed-atpt 'ar-backslashed-greater-angle-atpt)
;;;###autoload
(defun ar-backslashed-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for backslashed after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-backslashed-atpt 'ar-backslashed-lesser-angle-atpt)
;;;###autoload
(defun ar-backslashed-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for backslashed after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-backslash-backslashed-atpt 'ar-backslashed-backslash-atpt)
;;;###autoload
(defun ar-backslashed-backslash-atpt (&optional no-delimiters) 
  "Backslash backslashed at point if any. "
  (interactive "*p")
  (ar-th-backslash 'backslashed no-delimiters (interactive-p))) 

(defalias 'ar-brace-backslashed-atpt 'ar-backslashed-brace-atpt)
;;;###autoload
(defun ar-backslashed-brace-atpt (&optional no-delimiters) 
  "Braces backslashed at point if any. "
  (interactive "*p")
  (ar-th-brace 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-bracket-backslashed-atpt 'ar-backslashed-bracket-atpt)
;;;###autoload
(defun ar-backslashed-bracket-atpt (&optional no-delimiters) 
  "Brackets backslashed after point if any. "
  (interactive "*p")
  (ar-th-bracket 'backslashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-backslashed-atpt (&optional no-delimiters) 
  "Comments backslashed at point if any. "
  (interactive "*p")
  (ar-th-comment 'backslashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-backslashed-atpt (&optional no-delimiters) 
  "Put a comma after backslashed at point if any. "
  (interactive "*p")
  (ar-th-commatize 'backslashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-backslashed-atpt (&optional no-delimiters) 
  "Put a singlequote before backslashed at point if any. "
  (interactive "*p")
  (ar-th-quote 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-hyphen-backslashed-atpt 'ar-backslashed-hyphen-atpt)
;;;###autoload
(defun ar-backslashed-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around backslashed at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-mark-backslashed-atpt 'ar-backslashed-mark-atpt)
;;;###autoload
(defun ar-backslashed-mark-atpt () 
  "Marks backslashed at point if any. "
  (interactive)
  (ar-th-mark 'backslashed))

(defalias 'ar-hide-backslashed-atpt 'ar-backslashed-hide-atpt)
;;;###autoload
(defun ar-backslashed-hide-atpt () 
  "Hides backslashed at point. "
  (interactive)
  (ar-th-hide 'backslashed))

(defalias 'ar-show-backslashed-atpt 'ar-backslashed-show-atpt)
;;;###autoload
(defun ar-backslashed-show-atpt () 
  "Shows hidden backslashed at point. "
  (interactive)
  (ar-th-show 'backslashed))

(defalias 'ar-hide-show-backslashed-atpt 'ar-backslashed-hide-show-atpt)
;;;###autoload
(defun ar-backslashed-hide-show-atpt () 
  "Alternatively hides or shows backslashed at point. "
  (interactive)
  (ar-th-hide-show 'backslashed))

(defalias 'ar-highlight-backslashed-atpt-mode 'ar-backslashed-highlight-atpt-mode)
(defun ar-backslashed-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles backslashed-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-kill-backslashed-atpt 'ar-backslashed-kill-atpt)
;;;###autoload
(defun ar-backslashed-kill-atpt (&optional no-delimiters) 
  "Kills backslashed at point if any. "
  (interactive "*P")
  (ar-th-kill 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-backslashed-atpt 'ar-backslashed-left-right-singlequote-atpt)
;;;###autoload
(defun ar-backslashed-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-parentize-backslashed-atpt 'ar-backslashed-parentize-atpt)
;;;###autoload
(defun ar-backslashed-parentize-atpt (&optional no-delimiters) 
  "Parentizes backslashed at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-separate-backslashed-atpt 'ar-backslashed-separate-atpt)
;;;###autoload
(defun ar-backslashed-separate-atpt (&optional no-delimiters) 
  "Separates backslashed at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-singlequote-backslashed-atpt 'ar-backslashed-singlequote-atpt)
;;;###autoload
(defun ar-backslashed-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes backslashed at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-backslashed-atpt 'ar-backslashed-triplequote-dq-atpt)
;;;###autoload
(defun ar-backslashed-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around backslashed. "
  (interactive "*p")
  (ar-th-triplequote-dq 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-backslashed-atpt 'ar-backslashed-triplequote-sq-atpt)
;;;###autoload
(defun ar-backslashed-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around backslashed. "
  (interactive "*p")
  (ar-th-triplequote-sq 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-trim-backslashed-atpt 'ar-backslashed-trim-atpt)
;;;###autoload
(defun ar-backslashed-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'backslashed t t)) 
    (ar-th-trim 'backslashed t t)))

(defalias 'ar-trim-left-backslashed-atpt 'ar-backslashed-left-trim-atpt)
;;;###autoload
(defun ar-backslashed-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'backslashed t nil))
    (ar-th-trim 'backslashed t nil)))

(defalias 'ar-trim-right-backslashed-atpt 'ar-backslashed-right-trim-atpt)
;;;###autoload
(defun ar-backslashed-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'backslashed nil t))
    (ar-th-trim 'backslashed nil t)))

(defalias 'ar-backslashed-underscore-atpt 'ar-underscore-backslashed-atpt)
;;;###autoload
(defun ar-underscore-backslashed-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'backslashed no-delimiters (interactive-p)))

(defalias 'ar-backslashed-whitespace-atpt 'ar-whitespace-backslashed-atpt)
;;;###autoload
(defun ar-whitespace-backslashed-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'backslashed nil t))

(defalias 'ar-forward-backslashed-atpt 'ar-backslashed-forward-atpt)
;;;###autoload
(defun ar-backslashed-forward-atpt (&optional arg) 
  "Moves forward over backslashed at point if any, does nothing otherwise.
Returns end position of backslashed "
  (interactive "p")
  (ar-th-forward 'backslashed arg (interactive-p)))

(defalias 'ar-backward-backslashed-atpt 'ar-backslashed-backward-atpt)
;;;###autoload
(defun ar-backslashed-backward-atpt (&optional arg) 
  "Moves backward over backslashed before point if any, does nothing otherwise.
Returns beginning position of backslashed "
  (interactive "p")
  (ar-th-backward 'backslashed arg (interactive-p)))

(defalias 'ar-transpose-backslashed-atpt 'ar-backslashed-transpose-atpt)
;;;###autoload
(defun ar-backslashed-transpose-atpt (&optional arg) 
  "Transposes backslashed with backslashed before point if any. "
  (interactive "*p")
  (ar-th-transpose 'backslashed arg (interactive-p)))

(defalias 'ar-sort-backslashed-atpt 'ar-backslashed-sort-atpt)
;;;###autoload
(defun ar-backslashed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts backslasheds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'backslashed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-backslashed-atpt 'ar-backslashed-check-atpt)
;;;###autoload
(defun ar-backslashed-check-atpt () 
  "Return t if a backslashed at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-backslashed-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-backslashed-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-dollared-atpt (&optional arg no-delimiters) 
  "Returns dollared at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'dollared arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-dollared-atpt 'ar-dollared-bounds-atpt)
;;;###autoload
(defun ar-dollared-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of dollared if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'dollared no-delimiters (interactive-p)))

;;;###autoload
(defun ar-dollared-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position dollared at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'dollared no-delimiters (interactive-p)))

;;;###autoload
(defun ar-dollared-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of dollared at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'dollared no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-dollared-atpt 'ar-dollared-beginning-atpt)
;;;###autoload
(defun ar-dollared-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class dollared at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'dollared no-delimiters (interactive-p)))

(defalias 'ar-end-of-dollared-atpt 'ar-dollared-end-atpt)
;;;###autoload
(defun ar-dollared-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class dollared at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'dollared no-delimiters (interactive-p)))

(defalias 'ar-length-of-dollared-atpt 'ar-dollared-length-atpt)
;;;###autoload
(defun ar-dollared-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class dollared at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'dollared no-delimiters (interactive-p)))

(defalias 'ar-copy-dollared-atpt 'ar-dollared-copy-atpt)
;;;###autoload
(defun ar-dollared-copy-atpt (&optional no-delimiters) 
  "Returns a copy of dollared at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'dollared no-delimiters (interactive-p)))

(defalias 'ar-delete-dollared-in-region 'ar-dollared-delete-in-region)
;;;###autoload
(defun ar-dollared-delete-in-region (beg end) 
  "Deletes dollared at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'dollared beg end (interactive-p)))

;;;###autoload
(defun ar-blok-dollared-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around dollared.
  Returns blok or nil if no dollared at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'dollared no-delimiters (interactive-p)))

(defalias 'ar-escape-dollared-atpt 'ar-dollared-escape-atpt)
;;;###autoload
(defun ar-dollared-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted dollared at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'dollared no-delimiters))

(defalias 'ar-doublequote-dollared-atpt 'ar-dollared-doublequote-atpt)
;;;###autoload
(defun ar-dollared-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes dollared at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'dollared no-delimiters (interactive-p)))

(defalias 'ar-slash-dollared-atpt 'ar-dollared-slash-atpt)
;;;###autoload
(defun ar-dollared-slash-atpt (&optional no-delimiters) 
  "Doublequotes dollared at point if any. "
  (interactive "*p")
  (ar-th-slash 'dollared no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-dollared-atpt 'ar-dollared-double-backslash-atpt)
;;;###autoload
(defun ar-dollared-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around dollared at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'dollared no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-dollared-atpt 'ar-dollared-doubleslash-atpt)
;;;###autoload
(defun ar-dollared-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around dollared at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'dollared no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-dollared-atpt 'ar-dollared-doubleslashparen-atpt)
;;;###autoload
(defun ar-dollared-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around dollared at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'dollared no-delimiters (interactive-p)))

(defalias 'ar-slashparen-dollared-atpt 'ar-dollared-slashparen-atpt)
;;;###autoload
(defun ar-dollared-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around dollared at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'dollared no-delimiters (interactive-p)))

(defalias 'ar-dollar-dollared-atpt 'ar-dollared-dollar-atpt)
;;;###autoload
(defun ar-dollared-dollar-atpt (&optional no-delimiters) 
  "Doublequotes dollared at point if any. "
  (interactive "*p")
  (ar-th-dollar 'dollared no-delimiters (interactive-p)))

(defalias 'ar-equalize-dollared-atpt 'ar-dollared-equalize-atpt)
;;;###autoload
(defun ar-dollared-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around dollared at point if any. "
  (interactive "*p")
  (ar-th-equalize 'dollared no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-dollared-atpt 'ar-dollared-greater-angle-atpt)
;;;###autoload
(defun ar-dollared-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for dollared after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'dollared no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-dollared-atpt 'ar-dollared-lesser-angle-atpt)
;;;###autoload
(defun ar-dollared-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for dollared after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'dollared no-delimiters (interactive-p)))

(defalias 'ar-backslash-dollared-atpt 'ar-dollared-backslash-atpt)
;;;###autoload
(defun ar-dollared-backslash-atpt (&optional no-delimiters) 
  "Backslash dollared at point if any. "
  (interactive "*p")
  (ar-th-backslash 'dollared no-delimiters (interactive-p))) 

(defalias 'ar-brace-dollared-atpt 'ar-dollared-brace-atpt)
;;;###autoload
(defun ar-dollared-brace-atpt (&optional no-delimiters) 
  "Braces dollared at point if any. "
  (interactive "*p")
  (ar-th-brace 'dollared no-delimiters (interactive-p)))

(defalias 'ar-bracket-dollared-atpt 'ar-dollared-bracket-atpt)
;;;###autoload
(defun ar-dollared-bracket-atpt (&optional no-delimiters) 
  "Brackets dollared after point if any. "
  (interactive "*p")
  (ar-th-bracket 'dollared no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-dollared-atpt (&optional no-delimiters) 
  "Comments dollared at point if any. "
  (interactive "*p")
  (ar-th-comment 'dollared no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-dollared-atpt (&optional no-delimiters) 
  "Put a comma after dollared at point if any. "
  (interactive "*p")
  (ar-th-commatize 'dollared no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-dollared-atpt (&optional no-delimiters) 
  "Put a singlequote before dollared at point if any. "
  (interactive "*p")
  (ar-th-quote 'dollared no-delimiters (interactive-p)))

(defalias 'ar-hyphen-dollared-atpt 'ar-dollared-hyphen-atpt)
;;;###autoload
(defun ar-dollared-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around dollared at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'dollared no-delimiters (interactive-p)))

(defalias 'ar-mark-dollared-atpt 'ar-dollared-mark-atpt)
;;;###autoload
(defun ar-dollared-mark-atpt () 
  "Marks dollared at point if any. "
  (interactive)
  (ar-th-mark 'dollared))

(defalias 'ar-hide-dollared-atpt 'ar-dollared-hide-atpt)
;;;###autoload
(defun ar-dollared-hide-atpt () 
  "Hides dollared at point. "
  (interactive)
  (ar-th-hide 'dollared))

(defalias 'ar-show-dollared-atpt 'ar-dollared-show-atpt)
;;;###autoload
(defun ar-dollared-show-atpt () 
  "Shows hidden dollared at point. "
  (interactive)
  (ar-th-show 'dollared))

(defalias 'ar-hide-show-dollared-atpt 'ar-dollared-hide-show-atpt)
;;;###autoload
(defun ar-dollared-hide-show-atpt () 
  "Alternatively hides or shows dollared at point. "
  (interactive)
  (ar-th-hide-show 'dollared))

(defalias 'ar-highlight-dollared-atpt-mode 'ar-dollared-highlight-atpt-mode)
(defun ar-dollared-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles dollared-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'dollared no-delimiters (interactive-p)))

(defalias 'ar-kill-dollared-atpt 'ar-dollared-kill-atpt)
;;;###autoload
(defun ar-dollared-kill-atpt (&optional no-delimiters) 
  "Kills dollared at point if any. "
  (interactive "*P")
  (ar-th-kill 'dollared no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-dollared-atpt 'ar-dollared-left-right-singlequote-atpt)
;;;###autoload
(defun ar-dollared-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'dollared no-delimiters (interactive-p)))

(defalias 'ar-parentize-dollared-atpt 'ar-dollared-parentize-atpt)
;;;###autoload
(defun ar-dollared-parentize-atpt (&optional no-delimiters) 
  "Parentizes dollared at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'dollared no-delimiters (interactive-p)))

(defalias 'ar-separate-dollared-atpt 'ar-dollared-separate-atpt)
;;;###autoload
(defun ar-dollared-separate-atpt (&optional no-delimiters) 
  "Separates dollared at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'dollared no-delimiters (interactive-p)))

(defalias 'ar-singlequote-dollared-atpt 'ar-dollared-singlequote-atpt)
;;;###autoload
(defun ar-dollared-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes dollared at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'dollared no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-dollared-atpt 'ar-dollared-triplequote-dq-atpt)
;;;###autoload
(defun ar-dollared-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around dollared. "
  (interactive "*p")
  (ar-th-triplequote-dq 'dollared no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-dollared-atpt 'ar-dollared-triplequote-sq-atpt)
;;;###autoload
(defun ar-dollared-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around dollared. "
  (interactive "*p")
  (ar-th-triplequote-sq 'dollared no-delimiters (interactive-p)))

(defalias 'ar-trim-dollared-atpt 'ar-dollared-trim-atpt)
;;;###autoload
(defun ar-dollared-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'dollared t t)) 
    (ar-th-trim 'dollared t t)))

(defalias 'ar-trim-left-dollared-atpt 'ar-dollared-left-trim-atpt)
;;;###autoload
(defun ar-dollared-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'dollared t nil))
    (ar-th-trim 'dollared t nil)))

(defalias 'ar-trim-right-dollared-atpt 'ar-dollared-right-trim-atpt)
;;;###autoload
(defun ar-dollared-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'dollared nil t))
    (ar-th-trim 'dollared nil t)))

(defalias 'ar-dollared-underscore-atpt 'ar-underscore-dollared-atpt)
;;;###autoload
(defun ar-underscore-dollared-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'dollared no-delimiters (interactive-p)))

(defalias 'ar-dollared-whitespace-atpt 'ar-whitespace-dollared-atpt)
;;;###autoload
(defun ar-whitespace-dollared-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'dollared nil t))

(defalias 'ar-forward-dollared-atpt 'ar-dollared-forward-atpt)
;;;###autoload
(defun ar-dollared-forward-atpt (&optional arg) 
  "Moves forward over dollared at point if any, does nothing otherwise.
Returns end position of dollared "
  (interactive "p")
  (ar-th-forward 'dollared arg (interactive-p)))

(defalias 'ar-backward-dollared-atpt 'ar-dollared-backward-atpt)
;;;###autoload
(defun ar-dollared-backward-atpt (&optional arg) 
  "Moves backward over dollared before point if any, does nothing otherwise.
Returns beginning position of dollared "
  (interactive "p")
  (ar-th-backward 'dollared arg (interactive-p)))

(defalias 'ar-transpose-dollared-atpt 'ar-dollared-transpose-atpt)
;;;###autoload
(defun ar-dollared-transpose-atpt (&optional arg) 
  "Transposes dollared with dollared before point if any. "
  (interactive "*p")
  (ar-th-transpose 'dollared arg (interactive-p)))

(defalias 'ar-sort-dollared-atpt 'ar-dollared-sort-atpt)
;;;###autoload
(defun ar-dollared-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts dollareds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'dollared reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-dollared-atpt 'ar-dollared-check-atpt)
;;;###autoload
(defun ar-dollared-check-atpt () 
  "Return t if a dollared at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-dollared-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-dollared-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-doublequoted-atpt (&optional arg no-delimiters) 
  "Returns doublequoted at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'doublequoted arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-doublequoted-atpt 'ar-doublequoted-bounds-atpt)
;;;###autoload
(defun ar-doublequoted-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of doublequoted if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'doublequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-doublequoted-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position doublequoted at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'doublequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-doublequoted-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of doublequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-doublequoted-atpt 'ar-doublequoted-beginning-atpt)
;;;###autoload
(defun ar-doublequoted-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class doublequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-end-of-doublequoted-atpt 'ar-doublequoted-end-atpt)
;;;###autoload
(defun ar-doublequoted-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class doublequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-length-of-doublequoted-atpt 'ar-doublequoted-length-atpt)
;;;###autoload
(defun ar-doublequoted-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class doublequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-copy-doublequoted-atpt 'ar-doublequoted-copy-atpt)
;;;###autoload
(defun ar-doublequoted-copy-atpt (&optional no-delimiters) 
  "Returns a copy of doublequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-delete-doublequoted-in-region 'ar-doublequoted-delete-in-region)
;;;###autoload
(defun ar-doublequoted-delete-in-region (beg end) 
  "Deletes doublequoted at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'doublequoted beg end (interactive-p)))

;;;###autoload
(defun ar-blok-doublequoted-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around doublequoted.
  Returns blok or nil if no doublequoted at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-escape-doublequoted-atpt 'ar-doublequoted-escape-atpt)
;;;###autoload
(defun ar-doublequoted-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted doublequoted at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'doublequoted no-delimiters))

(defalias 'ar-doublequote-doublequoted-atpt 'ar-doublequoted-doublequote-atpt)
;;;###autoload
(defun ar-doublequoted-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes doublequoted at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-slash-doublequoted-atpt 'ar-doublequoted-slash-atpt)
;;;###autoload
(defun ar-doublequoted-slash-atpt (&optional no-delimiters) 
  "Doublequotes doublequoted at point if any. "
  (interactive "*p")
  (ar-th-slash 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-doublequoted-atpt 'ar-doublequoted-double-backslash-atpt)
;;;###autoload
(defun ar-doublequoted-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-doublequoted-atpt 'ar-doublequoted-doubleslash-atpt)
;;;###autoload
(defun ar-doublequoted-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-doublequoted-atpt 'ar-doublequoted-doubleslashparen-atpt)
;;;###autoload
(defun ar-doublequoted-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-slashparen-doublequoted-atpt 'ar-doublequoted-slashparen-atpt)
;;;###autoload
(defun ar-doublequoted-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-dollar-doublequoted-atpt 'ar-doublequoted-dollar-atpt)
;;;###autoload
(defun ar-doublequoted-dollar-atpt (&optional no-delimiters) 
  "Doublequotes doublequoted at point if any. "
  (interactive "*p")
  (ar-th-dollar 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-equalize-doublequoted-atpt 'ar-doublequoted-equalize-atpt)
;;;###autoload
(defun ar-doublequoted-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-equalize 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-doublequoted-atpt 'ar-doublequoted-greater-angle-atpt)
;;;###autoload
(defun ar-doublequoted-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for doublequoted after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-doublequoted-atpt 'ar-doublequoted-lesser-angle-atpt)
;;;###autoload
(defun ar-doublequoted-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for doublequoted after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-backslash-doublequoted-atpt 'ar-doublequoted-backslash-atpt)
;;;###autoload
(defun ar-doublequoted-backslash-atpt (&optional no-delimiters) 
  "Backslash doublequoted at point if any. "
  (interactive "*p")
  (ar-th-backslash 'doublequoted no-delimiters (interactive-p))) 

(defalias 'ar-brace-doublequoted-atpt 'ar-doublequoted-brace-atpt)
;;;###autoload
(defun ar-doublequoted-brace-atpt (&optional no-delimiters) 
  "Braces doublequoted at point if any. "
  (interactive "*p")
  (ar-th-brace 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-bracket-doublequoted-atpt 'ar-doublequoted-bracket-atpt)
;;;###autoload
(defun ar-doublequoted-bracket-atpt (&optional no-delimiters) 
  "Brackets doublequoted after point if any. "
  (interactive "*p")
  (ar-th-bracket 'doublequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-doublequoted-atpt (&optional no-delimiters) 
  "Comments doublequoted at point if any. "
  (interactive "*p")
  (ar-th-comment 'doublequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-doublequoted-atpt (&optional no-delimiters) 
  "Put a comma after doublequoted at point if any. "
  (interactive "*p")
  (ar-th-commatize 'doublequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-doublequoted-atpt (&optional no-delimiters) 
  "Put a singlequote before doublequoted at point if any. "
  (interactive "*p")
  (ar-th-quote 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-hyphen-doublequoted-atpt 'ar-doublequoted-hyphen-atpt)
;;;###autoload
(defun ar-doublequoted-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around doublequoted at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-mark-doublequoted-atpt 'ar-doublequoted-mark-atpt)
;;;###autoload
(defun ar-doublequoted-mark-atpt () 
  "Marks doublequoted at point if any. "
  (interactive)
  (ar-th-mark 'doublequoted))

(defalias 'ar-hide-doublequoted-atpt 'ar-doublequoted-hide-atpt)
;;;###autoload
(defun ar-doublequoted-hide-atpt () 
  "Hides doublequoted at point. "
  (interactive)
  (ar-th-hide 'doublequoted))

(defalias 'ar-show-doublequoted-atpt 'ar-doublequoted-show-atpt)
;;;###autoload
(defun ar-doublequoted-show-atpt () 
  "Shows hidden doublequoted at point. "
  (interactive)
  (ar-th-show 'doublequoted))

(defalias 'ar-hide-show-doublequoted-atpt 'ar-doublequoted-hide-show-atpt)
;;;###autoload
(defun ar-doublequoted-hide-show-atpt () 
  "Alternatively hides or shows doublequoted at point. "
  (interactive)
  (ar-th-hide-show 'doublequoted))

(defalias 'ar-highlight-doublequoted-atpt-mode 'ar-doublequoted-highlight-atpt-mode)
(defun ar-doublequoted-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles doublequoted-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-kill-doublequoted-atpt 'ar-doublequoted-kill-atpt)
;;;###autoload
(defun ar-doublequoted-kill-atpt (&optional no-delimiters) 
  "Kills doublequoted at point if any. "
  (interactive "*P")
  (ar-th-kill 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-doublequoted-atpt 'ar-doublequoted-left-right-singlequote-atpt)
;;;###autoload
(defun ar-doublequoted-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-parentize-doublequoted-atpt 'ar-doublequoted-parentize-atpt)
;;;###autoload
(defun ar-doublequoted-parentize-atpt (&optional no-delimiters) 
  "Parentizes doublequoted at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-separate-doublequoted-atpt 'ar-doublequoted-separate-atpt)
;;;###autoload
(defun ar-doublequoted-separate-atpt (&optional no-delimiters) 
  "Separates doublequoted at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-singlequote-doublequoted-atpt 'ar-doublequoted-singlequote-atpt)
;;;###autoload
(defun ar-doublequoted-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes doublequoted at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-doublequoted-atpt 'ar-doublequoted-triplequote-dq-atpt)
;;;###autoload
(defun ar-doublequoted-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around doublequoted. "
  (interactive "*p")
  (ar-th-triplequote-dq 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-doublequoted-atpt 'ar-doublequoted-triplequote-sq-atpt)
;;;###autoload
(defun ar-doublequoted-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around doublequoted. "
  (interactive "*p")
  (ar-th-triplequote-sq 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-trim-doublequoted-atpt 'ar-doublequoted-trim-atpt)
;;;###autoload
(defun ar-doublequoted-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'doublequoted t t)) 
    (ar-th-trim 'doublequoted t t)))

(defalias 'ar-trim-left-doublequoted-atpt 'ar-doublequoted-left-trim-atpt)
;;;###autoload
(defun ar-doublequoted-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'doublequoted t nil))
    (ar-th-trim 'doublequoted t nil)))

(defalias 'ar-trim-right-doublequoted-atpt 'ar-doublequoted-right-trim-atpt)
;;;###autoload
(defun ar-doublequoted-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'doublequoted nil t))
    (ar-th-trim 'doublequoted nil t)))

(defalias 'ar-doublequoted-underscore-atpt 'ar-underscore-doublequoted-atpt)
;;;###autoload
(defun ar-underscore-doublequoted-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'doublequoted no-delimiters (interactive-p)))

(defalias 'ar-doublequoted-whitespace-atpt 'ar-whitespace-doublequoted-atpt)
;;;###autoload
(defun ar-whitespace-doublequoted-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'doublequoted nil t))

(defalias 'ar-forward-doublequoted-atpt 'ar-doublequoted-forward-atpt)
;;;###autoload
(defun ar-doublequoted-forward-atpt (&optional arg) 
  "Moves forward over doublequoted at point if any, does nothing otherwise.
Returns end position of doublequoted "
  (interactive "p")
  (ar-th-forward 'doublequoted arg (interactive-p)))

(defalias 'ar-backward-doublequoted-atpt 'ar-doublequoted-backward-atpt)
;;;###autoload
(defun ar-doublequoted-backward-atpt (&optional arg) 
  "Moves backward over doublequoted before point if any, does nothing otherwise.
Returns beginning position of doublequoted "
  (interactive "p")
  (ar-th-backward 'doublequoted arg (interactive-p)))

(defalias 'ar-transpose-doublequoted-atpt 'ar-doublequoted-transpose-atpt)
;;;###autoload
(defun ar-doublequoted-transpose-atpt (&optional arg) 
  "Transposes doublequoted with doublequoted before point if any. "
  (interactive "*p")
  (ar-th-transpose 'doublequoted arg (interactive-p)))

(defalias 'ar-sort-doublequoted-atpt 'ar-doublequoted-sort-atpt)
;;;###autoload
(defun ar-doublequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts doublequoteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'doublequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-doublequoted-atpt 'ar-doublequoted-check-atpt)
;;;###autoload
(defun ar-doublequoted-check-atpt () 
  "Return t if a doublequoted at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-doublequoted-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-doublequoted-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-equalized-atpt (&optional arg no-delimiters) 
  "Returns equalized at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'equalized arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-equalized-atpt 'ar-equalized-bounds-atpt)
;;;###autoload
(defun ar-equalized-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of equalized if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'equalized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-equalized-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position equalized at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'equalized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-equalized-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of equalized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'equalized no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-equalized-atpt 'ar-equalized-beginning-atpt)
;;;###autoload
(defun ar-equalized-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class equalized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'equalized no-delimiters (interactive-p)))

(defalias 'ar-end-of-equalized-atpt 'ar-equalized-end-atpt)
;;;###autoload
(defun ar-equalized-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class equalized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'equalized no-delimiters (interactive-p)))

(defalias 'ar-length-of-equalized-atpt 'ar-equalized-length-atpt)
;;;###autoload
(defun ar-equalized-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class equalized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'equalized no-delimiters (interactive-p)))

(defalias 'ar-copy-equalized-atpt 'ar-equalized-copy-atpt)
;;;###autoload
(defun ar-equalized-copy-atpt (&optional no-delimiters) 
  "Returns a copy of equalized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'equalized no-delimiters (interactive-p)))

(defalias 'ar-delete-equalized-in-region 'ar-equalized-delete-in-region)
;;;###autoload
(defun ar-equalized-delete-in-region (beg end) 
  "Deletes equalized at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'equalized beg end (interactive-p)))

;;;###autoload
(defun ar-blok-equalized-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around equalized.
  Returns blok or nil if no equalized at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'equalized no-delimiters (interactive-p)))

(defalias 'ar-escape-equalized-atpt 'ar-equalized-escape-atpt)
;;;###autoload
(defun ar-equalized-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted equalized at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'equalized no-delimiters))

(defalias 'ar-doublequote-equalized-atpt 'ar-equalized-doublequote-atpt)
;;;###autoload
(defun ar-equalized-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes equalized at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'equalized no-delimiters (interactive-p)))

(defalias 'ar-slash-equalized-atpt 'ar-equalized-slash-atpt)
;;;###autoload
(defun ar-equalized-slash-atpt (&optional no-delimiters) 
  "Doublequotes equalized at point if any. "
  (interactive "*p")
  (ar-th-slash 'equalized no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-equalized-atpt 'ar-equalized-double-backslash-atpt)
;;;###autoload
(defun ar-equalized-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around equalized at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'equalized no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-equalized-atpt 'ar-equalized-doubleslash-atpt)
;;;###autoload
(defun ar-equalized-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around equalized at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'equalized no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-equalized-atpt 'ar-equalized-doubleslashparen-atpt)
;;;###autoload
(defun ar-equalized-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around equalized at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'equalized no-delimiters (interactive-p)))

(defalias 'ar-slashparen-equalized-atpt 'ar-equalized-slashparen-atpt)
;;;###autoload
(defun ar-equalized-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around equalized at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'equalized no-delimiters (interactive-p)))

(defalias 'ar-dollar-equalized-atpt 'ar-equalized-dollar-atpt)
;;;###autoload
(defun ar-equalized-dollar-atpt (&optional no-delimiters) 
  "Doublequotes equalized at point if any. "
  (interactive "*p")
  (ar-th-dollar 'equalized no-delimiters (interactive-p)))

(defalias 'ar-equalize-equalized-atpt 'ar-equalized-equalize-atpt)
;;;###autoload
(defun ar-equalized-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around equalized at point if any. "
  (interactive "*p")
  (ar-th-equalize 'equalized no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-equalized-atpt 'ar-equalized-greater-angle-atpt)
;;;###autoload
(defun ar-equalized-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for equalized after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'equalized no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-equalized-atpt 'ar-equalized-lesser-angle-atpt)
;;;###autoload
(defun ar-equalized-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for equalized after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'equalized no-delimiters (interactive-p)))

(defalias 'ar-backslash-equalized-atpt 'ar-equalized-backslash-atpt)
;;;###autoload
(defun ar-equalized-backslash-atpt (&optional no-delimiters) 
  "Backslash equalized at point if any. "
  (interactive "*p")
  (ar-th-backslash 'equalized no-delimiters (interactive-p))) 

(defalias 'ar-brace-equalized-atpt 'ar-equalized-brace-atpt)
;;;###autoload
(defun ar-equalized-brace-atpt (&optional no-delimiters) 
  "Braces equalized at point if any. "
  (interactive "*p")
  (ar-th-brace 'equalized no-delimiters (interactive-p)))

(defalias 'ar-bracket-equalized-atpt 'ar-equalized-bracket-atpt)
;;;###autoload
(defun ar-equalized-bracket-atpt (&optional no-delimiters) 
  "Brackets equalized after point if any. "
  (interactive "*p")
  (ar-th-bracket 'equalized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-equalized-atpt (&optional no-delimiters) 
  "Comments equalized at point if any. "
  (interactive "*p")
  (ar-th-comment 'equalized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-equalized-atpt (&optional no-delimiters) 
  "Put a comma after equalized at point if any. "
  (interactive "*p")
  (ar-th-commatize 'equalized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-equalized-atpt (&optional no-delimiters) 
  "Put a singlequote before equalized at point if any. "
  (interactive "*p")
  (ar-th-quote 'equalized no-delimiters (interactive-p)))

(defalias 'ar-hyphen-equalized-atpt 'ar-equalized-hyphen-atpt)
;;;###autoload
(defun ar-equalized-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around equalized at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'equalized no-delimiters (interactive-p)))

(defalias 'ar-mark-equalized-atpt 'ar-equalized-mark-atpt)
;;;###autoload
(defun ar-equalized-mark-atpt () 
  "Marks equalized at point if any. "
  (interactive)
  (ar-th-mark 'equalized))

(defalias 'ar-hide-equalized-atpt 'ar-equalized-hide-atpt)
;;;###autoload
(defun ar-equalized-hide-atpt () 
  "Hides equalized at point. "
  (interactive)
  (ar-th-hide 'equalized))

(defalias 'ar-show-equalized-atpt 'ar-equalized-show-atpt)
;;;###autoload
(defun ar-equalized-show-atpt () 
  "Shows hidden equalized at point. "
  (interactive)
  (ar-th-show 'equalized))

(defalias 'ar-hide-show-equalized-atpt 'ar-equalized-hide-show-atpt)
;;;###autoload
(defun ar-equalized-hide-show-atpt () 
  "Alternatively hides or shows equalized at point. "
  (interactive)
  (ar-th-hide-show 'equalized))

(defalias 'ar-highlight-equalized-atpt-mode 'ar-equalized-highlight-atpt-mode)
(defun ar-equalized-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles equalized-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'equalized no-delimiters (interactive-p)))

(defalias 'ar-kill-equalized-atpt 'ar-equalized-kill-atpt)
;;;###autoload
(defun ar-equalized-kill-atpt (&optional no-delimiters) 
  "Kills equalized at point if any. "
  (interactive "*P")
  (ar-th-kill 'equalized no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-equalized-atpt 'ar-equalized-left-right-singlequote-atpt)
;;;###autoload
(defun ar-equalized-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'equalized no-delimiters (interactive-p)))

(defalias 'ar-parentize-equalized-atpt 'ar-equalized-parentize-atpt)
;;;###autoload
(defun ar-equalized-parentize-atpt (&optional no-delimiters) 
  "Parentizes equalized at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'equalized no-delimiters (interactive-p)))

(defalias 'ar-separate-equalized-atpt 'ar-equalized-separate-atpt)
;;;###autoload
(defun ar-equalized-separate-atpt (&optional no-delimiters) 
  "Separates equalized at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'equalized no-delimiters (interactive-p)))

(defalias 'ar-singlequote-equalized-atpt 'ar-equalized-singlequote-atpt)
;;;###autoload
(defun ar-equalized-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes equalized at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'equalized no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-equalized-atpt 'ar-equalized-triplequote-dq-atpt)
;;;###autoload
(defun ar-equalized-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around equalized. "
  (interactive "*p")
  (ar-th-triplequote-dq 'equalized no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-equalized-atpt 'ar-equalized-triplequote-sq-atpt)
;;;###autoload
(defun ar-equalized-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around equalized. "
  (interactive "*p")
  (ar-th-triplequote-sq 'equalized no-delimiters (interactive-p)))

(defalias 'ar-trim-equalized-atpt 'ar-equalized-trim-atpt)
;;;###autoload
(defun ar-equalized-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'equalized t t)) 
    (ar-th-trim 'equalized t t)))

(defalias 'ar-trim-left-equalized-atpt 'ar-equalized-left-trim-atpt)
;;;###autoload
(defun ar-equalized-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'equalized t nil))
    (ar-th-trim 'equalized t nil)))

(defalias 'ar-trim-right-equalized-atpt 'ar-equalized-right-trim-atpt)
;;;###autoload
(defun ar-equalized-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'equalized nil t))
    (ar-th-trim 'equalized nil t)))

(defalias 'ar-equalized-underscore-atpt 'ar-underscore-equalized-atpt)
;;;###autoload
(defun ar-underscore-equalized-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'equalized no-delimiters (interactive-p)))

(defalias 'ar-equalized-whitespace-atpt 'ar-whitespace-equalized-atpt)
;;;###autoload
(defun ar-whitespace-equalized-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'equalized nil t))

(defalias 'ar-forward-equalized-atpt 'ar-equalized-forward-atpt)
;;;###autoload
(defun ar-equalized-forward-atpt (&optional arg) 
  "Moves forward over equalized at point if any, does nothing otherwise.
Returns end position of equalized "
  (interactive "p")
  (ar-th-forward 'equalized arg (interactive-p)))

(defalias 'ar-backward-equalized-atpt 'ar-equalized-backward-atpt)
;;;###autoload
(defun ar-equalized-backward-atpt (&optional arg) 
  "Moves backward over equalized before point if any, does nothing otherwise.
Returns beginning position of equalized "
  (interactive "p")
  (ar-th-backward 'equalized arg (interactive-p)))

(defalias 'ar-transpose-equalized-atpt 'ar-equalized-transpose-atpt)
;;;###autoload
(defun ar-equalized-transpose-atpt (&optional arg) 
  "Transposes equalized with equalized before point if any. "
  (interactive "*p")
  (ar-th-transpose 'equalized arg (interactive-p)))

(defalias 'ar-sort-equalized-atpt 'ar-equalized-sort-atpt)
;;;###autoload
(defun ar-equalized-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts equalizeds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'equalized reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-equalized-atpt 'ar-equalized-check-atpt)
;;;###autoload
(defun ar-equalized-check-atpt () 
  "Return t if a equalized at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-equalized-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-equalized-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-hyphened-atpt (&optional arg no-delimiters) 
  "Returns hyphened at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'hyphened arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-hyphened-atpt 'ar-hyphened-bounds-atpt)
;;;###autoload
(defun ar-hyphened-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of hyphened if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'hyphened no-delimiters (interactive-p)))

;;;###autoload
(defun ar-hyphened-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position hyphened at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'hyphened no-delimiters (interactive-p)))

;;;###autoload
(defun ar-hyphened-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of hyphened at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-hyphened-atpt 'ar-hyphened-beginning-atpt)
;;;###autoload
(defun ar-hyphened-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class hyphened at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-end-of-hyphened-atpt 'ar-hyphened-end-atpt)
;;;###autoload
(defun ar-hyphened-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class hyphened at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-length-of-hyphened-atpt 'ar-hyphened-length-atpt)
;;;###autoload
(defun ar-hyphened-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class hyphened at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-copy-hyphened-atpt 'ar-hyphened-copy-atpt)
;;;###autoload
(defun ar-hyphened-copy-atpt (&optional no-delimiters) 
  "Returns a copy of hyphened at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-delete-hyphened-in-region 'ar-hyphened-delete-in-region)
;;;###autoload
(defun ar-hyphened-delete-in-region (beg end) 
  "Deletes hyphened at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'hyphened beg end (interactive-p)))

;;;###autoload
(defun ar-blok-hyphened-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around hyphened.
  Returns blok or nil if no hyphened at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-escape-hyphened-atpt 'ar-hyphened-escape-atpt)
;;;###autoload
(defun ar-hyphened-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted hyphened at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'hyphened no-delimiters))

(defalias 'ar-doublequote-hyphened-atpt 'ar-hyphened-doublequote-atpt)
;;;###autoload
(defun ar-hyphened-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes hyphened at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-slash-hyphened-atpt 'ar-hyphened-slash-atpt)
;;;###autoload
(defun ar-hyphened-slash-atpt (&optional no-delimiters) 
  "Doublequotes hyphened at point if any. "
  (interactive "*p")
  (ar-th-slash 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-hyphened-atpt 'ar-hyphened-double-backslash-atpt)
;;;###autoload
(defun ar-hyphened-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around hyphened at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-hyphened-atpt 'ar-hyphened-doubleslash-atpt)
;;;###autoload
(defun ar-hyphened-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around hyphened at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-hyphened-atpt 'ar-hyphened-doubleslashparen-atpt)
;;;###autoload
(defun ar-hyphened-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around hyphened at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-slashparen-hyphened-atpt 'ar-hyphened-slashparen-atpt)
;;;###autoload
(defun ar-hyphened-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around hyphened at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-dollar-hyphened-atpt 'ar-hyphened-dollar-atpt)
;;;###autoload
(defun ar-hyphened-dollar-atpt (&optional no-delimiters) 
  "Doublequotes hyphened at point if any. "
  (interactive "*p")
  (ar-th-dollar 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-equalize-hyphened-atpt 'ar-hyphened-equalize-atpt)
;;;###autoload
(defun ar-hyphened-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around hyphened at point if any. "
  (interactive "*p")
  (ar-th-equalize 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-hyphened-atpt 'ar-hyphened-greater-angle-atpt)
;;;###autoload
(defun ar-hyphened-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for hyphened after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-hyphened-atpt 'ar-hyphened-lesser-angle-atpt)
;;;###autoload
(defun ar-hyphened-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for hyphened after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-backslash-hyphened-atpt 'ar-hyphened-backslash-atpt)
;;;###autoload
(defun ar-hyphened-backslash-atpt (&optional no-delimiters) 
  "Backslash hyphened at point if any. "
  (interactive "*p")
  (ar-th-backslash 'hyphened no-delimiters (interactive-p))) 

(defalias 'ar-brace-hyphened-atpt 'ar-hyphened-brace-atpt)
;;;###autoload
(defun ar-hyphened-brace-atpt (&optional no-delimiters) 
  "Braces hyphened at point if any. "
  (interactive "*p")
  (ar-th-brace 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-bracket-hyphened-atpt 'ar-hyphened-bracket-atpt)
;;;###autoload
(defun ar-hyphened-bracket-atpt (&optional no-delimiters) 
  "Brackets hyphened after point if any. "
  (interactive "*p")
  (ar-th-bracket 'hyphened no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-hyphened-atpt (&optional no-delimiters) 
  "Comments hyphened at point if any. "
  (interactive "*p")
  (ar-th-comment 'hyphened no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-hyphened-atpt (&optional no-delimiters) 
  "Put a comma after hyphened at point if any. "
  (interactive "*p")
  (ar-th-commatize 'hyphened no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-hyphened-atpt (&optional no-delimiters) 
  "Put a singlequote before hyphened at point if any. "
  (interactive "*p")
  (ar-th-quote 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-hyphen-hyphened-atpt 'ar-hyphened-hyphen-atpt)
;;;###autoload
(defun ar-hyphened-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around hyphened at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-mark-hyphened-atpt 'ar-hyphened-mark-atpt)
;;;###autoload
(defun ar-hyphened-mark-atpt () 
  "Marks hyphened at point if any. "
  (interactive)
  (ar-th-mark 'hyphened))

(defalias 'ar-hide-hyphened-atpt 'ar-hyphened-hide-atpt)
;;;###autoload
(defun ar-hyphened-hide-atpt () 
  "Hides hyphened at point. "
  (interactive)
  (ar-th-hide 'hyphened))

(defalias 'ar-show-hyphened-atpt 'ar-hyphened-show-atpt)
;;;###autoload
(defun ar-hyphened-show-atpt () 
  "Shows hidden hyphened at point. "
  (interactive)
  (ar-th-show 'hyphened))

(defalias 'ar-hide-show-hyphened-atpt 'ar-hyphened-hide-show-atpt)
;;;###autoload
(defun ar-hyphened-hide-show-atpt () 
  "Alternatively hides or shows hyphened at point. "
  (interactive)
  (ar-th-hide-show 'hyphened))

(defalias 'ar-highlight-hyphened-atpt-mode 'ar-hyphened-highlight-atpt-mode)
(defun ar-hyphened-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles hyphened-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-kill-hyphened-atpt 'ar-hyphened-kill-atpt)
;;;###autoload
(defun ar-hyphened-kill-atpt (&optional no-delimiters) 
  "Kills hyphened at point if any. "
  (interactive "*P")
  (ar-th-kill 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-hyphened-atpt 'ar-hyphened-left-right-singlequote-atpt)
;;;###autoload
(defun ar-hyphened-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-parentize-hyphened-atpt 'ar-hyphened-parentize-atpt)
;;;###autoload
(defun ar-hyphened-parentize-atpt (&optional no-delimiters) 
  "Parentizes hyphened at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-separate-hyphened-atpt 'ar-hyphened-separate-atpt)
;;;###autoload
(defun ar-hyphened-separate-atpt (&optional no-delimiters) 
  "Separates hyphened at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-singlequote-hyphened-atpt 'ar-hyphened-singlequote-atpt)
;;;###autoload
(defun ar-hyphened-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes hyphened at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-hyphened-atpt 'ar-hyphened-triplequote-dq-atpt)
;;;###autoload
(defun ar-hyphened-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around hyphened. "
  (interactive "*p")
  (ar-th-triplequote-dq 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-hyphened-atpt 'ar-hyphened-triplequote-sq-atpt)
;;;###autoload
(defun ar-hyphened-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around hyphened. "
  (interactive "*p")
  (ar-th-triplequote-sq 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-trim-hyphened-atpt 'ar-hyphened-trim-atpt)
;;;###autoload
(defun ar-hyphened-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'hyphened t t)) 
    (ar-th-trim 'hyphened t t)))

(defalias 'ar-trim-left-hyphened-atpt 'ar-hyphened-left-trim-atpt)
;;;###autoload
(defun ar-hyphened-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'hyphened t nil))
    (ar-th-trim 'hyphened t nil)))

(defalias 'ar-trim-right-hyphened-atpt 'ar-hyphened-right-trim-atpt)
;;;###autoload
(defun ar-hyphened-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'hyphened nil t))
    (ar-th-trim 'hyphened nil t)))

(defalias 'ar-hyphened-underscore-atpt 'ar-underscore-hyphened-atpt)
;;;###autoload
(defun ar-underscore-hyphened-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'hyphened no-delimiters (interactive-p)))

(defalias 'ar-hyphened-whitespace-atpt 'ar-whitespace-hyphened-atpt)
;;;###autoload
(defun ar-whitespace-hyphened-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'hyphened nil t))

(defalias 'ar-forward-hyphened-atpt 'ar-hyphened-forward-atpt)
;;;###autoload
(defun ar-hyphened-forward-atpt (&optional arg) 
  "Moves forward over hyphened at point if any, does nothing otherwise.
Returns end position of hyphened "
  (interactive "p")
  (ar-th-forward 'hyphened arg (interactive-p)))

(defalias 'ar-backward-hyphened-atpt 'ar-hyphened-backward-atpt)
;;;###autoload
(defun ar-hyphened-backward-atpt (&optional arg) 
  "Moves backward over hyphened before point if any, does nothing otherwise.
Returns beginning position of hyphened "
  (interactive "p")
  (ar-th-backward 'hyphened arg (interactive-p)))

(defalias 'ar-transpose-hyphened-atpt 'ar-hyphened-transpose-atpt)
;;;###autoload
(defun ar-hyphened-transpose-atpt (&optional arg) 
  "Transposes hyphened with hyphened before point if any. "
  (interactive "*p")
  (ar-th-transpose 'hyphened arg (interactive-p)))

(defalias 'ar-sort-hyphened-atpt 'ar-hyphened-sort-atpt)
;;;###autoload
(defun ar-hyphened-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts hypheneds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'hyphened reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-hyphened-atpt 'ar-hyphened-check-atpt)
;;;###autoload
(defun ar-hyphened-check-atpt () 
  "Return t if a hyphened at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-hyphened-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-hyphened-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-quoted-atpt (&optional arg no-delimiters) 
  "Returns quoted at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'quoted arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-quoted-atpt 'ar-quoted-bounds-atpt)
;;;###autoload
(defun ar-quoted-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of quoted if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'quoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quoted-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position quoted at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'quoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quoted-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of quoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'quoted no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-quoted-atpt 'ar-quoted-beginning-atpt)
;;;###autoload
(defun ar-quoted-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class quoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'quoted no-delimiters (interactive-p)))

(defalias 'ar-end-of-quoted-atpt 'ar-quoted-end-atpt)
;;;###autoload
(defun ar-quoted-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class quoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'quoted no-delimiters (interactive-p)))

(defalias 'ar-length-of-quoted-atpt 'ar-quoted-length-atpt)
;;;###autoload
(defun ar-quoted-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class quoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'quoted no-delimiters (interactive-p)))

(defalias 'ar-copy-quoted-atpt 'ar-quoted-copy-atpt)
;;;###autoload
(defun ar-quoted-copy-atpt (&optional no-delimiters) 
  "Returns a copy of quoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'quoted no-delimiters (interactive-p)))

(defalias 'ar-delete-quoted-in-region 'ar-quoted-delete-in-region)
;;;###autoload
(defun ar-quoted-delete-in-region (beg end) 
  "Deletes quoted at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'quoted beg end (interactive-p)))

;;;###autoload
(defun ar-blok-quoted-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around quoted.
  Returns blok or nil if no quoted at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'quoted no-delimiters (interactive-p)))

(defalias 'ar-escape-quoted-atpt 'ar-quoted-escape-atpt)
;;;###autoload
(defun ar-quoted-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted quoted at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'quoted no-delimiters))

(defalias 'ar-doublequote-quoted-atpt 'ar-quoted-doublequote-atpt)
;;;###autoload
(defun ar-quoted-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes quoted at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'quoted no-delimiters (interactive-p)))

(defalias 'ar-slash-quoted-atpt 'ar-quoted-slash-atpt)
;;;###autoload
(defun ar-quoted-slash-atpt (&optional no-delimiters) 
  "Doublequotes quoted at point if any. "
  (interactive "*p")
  (ar-th-slash 'quoted no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-quoted-atpt 'ar-quoted-double-backslash-atpt)
;;;###autoload
(defun ar-quoted-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around quoted at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'quoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-quoted-atpt 'ar-quoted-doubleslash-atpt)
;;;###autoload
(defun ar-quoted-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around quoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'quoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-quoted-atpt 'ar-quoted-doubleslashparen-atpt)
;;;###autoload
(defun ar-quoted-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around quoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'quoted no-delimiters (interactive-p)))

(defalias 'ar-slashparen-quoted-atpt 'ar-quoted-slashparen-atpt)
;;;###autoload
(defun ar-quoted-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around quoted at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'quoted no-delimiters (interactive-p)))

(defalias 'ar-dollar-quoted-atpt 'ar-quoted-dollar-atpt)
;;;###autoload
(defun ar-quoted-dollar-atpt (&optional no-delimiters) 
  "Doublequotes quoted at point if any. "
  (interactive "*p")
  (ar-th-dollar 'quoted no-delimiters (interactive-p)))

(defalias 'ar-equalize-quoted-atpt 'ar-quoted-equalize-atpt)
;;;###autoload
(defun ar-quoted-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around quoted at point if any. "
  (interactive "*p")
  (ar-th-equalize 'quoted no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-quoted-atpt 'ar-quoted-greater-angle-atpt)
;;;###autoload
(defun ar-quoted-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for quoted after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'quoted no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-quoted-atpt 'ar-quoted-lesser-angle-atpt)
;;;###autoload
(defun ar-quoted-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for quoted after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'quoted no-delimiters (interactive-p)))

(defalias 'ar-backslash-quoted-atpt 'ar-quoted-backslash-atpt)
;;;###autoload
(defun ar-quoted-backslash-atpt (&optional no-delimiters) 
  "Backslash quoted at point if any. "
  (interactive "*p")
  (ar-th-backslash 'quoted no-delimiters (interactive-p))) 

(defalias 'ar-brace-quoted-atpt 'ar-quoted-brace-atpt)
;;;###autoload
(defun ar-quoted-brace-atpt (&optional no-delimiters) 
  "Braces quoted at point if any. "
  (interactive "*p")
  (ar-th-brace 'quoted no-delimiters (interactive-p)))

(defalias 'ar-bracket-quoted-atpt 'ar-quoted-bracket-atpt)
;;;###autoload
(defun ar-quoted-bracket-atpt (&optional no-delimiters) 
  "Brackets quoted after point if any. "
  (interactive "*p")
  (ar-th-bracket 'quoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-quoted-atpt (&optional no-delimiters) 
  "Comments quoted at point if any. "
  (interactive "*p")
  (ar-th-comment 'quoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-quoted-atpt (&optional no-delimiters) 
  "Put a comma after quoted at point if any. "
  (interactive "*p")
  (ar-th-commatize 'quoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-quoted-atpt (&optional no-delimiters) 
  "Put a singlequote before quoted at point if any. "
  (interactive "*p")
  (ar-th-quote 'quoted no-delimiters (interactive-p)))

(defalias 'ar-hyphen-quoted-atpt 'ar-quoted-hyphen-atpt)
;;;###autoload
(defun ar-quoted-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around quoted at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'quoted no-delimiters (interactive-p)))

(defalias 'ar-mark-quoted-atpt 'ar-quoted-mark-atpt)
;;;###autoload
(defun ar-quoted-mark-atpt () 
  "Marks quoted at point if any. "
  (interactive)
  (ar-th-mark 'quoted))

(defalias 'ar-hide-quoted-atpt 'ar-quoted-hide-atpt)
;;;###autoload
(defun ar-quoted-hide-atpt () 
  "Hides quoted at point. "
  (interactive)
  (ar-th-hide 'quoted))

(defalias 'ar-show-quoted-atpt 'ar-quoted-show-atpt)
;;;###autoload
(defun ar-quoted-show-atpt () 
  "Shows hidden quoted at point. "
  (interactive)
  (ar-th-show 'quoted))

(defalias 'ar-hide-show-quoted-atpt 'ar-quoted-hide-show-atpt)
;;;###autoload
(defun ar-quoted-hide-show-atpt () 
  "Alternatively hides or shows quoted at point. "
  (interactive)
  (ar-th-hide-show 'quoted))

(defalias 'ar-highlight-quoted-atpt-mode 'ar-quoted-highlight-atpt-mode)
(defun ar-quoted-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles quoted-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'quoted no-delimiters (interactive-p)))

(defalias 'ar-kill-quoted-atpt 'ar-quoted-kill-atpt)
;;;###autoload
(defun ar-quoted-kill-atpt (&optional no-delimiters) 
  "Kills quoted at point if any. "
  (interactive "*P")
  (ar-th-kill 'quoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-quoted-atpt 'ar-quoted-left-right-singlequote-atpt)
;;;###autoload
(defun ar-quoted-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'quoted no-delimiters (interactive-p)))

(defalias 'ar-parentize-quoted-atpt 'ar-quoted-parentize-atpt)
;;;###autoload
(defun ar-quoted-parentize-atpt (&optional no-delimiters) 
  "Parentizes quoted at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'quoted no-delimiters (interactive-p)))

(defalias 'ar-separate-quoted-atpt 'ar-quoted-separate-atpt)
;;;###autoload
(defun ar-quoted-separate-atpt (&optional no-delimiters) 
  "Separates quoted at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'quoted no-delimiters (interactive-p)))

(defalias 'ar-singlequote-quoted-atpt 'ar-quoted-singlequote-atpt)
;;;###autoload
(defun ar-quoted-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes quoted at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'quoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-quoted-atpt 'ar-quoted-triplequote-dq-atpt)
;;;###autoload
(defun ar-quoted-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around quoted. "
  (interactive "*p")
  (ar-th-triplequote-dq 'quoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-quoted-atpt 'ar-quoted-triplequote-sq-atpt)
;;;###autoload
(defun ar-quoted-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around quoted. "
  (interactive "*p")
  (ar-th-triplequote-sq 'quoted no-delimiters (interactive-p)))

(defalias 'ar-trim-quoted-atpt 'ar-quoted-trim-atpt)
;;;###autoload
(defun ar-quoted-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'quoted t t)) 
    (ar-th-trim 'quoted t t)))

(defalias 'ar-trim-left-quoted-atpt 'ar-quoted-left-trim-atpt)
;;;###autoload
(defun ar-quoted-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'quoted t nil))
    (ar-th-trim 'quoted t nil)))

(defalias 'ar-trim-right-quoted-atpt 'ar-quoted-right-trim-atpt)
;;;###autoload
(defun ar-quoted-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'quoted nil t))
    (ar-th-trim 'quoted nil t)))

(defalias 'ar-quoted-underscore-atpt 'ar-underscore-quoted-atpt)
;;;###autoload
(defun ar-underscore-quoted-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'quoted no-delimiters (interactive-p)))

(defalias 'ar-quoted-whitespace-atpt 'ar-whitespace-quoted-atpt)
;;;###autoload
(defun ar-whitespace-quoted-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'quoted nil t))

(defalias 'ar-forward-quoted-atpt 'ar-quoted-forward-atpt)
;;;###autoload
(defun ar-quoted-forward-atpt (&optional arg) 
  "Moves forward over quoted at point if any, does nothing otherwise.
Returns end position of quoted "
  (interactive "p")
  (ar-th-forward 'quoted arg (interactive-p)))

(defalias 'ar-backward-quoted-atpt 'ar-quoted-backward-atpt)
;;;###autoload
(defun ar-quoted-backward-atpt (&optional arg) 
  "Moves backward over quoted before point if any, does nothing otherwise.
Returns beginning position of quoted "
  (interactive "p")
  (ar-th-backward 'quoted arg (interactive-p)))

(defalias 'ar-transpose-quoted-atpt 'ar-quoted-transpose-atpt)
;;;###autoload
(defun ar-quoted-transpose-atpt (&optional arg) 
  "Transposes quoted with quoted before point if any. "
  (interactive "*p")
  (ar-th-transpose 'quoted arg (interactive-p)))

(defalias 'ar-sort-quoted-atpt 'ar-quoted-sort-atpt)
;;;###autoload
(defun ar-quoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts quoteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'quoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-quoted-atpt 'ar-quoted-check-atpt)
;;;###autoload
(defun ar-quoted-check-atpt () 
  "Return t if a quoted at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-quoted-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-quoted-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-singlequoted-atpt (&optional arg no-delimiters) 
  "Returns singlequoted at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'singlequoted arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-singlequoted-atpt 'ar-singlequoted-bounds-atpt)
;;;###autoload
(defun ar-singlequoted-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of singlequoted if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-singlequoted-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position singlequoted at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-singlequoted-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-singlequoted-atpt 'ar-singlequoted-beginning-atpt)
;;;###autoload
(defun ar-singlequoted-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-end-of-singlequoted-atpt 'ar-singlequoted-end-atpt)
;;;###autoload
(defun ar-singlequoted-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-length-of-singlequoted-atpt 'ar-singlequoted-length-atpt)
;;;###autoload
(defun ar-singlequoted-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-copy-singlequoted-atpt 'ar-singlequoted-copy-atpt)
;;;###autoload
(defun ar-singlequoted-copy-atpt (&optional no-delimiters) 
  "Returns a copy of singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-delete-singlequoted-in-region 'ar-singlequoted-delete-in-region)
;;;###autoload
(defun ar-singlequoted-delete-in-region (beg end) 
  "Deletes singlequoted at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'singlequoted beg end (interactive-p)))

;;;###autoload
(defun ar-blok-singlequoted-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around singlequoted.
  Returns blok or nil if no singlequoted at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-escape-singlequoted-atpt 'ar-singlequoted-escape-atpt)
;;;###autoload
(defun ar-singlequoted-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted singlequoted at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'singlequoted no-delimiters))

(defalias 'ar-doublequote-singlequoted-atpt 'ar-singlequoted-doublequote-atpt)
;;;###autoload
(defun ar-singlequoted-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-slash-singlequoted-atpt 'ar-singlequoted-slash-atpt)
;;;###autoload
(defun ar-singlequoted-slash-atpt (&optional no-delimiters) 
  "Doublequotes singlequoted at point if any. "
  (interactive "*p")
  (ar-th-slash 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-singlequoted-atpt 'ar-singlequoted-double-backslash-atpt)
;;;###autoload
(defun ar-singlequoted-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-singlequoted-atpt 'ar-singlequoted-doubleslash-atpt)
;;;###autoload
(defun ar-singlequoted-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-singlequoted-atpt 'ar-singlequoted-doubleslashparen-atpt)
;;;###autoload
(defun ar-singlequoted-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-slashparen-singlequoted-atpt 'ar-singlequoted-slashparen-atpt)
;;;###autoload
(defun ar-singlequoted-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-dollar-singlequoted-atpt 'ar-singlequoted-dollar-atpt)
;;;###autoload
(defun ar-singlequoted-dollar-atpt (&optional no-delimiters) 
  "Doublequotes singlequoted at point if any. "
  (interactive "*p")
  (ar-th-dollar 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-equalize-singlequoted-atpt 'ar-singlequoted-equalize-atpt)
;;;###autoload
(defun ar-singlequoted-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-equalize 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-singlequoted-atpt 'ar-singlequoted-greater-angle-atpt)
;;;###autoload
(defun ar-singlequoted-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for singlequoted after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-singlequoted-atpt 'ar-singlequoted-lesser-angle-atpt)
;;;###autoload
(defun ar-singlequoted-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for singlequoted after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-backslash-singlequoted-atpt 'ar-singlequoted-backslash-atpt)
;;;###autoload
(defun ar-singlequoted-backslash-atpt (&optional no-delimiters) 
  "Backslash singlequoted at point if any. "
  (interactive "*p")
  (ar-th-backslash 'singlequoted no-delimiters (interactive-p))) 

(defalias 'ar-brace-singlequoted-atpt 'ar-singlequoted-brace-atpt)
;;;###autoload
(defun ar-singlequoted-brace-atpt (&optional no-delimiters) 
  "Braces singlequoted at point if any. "
  (interactive "*p")
  (ar-th-brace 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-bracket-singlequoted-atpt 'ar-singlequoted-bracket-atpt)
;;;###autoload
(defun ar-singlequoted-bracket-atpt (&optional no-delimiters) 
  "Brackets singlequoted after point if any. "
  (interactive "*p")
  (ar-th-bracket 'singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-singlequoted-atpt (&optional no-delimiters) 
  "Comments singlequoted at point if any. "
  (interactive "*p")
  (ar-th-comment 'singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-singlequoted-atpt (&optional no-delimiters) 
  "Put a comma after singlequoted at point if any. "
  (interactive "*p")
  (ar-th-commatize 'singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-singlequoted-atpt (&optional no-delimiters) 
  "Put a singlequote before singlequoted at point if any. "
  (interactive "*p")
  (ar-th-quote 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-hyphen-singlequoted-atpt 'ar-singlequoted-hyphen-atpt)
;;;###autoload
(defun ar-singlequoted-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around singlequoted at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-mark-singlequoted-atpt 'ar-singlequoted-mark-atpt)
;;;###autoload
(defun ar-singlequoted-mark-atpt () 
  "Marks singlequoted at point if any. "
  (interactive)
  (ar-th-mark 'singlequoted))

(defalias 'ar-hide-singlequoted-atpt 'ar-singlequoted-hide-atpt)
;;;###autoload
(defun ar-singlequoted-hide-atpt () 
  "Hides singlequoted at point. "
  (interactive)
  (ar-th-hide 'singlequoted))

(defalias 'ar-show-singlequoted-atpt 'ar-singlequoted-show-atpt)
;;;###autoload
(defun ar-singlequoted-show-atpt () 
  "Shows hidden singlequoted at point. "
  (interactive)
  (ar-th-show 'singlequoted))

(defalias 'ar-hide-show-singlequoted-atpt 'ar-singlequoted-hide-show-atpt)
;;;###autoload
(defun ar-singlequoted-hide-show-atpt () 
  "Alternatively hides or shows singlequoted at point. "
  (interactive)
  (ar-th-hide-show 'singlequoted))

(defalias 'ar-highlight-singlequoted-atpt-mode 'ar-singlequoted-highlight-atpt-mode)
(defun ar-singlequoted-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles singlequoted-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-kill-singlequoted-atpt 'ar-singlequoted-kill-atpt)
;;;###autoload
(defun ar-singlequoted-kill-atpt (&optional no-delimiters) 
  "Kills singlequoted at point if any. "
  (interactive "*P")
  (ar-th-kill 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-singlequoted-atpt 'ar-singlequoted-left-right-singlequote-atpt)
;;;###autoload
(defun ar-singlequoted-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-parentize-singlequoted-atpt 'ar-singlequoted-parentize-atpt)
;;;###autoload
(defun ar-singlequoted-parentize-atpt (&optional no-delimiters) 
  "Parentizes singlequoted at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-separate-singlequoted-atpt 'ar-singlequoted-separate-atpt)
;;;###autoload
(defun ar-singlequoted-separate-atpt (&optional no-delimiters) 
  "Separates singlequoted at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-singlequote-singlequoted-atpt 'ar-singlequoted-singlequote-atpt)
;;;###autoload
(defun ar-singlequoted-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes singlequoted at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-singlequoted-atpt 'ar-singlequoted-triplequote-dq-atpt)
;;;###autoload
(defun ar-singlequoted-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around singlequoted. "
  (interactive "*p")
  (ar-th-triplequote-dq 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-singlequoted-atpt 'ar-singlequoted-triplequote-sq-atpt)
;;;###autoload
(defun ar-singlequoted-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around singlequoted. "
  (interactive "*p")
  (ar-th-triplequote-sq 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-trim-singlequoted-atpt 'ar-singlequoted-trim-atpt)
;;;###autoload
(defun ar-singlequoted-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'singlequoted t t)) 
    (ar-th-trim 'singlequoted t t)))

(defalias 'ar-trim-left-singlequoted-atpt 'ar-singlequoted-left-trim-atpt)
;;;###autoload
(defun ar-singlequoted-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'singlequoted t nil))
    (ar-th-trim 'singlequoted t nil)))

(defalias 'ar-trim-right-singlequoted-atpt 'ar-singlequoted-right-trim-atpt)
;;;###autoload
(defun ar-singlequoted-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'singlequoted nil t))
    (ar-th-trim 'singlequoted nil t)))

(defalias 'ar-singlequoted-underscore-atpt 'ar-underscore-singlequoted-atpt)
;;;###autoload
(defun ar-underscore-singlequoted-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'singlequoted no-delimiters (interactive-p)))

(defalias 'ar-singlequoted-whitespace-atpt 'ar-whitespace-singlequoted-atpt)
;;;###autoload
(defun ar-whitespace-singlequoted-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'singlequoted nil t))

(defalias 'ar-forward-singlequoted-atpt 'ar-singlequoted-forward-atpt)
;;;###autoload
(defun ar-singlequoted-forward-atpt (&optional arg) 
  "Moves forward over singlequoted at point if any, does nothing otherwise.
Returns end position of singlequoted "
  (interactive "p")
  (ar-th-forward 'singlequoted arg (interactive-p)))

(defalias 'ar-backward-singlequoted-atpt 'ar-singlequoted-backward-atpt)
;;;###autoload
(defun ar-singlequoted-backward-atpt (&optional arg) 
  "Moves backward over singlequoted before point if any, does nothing otherwise.
Returns beginning position of singlequoted "
  (interactive "p")
  (ar-th-backward 'singlequoted arg (interactive-p)))

(defalias 'ar-transpose-singlequoted-atpt 'ar-singlequoted-transpose-atpt)
;;;###autoload
(defun ar-singlequoted-transpose-atpt (&optional arg) 
  "Transposes singlequoted with singlequoted before point if any. "
  (interactive "*p")
  (ar-th-transpose 'singlequoted arg (interactive-p)))

(defalias 'ar-sort-singlequoted-atpt 'ar-singlequoted-sort-atpt)
;;;###autoload
(defun ar-singlequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts singlequoteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'singlequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-singlequoted-atpt 'ar-singlequoted-check-atpt)
;;;###autoload
(defun ar-singlequoted-check-atpt () 
  "Return t if a singlequoted at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-singlequoted-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-singlequoted-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-slashed-atpt (&optional arg no-delimiters) 
  "Returns slashed at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'slashed arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-slashed-atpt 'ar-slashed-bounds-atpt)
;;;###autoload
(defun ar-slashed-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of slashed if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'slashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-slashed-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position slashed at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'slashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-slashed-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of slashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'slashed no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-slashed-atpt 'ar-slashed-beginning-atpt)
;;;###autoload
(defun ar-slashed-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class slashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'slashed no-delimiters (interactive-p)))

(defalias 'ar-end-of-slashed-atpt 'ar-slashed-end-atpt)
;;;###autoload
(defun ar-slashed-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class slashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'slashed no-delimiters (interactive-p)))

(defalias 'ar-length-of-slashed-atpt 'ar-slashed-length-atpt)
;;;###autoload
(defun ar-slashed-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class slashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'slashed no-delimiters (interactive-p)))

(defalias 'ar-copy-slashed-atpt 'ar-slashed-copy-atpt)
;;;###autoload
(defun ar-slashed-copy-atpt (&optional no-delimiters) 
  "Returns a copy of slashed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'slashed no-delimiters (interactive-p)))

(defalias 'ar-delete-slashed-in-region 'ar-slashed-delete-in-region)
;;;###autoload
(defun ar-slashed-delete-in-region (beg end) 
  "Deletes slashed at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'slashed beg end (interactive-p)))

;;;###autoload
(defun ar-blok-slashed-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around slashed.
  Returns blok or nil if no slashed at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'slashed no-delimiters (interactive-p)))

(defalias 'ar-escape-slashed-atpt 'ar-slashed-escape-atpt)
;;;###autoload
(defun ar-slashed-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted slashed at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'slashed no-delimiters))

(defalias 'ar-doublequote-slashed-atpt 'ar-slashed-doublequote-atpt)
;;;###autoload
(defun ar-slashed-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes slashed at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'slashed no-delimiters (interactive-p)))

(defalias 'ar-slash-slashed-atpt 'ar-slashed-slash-atpt)
;;;###autoload
(defun ar-slashed-slash-atpt (&optional no-delimiters) 
  "Doublequotes slashed at point if any. "
  (interactive "*p")
  (ar-th-slash 'slashed no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-slashed-atpt 'ar-slashed-double-backslash-atpt)
;;;###autoload
(defun ar-slashed-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around slashed at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'slashed no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-slashed-atpt 'ar-slashed-doubleslash-atpt)
;;;###autoload
(defun ar-slashed-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around slashed at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'slashed no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-slashed-atpt 'ar-slashed-doubleslashparen-atpt)
;;;###autoload
(defun ar-slashed-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around slashed at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'slashed no-delimiters (interactive-p)))

(defalias 'ar-slashparen-slashed-atpt 'ar-slashed-slashparen-atpt)
;;;###autoload
(defun ar-slashed-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around slashed at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'slashed no-delimiters (interactive-p)))

(defalias 'ar-dollar-slashed-atpt 'ar-slashed-dollar-atpt)
;;;###autoload
(defun ar-slashed-dollar-atpt (&optional no-delimiters) 
  "Doublequotes slashed at point if any. "
  (interactive "*p")
  (ar-th-dollar 'slashed no-delimiters (interactive-p)))

(defalias 'ar-equalize-slashed-atpt 'ar-slashed-equalize-atpt)
;;;###autoload
(defun ar-slashed-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around slashed at point if any. "
  (interactive "*p")
  (ar-th-equalize 'slashed no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-slashed-atpt 'ar-slashed-greater-angle-atpt)
;;;###autoload
(defun ar-slashed-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for slashed after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'slashed no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-slashed-atpt 'ar-slashed-lesser-angle-atpt)
;;;###autoload
(defun ar-slashed-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for slashed after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'slashed no-delimiters (interactive-p)))

(defalias 'ar-backslash-slashed-atpt 'ar-slashed-backslash-atpt)
;;;###autoload
(defun ar-slashed-backslash-atpt (&optional no-delimiters) 
  "Backslash slashed at point if any. "
  (interactive "*p")
  (ar-th-backslash 'slashed no-delimiters (interactive-p))) 

(defalias 'ar-brace-slashed-atpt 'ar-slashed-brace-atpt)
;;;###autoload
(defun ar-slashed-brace-atpt (&optional no-delimiters) 
  "Braces slashed at point if any. "
  (interactive "*p")
  (ar-th-brace 'slashed no-delimiters (interactive-p)))

(defalias 'ar-bracket-slashed-atpt 'ar-slashed-bracket-atpt)
;;;###autoload
(defun ar-slashed-bracket-atpt (&optional no-delimiters) 
  "Brackets slashed after point if any. "
  (interactive "*p")
  (ar-th-bracket 'slashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-slashed-atpt (&optional no-delimiters) 
  "Comments slashed at point if any. "
  (interactive "*p")
  (ar-th-comment 'slashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-slashed-atpt (&optional no-delimiters) 
  "Put a comma after slashed at point if any. "
  (interactive "*p")
  (ar-th-commatize 'slashed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-slashed-atpt (&optional no-delimiters) 
  "Put a singlequote before slashed at point if any. "
  (interactive "*p")
  (ar-th-quote 'slashed no-delimiters (interactive-p)))

(defalias 'ar-hyphen-slashed-atpt 'ar-slashed-hyphen-atpt)
;;;###autoload
(defun ar-slashed-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around slashed at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'slashed no-delimiters (interactive-p)))

(defalias 'ar-mark-slashed-atpt 'ar-slashed-mark-atpt)
;;;###autoload
(defun ar-slashed-mark-atpt () 
  "Marks slashed at point if any. "
  (interactive)
  (ar-th-mark 'slashed))

(defalias 'ar-hide-slashed-atpt 'ar-slashed-hide-atpt)
;;;###autoload
(defun ar-slashed-hide-atpt () 
  "Hides slashed at point. "
  (interactive)
  (ar-th-hide 'slashed))

(defalias 'ar-show-slashed-atpt 'ar-slashed-show-atpt)
;;;###autoload
(defun ar-slashed-show-atpt () 
  "Shows hidden slashed at point. "
  (interactive)
  (ar-th-show 'slashed))

(defalias 'ar-hide-show-slashed-atpt 'ar-slashed-hide-show-atpt)
;;;###autoload
(defun ar-slashed-hide-show-atpt () 
  "Alternatively hides or shows slashed at point. "
  (interactive)
  (ar-th-hide-show 'slashed))

(defalias 'ar-highlight-slashed-atpt-mode 'ar-slashed-highlight-atpt-mode)
(defun ar-slashed-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles slashed-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'slashed no-delimiters (interactive-p)))

(defalias 'ar-kill-slashed-atpt 'ar-slashed-kill-atpt)
;;;###autoload
(defun ar-slashed-kill-atpt (&optional no-delimiters) 
  "Kills slashed at point if any. "
  (interactive "*P")
  (ar-th-kill 'slashed no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-slashed-atpt 'ar-slashed-left-right-singlequote-atpt)
;;;###autoload
(defun ar-slashed-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'slashed no-delimiters (interactive-p)))

(defalias 'ar-parentize-slashed-atpt 'ar-slashed-parentize-atpt)
;;;###autoload
(defun ar-slashed-parentize-atpt (&optional no-delimiters) 
  "Parentizes slashed at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'slashed no-delimiters (interactive-p)))

(defalias 'ar-separate-slashed-atpt 'ar-slashed-separate-atpt)
;;;###autoload
(defun ar-slashed-separate-atpt (&optional no-delimiters) 
  "Separates slashed at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'slashed no-delimiters (interactive-p)))

(defalias 'ar-singlequote-slashed-atpt 'ar-slashed-singlequote-atpt)
;;;###autoload
(defun ar-slashed-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes slashed at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'slashed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-slashed-atpt 'ar-slashed-triplequote-dq-atpt)
;;;###autoload
(defun ar-slashed-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around slashed. "
  (interactive "*p")
  (ar-th-triplequote-dq 'slashed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-slashed-atpt 'ar-slashed-triplequote-sq-atpt)
;;;###autoload
(defun ar-slashed-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around slashed. "
  (interactive "*p")
  (ar-th-triplequote-sq 'slashed no-delimiters (interactive-p)))

(defalias 'ar-trim-slashed-atpt 'ar-slashed-trim-atpt)
;;;###autoload
(defun ar-slashed-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'slashed t t)) 
    (ar-th-trim 'slashed t t)))

(defalias 'ar-trim-left-slashed-atpt 'ar-slashed-left-trim-atpt)
;;;###autoload
(defun ar-slashed-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'slashed t nil))
    (ar-th-trim 'slashed t nil)))

(defalias 'ar-trim-right-slashed-atpt 'ar-slashed-right-trim-atpt)
;;;###autoload
(defun ar-slashed-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'slashed nil t))
    (ar-th-trim 'slashed nil t)))

(defalias 'ar-slashed-underscore-atpt 'ar-underscore-slashed-atpt)
;;;###autoload
(defun ar-underscore-slashed-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'slashed no-delimiters (interactive-p)))

(defalias 'ar-slashed-whitespace-atpt 'ar-whitespace-slashed-atpt)
;;;###autoload
(defun ar-whitespace-slashed-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'slashed nil t))

(defalias 'ar-forward-slashed-atpt 'ar-slashed-forward-atpt)
;;;###autoload
(defun ar-slashed-forward-atpt (&optional arg) 
  "Moves forward over slashed at point if any, does nothing otherwise.
Returns end position of slashed "
  (interactive "p")
  (ar-th-forward 'slashed arg (interactive-p)))

(defalias 'ar-backward-slashed-atpt 'ar-slashed-backward-atpt)
;;;###autoload
(defun ar-slashed-backward-atpt (&optional arg) 
  "Moves backward over slashed before point if any, does nothing otherwise.
Returns beginning position of slashed "
  (interactive "p")
  (ar-th-backward 'slashed arg (interactive-p)))

(defalias 'ar-transpose-slashed-atpt 'ar-slashed-transpose-atpt)
;;;###autoload
(defun ar-slashed-transpose-atpt (&optional arg) 
  "Transposes slashed with slashed before point if any. "
  (interactive "*p")
  (ar-th-transpose 'slashed arg (interactive-p)))

(defalias 'ar-sort-slashed-atpt 'ar-slashed-sort-atpt)
;;;###autoload
(defun ar-slashed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts slasheds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'slashed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-slashed-atpt 'ar-slashed-check-atpt)
;;;###autoload
(defun ar-slashed-check-atpt () 
  "Return t if a slashed at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-slashed-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-slashed-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-triplequoted-atpt (&optional arg no-delimiters) 
  "Returns triplequoted at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'triplequoted arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-triplequoted-atpt 'ar-triplequoted-bounds-atpt)
;;;###autoload
(defun ar-triplequoted-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of triplequoted if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'triplequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position triplequoted at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'triplequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of triplequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-triplequoted-atpt 'ar-triplequoted-beginning-atpt)
;;;###autoload
(defun ar-triplequoted-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class triplequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-end-of-triplequoted-atpt 'ar-triplequoted-end-atpt)
;;;###autoload
(defun ar-triplequoted-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class triplequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-length-of-triplequoted-atpt 'ar-triplequoted-length-atpt)
;;;###autoload
(defun ar-triplequoted-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class triplequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-copy-triplequoted-atpt 'ar-triplequoted-copy-atpt)
;;;###autoload
(defun ar-triplequoted-copy-atpt (&optional no-delimiters) 
  "Returns a copy of triplequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-delete-triplequoted-in-region 'ar-triplequoted-delete-in-region)
;;;###autoload
(defun ar-triplequoted-delete-in-region (beg end) 
  "Deletes triplequoted at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'triplequoted beg end (interactive-p)))

;;;###autoload
(defun ar-blok-triplequoted-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around triplequoted.
  Returns blok or nil if no triplequoted at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-escape-triplequoted-atpt 'ar-triplequoted-escape-atpt)
;;;###autoload
(defun ar-triplequoted-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted triplequoted at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'triplequoted no-delimiters))

(defalias 'ar-doublequote-triplequoted-atpt 'ar-triplequoted-doublequote-atpt)
;;;###autoload
(defun ar-triplequoted-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-slash-triplequoted-atpt 'ar-triplequoted-slash-atpt)
;;;###autoload
(defun ar-triplequoted-slash-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted at point if any. "
  (interactive "*p")
  (ar-th-slash 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-triplequoted-atpt 'ar-triplequoted-double-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-triplequoted-atpt 'ar-triplequoted-doubleslash-atpt)
;;;###autoload
(defun ar-triplequoted-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-triplequoted-atpt 'ar-triplequoted-doubleslashparen-atpt)
;;;###autoload
(defun ar-triplequoted-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-slashparen-triplequoted-atpt 'ar-triplequoted-slashparen-atpt)
;;;###autoload
(defun ar-triplequoted-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-dollar-triplequoted-atpt 'ar-triplequoted-dollar-atpt)
;;;###autoload
(defun ar-triplequoted-dollar-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted at point if any. "
  (interactive "*p")
  (ar-th-dollar 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-equalize-triplequoted-atpt 'ar-triplequoted-equalize-atpt)
;;;###autoload
(defun ar-triplequoted-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-equalize 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-triplequoted-atpt 'ar-triplequoted-greater-angle-atpt)
;;;###autoload
(defun ar-triplequoted-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-triplequoted-atpt 'ar-triplequoted-lesser-angle-atpt)
;;;###autoload
(defun ar-triplequoted-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-backslash-triplequoted-atpt 'ar-triplequoted-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-backslash-atpt (&optional no-delimiters) 
  "Backslash triplequoted at point if any. "
  (interactive "*p")
  (ar-th-backslash 'triplequoted no-delimiters (interactive-p))) 

(defalias 'ar-brace-triplequoted-atpt 'ar-triplequoted-brace-atpt)
;;;###autoload
(defun ar-triplequoted-brace-atpt (&optional no-delimiters) 
  "Braces triplequoted at point if any. "
  (interactive "*p")
  (ar-th-brace 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-bracket-triplequoted-atpt 'ar-triplequoted-bracket-atpt)
;;;###autoload
(defun ar-triplequoted-bracket-atpt (&optional no-delimiters) 
  "Brackets triplequoted after point if any. "
  (interactive "*p")
  (ar-th-bracket 'triplequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-triplequoted-atpt (&optional no-delimiters) 
  "Comments triplequoted at point if any. "
  (interactive "*p")
  (ar-th-comment 'triplequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-triplequoted-atpt (&optional no-delimiters) 
  "Put a comma after triplequoted at point if any. "
  (interactive "*p")
  (ar-th-commatize 'triplequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-triplequoted-atpt (&optional no-delimiters) 
  "Put a singlequote before triplequoted at point if any. "
  (interactive "*p")
  (ar-th-quote 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-hyphen-triplequoted-atpt 'ar-triplequoted-hyphen-atpt)
;;;###autoload
(defun ar-triplequoted-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around triplequoted at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-mark-triplequoted-atpt 'ar-triplequoted-mark-atpt)
;;;###autoload
(defun ar-triplequoted-mark-atpt () 
  "Marks triplequoted at point if any. "
  (interactive)
  (ar-th-mark 'triplequoted))

(defalias 'ar-hide-triplequoted-atpt 'ar-triplequoted-hide-atpt)
;;;###autoload
(defun ar-triplequoted-hide-atpt () 
  "Hides triplequoted at point. "
  (interactive)
  (ar-th-hide 'triplequoted))

(defalias 'ar-show-triplequoted-atpt 'ar-triplequoted-show-atpt)
;;;###autoload
(defun ar-triplequoted-show-atpt () 
  "Shows hidden triplequoted at point. "
  (interactive)
  (ar-th-show 'triplequoted))

(defalias 'ar-hide-show-triplequoted-atpt 'ar-triplequoted-hide-show-atpt)
;;;###autoload
(defun ar-triplequoted-hide-show-atpt () 
  "Alternatively hides or shows triplequoted at point. "
  (interactive)
  (ar-th-hide-show 'triplequoted))

(defalias 'ar-highlight-triplequoted-atpt-mode 'ar-triplequoted-highlight-atpt-mode)
(defun ar-triplequoted-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles triplequoted-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-kill-triplequoted-atpt 'ar-triplequoted-kill-atpt)
;;;###autoload
(defun ar-triplequoted-kill-atpt (&optional no-delimiters) 
  "Kills triplequoted at point if any. "
  (interactive "*P")
  (ar-th-kill 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-triplequoted-atpt 'ar-triplequoted-left-right-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-parentize-triplequoted-atpt 'ar-triplequoted-parentize-atpt)
;;;###autoload
(defun ar-triplequoted-parentize-atpt (&optional no-delimiters) 
  "Parentizes triplequoted at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-separate-triplequoted-atpt 'ar-triplequoted-separate-atpt)
;;;###autoload
(defun ar-triplequoted-separate-atpt (&optional no-delimiters) 
  "Separates triplequoted at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-singlequote-triplequoted-atpt 'ar-triplequoted-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes triplequoted at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-triplequoted-atpt 'ar-triplequoted-triplequote-dq-atpt)
;;;###autoload
(defun ar-triplequoted-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around triplequoted. "
  (interactive "*p")
  (ar-th-triplequote-dq 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-triplequoted-atpt 'ar-triplequoted-triplequote-sq-atpt)
;;;###autoload
(defun ar-triplequoted-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around triplequoted. "
  (interactive "*p")
  (ar-th-triplequote-sq 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-trim-triplequoted-atpt 'ar-triplequoted-trim-atpt)
;;;###autoload
(defun ar-triplequoted-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted t t)) 
    (ar-th-trim 'triplequoted t t)))

(defalias 'ar-trim-left-triplequoted-atpt 'ar-triplequoted-left-trim-atpt)
;;;###autoload
(defun ar-triplequoted-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted t nil))
    (ar-th-trim 'triplequoted t nil)))

(defalias 'ar-trim-right-triplequoted-atpt 'ar-triplequoted-right-trim-atpt)
;;;###autoload
(defun ar-triplequoted-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted nil t))
    (ar-th-trim 'triplequoted nil t)))

(defalias 'ar-triplequoted-underscore-atpt 'ar-underscore-triplequoted-atpt)
;;;###autoload
(defun ar-underscore-triplequoted-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'triplequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequoted-whitespace-atpt 'ar-whitespace-triplequoted-atpt)
;;;###autoload
(defun ar-whitespace-triplequoted-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'triplequoted nil t))

(defalias 'ar-forward-triplequoted-atpt 'ar-triplequoted-forward-atpt)
;;;###autoload
(defun ar-triplequoted-forward-atpt (&optional arg) 
  "Moves forward over triplequoted at point if any, does nothing otherwise.
Returns end position of triplequoted "
  (interactive "p")
  (ar-th-forward 'triplequoted arg (interactive-p)))

(defalias 'ar-backward-triplequoted-atpt 'ar-triplequoted-backward-atpt)
;;;###autoload
(defun ar-triplequoted-backward-atpt (&optional arg) 
  "Moves backward over triplequoted before point if any, does nothing otherwise.
Returns beginning position of triplequoted "
  (interactive "p")
  (ar-th-backward 'triplequoted arg (interactive-p)))

(defalias 'ar-transpose-triplequoted-atpt 'ar-triplequoted-transpose-atpt)
;;;###autoload
(defun ar-triplequoted-transpose-atpt (&optional arg) 
  "Transposes triplequoted with triplequoted before point if any. "
  (interactive "*p")
  (ar-th-transpose 'triplequoted arg (interactive-p)))

(defalias 'ar-sort-triplequoted-atpt 'ar-triplequoted-sort-atpt)
;;;###autoload
(defun ar-triplequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts triplequoteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'triplequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-triplequoted-atpt 'ar-triplequoted-check-atpt)
;;;###autoload
(defun ar-triplequoted-check-atpt () 
  "Return t if a triplequoted at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-triplequoted-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-triplequoted-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-triplequoted-dq-atpt (&optional arg no-delimiters) 
  "Returns triplequoted-dq at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'triplequoted-dq arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-triplequoted-dq-atpt 'ar-triplequoted-dq-bounds-atpt)
;;;###autoload
(defun ar-triplequoted-dq-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of triplequoted-dq if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'triplequoted-dq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-dq-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position triplequoted-dq at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'triplequoted-dq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-dq-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of triplequoted-dq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-triplequoted-dq-atpt 'ar-triplequoted-dq-beginning-atpt)
;;;###autoload
(defun ar-triplequoted-dq-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class triplequoted-dq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-end-of-triplequoted-dq-atpt 'ar-triplequoted-dq-end-atpt)
;;;###autoload
(defun ar-triplequoted-dq-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class triplequoted-dq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-length-of-triplequoted-dq-atpt 'ar-triplequoted-dq-length-atpt)
;;;###autoload
(defun ar-triplequoted-dq-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class triplequoted-dq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-copy-triplequoted-dq-atpt 'ar-triplequoted-dq-copy-atpt)
;;;###autoload
(defun ar-triplequoted-dq-copy-atpt (&optional no-delimiters) 
  "Returns a copy of triplequoted-dq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-delete-triplequoted-dq-in-region 'ar-triplequoted-dq-delete-in-region)
;;;###autoload
(defun ar-triplequoted-dq-delete-in-region (beg end) 
  "Deletes triplequoted-dq at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'triplequoted-dq beg end (interactive-p)))

;;;###autoload
(defun ar-blok-triplequoted-dq-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around triplequoted-dq.
  Returns blok or nil if no triplequoted-dq at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-escape-triplequoted-dq-atpt 'ar-triplequoted-dq-escape-atpt)
;;;###autoload
(defun ar-triplequoted-dq-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted triplequoted-dq at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'triplequoted-dq no-delimiters))

(defalias 'ar-doublequote-triplequoted-dq-atpt 'ar-triplequoted-dq-doublequote-atpt)
;;;###autoload
(defun ar-triplequoted-dq-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-slash-triplequoted-dq-atpt 'ar-triplequoted-dq-slash-atpt)
;;;###autoload
(defun ar-triplequoted-dq-slash-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-slash 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-triplequoted-dq-atpt 'ar-triplequoted-dq-double-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-dq-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-triplequoted-dq-atpt 'ar-triplequoted-dq-doubleslash-atpt)
;;;###autoload
(defun ar-triplequoted-dq-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-triplequoted-dq-atpt 'ar-triplequoted-dq-doubleslashparen-atpt)
;;;###autoload
(defun ar-triplequoted-dq-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-slashparen-triplequoted-dq-atpt 'ar-triplequoted-dq-slashparen-atpt)
;;;###autoload
(defun ar-triplequoted-dq-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-dollar-triplequoted-dq-atpt 'ar-triplequoted-dq-dollar-atpt)
;;;###autoload
(defun ar-triplequoted-dq-dollar-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-dollar 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-equalize-triplequoted-dq-atpt 'ar-triplequoted-dq-equalize-atpt)
;;;###autoload
(defun ar-triplequoted-dq-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-equalize 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-triplequoted-dq-atpt 'ar-triplequoted-dq-greater-angle-atpt)
;;;###autoload
(defun ar-triplequoted-dq-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted-dq after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-triplequoted-dq-atpt 'ar-triplequoted-dq-lesser-angle-atpt)
;;;###autoload
(defun ar-triplequoted-dq-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted-dq after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-backslash-triplequoted-dq-atpt 'ar-triplequoted-dq-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-dq-backslash-atpt (&optional no-delimiters) 
  "Backslash triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-backslash 'triplequoted-dq no-delimiters (interactive-p))) 

(defalias 'ar-brace-triplequoted-dq-atpt 'ar-triplequoted-dq-brace-atpt)
;;;###autoload
(defun ar-triplequoted-dq-brace-atpt (&optional no-delimiters) 
  "Braces triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-brace 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-bracket-triplequoted-dq-atpt 'ar-triplequoted-dq-bracket-atpt)
;;;###autoload
(defun ar-triplequoted-dq-bracket-atpt (&optional no-delimiters) 
  "Brackets triplequoted-dq after point if any. "
  (interactive "*p")
  (ar-th-bracket 'triplequoted-dq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-triplequoted-dq-atpt (&optional no-delimiters) 
  "Comments triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-comment 'triplequoted-dq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-triplequoted-dq-atpt (&optional no-delimiters) 
  "Put a comma after triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-commatize 'triplequoted-dq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-triplequoted-dq-atpt (&optional no-delimiters) 
  "Put a singlequote before triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-quote 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-hyphen-triplequoted-dq-atpt 'ar-triplequoted-dq-hyphen-atpt)
;;;###autoload
(defun ar-triplequoted-dq-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-mark-triplequoted-dq-atpt 'ar-triplequoted-dq-mark-atpt)
;;;###autoload
(defun ar-triplequoted-dq-mark-atpt () 
  "Marks triplequoted-dq at point if any. "
  (interactive)
  (ar-th-mark 'triplequoted-dq))

(defalias 'ar-hide-triplequoted-dq-atpt 'ar-triplequoted-dq-hide-atpt)
;;;###autoload
(defun ar-triplequoted-dq-hide-atpt () 
  "Hides triplequoted-dq at point. "
  (interactive)
  (ar-th-hide 'triplequoted-dq))

(defalias 'ar-show-triplequoted-dq-atpt 'ar-triplequoted-dq-show-atpt)
;;;###autoload
(defun ar-triplequoted-dq-show-atpt () 
  "Shows hidden triplequoted-dq at point. "
  (interactive)
  (ar-th-show 'triplequoted-dq))

(defalias 'ar-hide-show-triplequoted-dq-atpt 'ar-triplequoted-dq-hide-show-atpt)
;;;###autoload
(defun ar-triplequoted-dq-hide-show-atpt () 
  "Alternatively hides or shows triplequoted-dq at point. "
  (interactive)
  (ar-th-hide-show 'triplequoted-dq))

(defalias 'ar-highlight-triplequoted-dq-atpt-mode 'ar-triplequoted-dq-highlight-atpt-mode)
(defun ar-triplequoted-dq-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles triplequoted-dq-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-kill-triplequoted-dq-atpt 'ar-triplequoted-dq-kill-atpt)
;;;###autoload
(defun ar-triplequoted-dq-kill-atpt (&optional no-delimiters) 
  "Kills triplequoted-dq at point if any. "
  (interactive "*P")
  (ar-th-kill 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-triplequoted-dq-atpt 'ar-triplequoted-dq-left-right-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-dq-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-parentize-triplequoted-dq-atpt 'ar-triplequoted-dq-parentize-atpt)
;;;###autoload
(defun ar-triplequoted-dq-parentize-atpt (&optional no-delimiters) 
  "Parentizes triplequoted-dq at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-separate-triplequoted-dq-atpt 'ar-triplequoted-dq-separate-atpt)
;;;###autoload
(defun ar-triplequoted-dq-separate-atpt (&optional no-delimiters) 
  "Separates triplequoted-dq at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-singlequote-triplequoted-dq-atpt 'ar-triplequoted-dq-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-dq-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes triplequoted-dq at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-triplequoted-dq-atpt 'ar-triplequoted-dq-triplequote-dq-atpt)
;;;###autoload
(defun ar-triplequoted-dq-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around triplequoted-dq. "
  (interactive "*p")
  (ar-th-triplequote-dq 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-triplequoted-dq-atpt 'ar-triplequoted-dq-triplequote-sq-atpt)
;;;###autoload
(defun ar-triplequoted-dq-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around triplequoted-dq. "
  (interactive "*p")
  (ar-th-triplequote-sq 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-trim-triplequoted-dq-atpt 'ar-triplequoted-dq-trim-atpt)
;;;###autoload
(defun ar-triplequoted-dq-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-dq t t)) 
    (ar-th-trim 'triplequoted-dq t t)))

(defalias 'ar-trim-left-triplequoted-dq-atpt 'ar-triplequoted-dq-left-trim-atpt)
;;;###autoload
(defun ar-triplequoted-dq-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-dq t nil))
    (ar-th-trim 'triplequoted-dq t nil)))

(defalias 'ar-trim-right-triplequoted-dq-atpt 'ar-triplequoted-dq-right-trim-atpt)
;;;###autoload
(defun ar-triplequoted-dq-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-dq nil t))
    (ar-th-trim 'triplequoted-dq nil t)))

(defalias 'ar-triplequoted-dq-underscore-atpt 'ar-underscore-triplequoted-dq-atpt)
;;;###autoload
(defun ar-underscore-triplequoted-dq-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'triplequoted-dq no-delimiters (interactive-p)))

(defalias 'ar-triplequoted-dq-whitespace-atpt 'ar-whitespace-triplequoted-dq-atpt)
;;;###autoload
(defun ar-whitespace-triplequoted-dq-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'triplequoted-dq nil t))

(defalias 'ar-forward-triplequoted-dq-atpt 'ar-triplequoted-dq-forward-atpt)
;;;###autoload
(defun ar-triplequoted-dq-forward-atpt (&optional arg) 
  "Moves forward over triplequoted-dq at point if any, does nothing otherwise.
Returns end position of triplequoted-dq "
  (interactive "p")
  (ar-th-forward 'triplequoted-dq arg (interactive-p)))

(defalias 'ar-backward-triplequoted-dq-atpt 'ar-triplequoted-dq-backward-atpt)
;;;###autoload
(defun ar-triplequoted-dq-backward-atpt (&optional arg) 
  "Moves backward over triplequoted-dq before point if any, does nothing otherwise.
Returns beginning position of triplequoted-dq "
  (interactive "p")
  (ar-th-backward 'triplequoted-dq arg (interactive-p)))

(defalias 'ar-transpose-triplequoted-dq-atpt 'ar-triplequoted-dq-transpose-atpt)
;;;###autoload
(defun ar-triplequoted-dq-transpose-atpt (&optional arg) 
  "Transposes triplequoted-dq with triplequoted-dq before point if any. "
  (interactive "*p")
  (ar-th-transpose 'triplequoted-dq arg (interactive-p)))

(defalias 'ar-sort-triplequoted-dq-atpt 'ar-triplequoted-dq-sort-atpt)
;;;###autoload
(defun ar-triplequoted-dq-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts triplequoted-dqs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'triplequoted-dq reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-triplequoted-dq-atpt 'ar-triplequoted-dq-check-atpt)
;;;###autoload
(defun ar-triplequoted-dq-check-atpt () 
  "Return t if a triplequoted-dq at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-triplequoted-dq-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-triplequoted-dq-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-triplequoted-sq-atpt (&optional arg no-delimiters) 
  "Returns triplequoted-sq at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'triplequoted-sq arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-triplequoted-sq-atpt 'ar-triplequoted-sq-bounds-atpt)
;;;###autoload
(defun ar-triplequoted-sq-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of triplequoted-sq if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'triplequoted-sq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-sq-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position triplequoted-sq at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'triplequoted-sq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-triplequoted-sq-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of triplequoted-sq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-triplequoted-sq-atpt 'ar-triplequoted-sq-beginning-atpt)
;;;###autoload
(defun ar-triplequoted-sq-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class triplequoted-sq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-end-of-triplequoted-sq-atpt 'ar-triplequoted-sq-end-atpt)
;;;###autoload
(defun ar-triplequoted-sq-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class triplequoted-sq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-length-of-triplequoted-sq-atpt 'ar-triplequoted-sq-length-atpt)
;;;###autoload
(defun ar-triplequoted-sq-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class triplequoted-sq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-copy-triplequoted-sq-atpt 'ar-triplequoted-sq-copy-atpt)
;;;###autoload
(defun ar-triplequoted-sq-copy-atpt (&optional no-delimiters) 
  "Returns a copy of triplequoted-sq at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-delete-triplequoted-sq-in-region 'ar-triplequoted-sq-delete-in-region)
;;;###autoload
(defun ar-triplequoted-sq-delete-in-region (beg end) 
  "Deletes triplequoted-sq at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'triplequoted-sq beg end (interactive-p)))

;;;###autoload
(defun ar-blok-triplequoted-sq-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around triplequoted-sq.
  Returns blok or nil if no triplequoted-sq at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-escape-triplequoted-sq-atpt 'ar-triplequoted-sq-escape-atpt)
;;;###autoload
(defun ar-triplequoted-sq-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted triplequoted-sq at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'triplequoted-sq no-delimiters))

(defalias 'ar-doublequote-triplequoted-sq-atpt 'ar-triplequoted-sq-doublequote-atpt)
;;;###autoload
(defun ar-triplequoted-sq-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-slash-triplequoted-sq-atpt 'ar-triplequoted-sq-slash-atpt)
;;;###autoload
(defun ar-triplequoted-sq-slash-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-slash 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-triplequoted-sq-atpt 'ar-triplequoted-sq-double-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-sq-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-triplequoted-sq-atpt 'ar-triplequoted-sq-doubleslash-atpt)
;;;###autoload
(defun ar-triplequoted-sq-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-triplequoted-sq-atpt 'ar-triplequoted-sq-doubleslashparen-atpt)
;;;###autoload
(defun ar-triplequoted-sq-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-slashparen-triplequoted-sq-atpt 'ar-triplequoted-sq-slashparen-atpt)
;;;###autoload
(defun ar-triplequoted-sq-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-dollar-triplequoted-sq-atpt 'ar-triplequoted-sq-dollar-atpt)
;;;###autoload
(defun ar-triplequoted-sq-dollar-atpt (&optional no-delimiters) 
  "Doublequotes triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-dollar 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-equalize-triplequoted-sq-atpt 'ar-triplequoted-sq-equalize-atpt)
;;;###autoload
(defun ar-triplequoted-sq-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-equalize 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-triplequoted-sq-atpt 'ar-triplequoted-sq-greater-angle-atpt)
;;;###autoload
(defun ar-triplequoted-sq-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted-sq after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-triplequoted-sq-atpt 'ar-triplequoted-sq-lesser-angle-atpt)
;;;###autoload
(defun ar-triplequoted-sq-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for triplequoted-sq after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-backslash-triplequoted-sq-atpt 'ar-triplequoted-sq-backslash-atpt)
;;;###autoload
(defun ar-triplequoted-sq-backslash-atpt (&optional no-delimiters) 
  "Backslash triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-backslash 'triplequoted-sq no-delimiters (interactive-p))) 

(defalias 'ar-brace-triplequoted-sq-atpt 'ar-triplequoted-sq-brace-atpt)
;;;###autoload
(defun ar-triplequoted-sq-brace-atpt (&optional no-delimiters) 
  "Braces triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-brace 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-bracket-triplequoted-sq-atpt 'ar-triplequoted-sq-bracket-atpt)
;;;###autoload
(defun ar-triplequoted-sq-bracket-atpt (&optional no-delimiters) 
  "Brackets triplequoted-sq after point if any. "
  (interactive "*p")
  (ar-th-bracket 'triplequoted-sq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-triplequoted-sq-atpt (&optional no-delimiters) 
  "Comments triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-comment 'triplequoted-sq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-triplequoted-sq-atpt (&optional no-delimiters) 
  "Put a comma after triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-commatize 'triplequoted-sq no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-triplequoted-sq-atpt (&optional no-delimiters) 
  "Put a singlequote before triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-quote 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-hyphen-triplequoted-sq-atpt 'ar-triplequoted-sq-hyphen-atpt)
;;;###autoload
(defun ar-triplequoted-sq-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-mark-triplequoted-sq-atpt 'ar-triplequoted-sq-mark-atpt)
;;;###autoload
(defun ar-triplequoted-sq-mark-atpt () 
  "Marks triplequoted-sq at point if any. "
  (interactive)
  (ar-th-mark 'triplequoted-sq))

(defalias 'ar-hide-triplequoted-sq-atpt 'ar-triplequoted-sq-hide-atpt)
;;;###autoload
(defun ar-triplequoted-sq-hide-atpt () 
  "Hides triplequoted-sq at point. "
  (interactive)
  (ar-th-hide 'triplequoted-sq))

(defalias 'ar-show-triplequoted-sq-atpt 'ar-triplequoted-sq-show-atpt)
;;;###autoload
(defun ar-triplequoted-sq-show-atpt () 
  "Shows hidden triplequoted-sq at point. "
  (interactive)
  (ar-th-show 'triplequoted-sq))

(defalias 'ar-hide-show-triplequoted-sq-atpt 'ar-triplequoted-sq-hide-show-atpt)
;;;###autoload
(defun ar-triplequoted-sq-hide-show-atpt () 
  "Alternatively hides or shows triplequoted-sq at point. "
  (interactive)
  (ar-th-hide-show 'triplequoted-sq))

(defalias 'ar-highlight-triplequoted-sq-atpt-mode 'ar-triplequoted-sq-highlight-atpt-mode)
(defun ar-triplequoted-sq-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles triplequoted-sq-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-kill-triplequoted-sq-atpt 'ar-triplequoted-sq-kill-atpt)
;;;###autoload
(defun ar-triplequoted-sq-kill-atpt (&optional no-delimiters) 
  "Kills triplequoted-sq at point if any. "
  (interactive "*P")
  (ar-th-kill 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-triplequoted-sq-atpt 'ar-triplequoted-sq-left-right-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-sq-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-parentize-triplequoted-sq-atpt 'ar-triplequoted-sq-parentize-atpt)
;;;###autoload
(defun ar-triplequoted-sq-parentize-atpt (&optional no-delimiters) 
  "Parentizes triplequoted-sq at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-separate-triplequoted-sq-atpt 'ar-triplequoted-sq-separate-atpt)
;;;###autoload
(defun ar-triplequoted-sq-separate-atpt (&optional no-delimiters) 
  "Separates triplequoted-sq at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-singlequote-triplequoted-sq-atpt 'ar-triplequoted-sq-singlequote-atpt)
;;;###autoload
(defun ar-triplequoted-sq-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes triplequoted-sq at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-triplequoted-sq-atpt 'ar-triplequoted-sq-triplequote-dq-atpt)
;;;###autoload
(defun ar-triplequoted-sq-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around triplequoted-sq. "
  (interactive "*p")
  (ar-th-triplequote-dq 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-triplequoted-sq-atpt 'ar-triplequoted-sq-triplequote-sq-atpt)
;;;###autoload
(defun ar-triplequoted-sq-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around triplequoted-sq. "
  (interactive "*p")
  (ar-th-triplequote-sq 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-trim-triplequoted-sq-atpt 'ar-triplequoted-sq-trim-atpt)
;;;###autoload
(defun ar-triplequoted-sq-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-sq t t)) 
    (ar-th-trim 'triplequoted-sq t t)))

(defalias 'ar-trim-left-triplequoted-sq-atpt 'ar-triplequoted-sq-left-trim-atpt)
;;;###autoload
(defun ar-triplequoted-sq-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-sq t nil))
    (ar-th-trim 'triplequoted-sq t nil)))

(defalias 'ar-trim-right-triplequoted-sq-atpt 'ar-triplequoted-sq-right-trim-atpt)
;;;###autoload
(defun ar-triplequoted-sq-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'triplequoted-sq nil t))
    (ar-th-trim 'triplequoted-sq nil t)))

(defalias 'ar-triplequoted-sq-underscore-atpt 'ar-underscore-triplequoted-sq-atpt)
;;;###autoload
(defun ar-underscore-triplequoted-sq-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'triplequoted-sq no-delimiters (interactive-p)))

(defalias 'ar-triplequoted-sq-whitespace-atpt 'ar-whitespace-triplequoted-sq-atpt)
;;;###autoload
(defun ar-whitespace-triplequoted-sq-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'triplequoted-sq nil t))

(defalias 'ar-forward-triplequoted-sq-atpt 'ar-triplequoted-sq-forward-atpt)
;;;###autoload
(defun ar-triplequoted-sq-forward-atpt (&optional arg) 
  "Moves forward over triplequoted-sq at point if any, does nothing otherwise.
Returns end position of triplequoted-sq "
  (interactive "p")
  (ar-th-forward 'triplequoted-sq arg (interactive-p)))

(defalias 'ar-backward-triplequoted-sq-atpt 'ar-triplequoted-sq-backward-atpt)
;;;###autoload
(defun ar-triplequoted-sq-backward-atpt (&optional arg) 
  "Moves backward over triplequoted-sq before point if any, does nothing otherwise.
Returns beginning position of triplequoted-sq "
  (interactive "p")
  (ar-th-backward 'triplequoted-sq arg (interactive-p)))

(defalias 'ar-transpose-triplequoted-sq-atpt 'ar-triplequoted-sq-transpose-atpt)
;;;###autoload
(defun ar-triplequoted-sq-transpose-atpt (&optional arg) 
  "Transposes triplequoted-sq with triplequoted-sq before point if any. "
  (interactive "*p")
  (ar-th-transpose 'triplequoted-sq arg (interactive-p)))

(defalias 'ar-sort-triplequoted-sq-atpt 'ar-triplequoted-sq-sort-atpt)
;;;###autoload
(defun ar-triplequoted-sq-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts triplequoted-sqs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'triplequoted-sq reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-triplequoted-sq-atpt 'ar-triplequoted-sq-check-atpt)
;;;###autoload
(defun ar-triplequoted-sq-check-atpt () 
  "Return t if a triplequoted-sq at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-triplequoted-sq-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-triplequoted-sq-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-underscored-atpt (&optional arg no-delimiters) 
  "Returns underscored at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'underscored arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-underscored-atpt 'ar-underscored-bounds-atpt)
;;;###autoload
(defun ar-underscored-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of underscored if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'underscored no-delimiters (interactive-p)))

;;;###autoload
(defun ar-underscored-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position underscored at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'underscored no-delimiters (interactive-p)))

;;;###autoload
(defun ar-underscored-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of underscored at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'underscored no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-underscored-atpt 'ar-underscored-beginning-atpt)
;;;###autoload
(defun ar-underscored-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class underscored at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'underscored no-delimiters (interactive-p)))

(defalias 'ar-end-of-underscored-atpt 'ar-underscored-end-atpt)
;;;###autoload
(defun ar-underscored-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class underscored at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'underscored no-delimiters (interactive-p)))

(defalias 'ar-length-of-underscored-atpt 'ar-underscored-length-atpt)
;;;###autoload
(defun ar-underscored-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class underscored at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'underscored no-delimiters (interactive-p)))

(defalias 'ar-copy-underscored-atpt 'ar-underscored-copy-atpt)
;;;###autoload
(defun ar-underscored-copy-atpt (&optional no-delimiters) 
  "Returns a copy of underscored at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'underscored no-delimiters (interactive-p)))

(defalias 'ar-delete-underscored-in-region 'ar-underscored-delete-in-region)
;;;###autoload
(defun ar-underscored-delete-in-region (beg end) 
  "Deletes underscored at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'underscored beg end (interactive-p)))

;;;###autoload
(defun ar-blok-underscored-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around underscored.
  Returns blok or nil if no underscored at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'underscored no-delimiters (interactive-p)))

(defalias 'ar-escape-underscored-atpt 'ar-underscored-escape-atpt)
;;;###autoload
(defun ar-underscored-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted underscored at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'underscored no-delimiters))

(defalias 'ar-doublequote-underscored-atpt 'ar-underscored-doublequote-atpt)
;;;###autoload
(defun ar-underscored-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes underscored at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'underscored no-delimiters (interactive-p)))

(defalias 'ar-slash-underscored-atpt 'ar-underscored-slash-atpt)
;;;###autoload
(defun ar-underscored-slash-atpt (&optional no-delimiters) 
  "Doublequotes underscored at point if any. "
  (interactive "*p")
  (ar-th-slash 'underscored no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-underscored-atpt 'ar-underscored-double-backslash-atpt)
;;;###autoload
(defun ar-underscored-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around underscored at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'underscored no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-underscored-atpt 'ar-underscored-doubleslash-atpt)
;;;###autoload
(defun ar-underscored-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around underscored at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'underscored no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-underscored-atpt 'ar-underscored-doubleslashparen-atpt)
;;;###autoload
(defun ar-underscored-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around underscored at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'underscored no-delimiters (interactive-p)))

(defalias 'ar-slashparen-underscored-atpt 'ar-underscored-slashparen-atpt)
;;;###autoload
(defun ar-underscored-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around underscored at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'underscored no-delimiters (interactive-p)))

(defalias 'ar-dollar-underscored-atpt 'ar-underscored-dollar-atpt)
;;;###autoload
(defun ar-underscored-dollar-atpt (&optional no-delimiters) 
  "Doublequotes underscored at point if any. "
  (interactive "*p")
  (ar-th-dollar 'underscored no-delimiters (interactive-p)))

(defalias 'ar-equalize-underscored-atpt 'ar-underscored-equalize-atpt)
;;;###autoload
(defun ar-underscored-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around underscored at point if any. "
  (interactive "*p")
  (ar-th-equalize 'underscored no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-underscored-atpt 'ar-underscored-greater-angle-atpt)
;;;###autoload
(defun ar-underscored-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for underscored after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'underscored no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-underscored-atpt 'ar-underscored-lesser-angle-atpt)
;;;###autoload
(defun ar-underscored-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for underscored after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'underscored no-delimiters (interactive-p)))

(defalias 'ar-backslash-underscored-atpt 'ar-underscored-backslash-atpt)
;;;###autoload
(defun ar-underscored-backslash-atpt (&optional no-delimiters) 
  "Backslash underscored at point if any. "
  (interactive "*p")
  (ar-th-backslash 'underscored no-delimiters (interactive-p))) 

(defalias 'ar-brace-underscored-atpt 'ar-underscored-brace-atpt)
;;;###autoload
(defun ar-underscored-brace-atpt (&optional no-delimiters) 
  "Braces underscored at point if any. "
  (interactive "*p")
  (ar-th-brace 'underscored no-delimiters (interactive-p)))

(defalias 'ar-bracket-underscored-atpt 'ar-underscored-bracket-atpt)
;;;###autoload
(defun ar-underscored-bracket-atpt (&optional no-delimiters) 
  "Brackets underscored after point if any. "
  (interactive "*p")
  (ar-th-bracket 'underscored no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-underscored-atpt (&optional no-delimiters) 
  "Comments underscored at point if any. "
  (interactive "*p")
  (ar-th-comment 'underscored no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-underscored-atpt (&optional no-delimiters) 
  "Put a comma after underscored at point if any. "
  (interactive "*p")
  (ar-th-commatize 'underscored no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-underscored-atpt (&optional no-delimiters) 
  "Put a singlequote before underscored at point if any. "
  (interactive "*p")
  (ar-th-quote 'underscored no-delimiters (interactive-p)))

(defalias 'ar-hyphen-underscored-atpt 'ar-underscored-hyphen-atpt)
;;;###autoload
(defun ar-underscored-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around underscored at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'underscored no-delimiters (interactive-p)))

(defalias 'ar-mark-underscored-atpt 'ar-underscored-mark-atpt)
;;;###autoload
(defun ar-underscored-mark-atpt () 
  "Marks underscored at point if any. "
  (interactive)
  (ar-th-mark 'underscored))

(defalias 'ar-hide-underscored-atpt 'ar-underscored-hide-atpt)
;;;###autoload
(defun ar-underscored-hide-atpt () 
  "Hides underscored at point. "
  (interactive)
  (ar-th-hide 'underscored))

(defalias 'ar-show-underscored-atpt 'ar-underscored-show-atpt)
;;;###autoload
(defun ar-underscored-show-atpt () 
  "Shows hidden underscored at point. "
  (interactive)
  (ar-th-show 'underscored))

(defalias 'ar-hide-show-underscored-atpt 'ar-underscored-hide-show-atpt)
;;;###autoload
(defun ar-underscored-hide-show-atpt () 
  "Alternatively hides or shows underscored at point. "
  (interactive)
  (ar-th-hide-show 'underscored))

(defalias 'ar-highlight-underscored-atpt-mode 'ar-underscored-highlight-atpt-mode)
(defun ar-underscored-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles underscored-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'underscored no-delimiters (interactive-p)))

(defalias 'ar-kill-underscored-atpt 'ar-underscored-kill-atpt)
;;;###autoload
(defun ar-underscored-kill-atpt (&optional no-delimiters) 
  "Kills underscored at point if any. "
  (interactive "*P")
  (ar-th-kill 'underscored no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-underscored-atpt 'ar-underscored-left-right-singlequote-atpt)
;;;###autoload
(defun ar-underscored-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'underscored no-delimiters (interactive-p)))

(defalias 'ar-parentize-underscored-atpt 'ar-underscored-parentize-atpt)
;;;###autoload
(defun ar-underscored-parentize-atpt (&optional no-delimiters) 
  "Parentizes underscored at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'underscored no-delimiters (interactive-p)))

(defalias 'ar-separate-underscored-atpt 'ar-underscored-separate-atpt)
;;;###autoload
(defun ar-underscored-separate-atpt (&optional no-delimiters) 
  "Separates underscored at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'underscored no-delimiters (interactive-p)))

(defalias 'ar-singlequote-underscored-atpt 'ar-underscored-singlequote-atpt)
;;;###autoload
(defun ar-underscored-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes underscored at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'underscored no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-underscored-atpt 'ar-underscored-triplequote-dq-atpt)
;;;###autoload
(defun ar-underscored-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around underscored. "
  (interactive "*p")
  (ar-th-triplequote-dq 'underscored no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-underscored-atpt 'ar-underscored-triplequote-sq-atpt)
;;;###autoload
(defun ar-underscored-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around underscored. "
  (interactive "*p")
  (ar-th-triplequote-sq 'underscored no-delimiters (interactive-p)))

(defalias 'ar-trim-underscored-atpt 'ar-underscored-trim-atpt)
;;;###autoload
(defun ar-underscored-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'underscored t t)) 
    (ar-th-trim 'underscored t t)))

(defalias 'ar-trim-left-underscored-atpt 'ar-underscored-left-trim-atpt)
;;;###autoload
(defun ar-underscored-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'underscored t nil))
    (ar-th-trim 'underscored t nil)))

(defalias 'ar-trim-right-underscored-atpt 'ar-underscored-right-trim-atpt)
;;;###autoload
(defun ar-underscored-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'underscored nil t))
    (ar-th-trim 'underscored nil t)))

(defalias 'ar-underscored-underscore-atpt 'ar-underscore-underscored-atpt)
;;;###autoload
(defun ar-underscore-underscored-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'underscored no-delimiters (interactive-p)))

(defalias 'ar-underscored-whitespace-atpt 'ar-whitespace-underscored-atpt)
;;;###autoload
(defun ar-whitespace-underscored-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'underscored nil t))

(defalias 'ar-forward-underscored-atpt 'ar-underscored-forward-atpt)
;;;###autoload
(defun ar-underscored-forward-atpt (&optional arg) 
  "Moves forward over underscored at point if any, does nothing otherwise.
Returns end position of underscored "
  (interactive "p")
  (ar-th-forward 'underscored arg (interactive-p)))

(defalias 'ar-backward-underscored-atpt 'ar-underscored-backward-atpt)
;;;###autoload
(defun ar-underscored-backward-atpt (&optional arg) 
  "Moves backward over underscored before point if any, does nothing otherwise.
Returns beginning position of underscored "
  (interactive "p")
  (ar-th-backward 'underscored arg (interactive-p)))

(defalias 'ar-transpose-underscored-atpt 'ar-underscored-transpose-atpt)
;;;###autoload
(defun ar-underscored-transpose-atpt (&optional arg) 
  "Transposes underscored with underscored before point if any. "
  (interactive "*p")
  (ar-th-transpose 'underscored arg (interactive-p)))

(defalias 'ar-sort-underscored-atpt 'ar-underscored-sort-atpt)
;;;###autoload
(defun ar-underscored-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts underscoreds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'underscored reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-underscored-atpt 'ar-underscored-check-atpt)
;;;###autoload
(defun ar-underscored-check-atpt () 
  "Return t if a underscored at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-underscored-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-underscored-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-whitespaced-atpt (&optional arg no-delimiters) 
  "Returns whitespaced at point if any, nil otherwise."
  (interactive "p\nP")
  (ar-th 'whitespaced arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-whitespaced-atpt 'ar-whitespaced-bounds-atpt)
;;;###autoload
(defun ar-whitespaced-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of whitespaced if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'whitespaced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-whitespaced-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position whitespaced at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'whitespaced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-whitespaced-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of whitespaced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-whitespaced-atpt 'ar-whitespaced-beginning-atpt)
;;;###autoload
(defun ar-whitespaced-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class whitespaced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-end-of-whitespaced-atpt 'ar-whitespaced-end-atpt)
;;;###autoload
(defun ar-whitespaced-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class whitespaced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-length-of-whitespaced-atpt 'ar-whitespaced-length-atpt)
;;;###autoload
(defun ar-whitespaced-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class whitespaced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-copy-whitespaced-atpt 'ar-whitespaced-copy-atpt)
;;;###autoload
(defun ar-whitespaced-copy-atpt (&optional no-delimiters) 
  "Returns a copy of whitespaced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-delete-whitespaced-in-region 'ar-whitespaced-delete-in-region)
;;;###autoload
(defun ar-whitespaced-delete-in-region (beg end) 
  "Deletes whitespaced at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'whitespaced beg end (interactive-p)))

;;;###autoload
(defun ar-blok-whitespaced-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around whitespaced.
  Returns blok or nil if no whitespaced at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-escape-whitespaced-atpt 'ar-whitespaced-escape-atpt)
;;;###autoload
(defun ar-whitespaced-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted whitespaced at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'whitespaced no-delimiters))

(defalias 'ar-doublequote-whitespaced-atpt 'ar-whitespaced-doublequote-atpt)
;;;###autoload
(defun ar-whitespaced-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes whitespaced at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-slash-whitespaced-atpt 'ar-whitespaced-slash-atpt)
;;;###autoload
(defun ar-whitespaced-slash-atpt (&optional no-delimiters) 
  "Doublequotes whitespaced at point if any. "
  (interactive "*p")
  (ar-th-slash 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-whitespaced-atpt 'ar-whitespaced-double-backslash-atpt)
;;;###autoload
(defun ar-whitespaced-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-whitespaced-atpt 'ar-whitespaced-doubleslash-atpt)
;;;###autoload
(defun ar-whitespaced-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-whitespaced-atpt 'ar-whitespaced-doubleslashparen-atpt)
;;;###autoload
(defun ar-whitespaced-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-slashparen-whitespaced-atpt 'ar-whitespaced-slashparen-atpt)
;;;###autoload
(defun ar-whitespaced-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-dollar-whitespaced-atpt 'ar-whitespaced-dollar-atpt)
;;;###autoload
(defun ar-whitespaced-dollar-atpt (&optional no-delimiters) 
  "Doublequotes whitespaced at point if any. "
  (interactive "*p")
  (ar-th-dollar 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-equalize-whitespaced-atpt 'ar-whitespaced-equalize-atpt)
;;;###autoload
(defun ar-whitespaced-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-equalize 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-whitespaced-atpt 'ar-whitespaced-greater-angle-atpt)
;;;###autoload
(defun ar-whitespaced-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for whitespaced after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-whitespaced-atpt 'ar-whitespaced-lesser-angle-atpt)
;;;###autoload
(defun ar-whitespaced-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for whitespaced after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-backslash-whitespaced-atpt 'ar-whitespaced-backslash-atpt)
;;;###autoload
(defun ar-whitespaced-backslash-atpt (&optional no-delimiters) 
  "Backslash whitespaced at point if any. "
  (interactive "*p")
  (ar-th-backslash 'whitespaced no-delimiters (interactive-p))) 

(defalias 'ar-brace-whitespaced-atpt 'ar-whitespaced-brace-atpt)
;;;###autoload
(defun ar-whitespaced-brace-atpt (&optional no-delimiters) 
  "Braces whitespaced at point if any. "
  (interactive "*p")
  (ar-th-brace 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-bracket-whitespaced-atpt 'ar-whitespaced-bracket-atpt)
;;;###autoload
(defun ar-whitespaced-bracket-atpt (&optional no-delimiters) 
  "Brackets whitespaced after point if any. "
  (interactive "*p")
  (ar-th-bracket 'whitespaced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-whitespaced-atpt (&optional no-delimiters) 
  "Comments whitespaced at point if any. "
  (interactive "*p")
  (ar-th-comment 'whitespaced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-whitespaced-atpt (&optional no-delimiters) 
  "Put a comma after whitespaced at point if any. "
  (interactive "*p")
  (ar-th-commatize 'whitespaced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-whitespaced-atpt (&optional no-delimiters) 
  "Put a singlequote before whitespaced at point if any. "
  (interactive "*p")
  (ar-th-quote 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-hyphen-whitespaced-atpt 'ar-whitespaced-hyphen-atpt)
;;;###autoload
(defun ar-whitespaced-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around whitespaced at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-mark-whitespaced-atpt 'ar-whitespaced-mark-atpt)
;;;###autoload
(defun ar-whitespaced-mark-atpt () 
  "Marks whitespaced at point if any. "
  (interactive)
  (ar-th-mark 'whitespaced))

(defalias 'ar-hide-whitespaced-atpt 'ar-whitespaced-hide-atpt)
;;;###autoload
(defun ar-whitespaced-hide-atpt () 
  "Hides whitespaced at point. "
  (interactive)
  (ar-th-hide 'whitespaced))

(defalias 'ar-show-whitespaced-atpt 'ar-whitespaced-show-atpt)
;;;###autoload
(defun ar-whitespaced-show-atpt () 
  "Shows hidden whitespaced at point. "
  (interactive)
  (ar-th-show 'whitespaced))

(defalias 'ar-hide-show-whitespaced-atpt 'ar-whitespaced-hide-show-atpt)
;;;###autoload
(defun ar-whitespaced-hide-show-atpt () 
  "Alternatively hides or shows whitespaced at point. "
  (interactive)
  (ar-th-hide-show 'whitespaced))

(defalias 'ar-highlight-whitespaced-atpt-mode 'ar-whitespaced-highlight-atpt-mode)
(defun ar-whitespaced-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles whitespaced-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-kill-whitespaced-atpt 'ar-whitespaced-kill-atpt)
;;;###autoload
(defun ar-whitespaced-kill-atpt (&optional no-delimiters) 
  "Kills whitespaced at point if any. "
  (interactive "*P")
  (ar-th-kill 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-whitespaced-atpt 'ar-whitespaced-left-right-singlequote-atpt)
;;;###autoload
(defun ar-whitespaced-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-parentize-whitespaced-atpt 'ar-whitespaced-parentize-atpt)
;;;###autoload
(defun ar-whitespaced-parentize-atpt (&optional no-delimiters) 
  "Parentizes whitespaced at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-separate-whitespaced-atpt 'ar-whitespaced-separate-atpt)
;;;###autoload
(defun ar-whitespaced-separate-atpt (&optional no-delimiters) 
  "Separates whitespaced at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-singlequote-whitespaced-atpt 'ar-whitespaced-singlequote-atpt)
;;;###autoload
(defun ar-whitespaced-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes whitespaced at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-whitespaced-atpt 'ar-whitespaced-triplequote-dq-atpt)
;;;###autoload
(defun ar-whitespaced-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around whitespaced. "
  (interactive "*p")
  (ar-th-triplequote-dq 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-whitespaced-atpt 'ar-whitespaced-triplequote-sq-atpt)
;;;###autoload
(defun ar-whitespaced-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around whitespaced. "
  (interactive "*p")
  (ar-th-triplequote-sq 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-trim-whitespaced-atpt 'ar-whitespaced-trim-atpt)
;;;###autoload
(defun ar-whitespaced-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'whitespaced t t)) 
    (ar-th-trim 'whitespaced t t)))

(defalias 'ar-trim-left-whitespaced-atpt 'ar-whitespaced-left-trim-atpt)
;;;###autoload
(defun ar-whitespaced-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'whitespaced t nil))
    (ar-th-trim 'whitespaced t nil)))

(defalias 'ar-trim-right-whitespaced-atpt 'ar-whitespaced-right-trim-atpt)
;;;###autoload
(defun ar-whitespaced-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'whitespaced nil t))
    (ar-th-trim 'whitespaced nil t)))

(defalias 'ar-whitespaced-underscore-atpt 'ar-underscore-whitespaced-atpt)
;;;###autoload
(defun ar-underscore-whitespaced-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'whitespaced no-delimiters (interactive-p)))

(defalias 'ar-whitespaced-whitespace-atpt 'ar-whitespace-whitespaced-atpt)
;;;###autoload
(defun ar-whitespace-whitespaced-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'whitespaced nil t))

(defalias 'ar-forward-whitespaced-atpt 'ar-whitespaced-forward-atpt)
;;;###autoload
(defun ar-whitespaced-forward-atpt (&optional arg) 
  "Moves forward over whitespaced at point if any, does nothing otherwise.
Returns end position of whitespaced "
  (interactive "p")
  (ar-th-forward 'whitespaced arg (interactive-p)))

(defalias 'ar-backward-whitespaced-atpt 'ar-whitespaced-backward-atpt)
;;;###autoload
(defun ar-whitespaced-backward-atpt (&optional arg) 
  "Moves backward over whitespaced before point if any, does nothing otherwise.
Returns beginning position of whitespaced "
  (interactive "p")
  (ar-th-backward 'whitespaced arg (interactive-p)))

(defalias 'ar-transpose-whitespaced-atpt 'ar-whitespaced-transpose-atpt)
;;;###autoload
(defun ar-whitespaced-transpose-atpt (&optional arg) 
  "Transposes whitespaced with whitespaced before point if any. "
  (interactive "*p")
  (ar-th-transpose 'whitespaced arg (interactive-p)))

(defalias 'ar-sort-whitespaced-atpt 'ar-whitespaced-sort-atpt)
;;;###autoload
(defun ar-whitespaced-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts whitespaceds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'whitespaced reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-whitespaced-atpt 'ar-whitespaced-check-atpt)
;;;###autoload
(defun ar-whitespaced-check-atpt () 
  "Return t if a whitespaced at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-whitespaced-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-whitespaced-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;; ar-thing-at-point-utils-delimited-intern: ar-atpt-unpaired-delimited-list-roh end

;; ar-thing-at-point-utils-core: ar-atpt-delimited-list start

;;;###autoload
(defun ar-braced-atpt (&optional arg no-delimiters) 
  "Returns braced at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'braced arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-braced-atpt 'ar-braced-bounds-atpt)
;;;###autoload
(defun ar-braced-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of braced if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'braced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-braced-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position braced at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'braced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-braced-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of braced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'braced no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-braced-atpt 'ar-braced-beginning-atpt)
;;;###autoload
(defun ar-braced-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class braced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'braced no-delimiters (interactive-p)))

(defalias 'ar-end-of-braced-atpt 'ar-braced-end-atpt)
;;;###autoload
(defun ar-braced-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class braced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'braced no-delimiters (interactive-p)))

(defalias 'ar-in-braced-p-atpt 'ar-braced-in-p-atpt)
;;;###autoload
(defun ar-braced-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of braced at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'braced no-delimiters (interactive-p)))

(defalias 'ar-length-of-braced-atpt 'ar-braced-length-atpt)
;;;###autoload
(defun ar-braced-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class braced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'braced no-delimiters (interactive-p)))

(defalias 'ar-copy-braced-atpt 'ar-braced-copy-atpt)
;;;###autoload
(defun ar-braced-copy-atpt (&optional no-delimiters) 
  "Returns a copy of braced at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'braced no-delimiters (interactive-p)))

(defalias 'ar-delete-braced-in-region 'ar-braced-delete-in-region)
;;;###autoload
(defun ar-braced-delete-in-region (beg end) 
  "Deletes braced at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'braced beg end (interactive-p)))

;;;###autoload
(defun ar-blok-braced-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around braced.
  Returns blok or nil if no braced at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'braced no-delimiters (interactive-p)))

(defalias 'ar-escape-braced-atpt 'ar-braced-escape-atpt)
;;;###autoload
(defun ar-braced-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted braced at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'braced no-delimiters))

(defalias 'ar-doublequote-braced-atpt 'ar-braced-doublequote-atpt)
;;;###autoload
(defun ar-braced-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes braced at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'braced no-delimiters (interactive-p)))

(defalias 'ar-slash-braced-atpt 'ar-braced-slash-atpt)
;;;###autoload
(defun ar-braced-slash-atpt (&optional no-delimiters) 
  "Doublequotes braced at point if any. "
  (interactive "*p")
  (ar-th-slash 'braced no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-braced-atpt 'ar-braced-double-backslash-atpt)
;;;###autoload
(defun ar-braced-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around braced at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'braced no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-braced-atpt 'ar-braced-doubleslash-atpt)
;;;###autoload
(defun ar-braced-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around braced at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'braced no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-braced-atpt 'ar-braced-doubleslashparen-atpt)
;;;###autoload
(defun ar-braced-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around braced at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'braced no-delimiters (interactive-p)))

(defalias 'ar-slashparen-braced-atpt 'ar-braced-slashparen-atpt)
;;;###autoload
(defun ar-braced-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around braced at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'braced no-delimiters (interactive-p)))

(defalias 'ar-dollar-braced-atpt 'ar-braced-dollar-atpt)
;;;###autoload
(defun ar-braced-dollar-atpt (&optional no-delimiters) 
  "Doublequotes braced at point if any. "
  (interactive "*p")
  (ar-th-dollar 'braced no-delimiters (interactive-p)))

(defalias 'ar-equalize-braced-atpt 'ar-braced-equalize-atpt)
;;;###autoload
(defun ar-braced-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around braced at point if any. "
  (interactive "*p")
  (ar-th-equalize 'braced no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-braced-atpt 'ar-braced-greater-angle-atpt)
;;;###autoload
(defun ar-braced-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for braced after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'braced no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-braced-atpt 'ar-braced-lesser-angle-atpt)
;;;###autoload
(defun ar-braced-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for braced after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'braced no-delimiters (interactive-p)))

(defalias 'ar-backslash-braced-atpt 'ar-braced-backslash-atpt)
;;;###autoload
(defun ar-braced-backslash-atpt (&optional no-delimiters) 
  "Backslash braced at point if any. "
  (interactive "*p")
  (ar-th-backslash 'braced no-delimiters (interactive-p))) 

(defalias 'ar-brace-braced-atpt 'ar-braced-brace-atpt)
;;;###autoload
(defun ar-braced-brace-atpt (&optional no-delimiters) 
  "Braces braced at point if any. "
  (interactive "*p")
  (ar-th-brace 'braced no-delimiters (interactive-p)))

(defalias 'ar-bracket-braced-atpt 'ar-braced-bracket-atpt)
;;;###autoload
(defun ar-braced-bracket-atpt (&optional no-delimiters) 
  "Brackets braced after point if any. "
  (interactive "*p")
  (ar-th-bracket 'braced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-braced-atpt (&optional no-delimiters) 
  "Comments braced at point if any. "
  (interactive "*p")
  (ar-th-comment 'braced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-braced-atpt (&optional no-delimiters) 
  "Put a comma after braced at point if any. "
  (interactive "*p")
  (ar-th-commatize 'braced no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-braced-atpt (&optional no-delimiters) 
  "Put a singlequote before braced at point if any. "
  (interactive "*p")
  (ar-th-quote 'braced no-delimiters (interactive-p)))

(defalias 'ar-hyphen-braced-atpt 'ar-braced-hyphen-atpt)
;;;###autoload
(defun ar-braced-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around braced at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'braced no-delimiters (interactive-p)))

(defalias 'ar-mark-braced-atpt 'ar-braced-mark-atpt)
;;;###autoload
(defun ar-braced-mark-atpt () 
  "Marks braced at point if any. "
  (interactive)
  (ar-th-mark 'braced))

(defalias 'ar-hide-braced-atpt 'ar-braced-hide-atpt)
;;;###autoload
(defun ar-braced-hide-atpt () 
  "Hides braced at point. "
  (interactive)
  (ar-th-hide 'braced))

(defalias 'ar-show-braced-atpt 'ar-braced-show-atpt)
;;;###autoload
(defun ar-braced-show-atpt () 
  "Shows hidden braced at point. "
  (interactive)
  (ar-th-show 'braced))

(defalias 'ar-hide-show-braced-atpt 'ar-braced-hide-show-atpt)
;;;###autoload
(defun ar-braced-hide-show-atpt () 
  "Alternatively hides or shows braced at point. "
  (interactive)
  (ar-th-hide-show 'braced))

(defalias 'ar-highlight-braced-atpt-mode 'ar-braced-highlight-atpt-mode)

(defun ar-braced-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles braced-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'braced no-delimiters (interactive-p)))

(defalias 'ar-kill-braced-atpt 'ar-braced-kill-atpt)
;;;###autoload
(defun ar-braced-kill-atpt (&optional no-delimiters) 
  "Kills braced at point if any. "
  (interactive "*P")
  (ar-th-kill 'braced no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-braced-atpt 'ar-braced-left-right-singlequote-atpt)
;;;###autoload
(defun ar-braced-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'braced no-delimiters (interactive-p)))

(defalias 'ar-parentize-braced-atpt 'ar-braced-parentize-atpt)
;;;###autoload
(defun ar-braced-parentize-atpt (&optional no-delimiters) 
  "Parentizes braced at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'braced no-delimiters (interactive-p)))

(defalias 'ar-separate-braced-atpt 'ar-braced-separate-atpt)
;;;###autoload
(defun ar-braced-separate-atpt (&optional no-delimiters) 
  "Separates braced at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'braced no-delimiters (interactive-p)))

(defalias 'ar-singlequote-braced-atpt 'ar-braced-singlequote-atpt)
;;;###autoload
(defun ar-braced-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes braced at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'braced no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-braced-atpt 'ar-braced-triplequote-dq-atpt)
;;;###autoload
(defun ar-braced-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around braced. "
  (interactive "*p")
  (ar-th-triplequote-dq 'braced no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-braced-atpt 'ar-braced-triplequote-sq-atpt)
;;;###autoload
(defun ar-braced-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around braced. "
  (interactive "*p")
  (ar-th-triplequote-sq 'braced no-delimiters (interactive-p)))

(defalias 'ar-trim-braced-atpt 'ar-braced-trim-atpt)
;;;###autoload
(defun ar-braced-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'braced t t)) 
    (ar-th-trim 'braced t t)))

(defalias 'ar-trim-left-braced-atpt 'ar-braced-left-trim-atpt)
;;;###autoload
(defun ar-braced-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'braced t nil))
    (ar-th-trim 'braced t nil)))

(defalias 'ar-trim-right-braced-atpt 'ar-braced-right-trim-atpt)
;;;###autoload
(defun ar-braced-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'braced nil t))
    (ar-th-trim 'braced nil t)))

(defalias 'ar-braced-underscore-atpt 'ar-underscore-braced-atpt)
;;;###autoload
(defun ar-underscore-braced-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'braced no-delimiters (interactive-p)))

(defalias 'ar-braced-whitespace-atpt 'ar-whitespace-braced-atpt)
;;;###autoload
(defun ar-whitespace-braced-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'braced nil t))

(defalias 'ar-forward-braced-atpt 'ar-braced-forward-atpt)
;;;###autoload
(defun ar-braced-forward-atpt (&optional arg) 
  "Moves forward over braced at point if any, does nothing otherwise.
Returns end position of braced "
  (interactive "p")
  (ar-th-forward 'braced arg (interactive-p)))

(defalias 'ar-backward-braced-atpt 'ar-braced-backward-atpt)
;;;###autoload
(defun ar-braced-backward-atpt (&optional arg) 
  "Moves backward over braced before point if any, does nothing otherwise.
Returns beginning position of braced "
  (interactive "p")
  (ar-th-backward 'braced arg (interactive-p)))

(defalias 'ar-transpose-braced-atpt 'ar-braced-transpose-atpt)
;;;###autoload
(defun ar-braced-transpose-atpt (&optional arg) 
  "Transposes braced with braced before point if any. "
  (interactive "*p")
  (ar-th-transpose 'braced arg (interactive-p)))

(defalias 'ar-sort-braced-atpt 'ar-braced-sort-atpt)
;;;###autoload
(defun ar-braced-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts braceds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'braced reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-braced-atpt 'ar-braced-check-atpt)
;;;###autoload
(defun ar-braced-check-atpt () 
  "Return t if a braced at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-braced-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-braced-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-bracketed-atpt (&optional arg no-delimiters) 
  "Returns bracketed at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'bracketed arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-bracketed-atpt 'ar-bracketed-bounds-atpt)
;;;###autoload
(defun ar-bracketed-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of bracketed if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'bracketed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-bracketed-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position bracketed at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'bracketed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-bracketed-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of bracketed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-bracketed-atpt 'ar-bracketed-beginning-atpt)
;;;###autoload
(defun ar-bracketed-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class bracketed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-end-of-bracketed-atpt 'ar-bracketed-end-atpt)
;;;###autoload
(defun ar-bracketed-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class bracketed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-in-bracketed-p-atpt 'ar-bracketed-in-p-atpt)
;;;###autoload
(defun ar-bracketed-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of bracketed at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-length-of-bracketed-atpt 'ar-bracketed-length-atpt)
;;;###autoload
(defun ar-bracketed-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class bracketed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-copy-bracketed-atpt 'ar-bracketed-copy-atpt)
;;;###autoload
(defun ar-bracketed-copy-atpt (&optional no-delimiters) 
  "Returns a copy of bracketed at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-delete-bracketed-in-region 'ar-bracketed-delete-in-region)
;;;###autoload
(defun ar-bracketed-delete-in-region (beg end) 
  "Deletes bracketed at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'bracketed beg end (interactive-p)))

;;;###autoload
(defun ar-blok-bracketed-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around bracketed.
  Returns blok or nil if no bracketed at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-escape-bracketed-atpt 'ar-bracketed-escape-atpt)
;;;###autoload
(defun ar-bracketed-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted bracketed at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'bracketed no-delimiters))

(defalias 'ar-doublequote-bracketed-atpt 'ar-bracketed-doublequote-atpt)
;;;###autoload
(defun ar-bracketed-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes bracketed at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-slash-bracketed-atpt 'ar-bracketed-slash-atpt)
;;;###autoload
(defun ar-bracketed-slash-atpt (&optional no-delimiters) 
  "Doublequotes bracketed at point if any. "
  (interactive "*p")
  (ar-th-slash 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-bracketed-atpt 'ar-bracketed-double-backslash-atpt)
;;;###autoload
(defun ar-bracketed-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around bracketed at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-bracketed-atpt 'ar-bracketed-doubleslash-atpt)
;;;###autoload
(defun ar-bracketed-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around bracketed at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-bracketed-atpt 'ar-bracketed-doubleslashparen-atpt)
;;;###autoload
(defun ar-bracketed-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around bracketed at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-slashparen-bracketed-atpt 'ar-bracketed-slashparen-atpt)
;;;###autoload
(defun ar-bracketed-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around bracketed at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-dollar-bracketed-atpt 'ar-bracketed-dollar-atpt)
;;;###autoload
(defun ar-bracketed-dollar-atpt (&optional no-delimiters) 
  "Doublequotes bracketed at point if any. "
  (interactive "*p")
  (ar-th-dollar 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-equalize-bracketed-atpt 'ar-bracketed-equalize-atpt)
;;;###autoload
(defun ar-bracketed-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around bracketed at point if any. "
  (interactive "*p")
  (ar-th-equalize 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-bracketed-atpt 'ar-bracketed-greater-angle-atpt)
;;;###autoload
(defun ar-bracketed-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for bracketed after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-bracketed-atpt 'ar-bracketed-lesser-angle-atpt)
;;;###autoload
(defun ar-bracketed-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for bracketed after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-backslash-bracketed-atpt 'ar-bracketed-backslash-atpt)
;;;###autoload
(defun ar-bracketed-backslash-atpt (&optional no-delimiters) 
  "Backslash bracketed at point if any. "
  (interactive "*p")
  (ar-th-backslash 'bracketed no-delimiters (interactive-p))) 

(defalias 'ar-brace-bracketed-atpt 'ar-bracketed-brace-atpt)
;;;###autoload
(defun ar-bracketed-brace-atpt (&optional no-delimiters) 
  "Braces bracketed at point if any. "
  (interactive "*p")
  (ar-th-brace 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-bracket-bracketed-atpt 'ar-bracketed-bracket-atpt)
;;;###autoload
(defun ar-bracketed-bracket-atpt (&optional no-delimiters) 
  "Brackets bracketed after point if any. "
  (interactive "*p")
  (ar-th-bracket 'bracketed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-bracketed-atpt (&optional no-delimiters) 
  "Comments bracketed at point if any. "
  (interactive "*p")
  (ar-th-comment 'bracketed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-bracketed-atpt (&optional no-delimiters) 
  "Put a comma after bracketed at point if any. "
  (interactive "*p")
  (ar-th-commatize 'bracketed no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-bracketed-atpt (&optional no-delimiters) 
  "Put a singlequote before bracketed at point if any. "
  (interactive "*p")
  (ar-th-quote 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-hyphen-bracketed-atpt 'ar-bracketed-hyphen-atpt)
;;;###autoload
(defun ar-bracketed-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around bracketed at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-mark-bracketed-atpt 'ar-bracketed-mark-atpt)
;;;###autoload
(defun ar-bracketed-mark-atpt () 
  "Marks bracketed at point if any. "
  (interactive)
  (ar-th-mark 'bracketed))

(defalias 'ar-hide-bracketed-atpt 'ar-bracketed-hide-atpt)
;;;###autoload
(defun ar-bracketed-hide-atpt () 
  "Hides bracketed at point. "
  (interactive)
  (ar-th-hide 'bracketed))

(defalias 'ar-show-bracketed-atpt 'ar-bracketed-show-atpt)
;;;###autoload
(defun ar-bracketed-show-atpt () 
  "Shows hidden bracketed at point. "
  (interactive)
  (ar-th-show 'bracketed))

(defalias 'ar-hide-show-bracketed-atpt 'ar-bracketed-hide-show-atpt)
;;;###autoload
(defun ar-bracketed-hide-show-atpt () 
  "Alternatively hides or shows bracketed at point. "
  (interactive)
  (ar-th-hide-show 'bracketed))

(defalias 'ar-highlight-bracketed-atpt-mode 'ar-bracketed-highlight-atpt-mode)

(defun ar-bracketed-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles bracketed-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-kill-bracketed-atpt 'ar-bracketed-kill-atpt)
;;;###autoload
(defun ar-bracketed-kill-atpt (&optional no-delimiters) 
  "Kills bracketed at point if any. "
  (interactive "*P")
  (ar-th-kill 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-bracketed-atpt 'ar-bracketed-left-right-singlequote-atpt)
;;;###autoload
(defun ar-bracketed-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-parentize-bracketed-atpt 'ar-bracketed-parentize-atpt)
;;;###autoload
(defun ar-bracketed-parentize-atpt (&optional no-delimiters) 
  "Parentizes bracketed at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-separate-bracketed-atpt 'ar-bracketed-separate-atpt)
;;;###autoload
(defun ar-bracketed-separate-atpt (&optional no-delimiters) 
  "Separates bracketed at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-singlequote-bracketed-atpt 'ar-bracketed-singlequote-atpt)
;;;###autoload
(defun ar-bracketed-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes bracketed at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-bracketed-atpt 'ar-bracketed-triplequote-dq-atpt)
;;;###autoload
(defun ar-bracketed-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around bracketed. "
  (interactive "*p")
  (ar-th-triplequote-dq 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-bracketed-atpt 'ar-bracketed-triplequote-sq-atpt)
;;;###autoload
(defun ar-bracketed-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around bracketed. "
  (interactive "*p")
  (ar-th-triplequote-sq 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-trim-bracketed-atpt 'ar-bracketed-trim-atpt)
;;;###autoload
(defun ar-bracketed-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'bracketed t t)) 
    (ar-th-trim 'bracketed t t)))

(defalias 'ar-trim-left-bracketed-atpt 'ar-bracketed-left-trim-atpt)
;;;###autoload
(defun ar-bracketed-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'bracketed t nil))
    (ar-th-trim 'bracketed t nil)))

(defalias 'ar-trim-right-bracketed-atpt 'ar-bracketed-right-trim-atpt)
;;;###autoload
(defun ar-bracketed-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'bracketed nil t))
    (ar-th-trim 'bracketed nil t)))

(defalias 'ar-bracketed-underscore-atpt 'ar-underscore-bracketed-atpt)
;;;###autoload
(defun ar-underscore-bracketed-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'bracketed no-delimiters (interactive-p)))

(defalias 'ar-bracketed-whitespace-atpt 'ar-whitespace-bracketed-atpt)
;;;###autoload
(defun ar-whitespace-bracketed-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'bracketed nil t))

(defalias 'ar-forward-bracketed-atpt 'ar-bracketed-forward-atpt)
;;;###autoload
(defun ar-bracketed-forward-atpt (&optional arg) 
  "Moves forward over bracketed at point if any, does nothing otherwise.
Returns end position of bracketed "
  (interactive "p")
  (ar-th-forward 'bracketed arg (interactive-p)))

(defalias 'ar-backward-bracketed-atpt 'ar-bracketed-backward-atpt)
;;;###autoload
(defun ar-bracketed-backward-atpt (&optional arg) 
  "Moves backward over bracketed before point if any, does nothing otherwise.
Returns beginning position of bracketed "
  (interactive "p")
  (ar-th-backward 'bracketed arg (interactive-p)))

(defalias 'ar-transpose-bracketed-atpt 'ar-bracketed-transpose-atpt)
;;;###autoload
(defun ar-bracketed-transpose-atpt (&optional arg) 
  "Transposes bracketed with bracketed before point if any. "
  (interactive "*p")
  (ar-th-transpose 'bracketed arg (interactive-p)))

(defalias 'ar-sort-bracketed-atpt 'ar-bracketed-sort-atpt)
;;;###autoload
(defun ar-bracketed-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts bracketeds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'bracketed reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-bracketed-atpt 'ar-bracketed-check-atpt)
;;;###autoload
(defun ar-bracketed-check-atpt () 
  "Return t if a bracketed at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-bracketed-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-bracketed-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-lesser-angled-atpt (&optional arg no-delimiters) 
  "Returns lesser-angled at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'lesser-angled arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-lesser-angled-atpt 'ar-lesser-angled-bounds-atpt)
;;;###autoload
(defun ar-lesser-angled-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of lesser-angled if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'lesser-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lesser-angled-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position lesser-angled at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'lesser-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lesser-angled-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of lesser-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-lesser-angled-atpt 'ar-lesser-angled-beginning-atpt)
;;;###autoload
(defun ar-lesser-angled-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class lesser-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-end-of-lesser-angled-atpt 'ar-lesser-angled-end-atpt)
;;;###autoload
(defun ar-lesser-angled-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class lesser-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-in-lesser-angled-p-atpt 'ar-lesser-angled-in-p-atpt)
;;;###autoload
(defun ar-lesser-angled-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of lesser-angled at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-length-of-lesser-angled-atpt 'ar-lesser-angled-length-atpt)
;;;###autoload
(defun ar-lesser-angled-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class lesser-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-copy-lesser-angled-atpt 'ar-lesser-angled-copy-atpt)
;;;###autoload
(defun ar-lesser-angled-copy-atpt (&optional no-delimiters) 
  "Returns a copy of lesser-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-delete-lesser-angled-in-region 'ar-lesser-angled-delete-in-region)
;;;###autoload
(defun ar-lesser-angled-delete-in-region (beg end) 
  "Deletes lesser-angled at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'lesser-angled beg end (interactive-p)))

;;;###autoload
(defun ar-blok-lesser-angled-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around lesser-angled.
  Returns blok or nil if no lesser-angled at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-escape-lesser-angled-atpt 'ar-lesser-angled-escape-atpt)
;;;###autoload
(defun ar-lesser-angled-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted lesser-angled at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'lesser-angled no-delimiters))

(defalias 'ar-doublequote-lesser-angled-atpt 'ar-lesser-angled-doublequote-atpt)
;;;###autoload
(defun ar-lesser-angled-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-slash-lesser-angled-atpt 'ar-lesser-angled-slash-atpt)
;;;###autoload
(defun ar-lesser-angled-slash-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-slash 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-lesser-angled-atpt 'ar-lesser-angled-double-backslash-atpt)
;;;###autoload
(defun ar-lesser-angled-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-lesser-angled-atpt 'ar-lesser-angled-doubleslash-atpt)
;;;###autoload
(defun ar-lesser-angled-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-lesser-angled-atpt 'ar-lesser-angled-doubleslashparen-atpt)
;;;###autoload
(defun ar-lesser-angled-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-slashparen-lesser-angled-atpt 'ar-lesser-angled-slashparen-atpt)
;;;###autoload
(defun ar-lesser-angled-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-dollar-lesser-angled-atpt 'ar-lesser-angled-dollar-atpt)
;;;###autoload
(defun ar-lesser-angled-dollar-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-dollar 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-equalize-lesser-angled-atpt 'ar-lesser-angled-equalize-atpt)
;;;###autoload
(defun ar-lesser-angled-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-equalize 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-lesser-angled-atpt 'ar-lesser-angled-greater-angle-atpt)
;;;###autoload
(defun ar-lesser-angled-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for lesser-angled after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-lesser-angled-atpt 'ar-lesser-angled-lesser-angle-atpt)
;;;###autoload
(defun ar-lesser-angled-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for lesser-angled after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-backslash-lesser-angled-atpt 'ar-lesser-angled-backslash-atpt)
;;;###autoload
(defun ar-lesser-angled-backslash-atpt (&optional no-delimiters) 
  "Backslash lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-backslash 'lesser-angled no-delimiters (interactive-p))) 

(defalias 'ar-brace-lesser-angled-atpt 'ar-lesser-angled-brace-atpt)
;;;###autoload
(defun ar-lesser-angled-brace-atpt (&optional no-delimiters) 
  "Braces lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-brace 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-bracket-lesser-angled-atpt 'ar-lesser-angled-bracket-atpt)
;;;###autoload
(defun ar-lesser-angled-bracket-atpt (&optional no-delimiters) 
  "Brackets lesser-angled after point if any. "
  (interactive "*p")
  (ar-th-bracket 'lesser-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-lesser-angled-atpt (&optional no-delimiters) 
  "Comments lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-comment 'lesser-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-lesser-angled-atpt (&optional no-delimiters) 
  "Put a comma after lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-commatize 'lesser-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-lesser-angled-atpt (&optional no-delimiters) 
  "Put a singlequote before lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-quote 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-hyphen-lesser-angled-atpt 'ar-lesser-angled-hyphen-atpt)
;;;###autoload
(defun ar-lesser-angled-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-mark-lesser-angled-atpt 'ar-lesser-angled-mark-atpt)
;;;###autoload
(defun ar-lesser-angled-mark-atpt () 
  "Marks lesser-angled at point if any. "
  (interactive)
  (ar-th-mark 'lesser-angled))

(defalias 'ar-hide-lesser-angled-atpt 'ar-lesser-angled-hide-atpt)
;;;###autoload
(defun ar-lesser-angled-hide-atpt () 
  "Hides lesser-angled at point. "
  (interactive)
  (ar-th-hide 'lesser-angled))

(defalias 'ar-show-lesser-angled-atpt 'ar-lesser-angled-show-atpt)
;;;###autoload
(defun ar-lesser-angled-show-atpt () 
  "Shows hidden lesser-angled at point. "
  (interactive)
  (ar-th-show 'lesser-angled))

(defalias 'ar-hide-show-lesser-angled-atpt 'ar-lesser-angled-hide-show-atpt)
;;;###autoload
(defun ar-lesser-angled-hide-show-atpt () 
  "Alternatively hides or shows lesser-angled at point. "
  (interactive)
  (ar-th-hide-show 'lesser-angled))

(defalias 'ar-highlight-lesser-angled-atpt-mode 'ar-lesser-angled-highlight-atpt-mode)

(defun ar-lesser-angled-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles lesser-angled-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-kill-lesser-angled-atpt 'ar-lesser-angled-kill-atpt)
;;;###autoload
(defun ar-lesser-angled-kill-atpt (&optional no-delimiters) 
  "Kills lesser-angled at point if any. "
  (interactive "*P")
  (ar-th-kill 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-lesser-angled-atpt 'ar-lesser-angled-left-right-singlequote-atpt)
;;;###autoload
(defun ar-lesser-angled-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-parentize-lesser-angled-atpt 'ar-lesser-angled-parentize-atpt)
;;;###autoload
(defun ar-lesser-angled-parentize-atpt (&optional no-delimiters) 
  "Parentizes lesser-angled at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-separate-lesser-angled-atpt 'ar-lesser-angled-separate-atpt)
;;;###autoload
(defun ar-lesser-angled-separate-atpt (&optional no-delimiters) 
  "Separates lesser-angled at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-singlequote-lesser-angled-atpt 'ar-lesser-angled-singlequote-atpt)
;;;###autoload
(defun ar-lesser-angled-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes lesser-angled at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-lesser-angled-atpt 'ar-lesser-angled-triplequote-dq-atpt)
;;;###autoload
(defun ar-lesser-angled-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around lesser-angled. "
  (interactive "*p")
  (ar-th-triplequote-dq 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-lesser-angled-atpt 'ar-lesser-angled-triplequote-sq-atpt)
;;;###autoload
(defun ar-lesser-angled-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around lesser-angled. "
  (interactive "*p")
  (ar-th-triplequote-sq 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-trim-lesser-angled-atpt 'ar-lesser-angled-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled t t)) 
    (ar-th-trim 'lesser-angled t t)))

(defalias 'ar-trim-left-lesser-angled-atpt 'ar-lesser-angled-left-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled t nil))
    (ar-th-trim 'lesser-angled t nil)))

(defalias 'ar-trim-right-lesser-angled-atpt 'ar-lesser-angled-right-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled nil t))
    (ar-th-trim 'lesser-angled nil t)))

(defalias 'ar-lesser-angled-underscore-atpt 'ar-underscore-lesser-angled-atpt)
;;;###autoload
(defun ar-underscore-lesser-angled-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'lesser-angled no-delimiters (interactive-p)))

(defalias 'ar-lesser-angled-whitespace-atpt 'ar-whitespace-lesser-angled-atpt)
;;;###autoload
(defun ar-whitespace-lesser-angled-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'lesser-angled nil t))

(defalias 'ar-forward-lesser-angled-atpt 'ar-lesser-angled-forward-atpt)
;;;###autoload
(defun ar-lesser-angled-forward-atpt (&optional arg) 
  "Moves forward over lesser-angled at point if any, does nothing otherwise.
Returns end position of lesser-angled "
  (interactive "p")
  (ar-th-forward 'lesser-angled arg (interactive-p)))

(defalias 'ar-backward-lesser-angled-atpt 'ar-lesser-angled-backward-atpt)
;;;###autoload
(defun ar-lesser-angled-backward-atpt (&optional arg) 
  "Moves backward over lesser-angled before point if any, does nothing otherwise.
Returns beginning position of lesser-angled "
  (interactive "p")
  (ar-th-backward 'lesser-angled arg (interactive-p)))

(defalias 'ar-transpose-lesser-angled-atpt 'ar-lesser-angled-transpose-atpt)
;;;###autoload
(defun ar-lesser-angled-transpose-atpt (&optional arg) 
  "Transposes lesser-angled with lesser-angled before point if any. "
  (interactive "*p")
  (ar-th-transpose 'lesser-angled arg (interactive-p)))

(defalias 'ar-sort-lesser-angled-atpt 'ar-lesser-angled-sort-atpt)
;;;###autoload
(defun ar-lesser-angled-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts lesser-angleds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'lesser-angled reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-lesser-angled-atpt 'ar-lesser-angled-check-atpt)
;;;###autoload
(defun ar-lesser-angled-check-atpt () 
  "Return t if a lesser-angled at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-lesser-angled-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-lesser-angled-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-greater-angled-atpt (&optional arg no-delimiters) 
  "Returns greater-angled at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'greater-angled arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-greater-angled-atpt 'ar-greater-angled-bounds-atpt)
;;;###autoload
(defun ar-greater-angled-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of greater-angled if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'greater-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-greater-angled-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position greater-angled at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'greater-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-greater-angled-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of greater-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-greater-angled-atpt 'ar-greater-angled-beginning-atpt)
;;;###autoload
(defun ar-greater-angled-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class greater-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-end-of-greater-angled-atpt 'ar-greater-angled-end-atpt)
;;;###autoload
(defun ar-greater-angled-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class greater-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-in-greater-angled-p-atpt 'ar-greater-angled-in-p-atpt)
;;;###autoload
(defun ar-greater-angled-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of greater-angled at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-length-of-greater-angled-atpt 'ar-greater-angled-length-atpt)
;;;###autoload
(defun ar-greater-angled-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class greater-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-copy-greater-angled-atpt 'ar-greater-angled-copy-atpt)
;;;###autoload
(defun ar-greater-angled-copy-atpt (&optional no-delimiters) 
  "Returns a copy of greater-angled at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-delete-greater-angled-in-region 'ar-greater-angled-delete-in-region)
;;;###autoload
(defun ar-greater-angled-delete-in-region (beg end) 
  "Deletes greater-angled at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'greater-angled beg end (interactive-p)))

;;;###autoload
(defun ar-blok-greater-angled-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around greater-angled.
  Returns blok or nil if no greater-angled at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-escape-greater-angled-atpt 'ar-greater-angled-escape-atpt)
;;;###autoload
(defun ar-greater-angled-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted greater-angled at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'greater-angled no-delimiters))

(defalias 'ar-doublequote-greater-angled-atpt 'ar-greater-angled-doublequote-atpt)
;;;###autoload
(defun ar-greater-angled-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-slash-greater-angled-atpt 'ar-greater-angled-slash-atpt)
;;;###autoload
(defun ar-greater-angled-slash-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled at point if any. "
  (interactive "*p")
  (ar-th-slash 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-greater-angled-atpt 'ar-greater-angled-double-backslash-atpt)
;;;###autoload
(defun ar-greater-angled-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-greater-angled-atpt 'ar-greater-angled-doubleslash-atpt)
;;;###autoload
(defun ar-greater-angled-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-greater-angled-atpt 'ar-greater-angled-doubleslashparen-atpt)
;;;###autoload
(defun ar-greater-angled-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-slashparen-greater-angled-atpt 'ar-greater-angled-slashparen-atpt)
;;;###autoload
(defun ar-greater-angled-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-dollar-greater-angled-atpt 'ar-greater-angled-dollar-atpt)
;;;###autoload
(defun ar-greater-angled-dollar-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled at point if any. "
  (interactive "*p")
  (ar-th-dollar 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-equalize-greater-angled-atpt 'ar-greater-angled-equalize-atpt)
;;;###autoload
(defun ar-greater-angled-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-equalize 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-greater-angled-atpt 'ar-greater-angled-greater-angle-atpt)
;;;###autoload
(defun ar-greater-angled-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for greater-angled after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-greater-angled-atpt 'ar-greater-angled-lesser-angle-atpt)
;;;###autoload
(defun ar-greater-angled-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for greater-angled after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-backslash-greater-angled-atpt 'ar-greater-angled-backslash-atpt)
;;;###autoload
(defun ar-greater-angled-backslash-atpt (&optional no-delimiters) 
  "Backslash greater-angled at point if any. "
  (interactive "*p")
  (ar-th-backslash 'greater-angled no-delimiters (interactive-p))) 

(defalias 'ar-brace-greater-angled-atpt 'ar-greater-angled-brace-atpt)
;;;###autoload
(defun ar-greater-angled-brace-atpt (&optional no-delimiters) 
  "Braces greater-angled at point if any. "
  (interactive "*p")
  (ar-th-brace 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-bracket-greater-angled-atpt 'ar-greater-angled-bracket-atpt)
;;;###autoload
(defun ar-greater-angled-bracket-atpt (&optional no-delimiters) 
  "Brackets greater-angled after point if any. "
  (interactive "*p")
  (ar-th-bracket 'greater-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-greater-angled-atpt (&optional no-delimiters) 
  "Comments greater-angled at point if any. "
  (interactive "*p")
  (ar-th-comment 'greater-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-greater-angled-atpt (&optional no-delimiters) 
  "Put a comma after greater-angled at point if any. "
  (interactive "*p")
  (ar-th-commatize 'greater-angled no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-greater-angled-atpt (&optional no-delimiters) 
  "Put a singlequote before greater-angled at point if any. "
  (interactive "*p")
  (ar-th-quote 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-hyphen-greater-angled-atpt 'ar-greater-angled-hyphen-atpt)
;;;###autoload
(defun ar-greater-angled-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around greater-angled at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-mark-greater-angled-atpt 'ar-greater-angled-mark-atpt)
;;;###autoload
(defun ar-greater-angled-mark-atpt () 
  "Marks greater-angled at point if any. "
  (interactive)
  (ar-th-mark 'greater-angled))

(defalias 'ar-hide-greater-angled-atpt 'ar-greater-angled-hide-atpt)
;;;###autoload
(defun ar-greater-angled-hide-atpt () 
  "Hides greater-angled at point. "
  (interactive)
  (ar-th-hide 'greater-angled))

(defalias 'ar-show-greater-angled-atpt 'ar-greater-angled-show-atpt)
;;;###autoload
(defun ar-greater-angled-show-atpt () 
  "Shows hidden greater-angled at point. "
  (interactive)
  (ar-th-show 'greater-angled))

(defalias 'ar-hide-show-greater-angled-atpt 'ar-greater-angled-hide-show-atpt)
;;;###autoload
(defun ar-greater-angled-hide-show-atpt () 
  "Alternatively hides or shows greater-angled at point. "
  (interactive)
  (ar-th-hide-show 'greater-angled))

(defalias 'ar-highlight-greater-angled-atpt-mode 'ar-greater-angled-highlight-atpt-mode)

(defun ar-greater-angled-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles greater-angled-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-kill-greater-angled-atpt 'ar-greater-angled-kill-atpt)
;;;###autoload
(defun ar-greater-angled-kill-atpt (&optional no-delimiters) 
  "Kills greater-angled at point if any. "
  (interactive "*P")
  (ar-th-kill 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-greater-angled-atpt 'ar-greater-angled-left-right-singlequote-atpt)
;;;###autoload
(defun ar-greater-angled-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-parentize-greater-angled-atpt 'ar-greater-angled-parentize-atpt)
;;;###autoload
(defun ar-greater-angled-parentize-atpt (&optional no-delimiters) 
  "Parentizes greater-angled at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-separate-greater-angled-atpt 'ar-greater-angled-separate-atpt)
;;;###autoload
(defun ar-greater-angled-separate-atpt (&optional no-delimiters) 
  "Separates greater-angled at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-singlequote-greater-angled-atpt 'ar-greater-angled-singlequote-atpt)
;;;###autoload
(defun ar-greater-angled-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes greater-angled at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-greater-angled-atpt 'ar-greater-angled-triplequote-dq-atpt)
;;;###autoload
(defun ar-greater-angled-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around greater-angled. "
  (interactive "*p")
  (ar-th-triplequote-dq 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-greater-angled-atpt 'ar-greater-angled-triplequote-sq-atpt)
;;;###autoload
(defun ar-greater-angled-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around greater-angled. "
  (interactive "*p")
  (ar-th-triplequote-sq 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-trim-greater-angled-atpt 'ar-greater-angled-trim-atpt)
;;;###autoload
(defun ar-greater-angled-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled t t)) 
    (ar-th-trim 'greater-angled t t)))

(defalias 'ar-trim-left-greater-angled-atpt 'ar-greater-angled-left-trim-atpt)
;;;###autoload
(defun ar-greater-angled-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled t nil))
    (ar-th-trim 'greater-angled t nil)))

(defalias 'ar-trim-right-greater-angled-atpt 'ar-greater-angled-right-trim-atpt)
;;;###autoload
(defun ar-greater-angled-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled nil t))
    (ar-th-trim 'greater-angled nil t)))

(defalias 'ar-greater-angled-underscore-atpt 'ar-underscore-greater-angled-atpt)
;;;###autoload
(defun ar-underscore-greater-angled-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'greater-angled no-delimiters (interactive-p)))

(defalias 'ar-greater-angled-whitespace-atpt 'ar-whitespace-greater-angled-atpt)
;;;###autoload
(defun ar-whitespace-greater-angled-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'greater-angled nil t))

(defalias 'ar-forward-greater-angled-atpt 'ar-greater-angled-forward-atpt)
;;;###autoload
(defun ar-greater-angled-forward-atpt (&optional arg) 
  "Moves forward over greater-angled at point if any, does nothing otherwise.
Returns end position of greater-angled "
  (interactive "p")
  (ar-th-forward 'greater-angled arg (interactive-p)))

(defalias 'ar-backward-greater-angled-atpt 'ar-greater-angled-backward-atpt)
;;;###autoload
(defun ar-greater-angled-backward-atpt (&optional arg) 
  "Moves backward over greater-angled before point if any, does nothing otherwise.
Returns beginning position of greater-angled "
  (interactive "p")
  (ar-th-backward 'greater-angled arg (interactive-p)))

(defalias 'ar-transpose-greater-angled-atpt 'ar-greater-angled-transpose-atpt)
;;;###autoload
(defun ar-greater-angled-transpose-atpt (&optional arg) 
  "Transposes greater-angled with greater-angled before point if any. "
  (interactive "*p")
  (ar-th-transpose 'greater-angled arg (interactive-p)))

(defalias 'ar-sort-greater-angled-atpt 'ar-greater-angled-sort-atpt)
;;;###autoload
(defun ar-greater-angled-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts greater-angleds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'greater-angled reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-greater-angled-atpt 'ar-greater-angled-check-atpt)
;;;###autoload
(defun ar-greater-angled-check-atpt () 
  "Return t if a greater-angled at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-greater-angled-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-greater-angled-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-left-right-singlequoted-atpt (&optional arg no-delimiters) 
  "Returns left-right-singlequoted at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'left-right-singlequoted arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-left-right-singlequoted-atpt 'ar-left-right-singlequoted-bounds-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of left-right-singlequoted if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'left-right-singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-left-right-singlequoted-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position left-right-singlequoted at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'left-right-singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-left-right-singlequoted-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of left-right-singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-left-right-singlequoted-atpt 'ar-left-right-singlequoted-beginning-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class left-right-singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-end-of-left-right-singlequoted-atpt 'ar-left-right-singlequoted-end-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class left-right-singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-in-left-right-singlequoted-p-atpt 'ar-left-right-singlequoted-in-p-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of left-right-singlequoted at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-length-of-left-right-singlequoted-atpt 'ar-left-right-singlequoted-length-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class left-right-singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-copy-left-right-singlequoted-atpt 'ar-left-right-singlequoted-copy-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-copy-atpt (&optional no-delimiters) 
  "Returns a copy of left-right-singlequoted at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-delete-left-right-singlequoted-in-region 'ar-left-right-singlequoted-delete-in-region)
;;;###autoload
(defun ar-left-right-singlequoted-delete-in-region (beg end) 
  "Deletes left-right-singlequoted at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'left-right-singlequoted beg end (interactive-p)))

;;;###autoload
(defun ar-blok-left-right-singlequoted-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around left-right-singlequoted.
  Returns blok or nil if no left-right-singlequoted at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-escape-left-right-singlequoted-atpt 'ar-left-right-singlequoted-escape-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted left-right-singlequoted at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'left-right-singlequoted no-delimiters))

(defalias 'ar-doublequote-left-right-singlequoted-atpt 'ar-left-right-singlequoted-doublequote-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-slash-left-right-singlequoted-atpt 'ar-left-right-singlequoted-slash-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-slash-atpt (&optional no-delimiters) 
  "Doublequotes left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-slash 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-left-right-singlequoted-atpt 'ar-left-right-singlequoted-double-backslash-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-left-right-singlequoted-atpt 'ar-left-right-singlequoted-doubleslash-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-left-right-singlequoted-atpt 'ar-left-right-singlequoted-doubleslashparen-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-slashparen-left-right-singlequoted-atpt 'ar-left-right-singlequoted-slashparen-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-dollar-left-right-singlequoted-atpt 'ar-left-right-singlequoted-dollar-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-dollar-atpt (&optional no-delimiters) 
  "Doublequotes left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-dollar 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-equalize-left-right-singlequoted-atpt 'ar-left-right-singlequoted-equalize-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-equalize 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-left-right-singlequoted-atpt 'ar-left-right-singlequoted-greater-angle-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for left-right-singlequoted after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-left-right-singlequoted-atpt 'ar-left-right-singlequoted-lesser-angle-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for left-right-singlequoted after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-backslash-left-right-singlequoted-atpt 'ar-left-right-singlequoted-backslash-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-backslash-atpt (&optional no-delimiters) 
  "Backslash left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-backslash 'left-right-singlequoted no-delimiters (interactive-p))) 

(defalias 'ar-brace-left-right-singlequoted-atpt 'ar-left-right-singlequoted-brace-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-brace-atpt (&optional no-delimiters) 
  "Braces left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-brace 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-bracket-left-right-singlequoted-atpt 'ar-left-right-singlequoted-bracket-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-bracket-atpt (&optional no-delimiters) 
  "Brackets left-right-singlequoted after point if any. "
  (interactive "*p")
  (ar-th-bracket 'left-right-singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-left-right-singlequoted-atpt (&optional no-delimiters) 
  "Comments left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-comment 'left-right-singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-left-right-singlequoted-atpt (&optional no-delimiters) 
  "Put a comma after left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-commatize 'left-right-singlequoted no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-left-right-singlequoted-atpt (&optional no-delimiters) 
  "Put a singlequote before left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-quote 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-hyphen-left-right-singlequoted-atpt 'ar-left-right-singlequoted-hyphen-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-mark-left-right-singlequoted-atpt 'ar-left-right-singlequoted-mark-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-mark-atpt () 
  "Marks left-right-singlequoted at point if any. "
  (interactive)
  (ar-th-mark 'left-right-singlequoted))

(defalias 'ar-hide-left-right-singlequoted-atpt 'ar-left-right-singlequoted-hide-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-hide-atpt () 
  "Hides left-right-singlequoted at point. "
  (interactive)
  (ar-th-hide 'left-right-singlequoted))

(defalias 'ar-show-left-right-singlequoted-atpt 'ar-left-right-singlequoted-show-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-show-atpt () 
  "Shows hidden left-right-singlequoted at point. "
  (interactive)
  (ar-th-show 'left-right-singlequoted))

(defalias 'ar-hide-show-left-right-singlequoted-atpt 'ar-left-right-singlequoted-hide-show-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-hide-show-atpt () 
  "Alternatively hides or shows left-right-singlequoted at point. "
  (interactive)
  (ar-th-hide-show 'left-right-singlequoted))

(defalias 'ar-highlight-left-right-singlequoted-atpt-mode 'ar-left-right-singlequoted-highlight-atpt-mode)

(defun ar-left-right-singlequoted-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles left-right-singlequoted-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-kill-left-right-singlequoted-atpt 'ar-left-right-singlequoted-kill-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-kill-atpt (&optional no-delimiters) 
  "Kills left-right-singlequoted at point if any. "
  (interactive "*P")
  (ar-th-kill 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-left-right-singlequoted-atpt 'ar-left-right-singlequoted-left-right-singlequote-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-parentize-left-right-singlequoted-atpt 'ar-left-right-singlequoted-parentize-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-parentize-atpt (&optional no-delimiters) 
  "Parentizes left-right-singlequoted at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-separate-left-right-singlequoted-atpt 'ar-left-right-singlequoted-separate-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-separate-atpt (&optional no-delimiters) 
  "Separates left-right-singlequoted at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-singlequote-left-right-singlequoted-atpt 'ar-left-right-singlequoted-singlequote-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes left-right-singlequoted at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-left-right-singlequoted-atpt 'ar-left-right-singlequoted-triplequote-dq-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around left-right-singlequoted. "
  (interactive "*p")
  (ar-th-triplequote-dq 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-left-right-singlequoted-atpt 'ar-left-right-singlequoted-triplequote-sq-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around left-right-singlequoted. "
  (interactive "*p")
  (ar-th-triplequote-sq 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-trim-left-right-singlequoted-atpt 'ar-left-right-singlequoted-trim-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'left-right-singlequoted t t)) 
    (ar-th-trim 'left-right-singlequoted t t)))

(defalias 'ar-trim-left-left-right-singlequoted-atpt 'ar-left-right-singlequoted-left-trim-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'left-right-singlequoted t nil))
    (ar-th-trim 'left-right-singlequoted t nil)))

(defalias 'ar-trim-right-left-right-singlequoted-atpt 'ar-left-right-singlequoted-right-trim-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'left-right-singlequoted nil t))
    (ar-th-trim 'left-right-singlequoted nil t)))

(defalias 'ar-left-right-singlequoted-underscore-atpt 'ar-underscore-left-right-singlequoted-atpt)
;;;###autoload
(defun ar-underscore-left-right-singlequoted-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'left-right-singlequoted no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequoted-whitespace-atpt 'ar-whitespace-left-right-singlequoted-atpt)
;;;###autoload
(defun ar-whitespace-left-right-singlequoted-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'left-right-singlequoted nil t))

(defalias 'ar-forward-left-right-singlequoted-atpt 'ar-left-right-singlequoted-forward-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-forward-atpt (&optional arg) 
  "Moves forward over left-right-singlequoted at point if any, does nothing otherwise.
Returns end position of left-right-singlequoted "
  (interactive "p")
  (ar-th-forward 'left-right-singlequoted arg (interactive-p)))

(defalias 'ar-backward-left-right-singlequoted-atpt 'ar-left-right-singlequoted-backward-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-backward-atpt (&optional arg) 
  "Moves backward over left-right-singlequoted before point if any, does nothing otherwise.
Returns beginning position of left-right-singlequoted "
  (interactive "p")
  (ar-th-backward 'left-right-singlequoted arg (interactive-p)))

(defalias 'ar-transpose-left-right-singlequoted-atpt 'ar-left-right-singlequoted-transpose-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-transpose-atpt (&optional arg) 
  "Transposes left-right-singlequoted with left-right-singlequoted before point if any. "
  (interactive "*p")
  (ar-th-transpose 'left-right-singlequoted arg (interactive-p)))

(defalias 'ar-sort-left-right-singlequoted-atpt 'ar-left-right-singlequoted-sort-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts left-right-singlequoteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'left-right-singlequoted reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-left-right-singlequoted-atpt 'ar-left-right-singlequoted-check-atpt)
;;;###autoload
(defun ar-left-right-singlequoted-check-atpt () 
  "Return t if a left-right-singlequoted at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-left-right-singlequoted-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-left-right-singlequoted-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-parentized-atpt (&optional arg no-delimiters) 
  "Returns parentized at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'parentized arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-parentized-atpt 'ar-parentized-bounds-atpt)
;;;###autoload
(defun ar-parentized-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of parentized if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'parentized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-parentized-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position parentized at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'parentized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-parentized-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of parentized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'parentized no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-parentized-atpt 'ar-parentized-beginning-atpt)
;;;###autoload
(defun ar-parentized-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class parentized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'parentized no-delimiters (interactive-p)))

(defalias 'ar-end-of-parentized-atpt 'ar-parentized-end-atpt)
;;;###autoload
(defun ar-parentized-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class parentized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'parentized no-delimiters (interactive-p)))

(defalias 'ar-in-parentized-p-atpt 'ar-parentized-in-p-atpt)
;;;###autoload
(defun ar-parentized-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of parentized at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'parentized no-delimiters (interactive-p)))

(defalias 'ar-length-of-parentized-atpt 'ar-parentized-length-atpt)
;;;###autoload
(defun ar-parentized-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class parentized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'parentized no-delimiters (interactive-p)))

(defalias 'ar-copy-parentized-atpt 'ar-parentized-copy-atpt)
;;;###autoload
(defun ar-parentized-copy-atpt (&optional no-delimiters) 
  "Returns a copy of parentized at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'parentized no-delimiters (interactive-p)))

(defalias 'ar-delete-parentized-in-region 'ar-parentized-delete-in-region)
;;;###autoload
(defun ar-parentized-delete-in-region (beg end) 
  "Deletes parentized at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'parentized beg end (interactive-p)))

;;;###autoload
(defun ar-blok-parentized-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around parentized.
  Returns blok or nil if no parentized at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'parentized no-delimiters (interactive-p)))

(defalias 'ar-escape-parentized-atpt 'ar-parentized-escape-atpt)
;;;###autoload
(defun ar-parentized-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted parentized at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'parentized no-delimiters))

(defalias 'ar-doublequote-parentized-atpt 'ar-parentized-doublequote-atpt)
;;;###autoload
(defun ar-parentized-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes parentized at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'parentized no-delimiters (interactive-p)))

(defalias 'ar-slash-parentized-atpt 'ar-parentized-slash-atpt)
;;;###autoload
(defun ar-parentized-slash-atpt (&optional no-delimiters) 
  "Doublequotes parentized at point if any. "
  (interactive "*p")
  (ar-th-slash 'parentized no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-parentized-atpt 'ar-parentized-double-backslash-atpt)
;;;###autoload
(defun ar-parentized-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around parentized at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'parentized no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-parentized-atpt 'ar-parentized-doubleslash-atpt)
;;;###autoload
(defun ar-parentized-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around parentized at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'parentized no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-parentized-atpt 'ar-parentized-doubleslashparen-atpt)
;;;###autoload
(defun ar-parentized-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around parentized at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'parentized no-delimiters (interactive-p)))

(defalias 'ar-slashparen-parentized-atpt 'ar-parentized-slashparen-atpt)
;;;###autoload
(defun ar-parentized-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around parentized at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'parentized no-delimiters (interactive-p)))

(defalias 'ar-dollar-parentized-atpt 'ar-parentized-dollar-atpt)
;;;###autoload
(defun ar-parentized-dollar-atpt (&optional no-delimiters) 
  "Doublequotes parentized at point if any. "
  (interactive "*p")
  (ar-th-dollar 'parentized no-delimiters (interactive-p)))

(defalias 'ar-equalize-parentized-atpt 'ar-parentized-equalize-atpt)
;;;###autoload
(defun ar-parentized-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around parentized at point if any. "
  (interactive "*p")
  (ar-th-equalize 'parentized no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-parentized-atpt 'ar-parentized-greater-angle-atpt)
;;;###autoload
(defun ar-parentized-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for parentized after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'parentized no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-parentized-atpt 'ar-parentized-lesser-angle-atpt)
;;;###autoload
(defun ar-parentized-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for parentized after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'parentized no-delimiters (interactive-p)))

(defalias 'ar-backslash-parentized-atpt 'ar-parentized-backslash-atpt)
;;;###autoload
(defun ar-parentized-backslash-atpt (&optional no-delimiters) 
  "Backslash parentized at point if any. "
  (interactive "*p")
  (ar-th-backslash 'parentized no-delimiters (interactive-p))) 

(defalias 'ar-brace-parentized-atpt 'ar-parentized-brace-atpt)
;;;###autoload
(defun ar-parentized-brace-atpt (&optional no-delimiters) 
  "Braces parentized at point if any. "
  (interactive "*p")
  (ar-th-brace 'parentized no-delimiters (interactive-p)))

(defalias 'ar-bracket-parentized-atpt 'ar-parentized-bracket-atpt)
;;;###autoload
(defun ar-parentized-bracket-atpt (&optional no-delimiters) 
  "Brackets parentized after point if any. "
  (interactive "*p")
  (ar-th-bracket 'parentized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-parentized-atpt (&optional no-delimiters) 
  "Comments parentized at point if any. "
  (interactive "*p")
  (ar-th-comment 'parentized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-parentized-atpt (&optional no-delimiters) 
  "Put a comma after parentized at point if any. "
  (interactive "*p")
  (ar-th-commatize 'parentized no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-parentized-atpt (&optional no-delimiters) 
  "Put a singlequote before parentized at point if any. "
  (interactive "*p")
  (ar-th-quote 'parentized no-delimiters (interactive-p)))

(defalias 'ar-hyphen-parentized-atpt 'ar-parentized-hyphen-atpt)
;;;###autoload
(defun ar-parentized-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around parentized at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'parentized no-delimiters (interactive-p)))

(defalias 'ar-mark-parentized-atpt 'ar-parentized-mark-atpt)
;;;###autoload
(defun ar-parentized-mark-atpt () 
  "Marks parentized at point if any. "
  (interactive)
  (ar-th-mark 'parentized))

(defalias 'ar-hide-parentized-atpt 'ar-parentized-hide-atpt)
;;;###autoload
(defun ar-parentized-hide-atpt () 
  "Hides parentized at point. "
  (interactive)
  (ar-th-hide 'parentized))

(defalias 'ar-show-parentized-atpt 'ar-parentized-show-atpt)
;;;###autoload
(defun ar-parentized-show-atpt () 
  "Shows hidden parentized at point. "
  (interactive)
  (ar-th-show 'parentized))

(defalias 'ar-hide-show-parentized-atpt 'ar-parentized-hide-show-atpt)
;;;###autoload
(defun ar-parentized-hide-show-atpt () 
  "Alternatively hides or shows parentized at point. "
  (interactive)
  (ar-th-hide-show 'parentized))

(defalias 'ar-highlight-parentized-atpt-mode 'ar-parentized-highlight-atpt-mode)

(defun ar-parentized-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles parentized-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'parentized no-delimiters (interactive-p)))

(defalias 'ar-kill-parentized-atpt 'ar-parentized-kill-atpt)
;;;###autoload
(defun ar-parentized-kill-atpt (&optional no-delimiters) 
  "Kills parentized at point if any. "
  (interactive "*P")
  (ar-th-kill 'parentized no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-parentized-atpt 'ar-parentized-left-right-singlequote-atpt)
;;;###autoload
(defun ar-parentized-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'parentized no-delimiters (interactive-p)))

(defalias 'ar-parentize-parentized-atpt 'ar-parentized-parentize-atpt)
;;;###autoload
(defun ar-parentized-parentize-atpt (&optional no-delimiters) 
  "Parentizes parentized at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'parentized no-delimiters (interactive-p)))

(defalias 'ar-separate-parentized-atpt 'ar-parentized-separate-atpt)
;;;###autoload
(defun ar-parentized-separate-atpt (&optional no-delimiters) 
  "Separates parentized at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'parentized no-delimiters (interactive-p)))

(defalias 'ar-singlequote-parentized-atpt 'ar-parentized-singlequote-atpt)
;;;###autoload
(defun ar-parentized-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes parentized at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'parentized no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-parentized-atpt 'ar-parentized-triplequote-dq-atpt)
;;;###autoload
(defun ar-parentized-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around parentized. "
  (interactive "*p")
  (ar-th-triplequote-dq 'parentized no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-parentized-atpt 'ar-parentized-triplequote-sq-atpt)
;;;###autoload
(defun ar-parentized-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around parentized. "
  (interactive "*p")
  (ar-th-triplequote-sq 'parentized no-delimiters (interactive-p)))

(defalias 'ar-trim-parentized-atpt 'ar-parentized-trim-atpt)
;;;###autoload
(defun ar-parentized-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'parentized t t)) 
    (ar-th-trim 'parentized t t)))

(defalias 'ar-trim-left-parentized-atpt 'ar-parentized-left-trim-atpt)
;;;###autoload
(defun ar-parentized-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'parentized t nil))
    (ar-th-trim 'parentized t nil)))

(defalias 'ar-trim-right-parentized-atpt 'ar-parentized-right-trim-atpt)
;;;###autoload
(defun ar-parentized-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'parentized nil t))
    (ar-th-trim 'parentized nil t)))

(defalias 'ar-parentized-underscore-atpt 'ar-underscore-parentized-atpt)
;;;###autoload
(defun ar-underscore-parentized-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'parentized no-delimiters (interactive-p)))

(defalias 'ar-parentized-whitespace-atpt 'ar-whitespace-parentized-atpt)
;;;###autoload
(defun ar-whitespace-parentized-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'parentized nil t))

(defalias 'ar-forward-parentized-atpt 'ar-parentized-forward-atpt)
;;;###autoload
(defun ar-parentized-forward-atpt (&optional arg) 
  "Moves forward over parentized at point if any, does nothing otherwise.
Returns end position of parentized "
  (interactive "p")
  (ar-th-forward 'parentized arg (interactive-p)))

(defalias 'ar-backward-parentized-atpt 'ar-parentized-backward-atpt)
;;;###autoload
(defun ar-parentized-backward-atpt (&optional arg) 
  "Moves backward over parentized before point if any, does nothing otherwise.
Returns beginning position of parentized "
  (interactive "p")
  (ar-th-backward 'parentized arg (interactive-p)))

(defalias 'ar-transpose-parentized-atpt 'ar-parentized-transpose-atpt)
;;;###autoload
(defun ar-parentized-transpose-atpt (&optional arg) 
  "Transposes parentized with parentized before point if any. "
  (interactive "*p")
  (ar-th-transpose 'parentized arg (interactive-p)))

(defalias 'ar-sort-parentized-atpt 'ar-parentized-sort-atpt)
;;;###autoload
(defun ar-parentized-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts parentizeds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'parentized reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-parentized-atpt 'ar-parentized-check-atpt)
;;;###autoload
(defun ar-parentized-check-atpt () 
  "Return t if a parentized at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-parentized-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-parentized-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;; ar-thing-at-point-utils-core: ar-atpt-delimited-list end

;; ar-thing-at-point-utils-core: ar-atpt-rest-list start

;;;###autoload
(defun ar-abbrev-atpt (&optional arg no-delimiters) 
  "Returns abbrev at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'abbrev arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-abbrev-atpt 'ar-abbrev-bounds-atpt)
;;;###autoload
(defun ar-abbrev-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of abbrev if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'abbrev no-delimiters (interactive-p)))

;;;###autoload
(defun ar-abbrev-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position abbrev at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'abbrev no-delimiters (interactive-p)))

;;;###autoload
(defun ar-abbrev-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of abbrev at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-abbrev-atpt 'ar-abbrev-beginning-atpt)
;;;###autoload
(defun ar-abbrev-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class abbrev at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-end-of-abbrev-atpt 'ar-abbrev-end-atpt)
;;;###autoload
(defun ar-abbrev-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class abbrev at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-in-abbrev-p-atpt 'ar-abbrev-in-p-atpt)
;;;###autoload
(defun ar-abbrev-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of abbrev at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-length-of-abbrev-atpt 'ar-abbrev-length-atpt)
;;;###autoload
(defun ar-abbrev-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class abbrev at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-copy-abbrev-atpt 'ar-abbrev-copy-atpt)
;;;###autoload
(defun ar-abbrev-copy-atpt (&optional no-delimiters) 
  "Returns a copy of abbrev at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-delete-abbrev-in-region 'ar-abbrev-delete-in-region)
;;;###autoload
(defun ar-abbrev-delete-in-region (beg end) 
  "Deletes abbrev at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'abbrev beg end (interactive-p)))

;;;###autoload
(defun ar-blok-abbrev-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around abbrev.
  Returns blok or nil if no abbrev at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-escape-abbrev-atpt 'ar-abbrev-escape-atpt)
;;;###autoload
(defun ar-abbrev-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted abbrev at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'abbrev no-delimiters))

(defalias 'ar-doublequote-abbrev-atpt 'ar-abbrev-doublequote-atpt)
;;;###autoload
(defun ar-abbrev-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes abbrev at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-slash-abbrev-atpt 'ar-abbrev-slash-atpt)
;;;###autoload
(defun ar-abbrev-slash-atpt (&optional no-delimiters) 
  "Doublequotes abbrev at point if any. "
  (interactive "*p")
  (ar-th-slash 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-abbrev-atpt 'ar-abbrev-double-backslash-atpt)
;;;###autoload
(defun ar-abbrev-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around abbrev at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-abbrev-atpt 'ar-abbrev-doubleslash-atpt)
;;;###autoload
(defun ar-abbrev-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around abbrev at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-abbrev-atpt 'ar-abbrev-doubleslashparen-atpt)
;;;###autoload
(defun ar-abbrev-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around abbrev at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-slashparen-abbrev-atpt 'ar-abbrev-slashparen-atpt)
;;;###autoload
(defun ar-abbrev-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around abbrev at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-dollar-abbrev-atpt 'ar-abbrev-dollar-atpt)
;;;###autoload
(defun ar-abbrev-dollar-atpt (&optional no-delimiters) 
  "Doublequotes abbrev at point if any. "
  (interactive "*p")
  (ar-th-dollar 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-equalize-abbrev-atpt 'ar-abbrev-equalize-atpt)
;;;###autoload
(defun ar-abbrev-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around abbrev at point if any. "
  (interactive "*p")
  (ar-th-equalize 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-abbrev-atpt 'ar-abbrev-greater-angle-atpt)
;;;###autoload
(defun ar-abbrev-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for abbrev after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-abbrev-atpt 'ar-abbrev-lesser-angle-atpt)
;;;###autoload
(defun ar-abbrev-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for abbrev after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-backslash-abbrev-atpt 'ar-abbrev-backslash-atpt)
;;;###autoload
(defun ar-abbrev-backslash-atpt (&optional no-delimiters) 
  "Backslash abbrev at point if any. "
  (interactive "*p")
  (ar-th-backslash 'abbrev no-delimiters (interactive-p))) 

(defalias 'ar-brace-abbrev-atpt 'ar-abbrev-brace-atpt)
;;;###autoload
(defun ar-abbrev-brace-atpt (&optional no-delimiters) 
  "Braces abbrev at point if any. "
  (interactive "*p")
  (ar-th-brace 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-bracket-abbrev-atpt 'ar-abbrev-bracket-atpt)
;;;###autoload
(defun ar-abbrev-bracket-atpt (&optional no-delimiters) 
  "Brackets abbrev after point if any. "
  (interactive "*p")
  (ar-th-bracket 'abbrev no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-abbrev-atpt (&optional no-delimiters) 
  "Comments abbrev at point if any. "
  (interactive "*p")
  (ar-th-comment 'abbrev no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-abbrev-atpt (&optional no-delimiters) 
  "Put a comma after abbrev at point if any. "
  (interactive "*p")
  (ar-th-commatize 'abbrev no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-abbrev-atpt (&optional no-delimiters) 
  "Put a singlequote before abbrev at point if any. "
  (interactive "*p")
  (ar-th-quote 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-hyphen-abbrev-atpt 'ar-abbrev-hyphen-atpt)
;;;###autoload
(defun ar-abbrev-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around abbrev at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-mark-abbrev-atpt 'ar-abbrev-mark-atpt)
;;;###autoload
(defun ar-abbrev-mark-atpt () 
  "Marks abbrev at point if any. "
  (interactive)
  (ar-th-mark 'abbrev))

(defalias 'ar-hide-abbrev-atpt 'ar-abbrev-hide-atpt)
;;;###autoload
(defun ar-abbrev-hide-atpt () 
  "Hides abbrev at point. "
  (interactive)
  (ar-th-hide 'abbrev))

(defalias 'ar-show-abbrev-atpt 'ar-abbrev-show-atpt)
;;;###autoload
(defun ar-abbrev-show-atpt () 
  "Shows hidden abbrev at point. "
  (interactive)
  (ar-th-show 'abbrev))

(defalias 'ar-hide-show-abbrev-atpt 'ar-abbrev-hide-show-atpt)
;;;###autoload
(defun ar-abbrev-hide-show-atpt () 
  "Alternatively hides or shows abbrev at point. "
  (interactive)
  (ar-th-hide-show 'abbrev))

(defalias 'ar-highlight-abbrev-atpt-mode 'ar-abbrev-highlight-atpt-mode)

(defun ar-abbrev-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles abbrev-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-kill-abbrev-atpt 'ar-abbrev-kill-atpt)
;;;###autoload
(defun ar-abbrev-kill-atpt (&optional no-delimiters) 
  "Kills abbrev at point if any. "
  (interactive "*P")
  (ar-th-kill 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-abbrev-atpt 'ar-abbrev-left-right-singlequote-atpt)
;;;###autoload
(defun ar-abbrev-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-parentize-abbrev-atpt 'ar-abbrev-parentize-atpt)
;;;###autoload
(defun ar-abbrev-parentize-atpt (&optional no-delimiters) 
  "Parentizes abbrev at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-separate-abbrev-atpt 'ar-abbrev-separate-atpt)
;;;###autoload
(defun ar-abbrev-separate-atpt (&optional no-delimiters) 
  "Separates abbrev at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-singlequote-abbrev-atpt 'ar-abbrev-singlequote-atpt)
;;;###autoload
(defun ar-abbrev-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes abbrev at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-abbrev-atpt 'ar-abbrev-triplequote-dq-atpt)
;;;###autoload
(defun ar-abbrev-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around abbrev. "
  (interactive "*p")
  (ar-th-triplequote-dq 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-abbrev-atpt 'ar-abbrev-triplequote-sq-atpt)
;;;###autoload
(defun ar-abbrev-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around abbrev. "
  (interactive "*p")
  (ar-th-triplequote-sq 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-trim-abbrev-atpt 'ar-abbrev-trim-atpt)
;;;###autoload
(defun ar-abbrev-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'abbrev t t)) 
    (ar-th-trim 'abbrev t t)))

(defalias 'ar-trim-left-abbrev-atpt 'ar-abbrev-left-trim-atpt)
;;;###autoload
(defun ar-abbrev-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'abbrev t nil))
    (ar-th-trim 'abbrev t nil)))

(defalias 'ar-trim-right-abbrev-atpt 'ar-abbrev-right-trim-atpt)
;;;###autoload
(defun ar-abbrev-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'abbrev nil t))
    (ar-th-trim 'abbrev nil t)))

(defalias 'ar-abbrev-underscore-atpt 'ar-underscore-abbrev-atpt)
;;;###autoload
(defun ar-underscore-abbrev-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'abbrev no-delimiters (interactive-p)))

(defalias 'ar-abbrev-whitespace-atpt 'ar-whitespace-abbrev-atpt)
;;;###autoload
(defun ar-whitespace-abbrev-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'abbrev nil t))

(defalias 'ar-forward-abbrev-atpt 'ar-abbrev-forward-atpt)
;;;###autoload
(defun ar-abbrev-forward-atpt (&optional arg) 
  "Moves forward over abbrev at point if any, does nothing otherwise.
Returns end position of abbrev "
  (interactive "p")
  (ar-th-forward 'abbrev arg (interactive-p)))

(defalias 'ar-backward-abbrev-atpt 'ar-abbrev-backward-atpt)
;;;###autoload
(defun ar-abbrev-backward-atpt (&optional arg) 
  "Moves backward over abbrev before point if any, does nothing otherwise.
Returns beginning position of abbrev "
  (interactive "p")
  (ar-th-backward 'abbrev arg (interactive-p)))

(defalias 'ar-transpose-abbrev-atpt 'ar-abbrev-transpose-atpt)
;;;###autoload
(defun ar-abbrev-transpose-atpt (&optional arg) 
  "Transposes abbrev with abbrev before point if any. "
  (interactive "*p")
  (ar-th-transpose 'abbrev arg (interactive-p)))

(defalias 'ar-sort-abbrev-atpt 'ar-abbrev-sort-atpt)
;;;###autoload
(defun ar-abbrev-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts abbrevs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'abbrev reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-abbrev-atpt 'ar-abbrev-check-atpt)
;;;###autoload
(defun ar-abbrev-check-atpt () 
  "Return t if a abbrev at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-abbrev-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-abbrev-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-acronym-atpt (&optional arg no-delimiters) 
  "Returns acronym at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'acronym arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-acronym-atpt 'ar-acronym-bounds-atpt)
;;;###autoload
(defun ar-acronym-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of acronym if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'acronym no-delimiters (interactive-p)))

;;;###autoload
(defun ar-acronym-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position acronym at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'acronym no-delimiters (interactive-p)))

;;;###autoload
(defun ar-acronym-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of acronym at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'acronym no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-acronym-atpt 'ar-acronym-beginning-atpt)
;;;###autoload
(defun ar-acronym-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class acronym at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'acronym no-delimiters (interactive-p)))

(defalias 'ar-end-of-acronym-atpt 'ar-acronym-end-atpt)
;;;###autoload
(defun ar-acronym-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class acronym at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'acronym no-delimiters (interactive-p)))

(defalias 'ar-in-acronym-p-atpt 'ar-acronym-in-p-atpt)
;;;###autoload
(defun ar-acronym-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of acronym at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'acronym no-delimiters (interactive-p)))

(defalias 'ar-length-of-acronym-atpt 'ar-acronym-length-atpt)
;;;###autoload
(defun ar-acronym-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class acronym at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'acronym no-delimiters (interactive-p)))

(defalias 'ar-copy-acronym-atpt 'ar-acronym-copy-atpt)
;;;###autoload
(defun ar-acronym-copy-atpt (&optional no-delimiters) 
  "Returns a copy of acronym at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'acronym no-delimiters (interactive-p)))

(defalias 'ar-delete-acronym-in-region 'ar-acronym-delete-in-region)
;;;###autoload
(defun ar-acronym-delete-in-region (beg end) 
  "Deletes acronym at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'acronym beg end (interactive-p)))

;;;###autoload
(defun ar-blok-acronym-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around acronym.
  Returns blok or nil if no acronym at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'acronym no-delimiters (interactive-p)))

(defalias 'ar-escape-acronym-atpt 'ar-acronym-escape-atpt)
;;;###autoload
(defun ar-acronym-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted acronym at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'acronym no-delimiters))

(defalias 'ar-doublequote-acronym-atpt 'ar-acronym-doublequote-atpt)
;;;###autoload
(defun ar-acronym-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes acronym at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'acronym no-delimiters (interactive-p)))

(defalias 'ar-slash-acronym-atpt 'ar-acronym-slash-atpt)
;;;###autoload
(defun ar-acronym-slash-atpt (&optional no-delimiters) 
  "Doublequotes acronym at point if any. "
  (interactive "*p")
  (ar-th-slash 'acronym no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-acronym-atpt 'ar-acronym-double-backslash-atpt)
;;;###autoload
(defun ar-acronym-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around acronym at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'acronym no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-acronym-atpt 'ar-acronym-doubleslash-atpt)
;;;###autoload
(defun ar-acronym-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around acronym at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'acronym no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-acronym-atpt 'ar-acronym-doubleslashparen-atpt)
;;;###autoload
(defun ar-acronym-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around acronym at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'acronym no-delimiters (interactive-p)))

(defalias 'ar-slashparen-acronym-atpt 'ar-acronym-slashparen-atpt)
;;;###autoload
(defun ar-acronym-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around acronym at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'acronym no-delimiters (interactive-p)))

(defalias 'ar-dollar-acronym-atpt 'ar-acronym-dollar-atpt)
;;;###autoload
(defun ar-acronym-dollar-atpt (&optional no-delimiters) 
  "Doublequotes acronym at point if any. "
  (interactive "*p")
  (ar-th-dollar 'acronym no-delimiters (interactive-p)))

(defalias 'ar-equalize-acronym-atpt 'ar-acronym-equalize-atpt)
;;;###autoload
(defun ar-acronym-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around acronym at point if any. "
  (interactive "*p")
  (ar-th-equalize 'acronym no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-acronym-atpt 'ar-acronym-greater-angle-atpt)
;;;###autoload
(defun ar-acronym-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for acronym after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'acronym no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-acronym-atpt 'ar-acronym-lesser-angle-atpt)
;;;###autoload
(defun ar-acronym-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for acronym after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'acronym no-delimiters (interactive-p)))

(defalias 'ar-backslash-acronym-atpt 'ar-acronym-backslash-atpt)
;;;###autoload
(defun ar-acronym-backslash-atpt (&optional no-delimiters) 
  "Backslash acronym at point if any. "
  (interactive "*p")
  (ar-th-backslash 'acronym no-delimiters (interactive-p))) 

(defalias 'ar-brace-acronym-atpt 'ar-acronym-brace-atpt)
;;;###autoload
(defun ar-acronym-brace-atpt (&optional no-delimiters) 
  "Braces acronym at point if any. "
  (interactive "*p")
  (ar-th-brace 'acronym no-delimiters (interactive-p)))

(defalias 'ar-bracket-acronym-atpt 'ar-acronym-bracket-atpt)
;;;###autoload
(defun ar-acronym-bracket-atpt (&optional no-delimiters) 
  "Brackets acronym after point if any. "
  (interactive "*p")
  (ar-th-bracket 'acronym no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-acronym-atpt (&optional no-delimiters) 
  "Comments acronym at point if any. "
  (interactive "*p")
  (ar-th-comment 'acronym no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-acronym-atpt (&optional no-delimiters) 
  "Put a comma after acronym at point if any. "
  (interactive "*p")
  (ar-th-commatize 'acronym no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-acronym-atpt (&optional no-delimiters) 
  "Put a singlequote before acronym at point if any. "
  (interactive "*p")
  (ar-th-quote 'acronym no-delimiters (interactive-p)))

(defalias 'ar-hyphen-acronym-atpt 'ar-acronym-hyphen-atpt)
;;;###autoload
(defun ar-acronym-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around acronym at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'acronym no-delimiters (interactive-p)))

(defalias 'ar-mark-acronym-atpt 'ar-acronym-mark-atpt)
;;;###autoload
(defun ar-acronym-mark-atpt () 
  "Marks acronym at point if any. "
  (interactive)
  (ar-th-mark 'acronym))

(defalias 'ar-hide-acronym-atpt 'ar-acronym-hide-atpt)
;;;###autoload
(defun ar-acronym-hide-atpt () 
  "Hides acronym at point. "
  (interactive)
  (ar-th-hide 'acronym))

(defalias 'ar-show-acronym-atpt 'ar-acronym-show-atpt)
;;;###autoload
(defun ar-acronym-show-atpt () 
  "Shows hidden acronym at point. "
  (interactive)
  (ar-th-show 'acronym))

(defalias 'ar-hide-show-acronym-atpt 'ar-acronym-hide-show-atpt)
;;;###autoload
(defun ar-acronym-hide-show-atpt () 
  "Alternatively hides or shows acronym at point. "
  (interactive)
  (ar-th-hide-show 'acronym))

(defalias 'ar-highlight-acronym-atpt-mode 'ar-acronym-highlight-atpt-mode)

(defun ar-acronym-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles acronym-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'acronym no-delimiters (interactive-p)))

(defalias 'ar-kill-acronym-atpt 'ar-acronym-kill-atpt)
;;;###autoload
(defun ar-acronym-kill-atpt (&optional no-delimiters) 
  "Kills acronym at point if any. "
  (interactive "*P")
  (ar-th-kill 'acronym no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-acronym-atpt 'ar-acronym-left-right-singlequote-atpt)
;;;###autoload
(defun ar-acronym-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'acronym no-delimiters (interactive-p)))

(defalias 'ar-parentize-acronym-atpt 'ar-acronym-parentize-atpt)
;;;###autoload
(defun ar-acronym-parentize-atpt (&optional no-delimiters) 
  "Parentizes acronym at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'acronym no-delimiters (interactive-p)))

(defalias 'ar-separate-acronym-atpt 'ar-acronym-separate-atpt)
;;;###autoload
(defun ar-acronym-separate-atpt (&optional no-delimiters) 
  "Separates acronym at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'acronym no-delimiters (interactive-p)))

(defalias 'ar-singlequote-acronym-atpt 'ar-acronym-singlequote-atpt)
;;;###autoload
(defun ar-acronym-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes acronym at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'acronym no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-acronym-atpt 'ar-acronym-triplequote-dq-atpt)
;;;###autoload
(defun ar-acronym-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around acronym. "
  (interactive "*p")
  (ar-th-triplequote-dq 'acronym no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-acronym-atpt 'ar-acronym-triplequote-sq-atpt)
;;;###autoload
(defun ar-acronym-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around acronym. "
  (interactive "*p")
  (ar-th-triplequote-sq 'acronym no-delimiters (interactive-p)))

(defalias 'ar-trim-acronym-atpt 'ar-acronym-trim-atpt)
;;;###autoload
(defun ar-acronym-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'acronym t t)) 
    (ar-th-trim 'acronym t t)))

(defalias 'ar-trim-left-acronym-atpt 'ar-acronym-left-trim-atpt)
;;;###autoload
(defun ar-acronym-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'acronym t nil))
    (ar-th-trim 'acronym t nil)))

(defalias 'ar-trim-right-acronym-atpt 'ar-acronym-right-trim-atpt)
;;;###autoload
(defun ar-acronym-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'acronym nil t))
    (ar-th-trim 'acronym nil t)))

(defalias 'ar-acronym-underscore-atpt 'ar-underscore-acronym-atpt)
;;;###autoload
(defun ar-underscore-acronym-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'acronym no-delimiters (interactive-p)))

(defalias 'ar-acronym-whitespace-atpt 'ar-whitespace-acronym-atpt)
;;;###autoload
(defun ar-whitespace-acronym-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'acronym nil t))

(defalias 'ar-forward-acronym-atpt 'ar-acronym-forward-atpt)
;;;###autoload
(defun ar-acronym-forward-atpt (&optional arg) 
  "Moves forward over acronym at point if any, does nothing otherwise.
Returns end position of acronym "
  (interactive "p")
  (ar-th-forward 'acronym arg (interactive-p)))

(defalias 'ar-backward-acronym-atpt 'ar-acronym-backward-atpt)
;;;###autoload
(defun ar-acronym-backward-atpt (&optional arg) 
  "Moves backward over acronym before point if any, does nothing otherwise.
Returns beginning position of acronym "
  (interactive "p")
  (ar-th-backward 'acronym arg (interactive-p)))

(defalias 'ar-transpose-acronym-atpt 'ar-acronym-transpose-atpt)
;;;###autoload
(defun ar-acronym-transpose-atpt (&optional arg) 
  "Transposes acronym with acronym before point if any. "
  (interactive "*p")
  (ar-th-transpose 'acronym arg (interactive-p)))

(defalias 'ar-sort-acronym-atpt 'ar-acronym-sort-atpt)
;;;###autoload
(defun ar-acronym-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts acronyms in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'acronym reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-acronym-atpt 'ar-acronym-check-atpt)
;;;###autoload
(defun ar-acronym-check-atpt () 
  "Return t if a acronym at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-acronym-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-acronym-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-angled-no-nest-atpt (&optional arg no-delimiters) 
  "Returns angled-no-nest at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'angled-no-nest arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-angled-no-nest-atpt 'ar-angled-no-nest-bounds-atpt)
;;;###autoload
(defun ar-angled-no-nest-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of angled-no-nest if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'angled-no-nest no-delimiters (interactive-p)))

;;;###autoload
(defun ar-angled-no-nest-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position angled-no-nest at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'angled-no-nest no-delimiters (interactive-p)))

;;;###autoload
(defun ar-angled-no-nest-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of angled-no-nest at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-angled-no-nest-atpt 'ar-angled-no-nest-beginning-atpt)
;;;###autoload
(defun ar-angled-no-nest-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class angled-no-nest at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-end-of-angled-no-nest-atpt 'ar-angled-no-nest-end-atpt)
;;;###autoload
(defun ar-angled-no-nest-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class angled-no-nest at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-in-angled-no-nest-p-atpt 'ar-angled-no-nest-in-p-atpt)
;;;###autoload
(defun ar-angled-no-nest-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of angled-no-nest at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-length-of-angled-no-nest-atpt 'ar-angled-no-nest-length-atpt)
;;;###autoload
(defun ar-angled-no-nest-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class angled-no-nest at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-copy-angled-no-nest-atpt 'ar-angled-no-nest-copy-atpt)
;;;###autoload
(defun ar-angled-no-nest-copy-atpt (&optional no-delimiters) 
  "Returns a copy of angled-no-nest at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-delete-angled-no-nest-in-region 'ar-angled-no-nest-delete-in-region)
;;;###autoload
(defun ar-angled-no-nest-delete-in-region (beg end) 
  "Deletes angled-no-nest at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'angled-no-nest beg end (interactive-p)))

;;;###autoload
(defun ar-blok-angled-no-nest-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around angled-no-nest.
  Returns blok or nil if no angled-no-nest at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-escape-angled-no-nest-atpt 'ar-angled-no-nest-escape-atpt)
;;;###autoload
(defun ar-angled-no-nest-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted angled-no-nest at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'angled-no-nest no-delimiters))

(defalias 'ar-doublequote-angled-no-nest-atpt 'ar-angled-no-nest-doublequote-atpt)
;;;###autoload
(defun ar-angled-no-nest-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-slash-angled-no-nest-atpt 'ar-angled-no-nest-slash-atpt)
;;;###autoload
(defun ar-angled-no-nest-slash-atpt (&optional no-delimiters) 
  "Doublequotes angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-slash 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-angled-no-nest-atpt 'ar-angled-no-nest-double-backslash-atpt)
;;;###autoload
(defun ar-angled-no-nest-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-angled-no-nest-atpt 'ar-angled-no-nest-doubleslash-atpt)
;;;###autoload
(defun ar-angled-no-nest-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-angled-no-nest-atpt 'ar-angled-no-nest-doubleslashparen-atpt)
;;;###autoload
(defun ar-angled-no-nest-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-slashparen-angled-no-nest-atpt 'ar-angled-no-nest-slashparen-atpt)
;;;###autoload
(defun ar-angled-no-nest-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-dollar-angled-no-nest-atpt 'ar-angled-no-nest-dollar-atpt)
;;;###autoload
(defun ar-angled-no-nest-dollar-atpt (&optional no-delimiters) 
  "Doublequotes angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-dollar 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-equalize-angled-no-nest-atpt 'ar-angled-no-nest-equalize-atpt)
;;;###autoload
(defun ar-angled-no-nest-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-equalize 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-angled-no-nest-atpt 'ar-angled-no-nest-greater-angle-atpt)
;;;###autoload
(defun ar-angled-no-nest-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for angled-no-nest after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-angled-no-nest-atpt 'ar-angled-no-nest-lesser-angle-atpt)
;;;###autoload
(defun ar-angled-no-nest-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for angled-no-nest after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-backslash-angled-no-nest-atpt 'ar-angled-no-nest-backslash-atpt)
;;;###autoload
(defun ar-angled-no-nest-backslash-atpt (&optional no-delimiters) 
  "Backslash angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-backslash 'angled-no-nest no-delimiters (interactive-p))) 

(defalias 'ar-brace-angled-no-nest-atpt 'ar-angled-no-nest-brace-atpt)
;;;###autoload
(defun ar-angled-no-nest-brace-atpt (&optional no-delimiters) 
  "Braces angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-brace 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-bracket-angled-no-nest-atpt 'ar-angled-no-nest-bracket-atpt)
;;;###autoload
(defun ar-angled-no-nest-bracket-atpt (&optional no-delimiters) 
  "Brackets angled-no-nest after point if any. "
  (interactive "*p")
  (ar-th-bracket 'angled-no-nest no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-angled-no-nest-atpt (&optional no-delimiters) 
  "Comments angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-comment 'angled-no-nest no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-angled-no-nest-atpt (&optional no-delimiters) 
  "Put a comma after angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-commatize 'angled-no-nest no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-angled-no-nest-atpt (&optional no-delimiters) 
  "Put a singlequote before angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-quote 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-hyphen-angled-no-nest-atpt 'ar-angled-no-nest-hyphen-atpt)
;;;###autoload
(defun ar-angled-no-nest-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-mark-angled-no-nest-atpt 'ar-angled-no-nest-mark-atpt)
;;;###autoload
(defun ar-angled-no-nest-mark-atpt () 
  "Marks angled-no-nest at point if any. "
  (interactive)
  (ar-th-mark 'angled-no-nest))

(defalias 'ar-hide-angled-no-nest-atpt 'ar-angled-no-nest-hide-atpt)
;;;###autoload
(defun ar-angled-no-nest-hide-atpt () 
  "Hides angled-no-nest at point. "
  (interactive)
  (ar-th-hide 'angled-no-nest))

(defalias 'ar-show-angled-no-nest-atpt 'ar-angled-no-nest-show-atpt)
;;;###autoload
(defun ar-angled-no-nest-show-atpt () 
  "Shows hidden angled-no-nest at point. "
  (interactive)
  (ar-th-show 'angled-no-nest))

(defalias 'ar-hide-show-angled-no-nest-atpt 'ar-angled-no-nest-hide-show-atpt)
;;;###autoload
(defun ar-angled-no-nest-hide-show-atpt () 
  "Alternatively hides or shows angled-no-nest at point. "
  (interactive)
  (ar-th-hide-show 'angled-no-nest))

(defalias 'ar-highlight-angled-no-nest-atpt-mode 'ar-angled-no-nest-highlight-atpt-mode)

(defun ar-angled-no-nest-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles angled-no-nest-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-kill-angled-no-nest-atpt 'ar-angled-no-nest-kill-atpt)
;;;###autoload
(defun ar-angled-no-nest-kill-atpt (&optional no-delimiters) 
  "Kills angled-no-nest at point if any. "
  (interactive "*P")
  (ar-th-kill 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-angled-no-nest-atpt 'ar-angled-no-nest-left-right-singlequote-atpt)
;;;###autoload
(defun ar-angled-no-nest-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-parentize-angled-no-nest-atpt 'ar-angled-no-nest-parentize-atpt)
;;;###autoload
(defun ar-angled-no-nest-parentize-atpt (&optional no-delimiters) 
  "Parentizes angled-no-nest at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-separate-angled-no-nest-atpt 'ar-angled-no-nest-separate-atpt)
;;;###autoload
(defun ar-angled-no-nest-separate-atpt (&optional no-delimiters) 
  "Separates angled-no-nest at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-singlequote-angled-no-nest-atpt 'ar-angled-no-nest-singlequote-atpt)
;;;###autoload
(defun ar-angled-no-nest-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes angled-no-nest at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-angled-no-nest-atpt 'ar-angled-no-nest-triplequote-dq-atpt)
;;;###autoload
(defun ar-angled-no-nest-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around angled-no-nest. "
  (interactive "*p")
  (ar-th-triplequote-dq 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-angled-no-nest-atpt 'ar-angled-no-nest-triplequote-sq-atpt)
;;;###autoload
(defun ar-angled-no-nest-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around angled-no-nest. "
  (interactive "*p")
  (ar-th-triplequote-sq 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-trim-angled-no-nest-atpt 'ar-angled-no-nest-trim-atpt)
;;;###autoload
(defun ar-angled-no-nest-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'angled-no-nest t t)) 
    (ar-th-trim 'angled-no-nest t t)))

(defalias 'ar-trim-left-angled-no-nest-atpt 'ar-angled-no-nest-left-trim-atpt)
;;;###autoload
(defun ar-angled-no-nest-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'angled-no-nest t nil))
    (ar-th-trim 'angled-no-nest t nil)))

(defalias 'ar-trim-right-angled-no-nest-atpt 'ar-angled-no-nest-right-trim-atpt)
;;;###autoload
(defun ar-angled-no-nest-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'angled-no-nest nil t))
    (ar-th-trim 'angled-no-nest nil t)))

(defalias 'ar-angled-no-nest-underscore-atpt 'ar-underscore-angled-no-nest-atpt)
;;;###autoload
(defun ar-underscore-angled-no-nest-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'angled-no-nest no-delimiters (interactive-p)))

(defalias 'ar-angled-no-nest-whitespace-atpt 'ar-whitespace-angled-no-nest-atpt)
;;;###autoload
(defun ar-whitespace-angled-no-nest-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'angled-no-nest nil t))

(defalias 'ar-forward-angled-no-nest-atpt 'ar-angled-no-nest-forward-atpt)
;;;###autoload
(defun ar-angled-no-nest-forward-atpt (&optional arg) 
  "Moves forward over angled-no-nest at point if any, does nothing otherwise.
Returns end position of angled-no-nest "
  (interactive "p")
  (ar-th-forward 'angled-no-nest arg (interactive-p)))

(defalias 'ar-backward-angled-no-nest-atpt 'ar-angled-no-nest-backward-atpt)
;;;###autoload
(defun ar-angled-no-nest-backward-atpt (&optional arg) 
  "Moves backward over angled-no-nest before point if any, does nothing otherwise.
Returns beginning position of angled-no-nest "
  (interactive "p")
  (ar-th-backward 'angled-no-nest arg (interactive-p)))

(defalias 'ar-transpose-angled-no-nest-atpt 'ar-angled-no-nest-transpose-atpt)
;;;###autoload
(defun ar-angled-no-nest-transpose-atpt (&optional arg) 
  "Transposes angled-no-nest with angled-no-nest before point if any. "
  (interactive "*p")
  (ar-th-transpose 'angled-no-nest arg (interactive-p)))

(defalias 'ar-sort-angled-no-nest-atpt 'ar-angled-no-nest-sort-atpt)
;;;###autoload
(defun ar-angled-no-nest-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts angled-no-nests in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'angled-no-nest reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-angled-no-nest-atpt 'ar-angled-no-nest-check-atpt)
;;;###autoload
(defun ar-angled-no-nest-check-atpt () 
  "Return t if a angled-no-nest at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-angled-no-nest-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-angled-no-nest-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-greater-angled-nested-atpt (&optional arg no-delimiters) 
  "Returns greater-angled-nested at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'greater-angled-nested arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-greater-angled-nested-atpt 'ar-greater-angled-nested-bounds-atpt)
;;;###autoload
(defun ar-greater-angled-nested-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of greater-angled-nested if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'greater-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-greater-angled-nested-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position greater-angled-nested at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'greater-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-greater-angled-nested-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of greater-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-greater-angled-nested-atpt 'ar-greater-angled-nested-beginning-atpt)
;;;###autoload
(defun ar-greater-angled-nested-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class greater-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-end-of-greater-angled-nested-atpt 'ar-greater-angled-nested-end-atpt)
;;;###autoload
(defun ar-greater-angled-nested-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class greater-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-in-greater-angled-nested-p-atpt 'ar-greater-angled-nested-in-p-atpt)
;;;###autoload
(defun ar-greater-angled-nested-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of greater-angled-nested at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-length-of-greater-angled-nested-atpt 'ar-greater-angled-nested-length-atpt)
;;;###autoload
(defun ar-greater-angled-nested-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class greater-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-copy-greater-angled-nested-atpt 'ar-greater-angled-nested-copy-atpt)
;;;###autoload
(defun ar-greater-angled-nested-copy-atpt (&optional no-delimiters) 
  "Returns a copy of greater-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-delete-greater-angled-nested-in-region 'ar-greater-angled-nested-delete-in-region)
;;;###autoload
(defun ar-greater-angled-nested-delete-in-region (beg end) 
  "Deletes greater-angled-nested at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'greater-angled-nested beg end (interactive-p)))

;;;###autoload
(defun ar-blok-greater-angled-nested-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around greater-angled-nested.
  Returns blok or nil if no greater-angled-nested at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-escape-greater-angled-nested-atpt 'ar-greater-angled-nested-escape-atpt)
;;;###autoload
(defun ar-greater-angled-nested-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted greater-angled-nested at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'greater-angled-nested no-delimiters))

(defalias 'ar-doublequote-greater-angled-nested-atpt 'ar-greater-angled-nested-doublequote-atpt)
;;;###autoload
(defun ar-greater-angled-nested-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-slash-greater-angled-nested-atpt 'ar-greater-angled-nested-slash-atpt)
;;;###autoload
(defun ar-greater-angled-nested-slash-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-slash 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-greater-angled-nested-atpt 'ar-greater-angled-nested-double-backslash-atpt)
;;;###autoload
(defun ar-greater-angled-nested-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-greater-angled-nested-atpt 'ar-greater-angled-nested-doubleslash-atpt)
;;;###autoload
(defun ar-greater-angled-nested-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-greater-angled-nested-atpt 'ar-greater-angled-nested-doubleslashparen-atpt)
;;;###autoload
(defun ar-greater-angled-nested-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-slashparen-greater-angled-nested-atpt 'ar-greater-angled-nested-slashparen-atpt)
;;;###autoload
(defun ar-greater-angled-nested-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-dollar-greater-angled-nested-atpt 'ar-greater-angled-nested-dollar-atpt)
;;;###autoload
(defun ar-greater-angled-nested-dollar-atpt (&optional no-delimiters) 
  "Doublequotes greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-dollar 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-equalize-greater-angled-nested-atpt 'ar-greater-angled-nested-equalize-atpt)
;;;###autoload
(defun ar-greater-angled-nested-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-equalize 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-greater-angled-nested-atpt 'ar-greater-angled-nested-greater-angle-atpt)
;;;###autoload
(defun ar-greater-angled-nested-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for greater-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-greater-angled-nested-atpt 'ar-greater-angled-nested-lesser-angle-atpt)
;;;###autoload
(defun ar-greater-angled-nested-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for greater-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-backslash-greater-angled-nested-atpt 'ar-greater-angled-nested-backslash-atpt)
;;;###autoload
(defun ar-greater-angled-nested-backslash-atpt (&optional no-delimiters) 
  "Backslash greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-backslash 'greater-angled-nested no-delimiters (interactive-p))) 

(defalias 'ar-brace-greater-angled-nested-atpt 'ar-greater-angled-nested-brace-atpt)
;;;###autoload
(defun ar-greater-angled-nested-brace-atpt (&optional no-delimiters) 
  "Braces greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-brace 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-bracket-greater-angled-nested-atpt 'ar-greater-angled-nested-bracket-atpt)
;;;###autoload
(defun ar-greater-angled-nested-bracket-atpt (&optional no-delimiters) 
  "Brackets greater-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-bracket 'greater-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-greater-angled-nested-atpt (&optional no-delimiters) 
  "Comments greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-comment 'greater-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-greater-angled-nested-atpt (&optional no-delimiters) 
  "Put a comma after greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-commatize 'greater-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-greater-angled-nested-atpt (&optional no-delimiters) 
  "Put a singlequote before greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-quote 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-hyphen-greater-angled-nested-atpt 'ar-greater-angled-nested-hyphen-atpt)
;;;###autoload
(defun ar-greater-angled-nested-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-mark-greater-angled-nested-atpt 'ar-greater-angled-nested-mark-atpt)
;;;###autoload
(defun ar-greater-angled-nested-mark-atpt () 
  "Marks greater-angled-nested at point if any. "
  (interactive)
  (ar-th-mark 'greater-angled-nested))

(defalias 'ar-hide-greater-angled-nested-atpt 'ar-greater-angled-nested-hide-atpt)
;;;###autoload
(defun ar-greater-angled-nested-hide-atpt () 
  "Hides greater-angled-nested at point. "
  (interactive)
  (ar-th-hide 'greater-angled-nested))

(defalias 'ar-show-greater-angled-nested-atpt 'ar-greater-angled-nested-show-atpt)
;;;###autoload
(defun ar-greater-angled-nested-show-atpt () 
  "Shows hidden greater-angled-nested at point. "
  (interactive)
  (ar-th-show 'greater-angled-nested))

(defalias 'ar-hide-show-greater-angled-nested-atpt 'ar-greater-angled-nested-hide-show-atpt)
;;;###autoload
(defun ar-greater-angled-nested-hide-show-atpt () 
  "Alternatively hides or shows greater-angled-nested at point. "
  (interactive)
  (ar-th-hide-show 'greater-angled-nested))

(defalias 'ar-highlight-greater-angled-nested-atpt-mode 'ar-greater-angled-nested-highlight-atpt-mode)

(defun ar-greater-angled-nested-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles greater-angled-nested-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-kill-greater-angled-nested-atpt 'ar-greater-angled-nested-kill-atpt)
;;;###autoload
(defun ar-greater-angled-nested-kill-atpt (&optional no-delimiters) 
  "Kills greater-angled-nested at point if any. "
  (interactive "*P")
  (ar-th-kill 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-greater-angled-nested-atpt 'ar-greater-angled-nested-left-right-singlequote-atpt)
;;;###autoload
(defun ar-greater-angled-nested-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-parentize-greater-angled-nested-atpt 'ar-greater-angled-nested-parentize-atpt)
;;;###autoload
(defun ar-greater-angled-nested-parentize-atpt (&optional no-delimiters) 
  "Parentizes greater-angled-nested at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-separate-greater-angled-nested-atpt 'ar-greater-angled-nested-separate-atpt)
;;;###autoload
(defun ar-greater-angled-nested-separate-atpt (&optional no-delimiters) 
  "Separates greater-angled-nested at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-singlequote-greater-angled-nested-atpt 'ar-greater-angled-nested-singlequote-atpt)
;;;###autoload
(defun ar-greater-angled-nested-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes greater-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-greater-angled-nested-atpt 'ar-greater-angled-nested-triplequote-dq-atpt)
;;;###autoload
(defun ar-greater-angled-nested-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around greater-angled-nested. "
  (interactive "*p")
  (ar-th-triplequote-dq 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-greater-angled-nested-atpt 'ar-greater-angled-nested-triplequote-sq-atpt)
;;;###autoload
(defun ar-greater-angled-nested-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around greater-angled-nested. "
  (interactive "*p")
  (ar-th-triplequote-sq 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-trim-greater-angled-nested-atpt 'ar-greater-angled-nested-trim-atpt)
;;;###autoload
(defun ar-greater-angled-nested-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled-nested t t)) 
    (ar-th-trim 'greater-angled-nested t t)))

(defalias 'ar-trim-left-greater-angled-nested-atpt 'ar-greater-angled-nested-left-trim-atpt)
;;;###autoload
(defun ar-greater-angled-nested-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled-nested t nil))
    (ar-th-trim 'greater-angled-nested t nil)))

(defalias 'ar-trim-right-greater-angled-nested-atpt 'ar-greater-angled-nested-right-trim-atpt)
;;;###autoload
(defun ar-greater-angled-nested-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'greater-angled-nested nil t))
    (ar-th-trim 'greater-angled-nested nil t)))

(defalias 'ar-greater-angled-nested-underscore-atpt 'ar-underscore-greater-angled-nested-atpt)
;;;###autoload
(defun ar-underscore-greater-angled-nested-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'greater-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-greater-angled-nested-whitespace-atpt 'ar-whitespace-greater-angled-nested-atpt)
;;;###autoload
(defun ar-whitespace-greater-angled-nested-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'greater-angled-nested nil t))

(defalias 'ar-forward-greater-angled-nested-atpt 'ar-greater-angled-nested-forward-atpt)
;;;###autoload
(defun ar-greater-angled-nested-forward-atpt (&optional arg) 
  "Moves forward over greater-angled-nested at point if any, does nothing otherwise.
Returns end position of greater-angled-nested "
  (interactive "p")
  (ar-th-forward 'greater-angled-nested arg (interactive-p)))

(defalias 'ar-backward-greater-angled-nested-atpt 'ar-greater-angled-nested-backward-atpt)
;;;###autoload
(defun ar-greater-angled-nested-backward-atpt (&optional arg) 
  "Moves backward over greater-angled-nested before point if any, does nothing otherwise.
Returns beginning position of greater-angled-nested "
  (interactive "p")
  (ar-th-backward 'greater-angled-nested arg (interactive-p)))

(defalias 'ar-transpose-greater-angled-nested-atpt 'ar-greater-angled-nested-transpose-atpt)
;;;###autoload
(defun ar-greater-angled-nested-transpose-atpt (&optional arg) 
  "Transposes greater-angled-nested with greater-angled-nested before point if any. "
  (interactive "*p")
  (ar-th-transpose 'greater-angled-nested arg (interactive-p)))

(defalias 'ar-sort-greater-angled-nested-atpt 'ar-greater-angled-nested-sort-atpt)
;;;###autoload
(defun ar-greater-angled-nested-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts greater-angled-nesteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'greater-angled-nested reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-greater-angled-nested-atpt 'ar-greater-angled-nested-check-atpt)
;;;###autoload
(defun ar-greater-angled-nested-check-atpt () 
  "Return t if a greater-angled-nested at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-greater-angled-nested-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-greater-angled-nested-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-lesser-angled-nested-atpt (&optional arg no-delimiters) 
  "Returns lesser-angled-nested at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'lesser-angled-nested arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-lesser-angled-nested-atpt 'ar-lesser-angled-nested-bounds-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of lesser-angled-nested if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'lesser-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lesser-angled-nested-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position lesser-angled-nested at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'lesser-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-lesser-angled-nested-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of lesser-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-lesser-angled-nested-atpt 'ar-lesser-angled-nested-beginning-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class lesser-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-end-of-lesser-angled-nested-atpt 'ar-lesser-angled-nested-end-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class lesser-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-in-lesser-angled-nested-p-atpt 'ar-lesser-angled-nested-in-p-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of lesser-angled-nested at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-length-of-lesser-angled-nested-atpt 'ar-lesser-angled-nested-length-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class lesser-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-copy-lesser-angled-nested-atpt 'ar-lesser-angled-nested-copy-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-copy-atpt (&optional no-delimiters) 
  "Returns a copy of lesser-angled-nested at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-delete-lesser-angled-nested-in-region 'ar-lesser-angled-nested-delete-in-region)
;;;###autoload
(defun ar-lesser-angled-nested-delete-in-region (beg end) 
  "Deletes lesser-angled-nested at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'lesser-angled-nested beg end (interactive-p)))

;;;###autoload
(defun ar-blok-lesser-angled-nested-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around lesser-angled-nested.
  Returns blok or nil if no lesser-angled-nested at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-escape-lesser-angled-nested-atpt 'ar-lesser-angled-nested-escape-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted lesser-angled-nested at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'lesser-angled-nested no-delimiters))

(defalias 'ar-doublequote-lesser-angled-nested-atpt 'ar-lesser-angled-nested-doublequote-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-slash-lesser-angled-nested-atpt 'ar-lesser-angled-nested-slash-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-slash-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-slash 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-lesser-angled-nested-atpt 'ar-lesser-angled-nested-double-backslash-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-lesser-angled-nested-atpt 'ar-lesser-angled-nested-doubleslash-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-lesser-angled-nested-atpt 'ar-lesser-angled-nested-doubleslashparen-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-slashparen-lesser-angled-nested-atpt 'ar-lesser-angled-nested-slashparen-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-dollar-lesser-angled-nested-atpt 'ar-lesser-angled-nested-dollar-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-dollar-atpt (&optional no-delimiters) 
  "Doublequotes lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-dollar 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-equalize-lesser-angled-nested-atpt 'ar-lesser-angled-nested-equalize-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-equalize 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-lesser-angled-nested-atpt 'ar-lesser-angled-nested-greater-angle-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for lesser-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-lesser-angled-nested-atpt 'ar-lesser-angled-nested-lesser-angle-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for lesser-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-backslash-lesser-angled-nested-atpt 'ar-lesser-angled-nested-backslash-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-backslash-atpt (&optional no-delimiters) 
  "Backslash lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-backslash 'lesser-angled-nested no-delimiters (interactive-p))) 

(defalias 'ar-brace-lesser-angled-nested-atpt 'ar-lesser-angled-nested-brace-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-brace-atpt (&optional no-delimiters) 
  "Braces lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-brace 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-bracket-lesser-angled-nested-atpt 'ar-lesser-angled-nested-bracket-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-bracket-atpt (&optional no-delimiters) 
  "Brackets lesser-angled-nested after point if any. "
  (interactive "*p")
  (ar-th-bracket 'lesser-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-lesser-angled-nested-atpt (&optional no-delimiters) 
  "Comments lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-comment 'lesser-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-lesser-angled-nested-atpt (&optional no-delimiters) 
  "Put a comma after lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-commatize 'lesser-angled-nested no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-lesser-angled-nested-atpt (&optional no-delimiters) 
  "Put a singlequote before lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-quote 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-hyphen-lesser-angled-nested-atpt 'ar-lesser-angled-nested-hyphen-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-mark-lesser-angled-nested-atpt 'ar-lesser-angled-nested-mark-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-mark-atpt () 
  "Marks lesser-angled-nested at point if any. "
  (interactive)
  (ar-th-mark 'lesser-angled-nested))

(defalias 'ar-hide-lesser-angled-nested-atpt 'ar-lesser-angled-nested-hide-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-hide-atpt () 
  "Hides lesser-angled-nested at point. "
  (interactive)
  (ar-th-hide 'lesser-angled-nested))

(defalias 'ar-show-lesser-angled-nested-atpt 'ar-lesser-angled-nested-show-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-show-atpt () 
  "Shows hidden lesser-angled-nested at point. "
  (interactive)
  (ar-th-show 'lesser-angled-nested))

(defalias 'ar-hide-show-lesser-angled-nested-atpt 'ar-lesser-angled-nested-hide-show-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-hide-show-atpt () 
  "Alternatively hides or shows lesser-angled-nested at point. "
  (interactive)
  (ar-th-hide-show 'lesser-angled-nested))

(defalias 'ar-highlight-lesser-angled-nested-atpt-mode 'ar-lesser-angled-nested-highlight-atpt-mode)

(defun ar-lesser-angled-nested-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles lesser-angled-nested-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-kill-lesser-angled-nested-atpt 'ar-lesser-angled-nested-kill-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-kill-atpt (&optional no-delimiters) 
  "Kills lesser-angled-nested at point if any. "
  (interactive "*P")
  (ar-th-kill 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-lesser-angled-nested-atpt 'ar-lesser-angled-nested-left-right-singlequote-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-parentize-lesser-angled-nested-atpt 'ar-lesser-angled-nested-parentize-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-parentize-atpt (&optional no-delimiters) 
  "Parentizes lesser-angled-nested at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-separate-lesser-angled-nested-atpt 'ar-lesser-angled-nested-separate-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-separate-atpt (&optional no-delimiters) 
  "Separates lesser-angled-nested at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-singlequote-lesser-angled-nested-atpt 'ar-lesser-angled-nested-singlequote-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes lesser-angled-nested at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-lesser-angled-nested-atpt 'ar-lesser-angled-nested-triplequote-dq-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around lesser-angled-nested. "
  (interactive "*p")
  (ar-th-triplequote-dq 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-lesser-angled-nested-atpt 'ar-lesser-angled-nested-triplequote-sq-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around lesser-angled-nested. "
  (interactive "*p")
  (ar-th-triplequote-sq 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-trim-lesser-angled-nested-atpt 'ar-lesser-angled-nested-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled-nested t t)) 
    (ar-th-trim 'lesser-angled-nested t t)))

(defalias 'ar-trim-left-lesser-angled-nested-atpt 'ar-lesser-angled-nested-left-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled-nested t nil))
    (ar-th-trim 'lesser-angled-nested t nil)))

(defalias 'ar-trim-right-lesser-angled-nested-atpt 'ar-lesser-angled-nested-right-trim-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'lesser-angled-nested nil t))
    (ar-th-trim 'lesser-angled-nested nil t)))

(defalias 'ar-lesser-angled-nested-underscore-atpt 'ar-underscore-lesser-angled-nested-atpt)
;;;###autoload
(defun ar-underscore-lesser-angled-nested-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'lesser-angled-nested no-delimiters (interactive-p)))

(defalias 'ar-lesser-angled-nested-whitespace-atpt 'ar-whitespace-lesser-angled-nested-atpt)
;;;###autoload
(defun ar-whitespace-lesser-angled-nested-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'lesser-angled-nested nil t))

(defalias 'ar-forward-lesser-angled-nested-atpt 'ar-lesser-angled-nested-forward-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-forward-atpt (&optional arg) 
  "Moves forward over lesser-angled-nested at point if any, does nothing otherwise.
Returns end position of lesser-angled-nested "
  (interactive "p")
  (ar-th-forward 'lesser-angled-nested arg (interactive-p)))

(defalias 'ar-backward-lesser-angled-nested-atpt 'ar-lesser-angled-nested-backward-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-backward-atpt (&optional arg) 
  "Moves backward over lesser-angled-nested before point if any, does nothing otherwise.
Returns beginning position of lesser-angled-nested "
  (interactive "p")
  (ar-th-backward 'lesser-angled-nested arg (interactive-p)))

(defalias 'ar-transpose-lesser-angled-nested-atpt 'ar-lesser-angled-nested-transpose-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-transpose-atpt (&optional arg) 
  "Transposes lesser-angled-nested with lesser-angled-nested before point if any. "
  (interactive "*p")
  (ar-th-transpose 'lesser-angled-nested arg (interactive-p)))

(defalias 'ar-sort-lesser-angled-nested-atpt 'ar-lesser-angled-nested-sort-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts lesser-angled-nesteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'lesser-angled-nested reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-lesser-angled-nested-atpt 'ar-lesser-angled-nested-check-atpt)
;;;###autoload
(defun ar-lesser-angled-nested-check-atpt () 
  "Return t if a lesser-angled-nested at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-lesser-angled-nested-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-lesser-angled-nested-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-buffer-atpt (&optional arg no-delimiters) 
  "Returns buffer at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'buffer arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-buffer-atpt 'ar-buffer-bounds-atpt)
;;;###autoload
(defun ar-buffer-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of buffer if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'buffer no-delimiters (interactive-p)))

;;;###autoload
(defun ar-buffer-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position buffer at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'buffer no-delimiters (interactive-p)))

;;;###autoload
(defun ar-buffer-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of buffer at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'buffer no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-buffer-atpt 'ar-buffer-beginning-atpt)
;;;###autoload
(defun ar-buffer-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class buffer at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'buffer no-delimiters (interactive-p)))

(defalias 'ar-end-of-buffer-atpt 'ar-buffer-end-atpt)
;;;###autoload
(defun ar-buffer-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class buffer at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'buffer no-delimiters (interactive-p)))

(defalias 'ar-in-buffer-p-atpt 'ar-buffer-in-p-atpt)
;;;###autoload
(defun ar-buffer-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of buffer at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'buffer no-delimiters (interactive-p)))

(defalias 'ar-length-of-buffer-atpt 'ar-buffer-length-atpt)
;;;###autoload
(defun ar-buffer-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class buffer at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'buffer no-delimiters (interactive-p)))

(defalias 'ar-copy-buffer-atpt 'ar-buffer-copy-atpt)
;;;###autoload
(defun ar-buffer-copy-atpt (&optional no-delimiters) 
  "Returns a copy of buffer at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'buffer no-delimiters (interactive-p)))

(defalias 'ar-delete-buffer-in-region 'ar-buffer-delete-in-region)
;;;###autoload
(defun ar-buffer-delete-in-region (beg end) 
  "Deletes buffer at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'buffer beg end (interactive-p)))

;;;###autoload
(defun ar-blok-buffer-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around buffer.
  Returns blok or nil if no buffer at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'buffer no-delimiters (interactive-p)))

(defalias 'ar-escape-buffer-atpt 'ar-buffer-escape-atpt)
;;;###autoload
(defun ar-buffer-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted buffer at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'buffer no-delimiters))

(defalias 'ar-doublequote-buffer-atpt 'ar-buffer-doublequote-atpt)
;;;###autoload
(defun ar-buffer-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes buffer at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'buffer no-delimiters (interactive-p)))

(defalias 'ar-slash-buffer-atpt 'ar-buffer-slash-atpt)
;;;###autoload
(defun ar-buffer-slash-atpt (&optional no-delimiters) 
  "Doublequotes buffer at point if any. "
  (interactive "*p")
  (ar-th-slash 'buffer no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-buffer-atpt 'ar-buffer-double-backslash-atpt)
;;;###autoload
(defun ar-buffer-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around buffer at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'buffer no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-buffer-atpt 'ar-buffer-doubleslash-atpt)
;;;###autoload
(defun ar-buffer-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around buffer at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'buffer no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-buffer-atpt 'ar-buffer-doubleslashparen-atpt)
;;;###autoload
(defun ar-buffer-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around buffer at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'buffer no-delimiters (interactive-p)))

(defalias 'ar-slashparen-buffer-atpt 'ar-buffer-slashparen-atpt)
;;;###autoload
(defun ar-buffer-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around buffer at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'buffer no-delimiters (interactive-p)))

(defalias 'ar-dollar-buffer-atpt 'ar-buffer-dollar-atpt)
;;;###autoload
(defun ar-buffer-dollar-atpt (&optional no-delimiters) 
  "Doublequotes buffer at point if any. "
  (interactive "*p")
  (ar-th-dollar 'buffer no-delimiters (interactive-p)))

(defalias 'ar-equalize-buffer-atpt 'ar-buffer-equalize-atpt)
;;;###autoload
(defun ar-buffer-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around buffer at point if any. "
  (interactive "*p")
  (ar-th-equalize 'buffer no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-buffer-atpt 'ar-buffer-greater-angle-atpt)
;;;###autoload
(defun ar-buffer-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for buffer after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'buffer no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-buffer-atpt 'ar-buffer-lesser-angle-atpt)
;;;###autoload
(defun ar-buffer-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for buffer after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'buffer no-delimiters (interactive-p)))

(defalias 'ar-backslash-buffer-atpt 'ar-buffer-backslash-atpt)
;;;###autoload
(defun ar-buffer-backslash-atpt (&optional no-delimiters) 
  "Backslash buffer at point if any. "
  (interactive "*p")
  (ar-th-backslash 'buffer no-delimiters (interactive-p))) 

(defalias 'ar-brace-buffer-atpt 'ar-buffer-brace-atpt)
;;;###autoload
(defun ar-buffer-brace-atpt (&optional no-delimiters) 
  "Braces buffer at point if any. "
  (interactive "*p")
  (ar-th-brace 'buffer no-delimiters (interactive-p)))

(defalias 'ar-bracket-buffer-atpt 'ar-buffer-bracket-atpt)
;;;###autoload
(defun ar-buffer-bracket-atpt (&optional no-delimiters) 
  "Brackets buffer after point if any. "
  (interactive "*p")
  (ar-th-bracket 'buffer no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-buffer-atpt (&optional no-delimiters) 
  "Comments buffer at point if any. "
  (interactive "*p")
  (ar-th-comment 'buffer no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-buffer-atpt (&optional no-delimiters) 
  "Put a comma after buffer at point if any. "
  (interactive "*p")
  (ar-th-commatize 'buffer no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-buffer-atpt (&optional no-delimiters) 
  "Put a singlequote before buffer at point if any. "
  (interactive "*p")
  (ar-th-quote 'buffer no-delimiters (interactive-p)))

(defalias 'ar-hyphen-buffer-atpt 'ar-buffer-hyphen-atpt)
;;;###autoload
(defun ar-buffer-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around buffer at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'buffer no-delimiters (interactive-p)))

(defalias 'ar-mark-buffer-atpt 'ar-buffer-mark-atpt)
;;;###autoload
(defun ar-buffer-mark-atpt () 
  "Marks buffer at point if any. "
  (interactive)
  (ar-th-mark 'buffer))

(defalias 'ar-hide-buffer-atpt 'ar-buffer-hide-atpt)
;;;###autoload
(defun ar-buffer-hide-atpt () 
  "Hides buffer at point. "
  (interactive)
  (ar-th-hide 'buffer))

(defalias 'ar-show-buffer-atpt 'ar-buffer-show-atpt)
;;;###autoload
(defun ar-buffer-show-atpt () 
  "Shows hidden buffer at point. "
  (interactive)
  (ar-th-show 'buffer))

(defalias 'ar-hide-show-buffer-atpt 'ar-buffer-hide-show-atpt)
;;;###autoload
(defun ar-buffer-hide-show-atpt () 
  "Alternatively hides or shows buffer at point. "
  (interactive)
  (ar-th-hide-show 'buffer))

(defalias 'ar-highlight-buffer-atpt-mode 'ar-buffer-highlight-atpt-mode)

(defun ar-buffer-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles buffer-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'buffer no-delimiters (interactive-p)))

(defalias 'ar-kill-buffer-atpt 'ar-buffer-kill-atpt)
;;;###autoload
(defun ar-buffer-kill-atpt (&optional no-delimiters) 
  "Kills buffer at point if any. "
  (interactive "*P")
  (ar-th-kill 'buffer no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-buffer-atpt 'ar-buffer-left-right-singlequote-atpt)
;;;###autoload
(defun ar-buffer-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'buffer no-delimiters (interactive-p)))

(defalias 'ar-parentize-buffer-atpt 'ar-buffer-parentize-atpt)
;;;###autoload
(defun ar-buffer-parentize-atpt (&optional no-delimiters) 
  "Parentizes buffer at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'buffer no-delimiters (interactive-p)))

(defalias 'ar-separate-buffer-atpt 'ar-buffer-separate-atpt)
;;;###autoload
(defun ar-buffer-separate-atpt (&optional no-delimiters) 
  "Separates buffer at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'buffer no-delimiters (interactive-p)))

(defalias 'ar-singlequote-buffer-atpt 'ar-buffer-singlequote-atpt)
;;;###autoload
(defun ar-buffer-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes buffer at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'buffer no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-buffer-atpt 'ar-buffer-triplequote-dq-atpt)
;;;###autoload
(defun ar-buffer-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around buffer. "
  (interactive "*p")
  (ar-th-triplequote-dq 'buffer no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-buffer-atpt 'ar-buffer-triplequote-sq-atpt)
;;;###autoload
(defun ar-buffer-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around buffer. "
  (interactive "*p")
  (ar-th-triplequote-sq 'buffer no-delimiters (interactive-p)))

(defalias 'ar-trim-buffer-atpt 'ar-buffer-trim-atpt)
;;;###autoload
(defun ar-buffer-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'buffer t t)) 
    (ar-th-trim 'buffer t t)))

(defalias 'ar-trim-left-buffer-atpt 'ar-buffer-left-trim-atpt)
;;;###autoload
(defun ar-buffer-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'buffer t nil))
    (ar-th-trim 'buffer t nil)))

(defalias 'ar-trim-right-buffer-atpt 'ar-buffer-right-trim-atpt)
;;;###autoload
(defun ar-buffer-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'buffer nil t))
    (ar-th-trim 'buffer nil t)))

(defalias 'ar-buffer-underscore-atpt 'ar-underscore-buffer-atpt)
;;;###autoload
(defun ar-underscore-buffer-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'buffer no-delimiters (interactive-p)))

(defalias 'ar-buffer-whitespace-atpt 'ar-whitespace-buffer-atpt)
;;;###autoload
(defun ar-whitespace-buffer-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'buffer nil t))

(defalias 'ar-forward-buffer-atpt 'ar-buffer-forward-atpt)
;;;###autoload
(defun ar-buffer-forward-atpt (&optional arg) 
  "Moves forward over buffer at point if any, does nothing otherwise.
Returns end position of buffer "
  (interactive "p")
  (ar-th-forward 'buffer arg (interactive-p)))

(defalias 'ar-backward-buffer-atpt 'ar-buffer-backward-atpt)
;;;###autoload
(defun ar-buffer-backward-atpt (&optional arg) 
  "Moves backward over buffer before point if any, does nothing otherwise.
Returns beginning position of buffer "
  (interactive "p")
  (ar-th-backward 'buffer arg (interactive-p)))

(defalias 'ar-transpose-buffer-atpt 'ar-buffer-transpose-atpt)
;;;###autoload
(defun ar-buffer-transpose-atpt (&optional arg) 
  "Transposes buffer with buffer before point if any. "
  (interactive "*p")
  (ar-th-transpose 'buffer arg (interactive-p)))

(defalias 'ar-sort-buffer-atpt 'ar-buffer-sort-atpt)
;;;###autoload
(defun ar-buffer-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts buffers in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'buffer reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-buffer-atpt 'ar-buffer-check-atpt)
;;;###autoload
(defun ar-buffer-check-atpt () 
  "Return t if a buffer at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-buffer-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-buffer-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-comment-atpt (&optional arg no-delimiters) 
  "Returns comment at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'comment arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-comment-atpt 'ar-comment-bounds-atpt)
;;;###autoload
(defun ar-comment-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of comment if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'comment no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position comment at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'comment no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of comment at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'comment no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-comment-atpt 'ar-comment-beginning-atpt)
;;;###autoload
(defun ar-comment-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class comment at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'comment no-delimiters (interactive-p)))

(defalias 'ar-end-of-comment-atpt 'ar-comment-end-atpt)
;;;###autoload
(defun ar-comment-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class comment at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'comment no-delimiters (interactive-p)))

(defalias 'ar-in-comment-p-atpt 'ar-comment-in-p-atpt)
;;;###autoload
(defun ar-comment-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of comment at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'comment no-delimiters (interactive-p)))

(defalias 'ar-length-of-comment-atpt 'ar-comment-length-atpt)
;;;###autoload
(defun ar-comment-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class comment at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'comment no-delimiters (interactive-p)))

(defalias 'ar-copy-comment-atpt 'ar-comment-copy-atpt)
;;;###autoload
(defun ar-comment-copy-atpt (&optional no-delimiters) 
  "Returns a copy of comment at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'comment no-delimiters (interactive-p)))

(defalias 'ar-delete-comment-in-region 'ar-comment-delete-in-region)
;;;###autoload
(defun ar-comment-delete-in-region (beg end) 
  "Deletes comment at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'comment beg end (interactive-p)))

;;;###autoload
(defun ar-blok-comment-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around comment.
  Returns blok or nil if no comment at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'comment no-delimiters (interactive-p)))

(defalias 'ar-escape-comment-atpt 'ar-comment-escape-atpt)
;;;###autoload
(defun ar-comment-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted comment at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'comment no-delimiters))

(defalias 'ar-doublequote-comment-atpt 'ar-comment-doublequote-atpt)
;;;###autoload
(defun ar-comment-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes comment at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'comment no-delimiters (interactive-p)))

(defalias 'ar-slash-comment-atpt 'ar-comment-slash-atpt)
;;;###autoload
(defun ar-comment-slash-atpt (&optional no-delimiters) 
  "Doublequotes comment at point if any. "
  (interactive "*p")
  (ar-th-slash 'comment no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-comment-atpt 'ar-comment-double-backslash-atpt)
;;;###autoload
(defun ar-comment-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around comment at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'comment no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-comment-atpt 'ar-comment-doubleslash-atpt)
;;;###autoload
(defun ar-comment-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around comment at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'comment no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-comment-atpt 'ar-comment-doubleslashparen-atpt)
;;;###autoload
(defun ar-comment-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around comment at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'comment no-delimiters (interactive-p)))

(defalias 'ar-slashparen-comment-atpt 'ar-comment-slashparen-atpt)
;;;###autoload
(defun ar-comment-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around comment at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'comment no-delimiters (interactive-p)))

(defalias 'ar-dollar-comment-atpt 'ar-comment-dollar-atpt)
;;;###autoload
(defun ar-comment-dollar-atpt (&optional no-delimiters) 
  "Doublequotes comment at point if any. "
  (interactive "*p")
  (ar-th-dollar 'comment no-delimiters (interactive-p)))

(defalias 'ar-equalize-comment-atpt 'ar-comment-equalize-atpt)
;;;###autoload
(defun ar-comment-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around comment at point if any. "
  (interactive "*p")
  (ar-th-equalize 'comment no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-comment-atpt 'ar-comment-greater-angle-atpt)
;;;###autoload
(defun ar-comment-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for comment after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'comment no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-comment-atpt 'ar-comment-lesser-angle-atpt)
;;;###autoload
(defun ar-comment-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for comment after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'comment no-delimiters (interactive-p)))

(defalias 'ar-backslash-comment-atpt 'ar-comment-backslash-atpt)
;;;###autoload
(defun ar-comment-backslash-atpt (&optional no-delimiters) 
  "Backslash comment at point if any. "
  (interactive "*p")
  (ar-th-backslash 'comment no-delimiters (interactive-p))) 

(defalias 'ar-brace-comment-atpt 'ar-comment-brace-atpt)
;;;###autoload
(defun ar-comment-brace-atpt (&optional no-delimiters) 
  "Braces comment at point if any. "
  (interactive "*p")
  (ar-th-brace 'comment no-delimiters (interactive-p)))

(defalias 'ar-bracket-comment-atpt 'ar-comment-bracket-atpt)
;;;###autoload
(defun ar-comment-bracket-atpt (&optional no-delimiters) 
  "Brackets comment after point if any. "
  (interactive "*p")
  (ar-th-bracket 'comment no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-comment-atpt (&optional no-delimiters) 
  "Comments comment at point if any. "
  (interactive "*p")
  (ar-th-comment 'comment no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-comment-atpt (&optional no-delimiters) 
  "Put a comma after comment at point if any. "
  (interactive "*p")
  (ar-th-commatize 'comment no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-comment-atpt (&optional no-delimiters) 
  "Put a singlequote before comment at point if any. "
  (interactive "*p")
  (ar-th-quote 'comment no-delimiters (interactive-p)))

(defalias 'ar-hyphen-comment-atpt 'ar-comment-hyphen-atpt)
;;;###autoload
(defun ar-comment-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around comment at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'comment no-delimiters (interactive-p)))

(defalias 'ar-mark-comment-atpt 'ar-comment-mark-atpt)
;;;###autoload
(defun ar-comment-mark-atpt () 
  "Marks comment at point if any. "
  (interactive)
  (ar-th-mark 'comment))

(defalias 'ar-hide-comment-atpt 'ar-comment-hide-atpt)
;;;###autoload
(defun ar-comment-hide-atpt () 
  "Hides comment at point. "
  (interactive)
  (ar-th-hide 'comment))

(defalias 'ar-show-comment-atpt 'ar-comment-show-atpt)
;;;###autoload
(defun ar-comment-show-atpt () 
  "Shows hidden comment at point. "
  (interactive)
  (ar-th-show 'comment))

(defalias 'ar-hide-show-comment-atpt 'ar-comment-hide-show-atpt)
;;;###autoload
(defun ar-comment-hide-show-atpt () 
  "Alternatively hides or shows comment at point. "
  (interactive)
  (ar-th-hide-show 'comment))

(defalias 'ar-highlight-comment-atpt-mode 'ar-comment-highlight-atpt-mode)

(defun ar-comment-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles comment-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'comment no-delimiters (interactive-p)))

(defalias 'ar-kill-comment-atpt 'ar-comment-kill-atpt)
;;;###autoload
(defun ar-comment-kill-atpt (&optional no-delimiters) 
  "Kills comment at point if any. "
  (interactive "*P")
  (ar-th-kill 'comment no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-comment-atpt 'ar-comment-left-right-singlequote-atpt)
;;;###autoload
(defun ar-comment-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'comment no-delimiters (interactive-p)))

(defalias 'ar-parentize-comment-atpt 'ar-comment-parentize-atpt)
;;;###autoload
(defun ar-comment-parentize-atpt (&optional no-delimiters) 
  "Parentizes comment at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'comment no-delimiters (interactive-p)))

(defalias 'ar-separate-comment-atpt 'ar-comment-separate-atpt)
;;;###autoload
(defun ar-comment-separate-atpt (&optional no-delimiters) 
  "Separates comment at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'comment no-delimiters (interactive-p)))

(defalias 'ar-singlequote-comment-atpt 'ar-comment-singlequote-atpt)
;;;###autoload
(defun ar-comment-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes comment at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'comment no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-comment-atpt 'ar-comment-triplequote-dq-atpt)
;;;###autoload
(defun ar-comment-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around comment. "
  (interactive "*p")
  (ar-th-triplequote-dq 'comment no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-comment-atpt 'ar-comment-triplequote-sq-atpt)
;;;###autoload
(defun ar-comment-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around comment. "
  (interactive "*p")
  (ar-th-triplequote-sq 'comment no-delimiters (interactive-p)))

(defalias 'ar-trim-comment-atpt 'ar-comment-trim-atpt)
;;;###autoload
(defun ar-comment-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'comment t t)) 
    (ar-th-trim 'comment t t)))

(defalias 'ar-trim-left-comment-atpt 'ar-comment-left-trim-atpt)
;;;###autoload
(defun ar-comment-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'comment t nil))
    (ar-th-trim 'comment t nil)))

(defalias 'ar-trim-right-comment-atpt 'ar-comment-right-trim-atpt)
;;;###autoload
(defun ar-comment-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'comment nil t))
    (ar-th-trim 'comment nil t)))

(defalias 'ar-comment-underscore-atpt 'ar-underscore-comment-atpt)
;;;###autoload
(defun ar-underscore-comment-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'comment no-delimiters (interactive-p)))

(defalias 'ar-comment-whitespace-atpt 'ar-whitespace-comment-atpt)
;;;###autoload
(defun ar-whitespace-comment-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'comment nil t))

(defalias 'ar-forward-comment-atpt 'ar-comment-forward-atpt)
;;;###autoload
(defun ar-comment-forward-atpt (&optional arg) 
  "Moves forward over comment at point if any, does nothing otherwise.
Returns end position of comment "
  (interactive "p")
  (ar-th-forward 'comment arg (interactive-p)))

(defalias 'ar-backward-comment-atpt 'ar-comment-backward-atpt)
;;;###autoload
(defun ar-comment-backward-atpt (&optional arg) 
  "Moves backward over comment before point if any, does nothing otherwise.
Returns beginning position of comment "
  (interactive "p")
  (ar-th-backward 'comment arg (interactive-p)))

(defalias 'ar-transpose-comment-atpt 'ar-comment-transpose-atpt)
;;;###autoload
(defun ar-comment-transpose-atpt (&optional arg) 
  "Transposes comment with comment before point if any. "
  (interactive "*p")
  (ar-th-transpose 'comment arg (interactive-p)))

(defalias 'ar-sort-comment-atpt 'ar-comment-sort-atpt)
;;;###autoload
(defun ar-comment-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts comments in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'comment reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-comment-atpt 'ar-comment-check-atpt)
;;;###autoload
(defun ar-comment-check-atpt () 
  "Return t if a comment at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-comment-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-comment-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-csv-atpt (&optional arg no-delimiters) 
  "Returns csv at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'csv arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-csv-atpt 'ar-csv-bounds-atpt)
;;;###autoload
(defun ar-csv-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of csv if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'csv no-delimiters (interactive-p)))

;;;###autoload
(defun ar-csv-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position csv at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'csv no-delimiters (interactive-p)))

;;;###autoload
(defun ar-csv-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of csv at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'csv no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-csv-atpt 'ar-csv-beginning-atpt)
;;;###autoload
(defun ar-csv-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class csv at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'csv no-delimiters (interactive-p)))

(defalias 'ar-end-of-csv-atpt 'ar-csv-end-atpt)
;;;###autoload
(defun ar-csv-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class csv at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'csv no-delimiters (interactive-p)))

(defalias 'ar-in-csv-p-atpt 'ar-csv-in-p-atpt)
;;;###autoload
(defun ar-csv-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of csv at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'csv no-delimiters (interactive-p)))

(defalias 'ar-length-of-csv-atpt 'ar-csv-length-atpt)
;;;###autoload
(defun ar-csv-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class csv at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'csv no-delimiters (interactive-p)))

(defalias 'ar-copy-csv-atpt 'ar-csv-copy-atpt)
;;;###autoload
(defun ar-csv-copy-atpt (&optional no-delimiters) 
  "Returns a copy of csv at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'csv no-delimiters (interactive-p)))

(defalias 'ar-delete-csv-in-region 'ar-csv-delete-in-region)
;;;###autoload
(defun ar-csv-delete-in-region (beg end) 
  "Deletes csv at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'csv beg end (interactive-p)))

;;;###autoload
(defun ar-blok-csv-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around csv.
  Returns blok or nil if no csv at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'csv no-delimiters (interactive-p)))

(defalias 'ar-escape-csv-atpt 'ar-csv-escape-atpt)
;;;###autoload
(defun ar-csv-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted csv at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'csv no-delimiters))

(defalias 'ar-doublequote-csv-atpt 'ar-csv-doublequote-atpt)
;;;###autoload
(defun ar-csv-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes csv at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'csv no-delimiters (interactive-p)))

(defalias 'ar-slash-csv-atpt 'ar-csv-slash-atpt)
;;;###autoload
(defun ar-csv-slash-atpt (&optional no-delimiters) 
  "Doublequotes csv at point if any. "
  (interactive "*p")
  (ar-th-slash 'csv no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-csv-atpt 'ar-csv-double-backslash-atpt)
;;;###autoload
(defun ar-csv-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around csv at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'csv no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-csv-atpt 'ar-csv-doubleslash-atpt)
;;;###autoload
(defun ar-csv-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around csv at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'csv no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-csv-atpt 'ar-csv-doubleslashparen-atpt)
;;;###autoload
(defun ar-csv-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around csv at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'csv no-delimiters (interactive-p)))

(defalias 'ar-slashparen-csv-atpt 'ar-csv-slashparen-atpt)
;;;###autoload
(defun ar-csv-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around csv at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'csv no-delimiters (interactive-p)))

(defalias 'ar-dollar-csv-atpt 'ar-csv-dollar-atpt)
;;;###autoload
(defun ar-csv-dollar-atpt (&optional no-delimiters) 
  "Doublequotes csv at point if any. "
  (interactive "*p")
  (ar-th-dollar 'csv no-delimiters (interactive-p)))

(defalias 'ar-equalize-csv-atpt 'ar-csv-equalize-atpt)
;;;###autoload
(defun ar-csv-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around csv at point if any. "
  (interactive "*p")
  (ar-th-equalize 'csv no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-csv-atpt 'ar-csv-greater-angle-atpt)
;;;###autoload
(defun ar-csv-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for csv after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'csv no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-csv-atpt 'ar-csv-lesser-angle-atpt)
;;;###autoload
(defun ar-csv-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for csv after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'csv no-delimiters (interactive-p)))

(defalias 'ar-backslash-csv-atpt 'ar-csv-backslash-atpt)
;;;###autoload
(defun ar-csv-backslash-atpt (&optional no-delimiters) 
  "Backslash csv at point if any. "
  (interactive "*p")
  (ar-th-backslash 'csv no-delimiters (interactive-p))) 

(defalias 'ar-brace-csv-atpt 'ar-csv-brace-atpt)
;;;###autoload
(defun ar-csv-brace-atpt (&optional no-delimiters) 
  "Braces csv at point if any. "
  (interactive "*p")
  (ar-th-brace 'csv no-delimiters (interactive-p)))

(defalias 'ar-bracket-csv-atpt 'ar-csv-bracket-atpt)
;;;###autoload
(defun ar-csv-bracket-atpt (&optional no-delimiters) 
  "Brackets csv after point if any. "
  (interactive "*p")
  (ar-th-bracket 'csv no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-csv-atpt (&optional no-delimiters) 
  "Comments csv at point if any. "
  (interactive "*p")
  (ar-th-comment 'csv no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-csv-atpt (&optional no-delimiters) 
  "Put a comma after csv at point if any. "
  (interactive "*p")
  (ar-th-commatize 'csv no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-csv-atpt (&optional no-delimiters) 
  "Put a singlequote before csv at point if any. "
  (interactive "*p")
  (ar-th-quote 'csv no-delimiters (interactive-p)))

(defalias 'ar-hyphen-csv-atpt 'ar-csv-hyphen-atpt)
;;;###autoload
(defun ar-csv-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around csv at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'csv no-delimiters (interactive-p)))

(defalias 'ar-mark-csv-atpt 'ar-csv-mark-atpt)
;;;###autoload
(defun ar-csv-mark-atpt () 
  "Marks csv at point if any. "
  (interactive)
  (ar-th-mark 'csv))

(defalias 'ar-hide-csv-atpt 'ar-csv-hide-atpt)
;;;###autoload
(defun ar-csv-hide-atpt () 
  "Hides csv at point. "
  (interactive)
  (ar-th-hide 'csv))

(defalias 'ar-show-csv-atpt 'ar-csv-show-atpt)
;;;###autoload
(defun ar-csv-show-atpt () 
  "Shows hidden csv at point. "
  (interactive)
  (ar-th-show 'csv))

(defalias 'ar-hide-show-csv-atpt 'ar-csv-hide-show-atpt)
;;;###autoload
(defun ar-csv-hide-show-atpt () 
  "Alternatively hides or shows csv at point. "
  (interactive)
  (ar-th-hide-show 'csv))

(defalias 'ar-highlight-csv-atpt-mode 'ar-csv-highlight-atpt-mode)

(defun ar-csv-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles csv-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'csv no-delimiters (interactive-p)))

(defalias 'ar-kill-csv-atpt 'ar-csv-kill-atpt)
;;;###autoload
(defun ar-csv-kill-atpt (&optional no-delimiters) 
  "Kills csv at point if any. "
  (interactive "*P")
  (ar-th-kill 'csv no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-csv-atpt 'ar-csv-left-right-singlequote-atpt)
;;;###autoload
(defun ar-csv-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'csv no-delimiters (interactive-p)))

(defalias 'ar-parentize-csv-atpt 'ar-csv-parentize-atpt)
;;;###autoload
(defun ar-csv-parentize-atpt (&optional no-delimiters) 
  "Parentizes csv at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'csv no-delimiters (interactive-p)))

(defalias 'ar-separate-csv-atpt 'ar-csv-separate-atpt)
;;;###autoload
(defun ar-csv-separate-atpt (&optional no-delimiters) 
  "Separates csv at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'csv no-delimiters (interactive-p)))

(defalias 'ar-singlequote-csv-atpt 'ar-csv-singlequote-atpt)
;;;###autoload
(defun ar-csv-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes csv at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'csv no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-csv-atpt 'ar-csv-triplequote-dq-atpt)
;;;###autoload
(defun ar-csv-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around csv. "
  (interactive "*p")
  (ar-th-triplequote-dq 'csv no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-csv-atpt 'ar-csv-triplequote-sq-atpt)
;;;###autoload
(defun ar-csv-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around csv. "
  (interactive "*p")
  (ar-th-triplequote-sq 'csv no-delimiters (interactive-p)))

(defalias 'ar-trim-csv-atpt 'ar-csv-trim-atpt)
;;;###autoload
(defun ar-csv-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'csv t t)) 
    (ar-th-trim 'csv t t)))

(defalias 'ar-trim-left-csv-atpt 'ar-csv-left-trim-atpt)
;;;###autoload
(defun ar-csv-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'csv t nil))
    (ar-th-trim 'csv t nil)))

(defalias 'ar-trim-right-csv-atpt 'ar-csv-right-trim-atpt)
;;;###autoload
(defun ar-csv-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'csv nil t))
    (ar-th-trim 'csv nil t)))

(defalias 'ar-csv-underscore-atpt 'ar-underscore-csv-atpt)
;;;###autoload
(defun ar-underscore-csv-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'csv no-delimiters (interactive-p)))

(defalias 'ar-csv-whitespace-atpt 'ar-whitespace-csv-atpt)
;;;###autoload
(defun ar-whitespace-csv-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'csv nil t))

(defalias 'ar-forward-csv-atpt 'ar-csv-forward-atpt)
;;;###autoload
(defun ar-csv-forward-atpt (&optional arg) 
  "Moves forward over csv at point if any, does nothing otherwise.
Returns end position of csv "
  (interactive "p")
  (ar-th-forward 'csv arg (interactive-p)))

(defalias 'ar-backward-csv-atpt 'ar-csv-backward-atpt)
;;;###autoload
(defun ar-csv-backward-atpt (&optional arg) 
  "Moves backward over csv before point if any, does nothing otherwise.
Returns beginning position of csv "
  (interactive "p")
  (ar-th-backward 'csv arg (interactive-p)))

(defalias 'ar-transpose-csv-atpt 'ar-csv-transpose-atpt)
;;;###autoload
(defun ar-csv-transpose-atpt (&optional arg) 
  "Transposes csv with csv before point if any. "
  (interactive "*p")
  (ar-th-transpose 'csv arg (interactive-p)))

(defalias 'ar-sort-csv-atpt 'ar-csv-sort-atpt)
;;;###autoload
(defun ar-csv-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts csvs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'csv reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-csv-atpt 'ar-csv-check-atpt)
;;;###autoload
(defun ar-csv-check-atpt () 
  "Return t if a csv at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-csv-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-csv-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-date-atpt (&optional arg no-delimiters) 
  "Returns date at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'date arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-date-atpt 'ar-date-bounds-atpt)
;;;###autoload
(defun ar-date-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of date if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'date no-delimiters (interactive-p)))

;;;###autoload
(defun ar-date-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position date at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'date no-delimiters (interactive-p)))

;;;###autoload
(defun ar-date-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of date at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'date no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-date-atpt 'ar-date-beginning-atpt)
;;;###autoload
(defun ar-date-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class date at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'date no-delimiters (interactive-p)))

(defalias 'ar-end-of-date-atpt 'ar-date-end-atpt)
;;;###autoload
(defun ar-date-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class date at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'date no-delimiters (interactive-p)))

(defalias 'ar-in-date-p-atpt 'ar-date-in-p-atpt)
;;;###autoload
(defun ar-date-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of date at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'date no-delimiters (interactive-p)))

(defalias 'ar-length-of-date-atpt 'ar-date-length-atpt)
;;;###autoload
(defun ar-date-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class date at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'date no-delimiters (interactive-p)))

(defalias 'ar-copy-date-atpt 'ar-date-copy-atpt)
;;;###autoload
(defun ar-date-copy-atpt (&optional no-delimiters) 
  "Returns a copy of date at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'date no-delimiters (interactive-p)))

(defalias 'ar-delete-date-in-region 'ar-date-delete-in-region)
;;;###autoload
(defun ar-date-delete-in-region (beg end) 
  "Deletes date at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'date beg end (interactive-p)))

;;;###autoload
(defun ar-blok-date-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around date.
  Returns blok or nil if no date at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'date no-delimiters (interactive-p)))

(defalias 'ar-escape-date-atpt 'ar-date-escape-atpt)
;;;###autoload
(defun ar-date-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted date at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'date no-delimiters))

(defalias 'ar-doublequote-date-atpt 'ar-date-doublequote-atpt)
;;;###autoload
(defun ar-date-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes date at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'date no-delimiters (interactive-p)))

(defalias 'ar-slash-date-atpt 'ar-date-slash-atpt)
;;;###autoload
(defun ar-date-slash-atpt (&optional no-delimiters) 
  "Doublequotes date at point if any. "
  (interactive "*p")
  (ar-th-slash 'date no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-date-atpt 'ar-date-double-backslash-atpt)
;;;###autoload
(defun ar-date-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around date at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'date no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-date-atpt 'ar-date-doubleslash-atpt)
;;;###autoload
(defun ar-date-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around date at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'date no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-date-atpt 'ar-date-doubleslashparen-atpt)
;;;###autoload
(defun ar-date-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around date at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'date no-delimiters (interactive-p)))

(defalias 'ar-slashparen-date-atpt 'ar-date-slashparen-atpt)
;;;###autoload
(defun ar-date-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around date at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'date no-delimiters (interactive-p)))

(defalias 'ar-dollar-date-atpt 'ar-date-dollar-atpt)
;;;###autoload
(defun ar-date-dollar-atpt (&optional no-delimiters) 
  "Doublequotes date at point if any. "
  (interactive "*p")
  (ar-th-dollar 'date no-delimiters (interactive-p)))

(defalias 'ar-equalize-date-atpt 'ar-date-equalize-atpt)
;;;###autoload
(defun ar-date-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around date at point if any. "
  (interactive "*p")
  (ar-th-equalize 'date no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-date-atpt 'ar-date-greater-angle-atpt)
;;;###autoload
(defun ar-date-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for date after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'date no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-date-atpt 'ar-date-lesser-angle-atpt)
;;;###autoload
(defun ar-date-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for date after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'date no-delimiters (interactive-p)))

(defalias 'ar-backslash-date-atpt 'ar-date-backslash-atpt)
;;;###autoload
(defun ar-date-backslash-atpt (&optional no-delimiters) 
  "Backslash date at point if any. "
  (interactive "*p")
  (ar-th-backslash 'date no-delimiters (interactive-p))) 

(defalias 'ar-brace-date-atpt 'ar-date-brace-atpt)
;;;###autoload
(defun ar-date-brace-atpt (&optional no-delimiters) 
  "Braces date at point if any. "
  (interactive "*p")
  (ar-th-brace 'date no-delimiters (interactive-p)))

(defalias 'ar-bracket-date-atpt 'ar-date-bracket-atpt)
;;;###autoload
(defun ar-date-bracket-atpt (&optional no-delimiters) 
  "Brackets date after point if any. "
  (interactive "*p")
  (ar-th-bracket 'date no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-date-atpt (&optional no-delimiters) 
  "Comments date at point if any. "
  (interactive "*p")
  (ar-th-comment 'date no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-date-atpt (&optional no-delimiters) 
  "Put a comma after date at point if any. "
  (interactive "*p")
  (ar-th-commatize 'date no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-date-atpt (&optional no-delimiters) 
  "Put a singlequote before date at point if any. "
  (interactive "*p")
  (ar-th-quote 'date no-delimiters (interactive-p)))

(defalias 'ar-hyphen-date-atpt 'ar-date-hyphen-atpt)
;;;###autoload
(defun ar-date-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around date at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'date no-delimiters (interactive-p)))

(defalias 'ar-mark-date-atpt 'ar-date-mark-atpt)
;;;###autoload
(defun ar-date-mark-atpt () 
  "Marks date at point if any. "
  (interactive)
  (ar-th-mark 'date))

(defalias 'ar-hide-date-atpt 'ar-date-hide-atpt)
;;;###autoload
(defun ar-date-hide-atpt () 
  "Hides date at point. "
  (interactive)
  (ar-th-hide 'date))

(defalias 'ar-show-date-atpt 'ar-date-show-atpt)
;;;###autoload
(defun ar-date-show-atpt () 
  "Shows hidden date at point. "
  (interactive)
  (ar-th-show 'date))

(defalias 'ar-hide-show-date-atpt 'ar-date-hide-show-atpt)
;;;###autoload
(defun ar-date-hide-show-atpt () 
  "Alternatively hides or shows date at point. "
  (interactive)
  (ar-th-hide-show 'date))

(defalias 'ar-highlight-date-atpt-mode 'ar-date-highlight-atpt-mode)

(defun ar-date-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles date-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'date no-delimiters (interactive-p)))

(defalias 'ar-kill-date-atpt 'ar-date-kill-atpt)
;;;###autoload
(defun ar-date-kill-atpt (&optional no-delimiters) 
  "Kills date at point if any. "
  (interactive "*P")
  (ar-th-kill 'date no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-date-atpt 'ar-date-left-right-singlequote-atpt)
;;;###autoload
(defun ar-date-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'date no-delimiters (interactive-p)))

(defalias 'ar-parentize-date-atpt 'ar-date-parentize-atpt)
;;;###autoload
(defun ar-date-parentize-atpt (&optional no-delimiters) 
  "Parentizes date at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'date no-delimiters (interactive-p)))

(defalias 'ar-separate-date-atpt 'ar-date-separate-atpt)
;;;###autoload
(defun ar-date-separate-atpt (&optional no-delimiters) 
  "Separates date at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'date no-delimiters (interactive-p)))

(defalias 'ar-singlequote-date-atpt 'ar-date-singlequote-atpt)
;;;###autoload
(defun ar-date-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes date at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'date no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-date-atpt 'ar-date-triplequote-dq-atpt)
;;;###autoload
(defun ar-date-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around date. "
  (interactive "*p")
  (ar-th-triplequote-dq 'date no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-date-atpt 'ar-date-triplequote-sq-atpt)
;;;###autoload
(defun ar-date-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around date. "
  (interactive "*p")
  (ar-th-triplequote-sq 'date no-delimiters (interactive-p)))

(defalias 'ar-trim-date-atpt 'ar-date-trim-atpt)
;;;###autoload
(defun ar-date-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'date t t)) 
    (ar-th-trim 'date t t)))

(defalias 'ar-trim-left-date-atpt 'ar-date-left-trim-atpt)
;;;###autoload
(defun ar-date-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'date t nil))
    (ar-th-trim 'date t nil)))

(defalias 'ar-trim-right-date-atpt 'ar-date-right-trim-atpt)
;;;###autoload
(defun ar-date-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'date nil t))
    (ar-th-trim 'date nil t)))

(defalias 'ar-date-underscore-atpt 'ar-underscore-date-atpt)
;;;###autoload
(defun ar-underscore-date-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'date no-delimiters (interactive-p)))

(defalias 'ar-date-whitespace-atpt 'ar-whitespace-date-atpt)
;;;###autoload
(defun ar-whitespace-date-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'date nil t))

(defalias 'ar-forward-date-atpt 'ar-date-forward-atpt)
;;;###autoload
(defun ar-date-forward-atpt (&optional arg) 
  "Moves forward over date at point if any, does nothing otherwise.
Returns end position of date "
  (interactive "p")
  (ar-th-forward 'date arg (interactive-p)))

(defalias 'ar-backward-date-atpt 'ar-date-backward-atpt)
;;;###autoload
(defun ar-date-backward-atpt (&optional arg) 
  "Moves backward over date before point if any, does nothing otherwise.
Returns beginning position of date "
  (interactive "p")
  (ar-th-backward 'date arg (interactive-p)))

(defalias 'ar-transpose-date-atpt 'ar-date-transpose-atpt)
;;;###autoload
(defun ar-date-transpose-atpt (&optional arg) 
  "Transposes date with date before point if any. "
  (interactive "*p")
  (ar-th-transpose 'date arg (interactive-p)))

(defalias 'ar-sort-date-atpt 'ar-date-sort-atpt)
;;;###autoload
(defun ar-date-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts dates in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'date reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-date-atpt 'ar-date-check-atpt)
;;;###autoload
(defun ar-date-check-atpt () 
  "Return t if a date at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-date-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-date-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-defun-atpt (&optional arg no-delimiters) 
  "Returns defun at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'defun arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-defun-atpt 'ar-defun-bounds-atpt)
;;;###autoload
(defun ar-defun-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of defun if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'defun no-delimiters (interactive-p)))

;;;###autoload
(defun ar-defun-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position defun at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'defun no-delimiters (interactive-p)))

;;;###autoload
(defun ar-defun-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of defun at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'defun no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-defun-atpt 'ar-defun-beginning-atpt)
;;;###autoload
(defun ar-defun-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class defun at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'defun no-delimiters (interactive-p)))

(defalias 'ar-end-of-defun-atpt 'ar-defun-end-atpt)
;;;###autoload
(defun ar-defun-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class defun at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'defun no-delimiters (interactive-p)))

(defalias 'ar-in-defun-p-atpt 'ar-defun-in-p-atpt)
;;;###autoload
(defun ar-defun-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of defun at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'defun no-delimiters (interactive-p)))

(defalias 'ar-length-of-defun-atpt 'ar-defun-length-atpt)
;;;###autoload
(defun ar-defun-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class defun at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'defun no-delimiters (interactive-p)))

(defalias 'ar-copy-defun-atpt 'ar-defun-copy-atpt)
;;;###autoload
(defun ar-defun-copy-atpt (&optional no-delimiters) 
  "Returns a copy of defun at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'defun no-delimiters (interactive-p)))

(defalias 'ar-delete-defun-in-region 'ar-defun-delete-in-region)
;;;###autoload
(defun ar-defun-delete-in-region (beg end) 
  "Deletes defun at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'defun beg end (interactive-p)))

;;;###autoload
(defun ar-blok-defun-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around defun.
  Returns blok or nil if no defun at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'defun no-delimiters (interactive-p)))

(defalias 'ar-escape-defun-atpt 'ar-defun-escape-atpt)
;;;###autoload
(defun ar-defun-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted defun at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'defun no-delimiters))

(defalias 'ar-doublequote-defun-atpt 'ar-defun-doublequote-atpt)
;;;###autoload
(defun ar-defun-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes defun at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'defun no-delimiters (interactive-p)))

(defalias 'ar-slash-defun-atpt 'ar-defun-slash-atpt)
;;;###autoload
(defun ar-defun-slash-atpt (&optional no-delimiters) 
  "Doublequotes defun at point if any. "
  (interactive "*p")
  (ar-th-slash 'defun no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-defun-atpt 'ar-defun-double-backslash-atpt)
;;;###autoload
(defun ar-defun-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around defun at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'defun no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-defun-atpt 'ar-defun-doubleslash-atpt)
;;;###autoload
(defun ar-defun-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around defun at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'defun no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-defun-atpt 'ar-defun-doubleslashparen-atpt)
;;;###autoload
(defun ar-defun-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around defun at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'defun no-delimiters (interactive-p)))

(defalias 'ar-slashparen-defun-atpt 'ar-defun-slashparen-atpt)
;;;###autoload
(defun ar-defun-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around defun at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'defun no-delimiters (interactive-p)))

(defalias 'ar-dollar-defun-atpt 'ar-defun-dollar-atpt)
;;;###autoload
(defun ar-defun-dollar-atpt (&optional no-delimiters) 
  "Doublequotes defun at point if any. "
  (interactive "*p")
  (ar-th-dollar 'defun no-delimiters (interactive-p)))

(defalias 'ar-equalize-defun-atpt 'ar-defun-equalize-atpt)
;;;###autoload
(defun ar-defun-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around defun at point if any. "
  (interactive "*p")
  (ar-th-equalize 'defun no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-defun-atpt 'ar-defun-greater-angle-atpt)
;;;###autoload
(defun ar-defun-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for defun after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'defun no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-defun-atpt 'ar-defun-lesser-angle-atpt)
;;;###autoload
(defun ar-defun-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for defun after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'defun no-delimiters (interactive-p)))

(defalias 'ar-backslash-defun-atpt 'ar-defun-backslash-atpt)
;;;###autoload
(defun ar-defun-backslash-atpt (&optional no-delimiters) 
  "Backslash defun at point if any. "
  (interactive "*p")
  (ar-th-backslash 'defun no-delimiters (interactive-p))) 

(defalias 'ar-brace-defun-atpt 'ar-defun-brace-atpt)
;;;###autoload
(defun ar-defun-brace-atpt (&optional no-delimiters) 
  "Braces defun at point if any. "
  (interactive "*p")
  (ar-th-brace 'defun no-delimiters (interactive-p)))

(defalias 'ar-bracket-defun-atpt 'ar-defun-bracket-atpt)
;;;###autoload
(defun ar-defun-bracket-atpt (&optional no-delimiters) 
  "Brackets defun after point if any. "
  (interactive "*p")
  (ar-th-bracket 'defun no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-defun-atpt (&optional no-delimiters) 
  "Comments defun at point if any. "
  (interactive "*p")
  (ar-th-comment 'defun no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-defun-atpt (&optional no-delimiters) 
  "Put a comma after defun at point if any. "
  (interactive "*p")
  (ar-th-commatize 'defun no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-defun-atpt (&optional no-delimiters) 
  "Put a singlequote before defun at point if any. "
  (interactive "*p")
  (ar-th-quote 'defun no-delimiters (interactive-p)))

(defalias 'ar-hyphen-defun-atpt 'ar-defun-hyphen-atpt)
;;;###autoload
(defun ar-defun-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around defun at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'defun no-delimiters (interactive-p)))

(defalias 'ar-mark-defun-atpt 'ar-defun-mark-atpt)
;;;###autoload
(defun ar-defun-mark-atpt () 
  "Marks defun at point if any. "
  (interactive)
  (ar-th-mark 'defun))

(defalias 'ar-hide-defun-atpt 'ar-defun-hide-atpt)
;;;###autoload
(defun ar-defun-hide-atpt () 
  "Hides defun at point. "
  (interactive)
  (ar-th-hide 'defun))

(defalias 'ar-show-defun-atpt 'ar-defun-show-atpt)
;;;###autoload
(defun ar-defun-show-atpt () 
  "Shows hidden defun at point. "
  (interactive)
  (ar-th-show 'defun))

(defalias 'ar-hide-show-defun-atpt 'ar-defun-hide-show-atpt)
;;;###autoload
(defun ar-defun-hide-show-atpt () 
  "Alternatively hides or shows defun at point. "
  (interactive)
  (ar-th-hide-show 'defun))

(defalias 'ar-highlight-defun-atpt-mode 'ar-defun-highlight-atpt-mode)

(defun ar-defun-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles defun-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'defun no-delimiters (interactive-p)))

(defalias 'ar-kill-defun-atpt 'ar-defun-kill-atpt)
;;;###autoload
(defun ar-defun-kill-atpt (&optional no-delimiters) 
  "Kills defun at point if any. "
  (interactive "*P")
  (ar-th-kill 'defun no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-defun-atpt 'ar-defun-left-right-singlequote-atpt)
;;;###autoload
(defun ar-defun-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'defun no-delimiters (interactive-p)))

(defalias 'ar-parentize-defun-atpt 'ar-defun-parentize-atpt)
;;;###autoload
(defun ar-defun-parentize-atpt (&optional no-delimiters) 
  "Parentizes defun at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'defun no-delimiters (interactive-p)))

(defalias 'ar-separate-defun-atpt 'ar-defun-separate-atpt)
;;;###autoload
(defun ar-defun-separate-atpt (&optional no-delimiters) 
  "Separates defun at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'defun no-delimiters (interactive-p)))

(defalias 'ar-singlequote-defun-atpt 'ar-defun-singlequote-atpt)
;;;###autoload
(defun ar-defun-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes defun at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'defun no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-defun-atpt 'ar-defun-triplequote-dq-atpt)
;;;###autoload
(defun ar-defun-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around defun. "
  (interactive "*p")
  (ar-th-triplequote-dq 'defun no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-defun-atpt 'ar-defun-triplequote-sq-atpt)
;;;###autoload
(defun ar-defun-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around defun. "
  (interactive "*p")
  (ar-th-triplequote-sq 'defun no-delimiters (interactive-p)))

(defalias 'ar-trim-defun-atpt 'ar-defun-trim-atpt)
;;;###autoload
(defun ar-defun-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'defun t t)) 
    (ar-th-trim 'defun t t)))

(defalias 'ar-trim-left-defun-atpt 'ar-defun-left-trim-atpt)
;;;###autoload
(defun ar-defun-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'defun t nil))
    (ar-th-trim 'defun t nil)))

(defalias 'ar-trim-right-defun-atpt 'ar-defun-right-trim-atpt)
;;;###autoload
(defun ar-defun-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'defun nil t))
    (ar-th-trim 'defun nil t)))

(defalias 'ar-defun-underscore-atpt 'ar-underscore-defun-atpt)
;;;###autoload
(defun ar-underscore-defun-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'defun no-delimiters (interactive-p)))

(defalias 'ar-defun-whitespace-atpt 'ar-whitespace-defun-atpt)
;;;###autoload
(defun ar-whitespace-defun-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'defun nil t))

(defalias 'ar-forward-defun-atpt 'ar-defun-forward-atpt)
;;;###autoload
(defun ar-defun-forward-atpt (&optional arg) 
  "Moves forward over defun at point if any, does nothing otherwise.
Returns end position of defun "
  (interactive "p")
  (ar-th-forward 'defun arg (interactive-p)))

(defalias 'ar-backward-defun-atpt 'ar-defun-backward-atpt)
;;;###autoload
(defun ar-defun-backward-atpt (&optional arg) 
  "Moves backward over defun before point if any, does nothing otherwise.
Returns beginning position of defun "
  (interactive "p")
  (ar-th-backward 'defun arg (interactive-p)))

(defalias 'ar-transpose-defun-atpt 'ar-defun-transpose-atpt)
;;;###autoload
(defun ar-defun-transpose-atpt (&optional arg) 
  "Transposes defun with defun before point if any. "
  (interactive "*p")
  (ar-th-transpose 'defun arg (interactive-p)))

(defalias 'ar-sort-defun-atpt 'ar-defun-sort-atpt)
;;;###autoload
(defun ar-defun-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts defuns in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'defun reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-defun-atpt 'ar-defun-check-atpt)
;;;###autoload
(defun ar-defun-check-atpt () 
  "Return t if a defun at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-defun-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-defun-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-delimited-atpt (&optional arg no-delimiters) 
  "Returns delimited at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'delimited arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-delimited-atpt 'ar-delimited-bounds-atpt)
;;;###autoload
(defun ar-delimited-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of delimited if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'delimited no-delimiters (interactive-p)))

;;;###autoload
(defun ar-delimited-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position delimited at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'delimited no-delimiters (interactive-p)))

;;;###autoload
(defun ar-delimited-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of delimited at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'delimited no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-delimited-atpt 'ar-delimited-beginning-atpt)
;;;###autoload
(defun ar-delimited-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class delimited at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'delimited no-delimiters (interactive-p)))

(defalias 'ar-end-of-delimited-atpt 'ar-delimited-end-atpt)
;;;###autoload
(defun ar-delimited-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class delimited at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'delimited no-delimiters (interactive-p)))

(defalias 'ar-in-delimited-p-atpt 'ar-delimited-in-p-atpt)
;;;###autoload
(defun ar-delimited-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of delimited at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'delimited no-delimiters (interactive-p)))

(defalias 'ar-length-of-delimited-atpt 'ar-delimited-length-atpt)
;;;###autoload
(defun ar-delimited-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class delimited at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'delimited no-delimiters (interactive-p)))

(defalias 'ar-copy-delimited-atpt 'ar-delimited-copy-atpt)
;;;###autoload
(defun ar-delimited-copy-atpt (&optional no-delimiters) 
  "Returns a copy of delimited at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'delimited no-delimiters (interactive-p)))

(defalias 'ar-delete-delimited-in-region 'ar-delimited-delete-in-region)
;;;###autoload
(defun ar-delimited-delete-in-region (beg end) 
  "Deletes delimited at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'delimited beg end (interactive-p)))

;;;###autoload
(defun ar-blok-delimited-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around delimited.
  Returns blok or nil if no delimited at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'delimited no-delimiters (interactive-p)))

(defalias 'ar-escape-delimited-atpt 'ar-delimited-escape-atpt)
;;;###autoload
(defun ar-delimited-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted delimited at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'delimited no-delimiters))

(defalias 'ar-doublequote-delimited-atpt 'ar-delimited-doublequote-atpt)
;;;###autoload
(defun ar-delimited-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes delimited at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'delimited no-delimiters (interactive-p)))

(defalias 'ar-slash-delimited-atpt 'ar-delimited-slash-atpt)
;;;###autoload
(defun ar-delimited-slash-atpt (&optional no-delimiters) 
  "Doublequotes delimited at point if any. "
  (interactive "*p")
  (ar-th-slash 'delimited no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-delimited-atpt 'ar-delimited-double-backslash-atpt)
;;;###autoload
(defun ar-delimited-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around delimited at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'delimited no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-delimited-atpt 'ar-delimited-doubleslash-atpt)
;;;###autoload
(defun ar-delimited-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around delimited at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'delimited no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-delimited-atpt 'ar-delimited-doubleslashparen-atpt)
;;;###autoload
(defun ar-delimited-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around delimited at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'delimited no-delimiters (interactive-p)))

(defalias 'ar-slashparen-delimited-atpt 'ar-delimited-slashparen-atpt)
;;;###autoload
(defun ar-delimited-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around delimited at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'delimited no-delimiters (interactive-p)))

(defalias 'ar-dollar-delimited-atpt 'ar-delimited-dollar-atpt)
;;;###autoload
(defun ar-delimited-dollar-atpt (&optional no-delimiters) 
  "Doublequotes delimited at point if any. "
  (interactive "*p")
  (ar-th-dollar 'delimited no-delimiters (interactive-p)))

(defalias 'ar-equalize-delimited-atpt 'ar-delimited-equalize-atpt)
;;;###autoload
(defun ar-delimited-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around delimited at point if any. "
  (interactive "*p")
  (ar-th-equalize 'delimited no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-delimited-atpt 'ar-delimited-greater-angle-atpt)
;;;###autoload
(defun ar-delimited-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for delimited after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'delimited no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-delimited-atpt 'ar-delimited-lesser-angle-atpt)
;;;###autoload
(defun ar-delimited-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for delimited after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'delimited no-delimiters (interactive-p)))

(defalias 'ar-backslash-delimited-atpt 'ar-delimited-backslash-atpt)
;;;###autoload
(defun ar-delimited-backslash-atpt (&optional no-delimiters) 
  "Backslash delimited at point if any. "
  (interactive "*p")
  (ar-th-backslash 'delimited no-delimiters (interactive-p))) 

(defalias 'ar-brace-delimited-atpt 'ar-delimited-brace-atpt)
;;;###autoload
(defun ar-delimited-brace-atpt (&optional no-delimiters) 
  "Braces delimited at point if any. "
  (interactive "*p")
  (ar-th-brace 'delimited no-delimiters (interactive-p)))

(defalias 'ar-bracket-delimited-atpt 'ar-delimited-bracket-atpt)
;;;###autoload
(defun ar-delimited-bracket-atpt (&optional no-delimiters) 
  "Brackets delimited after point if any. "
  (interactive "*p")
  (ar-th-bracket 'delimited no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-delimited-atpt (&optional no-delimiters) 
  "Comments delimited at point if any. "
  (interactive "*p")
  (ar-th-comment 'delimited no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-delimited-atpt (&optional no-delimiters) 
  "Put a comma after delimited at point if any. "
  (interactive "*p")
  (ar-th-commatize 'delimited no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-delimited-atpt (&optional no-delimiters) 
  "Put a singlequote before delimited at point if any. "
  (interactive "*p")
  (ar-th-quote 'delimited no-delimiters (interactive-p)))

(defalias 'ar-hyphen-delimited-atpt 'ar-delimited-hyphen-atpt)
;;;###autoload
(defun ar-delimited-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around delimited at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'delimited no-delimiters (interactive-p)))

(defalias 'ar-mark-delimited-atpt 'ar-delimited-mark-atpt)
;;;###autoload
(defun ar-delimited-mark-atpt () 
  "Marks delimited at point if any. "
  (interactive)
  (ar-th-mark 'delimited))

(defalias 'ar-hide-delimited-atpt 'ar-delimited-hide-atpt)
;;;###autoload
(defun ar-delimited-hide-atpt () 
  "Hides delimited at point. "
  (interactive)
  (ar-th-hide 'delimited))

(defalias 'ar-show-delimited-atpt 'ar-delimited-show-atpt)
;;;###autoload
(defun ar-delimited-show-atpt () 
  "Shows hidden delimited at point. "
  (interactive)
  (ar-th-show 'delimited))

(defalias 'ar-hide-show-delimited-atpt 'ar-delimited-hide-show-atpt)
;;;###autoload
(defun ar-delimited-hide-show-atpt () 
  "Alternatively hides or shows delimited at point. "
  (interactive)
  (ar-th-hide-show 'delimited))

(defalias 'ar-highlight-delimited-atpt-mode 'ar-delimited-highlight-atpt-mode)

(defun ar-delimited-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles delimited-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'delimited no-delimiters (interactive-p)))

(defalias 'ar-kill-delimited-atpt 'ar-delimited-kill-atpt)
;;;###autoload
(defun ar-delimited-kill-atpt (&optional no-delimiters) 
  "Kills delimited at point if any. "
  (interactive "*P")
  (ar-th-kill 'delimited no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-delimited-atpt 'ar-delimited-left-right-singlequote-atpt)
;;;###autoload
(defun ar-delimited-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'delimited no-delimiters (interactive-p)))

(defalias 'ar-parentize-delimited-atpt 'ar-delimited-parentize-atpt)
;;;###autoload
(defun ar-delimited-parentize-atpt (&optional no-delimiters) 
  "Parentizes delimited at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'delimited no-delimiters (interactive-p)))

(defalias 'ar-separate-delimited-atpt 'ar-delimited-separate-atpt)
;;;###autoload
(defun ar-delimited-separate-atpt (&optional no-delimiters) 
  "Separates delimited at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'delimited no-delimiters (interactive-p)))

(defalias 'ar-singlequote-delimited-atpt 'ar-delimited-singlequote-atpt)
;;;###autoload
(defun ar-delimited-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes delimited at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'delimited no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-delimited-atpt 'ar-delimited-triplequote-dq-atpt)
;;;###autoload
(defun ar-delimited-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around delimited. "
  (interactive "*p")
  (ar-th-triplequote-dq 'delimited no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-delimited-atpt 'ar-delimited-triplequote-sq-atpt)
;;;###autoload
(defun ar-delimited-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around delimited. "
  (interactive "*p")
  (ar-th-triplequote-sq 'delimited no-delimiters (interactive-p)))

(defalias 'ar-trim-delimited-atpt 'ar-delimited-trim-atpt)
;;;###autoload
(defun ar-delimited-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'delimited t t)) 
    (ar-th-trim 'delimited t t)))

(defalias 'ar-trim-left-delimited-atpt 'ar-delimited-left-trim-atpt)
;;;###autoload
(defun ar-delimited-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'delimited t nil))
    (ar-th-trim 'delimited t nil)))

(defalias 'ar-trim-right-delimited-atpt 'ar-delimited-right-trim-atpt)
;;;###autoload
(defun ar-delimited-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'delimited nil t))
    (ar-th-trim 'delimited nil t)))

(defalias 'ar-delimited-underscore-atpt 'ar-underscore-delimited-atpt)
;;;###autoload
(defun ar-underscore-delimited-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'delimited no-delimiters (interactive-p)))

(defalias 'ar-delimited-whitespace-atpt 'ar-whitespace-delimited-atpt)
;;;###autoload
(defun ar-whitespace-delimited-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'delimited nil t))

(defalias 'ar-forward-delimited-atpt 'ar-delimited-forward-atpt)
;;;###autoload
(defun ar-delimited-forward-atpt (&optional arg) 
  "Moves forward over delimited at point if any, does nothing otherwise.
Returns end position of delimited "
  (interactive "p")
  (ar-th-forward 'delimited arg (interactive-p)))

(defalias 'ar-backward-delimited-atpt 'ar-delimited-backward-atpt)
;;;###autoload
(defun ar-delimited-backward-atpt (&optional arg) 
  "Moves backward over delimited before point if any, does nothing otherwise.
Returns beginning position of delimited "
  (interactive "p")
  (ar-th-backward 'delimited arg (interactive-p)))

(defalias 'ar-transpose-delimited-atpt 'ar-delimited-transpose-atpt)
;;;###autoload
(defun ar-delimited-transpose-atpt (&optional arg) 
  "Transposes delimited with delimited before point if any. "
  (interactive "*p")
  (ar-th-transpose 'delimited arg (interactive-p)))

(defalias 'ar-sort-delimited-atpt 'ar-delimited-sort-atpt)
;;;###autoload
(defun ar-delimited-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts delimiteds in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'delimited reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-delimited-atpt 'ar-delimited-check-atpt)
;;;###autoload
(defun ar-delimited-check-atpt () 
  "Return t if a delimited at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-delimited-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-delimited-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-email-atpt (&optional arg no-delimiters) 
  "Returns email at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'email arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-email-atpt 'ar-email-bounds-atpt)
;;;###autoload
(defun ar-email-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of email if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'email no-delimiters (interactive-p)))

;;;###autoload
(defun ar-email-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position email at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'email no-delimiters (interactive-p)))

;;;###autoload
(defun ar-email-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of email at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'email no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-email-atpt 'ar-email-beginning-atpt)
;;;###autoload
(defun ar-email-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class email at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'email no-delimiters (interactive-p)))

(defalias 'ar-end-of-email-atpt 'ar-email-end-atpt)
;;;###autoload
(defun ar-email-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class email at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'email no-delimiters (interactive-p)))

(defalias 'ar-in-email-p-atpt 'ar-email-in-p-atpt)
;;;###autoload
(defun ar-email-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of email at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'email no-delimiters (interactive-p)))

(defalias 'ar-length-of-email-atpt 'ar-email-length-atpt)
;;;###autoload
(defun ar-email-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class email at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'email no-delimiters (interactive-p)))

(defalias 'ar-copy-email-atpt 'ar-email-copy-atpt)
;;;###autoload
(defun ar-email-copy-atpt (&optional no-delimiters) 
  "Returns a copy of email at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'email no-delimiters (interactive-p)))

(defalias 'ar-delete-email-in-region 'ar-email-delete-in-region)
;;;###autoload
(defun ar-email-delete-in-region (beg end) 
  "Deletes email at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'email beg end (interactive-p)))

;;;###autoload
(defun ar-blok-email-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around email.
  Returns blok or nil if no email at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'email no-delimiters (interactive-p)))

(defalias 'ar-escape-email-atpt 'ar-email-escape-atpt)
;;;###autoload
(defun ar-email-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted email at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'email no-delimiters))

(defalias 'ar-doublequote-email-atpt 'ar-email-doublequote-atpt)
;;;###autoload
(defun ar-email-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes email at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'email no-delimiters (interactive-p)))

(defalias 'ar-slash-email-atpt 'ar-email-slash-atpt)
;;;###autoload
(defun ar-email-slash-atpt (&optional no-delimiters) 
  "Doublequotes email at point if any. "
  (interactive "*p")
  (ar-th-slash 'email no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-email-atpt 'ar-email-double-backslash-atpt)
;;;###autoload
(defun ar-email-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around email at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'email no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-email-atpt 'ar-email-doubleslash-atpt)
;;;###autoload
(defun ar-email-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around email at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'email no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-email-atpt 'ar-email-doubleslashparen-atpt)
;;;###autoload
(defun ar-email-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around email at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'email no-delimiters (interactive-p)))

(defalias 'ar-slashparen-email-atpt 'ar-email-slashparen-atpt)
;;;###autoload
(defun ar-email-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around email at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'email no-delimiters (interactive-p)))

(defalias 'ar-dollar-email-atpt 'ar-email-dollar-atpt)
;;;###autoload
(defun ar-email-dollar-atpt (&optional no-delimiters) 
  "Doublequotes email at point if any. "
  (interactive "*p")
  (ar-th-dollar 'email no-delimiters (interactive-p)))

(defalias 'ar-equalize-email-atpt 'ar-email-equalize-atpt)
;;;###autoload
(defun ar-email-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around email at point if any. "
  (interactive "*p")
  (ar-th-equalize 'email no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-email-atpt 'ar-email-greater-angle-atpt)
;;;###autoload
(defun ar-email-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for email after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'email no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-email-atpt 'ar-email-lesser-angle-atpt)
;;;###autoload
(defun ar-email-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for email after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'email no-delimiters (interactive-p)))

(defalias 'ar-backslash-email-atpt 'ar-email-backslash-atpt)
;;;###autoload
(defun ar-email-backslash-atpt (&optional no-delimiters) 
  "Backslash email at point if any. "
  (interactive "*p")
  (ar-th-backslash 'email no-delimiters (interactive-p))) 

(defalias 'ar-brace-email-atpt 'ar-email-brace-atpt)
;;;###autoload
(defun ar-email-brace-atpt (&optional no-delimiters) 
  "Braces email at point if any. "
  (interactive "*p")
  (ar-th-brace 'email no-delimiters (interactive-p)))

(defalias 'ar-bracket-email-atpt 'ar-email-bracket-atpt)
;;;###autoload
(defun ar-email-bracket-atpt (&optional no-delimiters) 
  "Brackets email after point if any. "
  (interactive "*p")
  (ar-th-bracket 'email no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-email-atpt (&optional no-delimiters) 
  "Comments email at point if any. "
  (interactive "*p")
  (ar-th-comment 'email no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-email-atpt (&optional no-delimiters) 
  "Put a comma after email at point if any. "
  (interactive "*p")
  (ar-th-commatize 'email no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-email-atpt (&optional no-delimiters) 
  "Put a singlequote before email at point if any. "
  (interactive "*p")
  (ar-th-quote 'email no-delimiters (interactive-p)))

(defalias 'ar-hyphen-email-atpt 'ar-email-hyphen-atpt)
;;;###autoload
(defun ar-email-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around email at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'email no-delimiters (interactive-p)))

(defalias 'ar-mark-email-atpt 'ar-email-mark-atpt)
;;;###autoload
(defun ar-email-mark-atpt () 
  "Marks email at point if any. "
  (interactive)
  (ar-th-mark 'email))

(defalias 'ar-hide-email-atpt 'ar-email-hide-atpt)
;;;###autoload
(defun ar-email-hide-atpt () 
  "Hides email at point. "
  (interactive)
  (ar-th-hide 'email))

(defalias 'ar-show-email-atpt 'ar-email-show-atpt)
;;;###autoload
(defun ar-email-show-atpt () 
  "Shows hidden email at point. "
  (interactive)
  (ar-th-show 'email))

(defalias 'ar-hide-show-email-atpt 'ar-email-hide-show-atpt)
;;;###autoload
(defun ar-email-hide-show-atpt () 
  "Alternatively hides or shows email at point. "
  (interactive)
  (ar-th-hide-show 'email))

(defalias 'ar-highlight-email-atpt-mode 'ar-email-highlight-atpt-mode)

(defun ar-email-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles email-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'email no-delimiters (interactive-p)))

(defalias 'ar-kill-email-atpt 'ar-email-kill-atpt)
;;;###autoload
(defun ar-email-kill-atpt (&optional no-delimiters) 
  "Kills email at point if any. "
  (interactive "*P")
  (ar-th-kill 'email no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-email-atpt 'ar-email-left-right-singlequote-atpt)
;;;###autoload
(defun ar-email-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'email no-delimiters (interactive-p)))

(defalias 'ar-parentize-email-atpt 'ar-email-parentize-atpt)
;;;###autoload
(defun ar-email-parentize-atpt (&optional no-delimiters) 
  "Parentizes email at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'email no-delimiters (interactive-p)))

(defalias 'ar-separate-email-atpt 'ar-email-separate-atpt)
;;;###autoload
(defun ar-email-separate-atpt (&optional no-delimiters) 
  "Separates email at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'email no-delimiters (interactive-p)))

(defalias 'ar-singlequote-email-atpt 'ar-email-singlequote-atpt)
;;;###autoload
(defun ar-email-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes email at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'email no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-email-atpt 'ar-email-triplequote-dq-atpt)
;;;###autoload
(defun ar-email-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around email. "
  (interactive "*p")
  (ar-th-triplequote-dq 'email no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-email-atpt 'ar-email-triplequote-sq-atpt)
;;;###autoload
(defun ar-email-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around email. "
  (interactive "*p")
  (ar-th-triplequote-sq 'email no-delimiters (interactive-p)))

(defalias 'ar-trim-email-atpt 'ar-email-trim-atpt)
;;;###autoload
(defun ar-email-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'email t t)) 
    (ar-th-trim 'email t t)))

(defalias 'ar-trim-left-email-atpt 'ar-email-left-trim-atpt)
;;;###autoload
(defun ar-email-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'email t nil))
    (ar-th-trim 'email t nil)))

(defalias 'ar-trim-right-email-atpt 'ar-email-right-trim-atpt)
;;;###autoload
(defun ar-email-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'email nil t))
    (ar-th-trim 'email nil t)))

(defalias 'ar-email-underscore-atpt 'ar-underscore-email-atpt)
;;;###autoload
(defun ar-underscore-email-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'email no-delimiters (interactive-p)))

(defalias 'ar-email-whitespace-atpt 'ar-whitespace-email-atpt)
;;;###autoload
(defun ar-whitespace-email-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'email nil t))

(defalias 'ar-forward-email-atpt 'ar-email-forward-atpt)
;;;###autoload
(defun ar-email-forward-atpt (&optional arg) 
  "Moves forward over email at point if any, does nothing otherwise.
Returns end position of email "
  (interactive "p")
  (ar-th-forward 'email arg (interactive-p)))

(defalias 'ar-backward-email-atpt 'ar-email-backward-atpt)
;;;###autoload
(defun ar-email-backward-atpt (&optional arg) 
  "Moves backward over email before point if any, does nothing otherwise.
Returns beginning position of email "
  (interactive "p")
  (ar-th-backward 'email arg (interactive-p)))

(defalias 'ar-transpose-email-atpt 'ar-email-transpose-atpt)
;;;###autoload
(defun ar-email-transpose-atpt (&optional arg) 
  "Transposes email with email before point if any. "
  (interactive "*p")
  (ar-th-transpose 'email arg (interactive-p)))

(defalias 'ar-sort-email-atpt 'ar-email-sort-atpt)
;;;###autoload
(defun ar-email-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts emails in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'email reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-email-atpt 'ar-email-check-atpt)
;;;###autoload
(defun ar-email-check-atpt () 
  "Return t if a email at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-email-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-email-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-filename-atpt (&optional arg no-delimiters) 
  "Returns filename at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'filename arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-filename-atpt 'ar-filename-bounds-atpt)
;;;###autoload
(defun ar-filename-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of filename if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'filename no-delimiters (interactive-p)))

;;;###autoload
(defun ar-filename-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position filename at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'filename no-delimiters (interactive-p)))

;;;###autoload
(defun ar-filename-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of filename at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'filename no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-filename-atpt 'ar-filename-beginning-atpt)
;;;###autoload
(defun ar-filename-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class filename at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'filename no-delimiters (interactive-p)))

(defalias 'ar-end-of-filename-atpt 'ar-filename-end-atpt)
;;;###autoload
(defun ar-filename-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class filename at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'filename no-delimiters (interactive-p)))

(defalias 'ar-in-filename-p-atpt 'ar-filename-in-p-atpt)
;;;###autoload
(defun ar-filename-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of filename at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'filename no-delimiters (interactive-p)))

(defalias 'ar-length-of-filename-atpt 'ar-filename-length-atpt)
;;;###autoload
(defun ar-filename-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class filename at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'filename no-delimiters (interactive-p)))

(defalias 'ar-copy-filename-atpt 'ar-filename-copy-atpt)
;;;###autoload
(defun ar-filename-copy-atpt (&optional no-delimiters) 
  "Returns a copy of filename at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'filename no-delimiters (interactive-p)))

(defalias 'ar-delete-filename-in-region 'ar-filename-delete-in-region)
;;;###autoload
(defun ar-filename-delete-in-region (beg end) 
  "Deletes filename at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'filename beg end (interactive-p)))

;;;###autoload
(defun ar-blok-filename-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around filename.
  Returns blok or nil if no filename at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'filename no-delimiters (interactive-p)))

(defalias 'ar-escape-filename-atpt 'ar-filename-escape-atpt)
;;;###autoload
(defun ar-filename-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted filename at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'filename no-delimiters))

(defalias 'ar-doublequote-filename-atpt 'ar-filename-doublequote-atpt)
;;;###autoload
(defun ar-filename-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes filename at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'filename no-delimiters (interactive-p)))

(defalias 'ar-slash-filename-atpt 'ar-filename-slash-atpt)
;;;###autoload
(defun ar-filename-slash-atpt (&optional no-delimiters) 
  "Doublequotes filename at point if any. "
  (interactive "*p")
  (ar-th-slash 'filename no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-filename-atpt 'ar-filename-double-backslash-atpt)
;;;###autoload
(defun ar-filename-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around filename at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'filename no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-filename-atpt 'ar-filename-doubleslash-atpt)
;;;###autoload
(defun ar-filename-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around filename at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'filename no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-filename-atpt 'ar-filename-doubleslashparen-atpt)
;;;###autoload
(defun ar-filename-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around filename at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'filename no-delimiters (interactive-p)))

(defalias 'ar-slashparen-filename-atpt 'ar-filename-slashparen-atpt)
;;;###autoload
(defun ar-filename-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around filename at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'filename no-delimiters (interactive-p)))

(defalias 'ar-dollar-filename-atpt 'ar-filename-dollar-atpt)
;;;###autoload
(defun ar-filename-dollar-atpt (&optional no-delimiters) 
  "Doublequotes filename at point if any. "
  (interactive "*p")
  (ar-th-dollar 'filename no-delimiters (interactive-p)))

(defalias 'ar-equalize-filename-atpt 'ar-filename-equalize-atpt)
;;;###autoload
(defun ar-filename-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around filename at point if any. "
  (interactive "*p")
  (ar-th-equalize 'filename no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-filename-atpt 'ar-filename-greater-angle-atpt)
;;;###autoload
(defun ar-filename-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for filename after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'filename no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-filename-atpt 'ar-filename-lesser-angle-atpt)
;;;###autoload
(defun ar-filename-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for filename after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'filename no-delimiters (interactive-p)))

(defalias 'ar-backslash-filename-atpt 'ar-filename-backslash-atpt)
;;;###autoload
(defun ar-filename-backslash-atpt (&optional no-delimiters) 
  "Backslash filename at point if any. "
  (interactive "*p")
  (ar-th-backslash 'filename no-delimiters (interactive-p))) 

(defalias 'ar-brace-filename-atpt 'ar-filename-brace-atpt)
;;;###autoload
(defun ar-filename-brace-atpt (&optional no-delimiters) 
  "Braces filename at point if any. "
  (interactive "*p")
  (ar-th-brace 'filename no-delimiters (interactive-p)))

(defalias 'ar-bracket-filename-atpt 'ar-filename-bracket-atpt)
;;;###autoload
(defun ar-filename-bracket-atpt (&optional no-delimiters) 
  "Brackets filename after point if any. "
  (interactive "*p")
  (ar-th-bracket 'filename no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-filename-atpt (&optional no-delimiters) 
  "Comments filename at point if any. "
  (interactive "*p")
  (ar-th-comment 'filename no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-filename-atpt (&optional no-delimiters) 
  "Put a comma after filename at point if any. "
  (interactive "*p")
  (ar-th-commatize 'filename no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-filename-atpt (&optional no-delimiters) 
  "Put a singlequote before filename at point if any. "
  (interactive "*p")
  (ar-th-quote 'filename no-delimiters (interactive-p)))

(defalias 'ar-hyphen-filename-atpt 'ar-filename-hyphen-atpt)
;;;###autoload
(defun ar-filename-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around filename at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'filename no-delimiters (interactive-p)))

(defalias 'ar-mark-filename-atpt 'ar-filename-mark-atpt)
;;;###autoload
(defun ar-filename-mark-atpt () 
  "Marks filename at point if any. "
  (interactive)
  (ar-th-mark 'filename))

(defalias 'ar-hide-filename-atpt 'ar-filename-hide-atpt)
;;;###autoload
(defun ar-filename-hide-atpt () 
  "Hides filename at point. "
  (interactive)
  (ar-th-hide 'filename))

(defalias 'ar-show-filename-atpt 'ar-filename-show-atpt)
;;;###autoload
(defun ar-filename-show-atpt () 
  "Shows hidden filename at point. "
  (interactive)
  (ar-th-show 'filename))

(defalias 'ar-hide-show-filename-atpt 'ar-filename-hide-show-atpt)
;;;###autoload
(defun ar-filename-hide-show-atpt () 
  "Alternatively hides or shows filename at point. "
  (interactive)
  (ar-th-hide-show 'filename))

(defalias 'ar-highlight-filename-atpt-mode 'ar-filename-highlight-atpt-mode)

(defun ar-filename-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles filename-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'filename no-delimiters (interactive-p)))

(defalias 'ar-kill-filename-atpt 'ar-filename-kill-atpt)
;;;###autoload
(defun ar-filename-kill-atpt (&optional no-delimiters) 
  "Kills filename at point if any. "
  (interactive "*P")
  (ar-th-kill 'filename no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-filename-atpt 'ar-filename-left-right-singlequote-atpt)
;;;###autoload
(defun ar-filename-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'filename no-delimiters (interactive-p)))

(defalias 'ar-parentize-filename-atpt 'ar-filename-parentize-atpt)
;;;###autoload
(defun ar-filename-parentize-atpt (&optional no-delimiters) 
  "Parentizes filename at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'filename no-delimiters (interactive-p)))

(defalias 'ar-separate-filename-atpt 'ar-filename-separate-atpt)
;;;###autoload
(defun ar-filename-separate-atpt (&optional no-delimiters) 
  "Separates filename at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'filename no-delimiters (interactive-p)))

(defalias 'ar-singlequote-filename-atpt 'ar-filename-singlequote-atpt)
;;;###autoload
(defun ar-filename-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes filename at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'filename no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-filename-atpt 'ar-filename-triplequote-dq-atpt)
;;;###autoload
(defun ar-filename-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around filename. "
  (interactive "*p")
  (ar-th-triplequote-dq 'filename no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-filename-atpt 'ar-filename-triplequote-sq-atpt)
;;;###autoload
(defun ar-filename-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around filename. "
  (interactive "*p")
  (ar-th-triplequote-sq 'filename no-delimiters (interactive-p)))

(defalias 'ar-trim-filename-atpt 'ar-filename-trim-atpt)
;;;###autoload
(defun ar-filename-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'filename t t)) 
    (ar-th-trim 'filename t t)))

(defalias 'ar-trim-left-filename-atpt 'ar-filename-left-trim-atpt)
;;;###autoload
(defun ar-filename-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'filename t nil))
    (ar-th-trim 'filename t nil)))

(defalias 'ar-trim-right-filename-atpt 'ar-filename-right-trim-atpt)
;;;###autoload
(defun ar-filename-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'filename nil t))
    (ar-th-trim 'filename nil t)))

(defalias 'ar-filename-underscore-atpt 'ar-underscore-filename-atpt)
;;;###autoload
(defun ar-underscore-filename-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'filename no-delimiters (interactive-p)))

(defalias 'ar-filename-whitespace-atpt 'ar-whitespace-filename-atpt)
;;;###autoload
(defun ar-whitespace-filename-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'filename nil t))

(defalias 'ar-forward-filename-atpt 'ar-filename-forward-atpt)
;;;###autoload
(defun ar-filename-forward-atpt (&optional arg) 
  "Moves forward over filename at point if any, does nothing otherwise.
Returns end position of filename "
  (interactive "p")
  (ar-th-forward 'filename arg (interactive-p)))

(defalias 'ar-backward-filename-atpt 'ar-filename-backward-atpt)
;;;###autoload
(defun ar-filename-backward-atpt (&optional arg) 
  "Moves backward over filename before point if any, does nothing otherwise.
Returns beginning position of filename "
  (interactive "p")
  (ar-th-backward 'filename arg (interactive-p)))

(defalias 'ar-transpose-filename-atpt 'ar-filename-transpose-atpt)
;;;###autoload
(defun ar-filename-transpose-atpt (&optional arg) 
  "Transposes filename with filename before point if any. "
  (interactive "*p")
  (ar-th-transpose 'filename arg (interactive-p)))

(defalias 'ar-sort-filename-atpt 'ar-filename-sort-atpt)
;;;###autoload
(defun ar-filename-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts filenames in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'filename reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-filename-atpt 'ar-filename-check-atpt)
;;;###autoload
(defun ar-filename-check-atpt () 
  "Return t if a filename at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-filename-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-filename-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-float-atpt (&optional arg no-delimiters) 
  "Returns float at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'float arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-float-atpt 'ar-float-bounds-atpt)
;;;###autoload
(defun ar-float-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of float if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'float no-delimiters (interactive-p)))

;;;###autoload
(defun ar-float-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position float at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'float no-delimiters (interactive-p)))

;;;###autoload
(defun ar-float-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of float at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'float no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-float-atpt 'ar-float-beginning-atpt)
;;;###autoload
(defun ar-float-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class float at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'float no-delimiters (interactive-p)))

(defalias 'ar-end-of-float-atpt 'ar-float-end-atpt)
;;;###autoload
(defun ar-float-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class float at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'float no-delimiters (interactive-p)))

(defalias 'ar-in-float-p-atpt 'ar-float-in-p-atpt)
;;;###autoload
(defun ar-float-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of float at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'float no-delimiters (interactive-p)))

(defalias 'ar-length-of-float-atpt 'ar-float-length-atpt)
;;;###autoload
(defun ar-float-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class float at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'float no-delimiters (interactive-p)))

(defalias 'ar-copy-float-atpt 'ar-float-copy-atpt)
;;;###autoload
(defun ar-float-copy-atpt (&optional no-delimiters) 
  "Returns a copy of float at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'float no-delimiters (interactive-p)))

(defalias 'ar-delete-float-in-region 'ar-float-delete-in-region)
;;;###autoload
(defun ar-float-delete-in-region (beg end) 
  "Deletes float at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'float beg end (interactive-p)))

;;;###autoload
(defun ar-blok-float-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around float.
  Returns blok or nil if no float at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'float no-delimiters (interactive-p)))

(defalias 'ar-escape-float-atpt 'ar-float-escape-atpt)
;;;###autoload
(defun ar-float-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted float at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'float no-delimiters))

(defalias 'ar-doublequote-float-atpt 'ar-float-doublequote-atpt)
;;;###autoload
(defun ar-float-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes float at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'float no-delimiters (interactive-p)))

(defalias 'ar-slash-float-atpt 'ar-float-slash-atpt)
;;;###autoload
(defun ar-float-slash-atpt (&optional no-delimiters) 
  "Doublequotes float at point if any. "
  (interactive "*p")
  (ar-th-slash 'float no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-float-atpt 'ar-float-double-backslash-atpt)
;;;###autoload
(defun ar-float-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around float at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'float no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-float-atpt 'ar-float-doubleslash-atpt)
;;;###autoload
(defun ar-float-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around float at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'float no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-float-atpt 'ar-float-doubleslashparen-atpt)
;;;###autoload
(defun ar-float-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around float at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'float no-delimiters (interactive-p)))

(defalias 'ar-slashparen-float-atpt 'ar-float-slashparen-atpt)
;;;###autoload
(defun ar-float-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around float at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'float no-delimiters (interactive-p)))

(defalias 'ar-dollar-float-atpt 'ar-float-dollar-atpt)
;;;###autoload
(defun ar-float-dollar-atpt (&optional no-delimiters) 
  "Doublequotes float at point if any. "
  (interactive "*p")
  (ar-th-dollar 'float no-delimiters (interactive-p)))

(defalias 'ar-equalize-float-atpt 'ar-float-equalize-atpt)
;;;###autoload
(defun ar-float-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around float at point if any. "
  (interactive "*p")
  (ar-th-equalize 'float no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-float-atpt 'ar-float-greater-angle-atpt)
;;;###autoload
(defun ar-float-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for float after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'float no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-float-atpt 'ar-float-lesser-angle-atpt)
;;;###autoload
(defun ar-float-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for float after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'float no-delimiters (interactive-p)))

(defalias 'ar-backslash-float-atpt 'ar-float-backslash-atpt)
;;;###autoload
(defun ar-float-backslash-atpt (&optional no-delimiters) 
  "Backslash float at point if any. "
  (interactive "*p")
  (ar-th-backslash 'float no-delimiters (interactive-p))) 

(defalias 'ar-brace-float-atpt 'ar-float-brace-atpt)
;;;###autoload
(defun ar-float-brace-atpt (&optional no-delimiters) 
  "Braces float at point if any. "
  (interactive "*p")
  (ar-th-brace 'float no-delimiters (interactive-p)))

(defalias 'ar-bracket-float-atpt 'ar-float-bracket-atpt)
;;;###autoload
(defun ar-float-bracket-atpt (&optional no-delimiters) 
  "Brackets float after point if any. "
  (interactive "*p")
  (ar-th-bracket 'float no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-float-atpt (&optional no-delimiters) 
  "Comments float at point if any. "
  (interactive "*p")
  (ar-th-comment 'float no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-float-atpt (&optional no-delimiters) 
  "Put a comma after float at point if any. "
  (interactive "*p")
  (ar-th-commatize 'float no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-float-atpt (&optional no-delimiters) 
  "Put a singlequote before float at point if any. "
  (interactive "*p")
  (ar-th-quote 'float no-delimiters (interactive-p)))

(defalias 'ar-hyphen-float-atpt 'ar-float-hyphen-atpt)
;;;###autoload
(defun ar-float-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around float at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'float no-delimiters (interactive-p)))

(defalias 'ar-mark-float-atpt 'ar-float-mark-atpt)
;;;###autoload
(defun ar-float-mark-atpt () 
  "Marks float at point if any. "
  (interactive)
  (ar-th-mark 'float))

(defalias 'ar-hide-float-atpt 'ar-float-hide-atpt)
;;;###autoload
(defun ar-float-hide-atpt () 
  "Hides float at point. "
  (interactive)
  (ar-th-hide 'float))

(defalias 'ar-show-float-atpt 'ar-float-show-atpt)
;;;###autoload
(defun ar-float-show-atpt () 
  "Shows hidden float at point. "
  (interactive)
  (ar-th-show 'float))

(defalias 'ar-hide-show-float-atpt 'ar-float-hide-show-atpt)
;;;###autoload
(defun ar-float-hide-show-atpt () 
  "Alternatively hides or shows float at point. "
  (interactive)
  (ar-th-hide-show 'float))

(defalias 'ar-highlight-float-atpt-mode 'ar-float-highlight-atpt-mode)

(defun ar-float-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles float-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'float no-delimiters (interactive-p)))

(defalias 'ar-kill-float-atpt 'ar-float-kill-atpt)
;;;###autoload
(defun ar-float-kill-atpt (&optional no-delimiters) 
  "Kills float at point if any. "
  (interactive "*P")
  (ar-th-kill 'float no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-float-atpt 'ar-float-left-right-singlequote-atpt)
;;;###autoload
(defun ar-float-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'float no-delimiters (interactive-p)))

(defalias 'ar-parentize-float-atpt 'ar-float-parentize-atpt)
;;;###autoload
(defun ar-float-parentize-atpt (&optional no-delimiters) 
  "Parentizes float at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'float no-delimiters (interactive-p)))

(defalias 'ar-separate-float-atpt 'ar-float-separate-atpt)
;;;###autoload
(defun ar-float-separate-atpt (&optional no-delimiters) 
  "Separates float at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'float no-delimiters (interactive-p)))

(defalias 'ar-singlequote-float-atpt 'ar-float-singlequote-atpt)
;;;###autoload
(defun ar-float-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes float at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'float no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-float-atpt 'ar-float-triplequote-dq-atpt)
;;;###autoload
(defun ar-float-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around float. "
  (interactive "*p")
  (ar-th-triplequote-dq 'float no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-float-atpt 'ar-float-triplequote-sq-atpt)
;;;###autoload
(defun ar-float-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around float. "
  (interactive "*p")
  (ar-th-triplequote-sq 'float no-delimiters (interactive-p)))

(defalias 'ar-trim-float-atpt 'ar-float-trim-atpt)
;;;###autoload
(defun ar-float-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'float t t)) 
    (ar-th-trim 'float t t)))

(defalias 'ar-trim-left-float-atpt 'ar-float-left-trim-atpt)
;;;###autoload
(defun ar-float-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'float t nil))
    (ar-th-trim 'float t nil)))

(defalias 'ar-trim-right-float-atpt 'ar-float-right-trim-atpt)
;;;###autoload
(defun ar-float-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'float nil t))
    (ar-th-trim 'float nil t)))

(defalias 'ar-float-underscore-atpt 'ar-underscore-float-atpt)
;;;###autoload
(defun ar-underscore-float-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'float no-delimiters (interactive-p)))

(defalias 'ar-float-whitespace-atpt 'ar-whitespace-float-atpt)
;;;###autoload
(defun ar-whitespace-float-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'float nil t))

(defalias 'ar-forward-float-atpt 'ar-float-forward-atpt)
;;;###autoload
(defun ar-float-forward-atpt (&optional arg) 
  "Moves forward over float at point if any, does nothing otherwise.
Returns end position of float "
  (interactive "p")
  (ar-th-forward 'float arg (interactive-p)))

(defalias 'ar-backward-float-atpt 'ar-float-backward-atpt)
;;;###autoload
(defun ar-float-backward-atpt (&optional arg) 
  "Moves backward over float before point if any, does nothing otherwise.
Returns beginning position of float "
  (interactive "p")
  (ar-th-backward 'float arg (interactive-p)))

(defalias 'ar-transpose-float-atpt 'ar-float-transpose-atpt)
;;;###autoload
(defun ar-float-transpose-atpt (&optional arg) 
  "Transposes float with float before point if any. "
  (interactive "*p")
  (ar-th-transpose 'float arg (interactive-p)))

(defalias 'ar-sort-float-atpt 'ar-float-sort-atpt)
;;;###autoload
(defun ar-float-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts floats in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'float reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-float-atpt 'ar-float-check-atpt)
;;;###autoload
(defun ar-float-check-atpt () 
  "Return t if a float at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-float-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-float-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-function-atpt (&optional arg no-delimiters) 
  "Returns function at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'function arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-function-atpt 'ar-function-bounds-atpt)
;;;###autoload
(defun ar-function-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of function if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'function no-delimiters (interactive-p)))

;;;###autoload
(defun ar-function-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position function at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'function no-delimiters (interactive-p)))

;;;###autoload
(defun ar-function-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of function at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'function no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-function-atpt 'ar-function-beginning-atpt)
;;;###autoload
(defun ar-function-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class function at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'function no-delimiters (interactive-p)))

(defalias 'ar-end-of-function-atpt 'ar-function-end-atpt)
;;;###autoload
(defun ar-function-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class function at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'function no-delimiters (interactive-p)))

(defalias 'ar-in-function-p-atpt 'ar-function-in-p-atpt)
;;;###autoload
(defun ar-function-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of function at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'function no-delimiters (interactive-p)))

(defalias 'ar-length-of-function-atpt 'ar-function-length-atpt)
;;;###autoload
(defun ar-function-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class function at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'function no-delimiters (interactive-p)))

(defalias 'ar-copy-function-atpt 'ar-function-copy-atpt)
;;;###autoload
(defun ar-function-copy-atpt (&optional no-delimiters) 
  "Returns a copy of function at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'function no-delimiters (interactive-p)))

(defalias 'ar-delete-function-in-region 'ar-function-delete-in-region)
;;;###autoload
(defun ar-function-delete-in-region (beg end) 
  "Deletes function at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'function beg end (interactive-p)))

;;;###autoload
(defun ar-blok-function-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around function.
  Returns blok or nil if no function at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'function no-delimiters (interactive-p)))

(defalias 'ar-escape-function-atpt 'ar-function-escape-atpt)
;;;###autoload
(defun ar-function-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted function at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'function no-delimiters))

(defalias 'ar-doublequote-function-atpt 'ar-function-doublequote-atpt)
;;;###autoload
(defun ar-function-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes function at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'function no-delimiters (interactive-p)))

(defalias 'ar-slash-function-atpt 'ar-function-slash-atpt)
;;;###autoload
(defun ar-function-slash-atpt (&optional no-delimiters) 
  "Doublequotes function at point if any. "
  (interactive "*p")
  (ar-th-slash 'function no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-function-atpt 'ar-function-double-backslash-atpt)
;;;###autoload
(defun ar-function-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around function at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'function no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-function-atpt 'ar-function-doubleslash-atpt)
;;;###autoload
(defun ar-function-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around function at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'function no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-function-atpt 'ar-function-doubleslashparen-atpt)
;;;###autoload
(defun ar-function-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around function at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'function no-delimiters (interactive-p)))

(defalias 'ar-slashparen-function-atpt 'ar-function-slashparen-atpt)
;;;###autoload
(defun ar-function-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around function at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'function no-delimiters (interactive-p)))

(defalias 'ar-dollar-function-atpt 'ar-function-dollar-atpt)
;;;###autoload
(defun ar-function-dollar-atpt (&optional no-delimiters) 
  "Doublequotes function at point if any. "
  (interactive "*p")
  (ar-th-dollar 'function no-delimiters (interactive-p)))

(defalias 'ar-equalize-function-atpt 'ar-function-equalize-atpt)
;;;###autoload
(defun ar-function-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around function at point if any. "
  (interactive "*p")
  (ar-th-equalize 'function no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-function-atpt 'ar-function-greater-angle-atpt)
;;;###autoload
(defun ar-function-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for function after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'function no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-function-atpt 'ar-function-lesser-angle-atpt)
;;;###autoload
(defun ar-function-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for function after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'function no-delimiters (interactive-p)))

(defalias 'ar-backslash-function-atpt 'ar-function-backslash-atpt)
;;;###autoload
(defun ar-function-backslash-atpt (&optional no-delimiters) 
  "Backslash function at point if any. "
  (interactive "*p")
  (ar-th-backslash 'function no-delimiters (interactive-p))) 

(defalias 'ar-brace-function-atpt 'ar-function-brace-atpt)
;;;###autoload
(defun ar-function-brace-atpt (&optional no-delimiters) 
  "Braces function at point if any. "
  (interactive "*p")
  (ar-th-brace 'function no-delimiters (interactive-p)))

(defalias 'ar-bracket-function-atpt 'ar-function-bracket-atpt)
;;;###autoload
(defun ar-function-bracket-atpt (&optional no-delimiters) 
  "Brackets function after point if any. "
  (interactive "*p")
  (ar-th-bracket 'function no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-function-atpt (&optional no-delimiters) 
  "Comments function at point if any. "
  (interactive "*p")
  (ar-th-comment 'function no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-function-atpt (&optional no-delimiters) 
  "Put a comma after function at point if any. "
  (interactive "*p")
  (ar-th-commatize 'function no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-function-atpt (&optional no-delimiters) 
  "Put a singlequote before function at point if any. "
  (interactive "*p")
  (ar-th-quote 'function no-delimiters (interactive-p)))

(defalias 'ar-hyphen-function-atpt 'ar-function-hyphen-atpt)
;;;###autoload
(defun ar-function-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around function at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'function no-delimiters (interactive-p)))

(defalias 'ar-mark-function-atpt 'ar-function-mark-atpt)
;;;###autoload
(defun ar-function-mark-atpt () 
  "Marks function at point if any. "
  (interactive)
  (ar-th-mark 'function))

(defalias 'ar-hide-function-atpt 'ar-function-hide-atpt)
;;;###autoload
(defun ar-function-hide-atpt () 
  "Hides function at point. "
  (interactive)
  (ar-th-hide 'function))

(defalias 'ar-show-function-atpt 'ar-function-show-atpt)
;;;###autoload
(defun ar-function-show-atpt () 
  "Shows hidden function at point. "
  (interactive)
  (ar-th-show 'function))

(defalias 'ar-hide-show-function-atpt 'ar-function-hide-show-atpt)
;;;###autoload
(defun ar-function-hide-show-atpt () 
  "Alternatively hides or shows function at point. "
  (interactive)
  (ar-th-hide-show 'function))

(defalias 'ar-highlight-function-atpt-mode 'ar-function-highlight-atpt-mode)

(defun ar-function-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles function-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'function no-delimiters (interactive-p)))

(defalias 'ar-kill-function-atpt 'ar-function-kill-atpt)
;;;###autoload
(defun ar-function-kill-atpt (&optional no-delimiters) 
  "Kills function at point if any. "
  (interactive "*P")
  (ar-th-kill 'function no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-function-atpt 'ar-function-left-right-singlequote-atpt)
;;;###autoload
(defun ar-function-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'function no-delimiters (interactive-p)))

(defalias 'ar-parentize-function-atpt 'ar-function-parentize-atpt)
;;;###autoload
(defun ar-function-parentize-atpt (&optional no-delimiters) 
  "Parentizes function at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'function no-delimiters (interactive-p)))

(defalias 'ar-separate-function-atpt 'ar-function-separate-atpt)
;;;###autoload
(defun ar-function-separate-atpt (&optional no-delimiters) 
  "Separates function at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'function no-delimiters (interactive-p)))

(defalias 'ar-singlequote-function-atpt 'ar-function-singlequote-atpt)
;;;###autoload
(defun ar-function-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes function at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'function no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-function-atpt 'ar-function-triplequote-dq-atpt)
;;;###autoload
(defun ar-function-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around function. "
  (interactive "*p")
  (ar-th-triplequote-dq 'function no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-function-atpt 'ar-function-triplequote-sq-atpt)
;;;###autoload
(defun ar-function-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around function. "
  (interactive "*p")
  (ar-th-triplequote-sq 'function no-delimiters (interactive-p)))

(defalias 'ar-trim-function-atpt 'ar-function-trim-atpt)
;;;###autoload
(defun ar-function-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'function t t)) 
    (ar-th-trim 'function t t)))

(defalias 'ar-trim-left-function-atpt 'ar-function-left-trim-atpt)
;;;###autoload
(defun ar-function-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'function t nil))
    (ar-th-trim 'function t nil)))

(defalias 'ar-trim-right-function-atpt 'ar-function-right-trim-atpt)
;;;###autoload
(defun ar-function-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'function nil t))
    (ar-th-trim 'function nil t)))

(defalias 'ar-function-underscore-atpt 'ar-underscore-function-atpt)
;;;###autoload
(defun ar-underscore-function-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'function no-delimiters (interactive-p)))

(defalias 'ar-function-whitespace-atpt 'ar-whitespace-function-atpt)
;;;###autoload
(defun ar-whitespace-function-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'function nil t))

(defalias 'ar-forward-function-atpt 'ar-function-forward-atpt)
;;;###autoload
(defun ar-function-forward-atpt (&optional arg) 
  "Moves forward over function at point if any, does nothing otherwise.
Returns end position of function "
  (interactive "p")
  (ar-th-forward 'function arg (interactive-p)))

(defalias 'ar-backward-function-atpt 'ar-function-backward-atpt)
;;;###autoload
(defun ar-function-backward-atpt (&optional arg) 
  "Moves backward over function before point if any, does nothing otherwise.
Returns beginning position of function "
  (interactive "p")
  (ar-th-backward 'function arg (interactive-p)))

(defalias 'ar-transpose-function-atpt 'ar-function-transpose-atpt)
;;;###autoload
(defun ar-function-transpose-atpt (&optional arg) 
  "Transposes function with function before point if any. "
  (interactive "*p")
  (ar-th-transpose 'function arg (interactive-p)))

(defalias 'ar-sort-function-atpt 'ar-function-sort-atpt)
;;;###autoload
(defun ar-function-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts functions in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'function reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-function-atpt 'ar-function-check-atpt)
;;;###autoload
(defun ar-function-check-atpt () 
  "Return t if a function at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-function-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-function-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-ip-atpt (&optional arg no-delimiters) 
  "Returns ip at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'ip arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-ip-atpt 'ar-ip-bounds-atpt)
;;;###autoload
(defun ar-ip-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of ip if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'ip no-delimiters (interactive-p)))

;;;###autoload
(defun ar-ip-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position ip at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'ip no-delimiters (interactive-p)))

;;;###autoload
(defun ar-ip-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of ip at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'ip no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-ip-atpt 'ar-ip-beginning-atpt)
;;;###autoload
(defun ar-ip-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class ip at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'ip no-delimiters (interactive-p)))

(defalias 'ar-end-of-ip-atpt 'ar-ip-end-atpt)
;;;###autoload
(defun ar-ip-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class ip at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'ip no-delimiters (interactive-p)))

(defalias 'ar-in-ip-p-atpt 'ar-ip-in-p-atpt)
;;;###autoload
(defun ar-ip-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of ip at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'ip no-delimiters (interactive-p)))

(defalias 'ar-length-of-ip-atpt 'ar-ip-length-atpt)
;;;###autoload
(defun ar-ip-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class ip at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'ip no-delimiters (interactive-p)))

(defalias 'ar-copy-ip-atpt 'ar-ip-copy-atpt)
;;;###autoload
(defun ar-ip-copy-atpt (&optional no-delimiters) 
  "Returns a copy of ip at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'ip no-delimiters (interactive-p)))

(defalias 'ar-delete-ip-in-region 'ar-ip-delete-in-region)
;;;###autoload
(defun ar-ip-delete-in-region (beg end) 
  "Deletes ip at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'ip beg end (interactive-p)))

;;;###autoload
(defun ar-blok-ip-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around ip.
  Returns blok or nil if no ip at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'ip no-delimiters (interactive-p)))

(defalias 'ar-escape-ip-atpt 'ar-ip-escape-atpt)
;;;###autoload
(defun ar-ip-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted ip at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'ip no-delimiters))

(defalias 'ar-doublequote-ip-atpt 'ar-ip-doublequote-atpt)
;;;###autoload
(defun ar-ip-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes ip at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'ip no-delimiters (interactive-p)))

(defalias 'ar-slash-ip-atpt 'ar-ip-slash-atpt)
;;;###autoload
(defun ar-ip-slash-atpt (&optional no-delimiters) 
  "Doublequotes ip at point if any. "
  (interactive "*p")
  (ar-th-slash 'ip no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-ip-atpt 'ar-ip-double-backslash-atpt)
;;;###autoload
(defun ar-ip-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around ip at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'ip no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-ip-atpt 'ar-ip-doubleslash-atpt)
;;;###autoload
(defun ar-ip-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around ip at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'ip no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-ip-atpt 'ar-ip-doubleslashparen-atpt)
;;;###autoload
(defun ar-ip-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around ip at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'ip no-delimiters (interactive-p)))

(defalias 'ar-slashparen-ip-atpt 'ar-ip-slashparen-atpt)
;;;###autoload
(defun ar-ip-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around ip at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'ip no-delimiters (interactive-p)))

(defalias 'ar-dollar-ip-atpt 'ar-ip-dollar-atpt)
;;;###autoload
(defun ar-ip-dollar-atpt (&optional no-delimiters) 
  "Doublequotes ip at point if any. "
  (interactive "*p")
  (ar-th-dollar 'ip no-delimiters (interactive-p)))

(defalias 'ar-equalize-ip-atpt 'ar-ip-equalize-atpt)
;;;###autoload
(defun ar-ip-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around ip at point if any. "
  (interactive "*p")
  (ar-th-equalize 'ip no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-ip-atpt 'ar-ip-greater-angle-atpt)
;;;###autoload
(defun ar-ip-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for ip after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'ip no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-ip-atpt 'ar-ip-lesser-angle-atpt)
;;;###autoload
(defun ar-ip-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for ip after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'ip no-delimiters (interactive-p)))

(defalias 'ar-backslash-ip-atpt 'ar-ip-backslash-atpt)
;;;###autoload
(defun ar-ip-backslash-atpt (&optional no-delimiters) 
  "Backslash ip at point if any. "
  (interactive "*p")
  (ar-th-backslash 'ip no-delimiters (interactive-p))) 

(defalias 'ar-brace-ip-atpt 'ar-ip-brace-atpt)
;;;###autoload
(defun ar-ip-brace-atpt (&optional no-delimiters) 
  "Braces ip at point if any. "
  (interactive "*p")
  (ar-th-brace 'ip no-delimiters (interactive-p)))

(defalias 'ar-bracket-ip-atpt 'ar-ip-bracket-atpt)
;;;###autoload
(defun ar-ip-bracket-atpt (&optional no-delimiters) 
  "Brackets ip after point if any. "
  (interactive "*p")
  (ar-th-bracket 'ip no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-ip-atpt (&optional no-delimiters) 
  "Comments ip at point if any. "
  (interactive "*p")
  (ar-th-comment 'ip no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-ip-atpt (&optional no-delimiters) 
  "Put a comma after ip at point if any. "
  (interactive "*p")
  (ar-th-commatize 'ip no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-ip-atpt (&optional no-delimiters) 
  "Put a singlequote before ip at point if any. "
  (interactive "*p")
  (ar-th-quote 'ip no-delimiters (interactive-p)))

(defalias 'ar-hyphen-ip-atpt 'ar-ip-hyphen-atpt)
;;;###autoload
(defun ar-ip-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around ip at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'ip no-delimiters (interactive-p)))

(defalias 'ar-mark-ip-atpt 'ar-ip-mark-atpt)
;;;###autoload
(defun ar-ip-mark-atpt () 
  "Marks ip at point if any. "
  (interactive)
  (ar-th-mark 'ip))

(defalias 'ar-hide-ip-atpt 'ar-ip-hide-atpt)
;;;###autoload
(defun ar-ip-hide-atpt () 
  "Hides ip at point. "
  (interactive)
  (ar-th-hide 'ip))

(defalias 'ar-show-ip-atpt 'ar-ip-show-atpt)
;;;###autoload
(defun ar-ip-show-atpt () 
  "Shows hidden ip at point. "
  (interactive)
  (ar-th-show 'ip))

(defalias 'ar-hide-show-ip-atpt 'ar-ip-hide-show-atpt)
;;;###autoload
(defun ar-ip-hide-show-atpt () 
  "Alternatively hides or shows ip at point. "
  (interactive)
  (ar-th-hide-show 'ip))

(defalias 'ar-highlight-ip-atpt-mode 'ar-ip-highlight-atpt-mode)

(defun ar-ip-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles ip-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'ip no-delimiters (interactive-p)))

(defalias 'ar-kill-ip-atpt 'ar-ip-kill-atpt)
;;;###autoload
(defun ar-ip-kill-atpt (&optional no-delimiters) 
  "Kills ip at point if any. "
  (interactive "*P")
  (ar-th-kill 'ip no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-ip-atpt 'ar-ip-left-right-singlequote-atpt)
;;;###autoload
(defun ar-ip-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'ip no-delimiters (interactive-p)))

(defalias 'ar-parentize-ip-atpt 'ar-ip-parentize-atpt)
;;;###autoload
(defun ar-ip-parentize-atpt (&optional no-delimiters) 
  "Parentizes ip at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'ip no-delimiters (interactive-p)))

(defalias 'ar-separate-ip-atpt 'ar-ip-separate-atpt)
;;;###autoload
(defun ar-ip-separate-atpt (&optional no-delimiters) 
  "Separates ip at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'ip no-delimiters (interactive-p)))

(defalias 'ar-singlequote-ip-atpt 'ar-ip-singlequote-atpt)
;;;###autoload
(defun ar-ip-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes ip at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'ip no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-ip-atpt 'ar-ip-triplequote-dq-atpt)
;;;###autoload
(defun ar-ip-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around ip. "
  (interactive "*p")
  (ar-th-triplequote-dq 'ip no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-ip-atpt 'ar-ip-triplequote-sq-atpt)
;;;###autoload
(defun ar-ip-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around ip. "
  (interactive "*p")
  (ar-th-triplequote-sq 'ip no-delimiters (interactive-p)))

(defalias 'ar-trim-ip-atpt 'ar-ip-trim-atpt)
;;;###autoload
(defun ar-ip-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ip t t)) 
    (ar-th-trim 'ip t t)))

(defalias 'ar-trim-left-ip-atpt 'ar-ip-left-trim-atpt)
;;;###autoload
(defun ar-ip-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ip t nil))
    (ar-th-trim 'ip t nil)))

(defalias 'ar-trim-right-ip-atpt 'ar-ip-right-trim-atpt)
;;;###autoload
(defun ar-ip-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'ip nil t))
    (ar-th-trim 'ip nil t)))

(defalias 'ar-ip-underscore-atpt 'ar-underscore-ip-atpt)
;;;###autoload
(defun ar-underscore-ip-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'ip no-delimiters (interactive-p)))

(defalias 'ar-ip-whitespace-atpt 'ar-whitespace-ip-atpt)
;;;###autoload
(defun ar-whitespace-ip-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'ip nil t))

(defalias 'ar-forward-ip-atpt 'ar-ip-forward-atpt)
;;;###autoload
(defun ar-ip-forward-atpt (&optional arg) 
  "Moves forward over ip at point if any, does nothing otherwise.
Returns end position of ip "
  (interactive "p")
  (ar-th-forward 'ip arg (interactive-p)))

(defalias 'ar-backward-ip-atpt 'ar-ip-backward-atpt)
;;;###autoload
(defun ar-ip-backward-atpt (&optional arg) 
  "Moves backward over ip before point if any, does nothing otherwise.
Returns beginning position of ip "
  (interactive "p")
  (ar-th-backward 'ip arg (interactive-p)))

(defalias 'ar-transpose-ip-atpt 'ar-ip-transpose-atpt)
;;;###autoload
(defun ar-ip-transpose-atpt (&optional arg) 
  "Transposes ip with ip before point if any. "
  (interactive "*p")
  (ar-th-transpose 'ip arg (interactive-p)))

(defalias 'ar-sort-ip-atpt 'ar-ip-sort-atpt)
;;;###autoload
(defun ar-ip-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts ips in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'ip reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-ip-atpt 'ar-ip-check-atpt)
;;;###autoload
(defun ar-ip-check-atpt () 
  "Return t if a ip at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-ip-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-ip-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-isbn-atpt (&optional arg no-delimiters) 
  "Returns isbn at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'isbn arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-isbn-atpt 'ar-isbn-bounds-atpt)
;;;###autoload
(defun ar-isbn-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of isbn if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'isbn no-delimiters (interactive-p)))

;;;###autoload
(defun ar-isbn-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position isbn at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'isbn no-delimiters (interactive-p)))

;;;###autoload
(defun ar-isbn-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of isbn at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'isbn no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-isbn-atpt 'ar-isbn-beginning-atpt)
;;;###autoload
(defun ar-isbn-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class isbn at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'isbn no-delimiters (interactive-p)))

(defalias 'ar-end-of-isbn-atpt 'ar-isbn-end-atpt)
;;;###autoload
(defun ar-isbn-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class isbn at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'isbn no-delimiters (interactive-p)))

(defalias 'ar-in-isbn-p-atpt 'ar-isbn-in-p-atpt)
;;;###autoload
(defun ar-isbn-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of isbn at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'isbn no-delimiters (interactive-p)))

(defalias 'ar-length-of-isbn-atpt 'ar-isbn-length-atpt)
;;;###autoload
(defun ar-isbn-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class isbn at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'isbn no-delimiters (interactive-p)))

(defalias 'ar-copy-isbn-atpt 'ar-isbn-copy-atpt)
;;;###autoload
(defun ar-isbn-copy-atpt (&optional no-delimiters) 
  "Returns a copy of isbn at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'isbn no-delimiters (interactive-p)))

(defalias 'ar-delete-isbn-in-region 'ar-isbn-delete-in-region)
;;;###autoload
(defun ar-isbn-delete-in-region (beg end) 
  "Deletes isbn at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'isbn beg end (interactive-p)))

;;;###autoload
(defun ar-blok-isbn-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around isbn.
  Returns blok or nil if no isbn at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'isbn no-delimiters (interactive-p)))

(defalias 'ar-escape-isbn-atpt 'ar-isbn-escape-atpt)
;;;###autoload
(defun ar-isbn-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted isbn at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'isbn no-delimiters))

(defalias 'ar-doublequote-isbn-atpt 'ar-isbn-doublequote-atpt)
;;;###autoload
(defun ar-isbn-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes isbn at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'isbn no-delimiters (interactive-p)))

(defalias 'ar-slash-isbn-atpt 'ar-isbn-slash-atpt)
;;;###autoload
(defun ar-isbn-slash-atpt (&optional no-delimiters) 
  "Doublequotes isbn at point if any. "
  (interactive "*p")
  (ar-th-slash 'isbn no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-isbn-atpt 'ar-isbn-double-backslash-atpt)
;;;###autoload
(defun ar-isbn-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around isbn at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'isbn no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-isbn-atpt 'ar-isbn-doubleslash-atpt)
;;;###autoload
(defun ar-isbn-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around isbn at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'isbn no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-isbn-atpt 'ar-isbn-doubleslashparen-atpt)
;;;###autoload
(defun ar-isbn-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around isbn at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'isbn no-delimiters (interactive-p)))

(defalias 'ar-slashparen-isbn-atpt 'ar-isbn-slashparen-atpt)
;;;###autoload
(defun ar-isbn-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around isbn at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'isbn no-delimiters (interactive-p)))

(defalias 'ar-dollar-isbn-atpt 'ar-isbn-dollar-atpt)
;;;###autoload
(defun ar-isbn-dollar-atpt (&optional no-delimiters) 
  "Doublequotes isbn at point if any. "
  (interactive "*p")
  (ar-th-dollar 'isbn no-delimiters (interactive-p)))

(defalias 'ar-equalize-isbn-atpt 'ar-isbn-equalize-atpt)
;;;###autoload
(defun ar-isbn-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around isbn at point if any. "
  (interactive "*p")
  (ar-th-equalize 'isbn no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-isbn-atpt 'ar-isbn-greater-angle-atpt)
;;;###autoload
(defun ar-isbn-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for isbn after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'isbn no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-isbn-atpt 'ar-isbn-lesser-angle-atpt)
;;;###autoload
(defun ar-isbn-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for isbn after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'isbn no-delimiters (interactive-p)))

(defalias 'ar-backslash-isbn-atpt 'ar-isbn-backslash-atpt)
;;;###autoload
(defun ar-isbn-backslash-atpt (&optional no-delimiters) 
  "Backslash isbn at point if any. "
  (interactive "*p")
  (ar-th-backslash 'isbn no-delimiters (interactive-p))) 

(defalias 'ar-brace-isbn-atpt 'ar-isbn-brace-atpt)
;;;###autoload
(defun ar-isbn-brace-atpt (&optional no-delimiters) 
  "Braces isbn at point if any. "
  (interactive "*p")
  (ar-th-brace 'isbn no-delimiters (interactive-p)))

(defalias 'ar-bracket-isbn-atpt 'ar-isbn-bracket-atpt)
;;;###autoload
(defun ar-isbn-bracket-atpt (&optional no-delimiters) 
  "Brackets isbn after point if any. "
  (interactive "*p")
  (ar-th-bracket 'isbn no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-isbn-atpt (&optional no-delimiters) 
  "Comments isbn at point if any. "
  (interactive "*p")
  (ar-th-comment 'isbn no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-isbn-atpt (&optional no-delimiters) 
  "Put a comma after isbn at point if any. "
  (interactive "*p")
  (ar-th-commatize 'isbn no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-isbn-atpt (&optional no-delimiters) 
  "Put a singlequote before isbn at point if any. "
  (interactive "*p")
  (ar-th-quote 'isbn no-delimiters (interactive-p)))

(defalias 'ar-hyphen-isbn-atpt 'ar-isbn-hyphen-atpt)
;;;###autoload
(defun ar-isbn-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around isbn at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'isbn no-delimiters (interactive-p)))

(defalias 'ar-mark-isbn-atpt 'ar-isbn-mark-atpt)
;;;###autoload
(defun ar-isbn-mark-atpt () 
  "Marks isbn at point if any. "
  (interactive)
  (ar-th-mark 'isbn))

(defalias 'ar-hide-isbn-atpt 'ar-isbn-hide-atpt)
;;;###autoload
(defun ar-isbn-hide-atpt () 
  "Hides isbn at point. "
  (interactive)
  (ar-th-hide 'isbn))

(defalias 'ar-show-isbn-atpt 'ar-isbn-show-atpt)
;;;###autoload
(defun ar-isbn-show-atpt () 
  "Shows hidden isbn at point. "
  (interactive)
  (ar-th-show 'isbn))

(defalias 'ar-hide-show-isbn-atpt 'ar-isbn-hide-show-atpt)
;;;###autoload
(defun ar-isbn-hide-show-atpt () 
  "Alternatively hides or shows isbn at point. "
  (interactive)
  (ar-th-hide-show 'isbn))

(defalias 'ar-highlight-isbn-atpt-mode 'ar-isbn-highlight-atpt-mode)

(defun ar-isbn-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles isbn-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'isbn no-delimiters (interactive-p)))

(defalias 'ar-kill-isbn-atpt 'ar-isbn-kill-atpt)
;;;###autoload
(defun ar-isbn-kill-atpt (&optional no-delimiters) 
  "Kills isbn at point if any. "
  (interactive "*P")
  (ar-th-kill 'isbn no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-isbn-atpt 'ar-isbn-left-right-singlequote-atpt)
;;;###autoload
(defun ar-isbn-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'isbn no-delimiters (interactive-p)))

(defalias 'ar-parentize-isbn-atpt 'ar-isbn-parentize-atpt)
;;;###autoload
(defun ar-isbn-parentize-atpt (&optional no-delimiters) 
  "Parentizes isbn at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'isbn no-delimiters (interactive-p)))

(defalias 'ar-separate-isbn-atpt 'ar-isbn-separate-atpt)
;;;###autoload
(defun ar-isbn-separate-atpt (&optional no-delimiters) 
  "Separates isbn at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'isbn no-delimiters (interactive-p)))

(defalias 'ar-singlequote-isbn-atpt 'ar-isbn-singlequote-atpt)
;;;###autoload
(defun ar-isbn-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes isbn at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'isbn no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-isbn-atpt 'ar-isbn-triplequote-dq-atpt)
;;;###autoload
(defun ar-isbn-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around isbn. "
  (interactive "*p")
  (ar-th-triplequote-dq 'isbn no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-isbn-atpt 'ar-isbn-triplequote-sq-atpt)
;;;###autoload
(defun ar-isbn-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around isbn. "
  (interactive "*p")
  (ar-th-triplequote-sq 'isbn no-delimiters (interactive-p)))

(defalias 'ar-trim-isbn-atpt 'ar-isbn-trim-atpt)
;;;###autoload
(defun ar-isbn-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'isbn t t)) 
    (ar-th-trim 'isbn t t)))

(defalias 'ar-trim-left-isbn-atpt 'ar-isbn-left-trim-atpt)
;;;###autoload
(defun ar-isbn-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'isbn t nil))
    (ar-th-trim 'isbn t nil)))

(defalias 'ar-trim-right-isbn-atpt 'ar-isbn-right-trim-atpt)
;;;###autoload
(defun ar-isbn-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'isbn nil t))
    (ar-th-trim 'isbn nil t)))

(defalias 'ar-isbn-underscore-atpt 'ar-underscore-isbn-atpt)
;;;###autoload
(defun ar-underscore-isbn-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'isbn no-delimiters (interactive-p)))

(defalias 'ar-isbn-whitespace-atpt 'ar-whitespace-isbn-atpt)
;;;###autoload
(defun ar-whitespace-isbn-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'isbn nil t))

(defalias 'ar-forward-isbn-atpt 'ar-isbn-forward-atpt)
;;;###autoload
(defun ar-isbn-forward-atpt (&optional arg) 
  "Moves forward over isbn at point if any, does nothing otherwise.
Returns end position of isbn "
  (interactive "p")
  (ar-th-forward 'isbn arg (interactive-p)))

(defalias 'ar-backward-isbn-atpt 'ar-isbn-backward-atpt)
;;;###autoload
(defun ar-isbn-backward-atpt (&optional arg) 
  "Moves backward over isbn before point if any, does nothing otherwise.
Returns beginning position of isbn "
  (interactive "p")
  (ar-th-backward 'isbn arg (interactive-p)))

(defalias 'ar-transpose-isbn-atpt 'ar-isbn-transpose-atpt)
;;;###autoload
(defun ar-isbn-transpose-atpt (&optional arg) 
  "Transposes isbn with isbn before point if any. "
  (interactive "*p")
  (ar-th-transpose 'isbn arg (interactive-p)))

(defalias 'ar-sort-isbn-atpt 'ar-isbn-sort-atpt)
;;;###autoload
(defun ar-isbn-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts isbns in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'isbn reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-isbn-atpt 'ar-isbn-check-atpt)
;;;###autoload
(defun ar-isbn-check-atpt () 
  "Return t if a isbn at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-isbn-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-isbn-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-line-atpt (&optional arg no-delimiters) 
  "Returns line at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'line arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-line-atpt 'ar-line-bounds-atpt)
;;;###autoload
(defun ar-line-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of line if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'line no-delimiters (interactive-p)))

;;;###autoload
(defun ar-line-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position line at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'line no-delimiters (interactive-p)))

;;;###autoload
(defun ar-line-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of line at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'line no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-line-atpt 'ar-line-beginning-atpt)
;;;###autoload
(defun ar-line-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class line at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'line no-delimiters (interactive-p)))

(defalias 'ar-end-of-line-atpt 'ar-line-end-atpt)
;;;###autoload
(defun ar-line-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class line at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'line no-delimiters (interactive-p)))

(defalias 'ar-in-line-p-atpt 'ar-line-in-p-atpt)
;;;###autoload
(defun ar-line-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of line at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'line no-delimiters (interactive-p)))

(defalias 'ar-length-of-line-atpt 'ar-line-length-atpt)
;;;###autoload
(defun ar-line-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class line at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'line no-delimiters (interactive-p)))

(defalias 'ar-copy-line-atpt 'ar-line-copy-atpt)
;;;###autoload
(defun ar-line-copy-atpt (&optional no-delimiters) 
  "Returns a copy of line at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'line no-delimiters (interactive-p)))

(defalias 'ar-delete-line-in-region 'ar-line-delete-in-region)
;;;###autoload
(defun ar-line-delete-in-region (beg end) 
  "Deletes line at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'line beg end (interactive-p)))

;;;###autoload
(defun ar-blok-line-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around line.
  Returns blok or nil if no line at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'line no-delimiters (interactive-p)))

(defalias 'ar-escape-line-atpt 'ar-line-escape-atpt)
;;;###autoload
(defun ar-line-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted line at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'line no-delimiters))

(defalias 'ar-doublequote-line-atpt 'ar-line-doublequote-atpt)
;;;###autoload
(defun ar-line-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes line at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'line no-delimiters (interactive-p)))

(defalias 'ar-slash-line-atpt 'ar-line-slash-atpt)
;;;###autoload
(defun ar-line-slash-atpt (&optional no-delimiters) 
  "Doublequotes line at point if any. "
  (interactive "*p")
  (ar-th-slash 'line no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-line-atpt 'ar-line-double-backslash-atpt)
;;;###autoload
(defun ar-line-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around line at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'line no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-line-atpt 'ar-line-doubleslash-atpt)
;;;###autoload
(defun ar-line-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around line at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'line no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-line-atpt 'ar-line-doubleslashparen-atpt)
;;;###autoload
(defun ar-line-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around line at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'line no-delimiters (interactive-p)))

(defalias 'ar-slashparen-line-atpt 'ar-line-slashparen-atpt)
;;;###autoload
(defun ar-line-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around line at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'line no-delimiters (interactive-p)))

(defalias 'ar-dollar-line-atpt 'ar-line-dollar-atpt)
;;;###autoload
(defun ar-line-dollar-atpt (&optional no-delimiters) 
  "Doublequotes line at point if any. "
  (interactive "*p")
  (ar-th-dollar 'line no-delimiters (interactive-p)))

(defalias 'ar-equalize-line-atpt 'ar-line-equalize-atpt)
;;;###autoload
(defun ar-line-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around line at point if any. "
  (interactive "*p")
  (ar-th-equalize 'line no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-line-atpt 'ar-line-greater-angle-atpt)
;;;###autoload
(defun ar-line-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for line after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'line no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-line-atpt 'ar-line-lesser-angle-atpt)
;;;###autoload
(defun ar-line-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for line after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'line no-delimiters (interactive-p)))

(defalias 'ar-backslash-line-atpt 'ar-line-backslash-atpt)
;;;###autoload
(defun ar-line-backslash-atpt (&optional no-delimiters) 
  "Backslash line at point if any. "
  (interactive "*p")
  (ar-th-backslash 'line no-delimiters (interactive-p))) 

(defalias 'ar-brace-line-atpt 'ar-line-brace-atpt)
;;;###autoload
(defun ar-line-brace-atpt (&optional no-delimiters) 
  "Braces line at point if any. "
  (interactive "*p")
  (ar-th-brace 'line no-delimiters (interactive-p)))

(defalias 'ar-bracket-line-atpt 'ar-line-bracket-atpt)
;;;###autoload
(defun ar-line-bracket-atpt (&optional no-delimiters) 
  "Brackets line after point if any. "
  (interactive "*p")
  (ar-th-bracket 'line no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-line-atpt (&optional no-delimiters) 
  "Comments line at point if any. "
  (interactive "*p")
  (ar-th-comment 'line no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-line-atpt (&optional no-delimiters) 
  "Put a comma after line at point if any. "
  (interactive "*p")
  (ar-th-commatize 'line no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-line-atpt (&optional no-delimiters) 
  "Put a singlequote before line at point if any. "
  (interactive "*p")
  (ar-th-quote 'line no-delimiters (interactive-p)))

(defalias 'ar-hyphen-line-atpt 'ar-line-hyphen-atpt)
;;;###autoload
(defun ar-line-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around line at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'line no-delimiters (interactive-p)))

(defalias 'ar-mark-line-atpt 'ar-line-mark-atpt)
;;;###autoload
(defun ar-line-mark-atpt () 
  "Marks line at point if any. "
  (interactive)
  (ar-th-mark 'line))

(defalias 'ar-hide-line-atpt 'ar-line-hide-atpt)
;;;###autoload
(defun ar-line-hide-atpt () 
  "Hides line at point. "
  (interactive)
  (ar-th-hide 'line))

(defalias 'ar-show-line-atpt 'ar-line-show-atpt)
;;;###autoload
(defun ar-line-show-atpt () 
  "Shows hidden line at point. "
  (interactive)
  (ar-th-show 'line))

(defalias 'ar-hide-show-line-atpt 'ar-line-hide-show-atpt)
;;;###autoload
(defun ar-line-hide-show-atpt () 
  "Alternatively hides or shows line at point. "
  (interactive)
  (ar-th-hide-show 'line))

(defalias 'ar-highlight-line-atpt-mode 'ar-line-highlight-atpt-mode)

(defun ar-line-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles line-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'line no-delimiters (interactive-p)))

(defalias 'ar-kill-line-atpt 'ar-line-kill-atpt)
;;;###autoload
(defun ar-line-kill-atpt (&optional no-delimiters) 
  "Kills line at point if any. "
  (interactive "*P")
  (ar-th-kill 'line no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-line-atpt 'ar-line-left-right-singlequote-atpt)
;;;###autoload
(defun ar-line-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'line no-delimiters (interactive-p)))

(defalias 'ar-parentize-line-atpt 'ar-line-parentize-atpt)
;;;###autoload
(defun ar-line-parentize-atpt (&optional no-delimiters) 
  "Parentizes line at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'line no-delimiters (interactive-p)))

(defalias 'ar-separate-line-atpt 'ar-line-separate-atpt)
;;;###autoload
(defun ar-line-separate-atpt (&optional no-delimiters) 
  "Separates line at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'line no-delimiters (interactive-p)))

(defalias 'ar-singlequote-line-atpt 'ar-line-singlequote-atpt)
;;;###autoload
(defun ar-line-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes line at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'line no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-line-atpt 'ar-line-triplequote-dq-atpt)
;;;###autoload
(defun ar-line-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around line. "
  (interactive "*p")
  (ar-th-triplequote-dq 'line no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-line-atpt 'ar-line-triplequote-sq-atpt)
;;;###autoload
(defun ar-line-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around line. "
  (interactive "*p")
  (ar-th-triplequote-sq 'line no-delimiters (interactive-p)))

(defalias 'ar-trim-line-atpt 'ar-line-trim-atpt)
;;;###autoload
(defun ar-line-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'line t t)) 
    (ar-th-trim 'line t t)))

(defalias 'ar-trim-left-line-atpt 'ar-line-left-trim-atpt)
;;;###autoload
(defun ar-line-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'line t nil))
    (ar-th-trim 'line t nil)))

(defalias 'ar-trim-right-line-atpt 'ar-line-right-trim-atpt)
;;;###autoload
(defun ar-line-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'line nil t))
    (ar-th-trim 'line nil t)))

(defalias 'ar-line-underscore-atpt 'ar-underscore-line-atpt)
;;;###autoload
(defun ar-underscore-line-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'line no-delimiters (interactive-p)))

(defalias 'ar-line-whitespace-atpt 'ar-whitespace-line-atpt)
;;;###autoload
(defun ar-whitespace-line-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'line nil t))

(defalias 'ar-forward-line-atpt 'ar-line-forward-atpt)
;;;###autoload
(defun ar-line-forward-atpt (&optional arg) 
  "Moves forward over line at point if any, does nothing otherwise.
Returns end position of line "
  (interactive "p")
  (ar-th-forward 'line arg (interactive-p)))

(defalias 'ar-backward-line-atpt 'ar-line-backward-atpt)
;;;###autoload
(defun ar-line-backward-atpt (&optional arg) 
  "Moves backward over line before point if any, does nothing otherwise.
Returns beginning position of line "
  (interactive "p")
  (ar-th-backward 'line arg (interactive-p)))

(defalias 'ar-transpose-line-atpt 'ar-line-transpose-atpt)
;;;###autoload
(defun ar-line-transpose-atpt (&optional arg) 
  "Transposes line with line before point if any. "
  (interactive "*p")
  (ar-th-transpose 'line arg (interactive-p)))

(defalias 'ar-sort-line-atpt 'ar-line-sort-atpt)
;;;###autoload
(defun ar-line-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts lines in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'line reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-line-atpt 'ar-line-check-atpt)
;;;###autoload
(defun ar-line-check-atpt () 
  "Return t if a line at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-line-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-line-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-name-atpt (&optional arg no-delimiters) 
  "Returns name at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'name arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-name-atpt 'ar-name-bounds-atpt)
;;;###autoload
(defun ar-name-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of name if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'name no-delimiters (interactive-p)))

;;;###autoload
(defun ar-name-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position name at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'name no-delimiters (interactive-p)))

;;;###autoload
(defun ar-name-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of name at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'name no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-name-atpt 'ar-name-beginning-atpt)
;;;###autoload
(defun ar-name-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class name at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'name no-delimiters (interactive-p)))

(defalias 'ar-end-of-name-atpt 'ar-name-end-atpt)
;;;###autoload
(defun ar-name-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class name at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'name no-delimiters (interactive-p)))

(defalias 'ar-in-name-p-atpt 'ar-name-in-p-atpt)
;;;###autoload
(defun ar-name-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of name at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'name no-delimiters (interactive-p)))

(defalias 'ar-length-of-name-atpt 'ar-name-length-atpt)
;;;###autoload
(defun ar-name-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class name at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'name no-delimiters (interactive-p)))

(defalias 'ar-copy-name-atpt 'ar-name-copy-atpt)
;;;###autoload
(defun ar-name-copy-atpt (&optional no-delimiters) 
  "Returns a copy of name at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'name no-delimiters (interactive-p)))

(defalias 'ar-delete-name-in-region 'ar-name-delete-in-region)
;;;###autoload
(defun ar-name-delete-in-region (beg end) 
  "Deletes name at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'name beg end (interactive-p)))

;;;###autoload
(defun ar-blok-name-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around name.
  Returns blok or nil if no name at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'name no-delimiters (interactive-p)))

(defalias 'ar-escape-name-atpt 'ar-name-escape-atpt)
;;;###autoload
(defun ar-name-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted name at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'name no-delimiters))

(defalias 'ar-doublequote-name-atpt 'ar-name-doublequote-atpt)
;;;###autoload
(defun ar-name-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes name at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'name no-delimiters (interactive-p)))

(defalias 'ar-slash-name-atpt 'ar-name-slash-atpt)
;;;###autoload
(defun ar-name-slash-atpt (&optional no-delimiters) 
  "Doublequotes name at point if any. "
  (interactive "*p")
  (ar-th-slash 'name no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-name-atpt 'ar-name-double-backslash-atpt)
;;;###autoload
(defun ar-name-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around name at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'name no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-name-atpt 'ar-name-doubleslash-atpt)
;;;###autoload
(defun ar-name-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around name at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'name no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-name-atpt 'ar-name-doubleslashparen-atpt)
;;;###autoload
(defun ar-name-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around name at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'name no-delimiters (interactive-p)))

(defalias 'ar-slashparen-name-atpt 'ar-name-slashparen-atpt)
;;;###autoload
(defun ar-name-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around name at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'name no-delimiters (interactive-p)))

(defalias 'ar-dollar-name-atpt 'ar-name-dollar-atpt)
;;;###autoload
(defun ar-name-dollar-atpt (&optional no-delimiters) 
  "Doublequotes name at point if any. "
  (interactive "*p")
  (ar-th-dollar 'name no-delimiters (interactive-p)))

(defalias 'ar-equalize-name-atpt 'ar-name-equalize-atpt)
;;;###autoload
(defun ar-name-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around name at point if any. "
  (interactive "*p")
  (ar-th-equalize 'name no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-name-atpt 'ar-name-greater-angle-atpt)
;;;###autoload
(defun ar-name-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for name after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'name no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-name-atpt 'ar-name-lesser-angle-atpt)
;;;###autoload
(defun ar-name-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for name after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'name no-delimiters (interactive-p)))

(defalias 'ar-backslash-name-atpt 'ar-name-backslash-atpt)
;;;###autoload
(defun ar-name-backslash-atpt (&optional no-delimiters) 
  "Backslash name at point if any. "
  (interactive "*p")
  (ar-th-backslash 'name no-delimiters (interactive-p))) 

(defalias 'ar-brace-name-atpt 'ar-name-brace-atpt)
;;;###autoload
(defun ar-name-brace-atpt (&optional no-delimiters) 
  "Braces name at point if any. "
  (interactive "*p")
  (ar-th-brace 'name no-delimiters (interactive-p)))

(defalias 'ar-bracket-name-atpt 'ar-name-bracket-atpt)
;;;###autoload
(defun ar-name-bracket-atpt (&optional no-delimiters) 
  "Brackets name after point if any. "
  (interactive "*p")
  (ar-th-bracket 'name no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-name-atpt (&optional no-delimiters) 
  "Comments name at point if any. "
  (interactive "*p")
  (ar-th-comment 'name no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-name-atpt (&optional no-delimiters) 
  "Put a comma after name at point if any. "
  (interactive "*p")
  (ar-th-commatize 'name no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-name-atpt (&optional no-delimiters) 
  "Put a singlequote before name at point if any. "
  (interactive "*p")
  (ar-th-quote 'name no-delimiters (interactive-p)))

(defalias 'ar-hyphen-name-atpt 'ar-name-hyphen-atpt)
;;;###autoload
(defun ar-name-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around name at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'name no-delimiters (interactive-p)))

(defalias 'ar-mark-name-atpt 'ar-name-mark-atpt)
;;;###autoload
(defun ar-name-mark-atpt () 
  "Marks name at point if any. "
  (interactive)
  (ar-th-mark 'name))

(defalias 'ar-hide-name-atpt 'ar-name-hide-atpt)
;;;###autoload
(defun ar-name-hide-atpt () 
  "Hides name at point. "
  (interactive)
  (ar-th-hide 'name))

(defalias 'ar-show-name-atpt 'ar-name-show-atpt)
;;;###autoload
(defun ar-name-show-atpt () 
  "Shows hidden name at point. "
  (interactive)
  (ar-th-show 'name))

(defalias 'ar-hide-show-name-atpt 'ar-name-hide-show-atpt)
;;;###autoload
(defun ar-name-hide-show-atpt () 
  "Alternatively hides or shows name at point. "
  (interactive)
  (ar-th-hide-show 'name))

(defalias 'ar-highlight-name-atpt-mode 'ar-name-highlight-atpt-mode)

(defun ar-name-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles name-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'name no-delimiters (interactive-p)))

(defalias 'ar-kill-name-atpt 'ar-name-kill-atpt)
;;;###autoload
(defun ar-name-kill-atpt (&optional no-delimiters) 
  "Kills name at point if any. "
  (interactive "*P")
  (ar-th-kill 'name no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-name-atpt 'ar-name-left-right-singlequote-atpt)
;;;###autoload
(defun ar-name-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'name no-delimiters (interactive-p)))

(defalias 'ar-parentize-name-atpt 'ar-name-parentize-atpt)
;;;###autoload
(defun ar-name-parentize-atpt (&optional no-delimiters) 
  "Parentizes name at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'name no-delimiters (interactive-p)))

(defalias 'ar-separate-name-atpt 'ar-name-separate-atpt)
;;;###autoload
(defun ar-name-separate-atpt (&optional no-delimiters) 
  "Separates name at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'name no-delimiters (interactive-p)))

(defalias 'ar-singlequote-name-atpt 'ar-name-singlequote-atpt)
;;;###autoload
(defun ar-name-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes name at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'name no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-name-atpt 'ar-name-triplequote-dq-atpt)
;;;###autoload
(defun ar-name-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around name. "
  (interactive "*p")
  (ar-th-triplequote-dq 'name no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-name-atpt 'ar-name-triplequote-sq-atpt)
;;;###autoload
(defun ar-name-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around name. "
  (interactive "*p")
  (ar-th-triplequote-sq 'name no-delimiters (interactive-p)))

(defalias 'ar-trim-name-atpt 'ar-name-trim-atpt)
;;;###autoload
(defun ar-name-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'name t t)) 
    (ar-th-trim 'name t t)))

(defalias 'ar-trim-left-name-atpt 'ar-name-left-trim-atpt)
;;;###autoload
(defun ar-name-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'name t nil))
    (ar-th-trim 'name t nil)))

(defalias 'ar-trim-right-name-atpt 'ar-name-right-trim-atpt)
;;;###autoload
(defun ar-name-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'name nil t))
    (ar-th-trim 'name nil t)))

(defalias 'ar-name-underscore-atpt 'ar-underscore-name-atpt)
;;;###autoload
(defun ar-underscore-name-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'name no-delimiters (interactive-p)))

(defalias 'ar-name-whitespace-atpt 'ar-whitespace-name-atpt)
;;;###autoload
(defun ar-whitespace-name-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'name nil t))

(defalias 'ar-forward-name-atpt 'ar-name-forward-atpt)
;;;###autoload
(defun ar-name-forward-atpt (&optional arg) 
  "Moves forward over name at point if any, does nothing otherwise.
Returns end position of name "
  (interactive "p")
  (ar-th-forward 'name arg (interactive-p)))

(defalias 'ar-backward-name-atpt 'ar-name-backward-atpt)
;;;###autoload
(defun ar-name-backward-atpt (&optional arg) 
  "Moves backward over name before point if any, does nothing otherwise.
Returns beginning position of name "
  (interactive "p")
  (ar-th-backward 'name arg (interactive-p)))

(defalias 'ar-transpose-name-atpt 'ar-name-transpose-atpt)
;;;###autoload
(defun ar-name-transpose-atpt (&optional arg) 
  "Transposes name with name before point if any. "
  (interactive "*p")
  (ar-th-transpose 'name arg (interactive-p)))

(defalias 'ar-sort-name-atpt 'ar-name-sort-atpt)
;;;###autoload
(defun ar-name-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts names in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'name reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-name-atpt 'ar-name-check-atpt)
;;;###autoload
(defun ar-name-check-atpt () 
  "Return t if a name at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-name-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-name-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-number-atpt (&optional arg no-delimiters) 
  "Returns number at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'number arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-number-atpt 'ar-number-bounds-atpt)
;;;###autoload
(defun ar-number-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of number if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'number no-delimiters (interactive-p)))

;;;###autoload
(defun ar-number-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position number at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'number no-delimiters (interactive-p)))

;;;###autoload
(defun ar-number-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of number at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'number no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-number-atpt 'ar-number-beginning-atpt)
;;;###autoload
(defun ar-number-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class number at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'number no-delimiters (interactive-p)))

(defalias 'ar-end-of-number-atpt 'ar-number-end-atpt)
;;;###autoload
(defun ar-number-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class number at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'number no-delimiters (interactive-p)))

(defalias 'ar-in-number-p-atpt 'ar-number-in-p-atpt)
;;;###autoload
(defun ar-number-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of number at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'number no-delimiters (interactive-p)))

(defalias 'ar-length-of-number-atpt 'ar-number-length-atpt)
;;;###autoload
(defun ar-number-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class number at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'number no-delimiters (interactive-p)))

(defalias 'ar-copy-number-atpt 'ar-number-copy-atpt)
;;;###autoload
(defun ar-number-copy-atpt (&optional no-delimiters) 
  "Returns a copy of number at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'number no-delimiters (interactive-p)))

(defalias 'ar-delete-number-in-region 'ar-number-delete-in-region)
;;;###autoload
(defun ar-number-delete-in-region (beg end) 
  "Deletes number at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'number beg end (interactive-p)))

;;;###autoload
(defun ar-blok-number-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around number.
  Returns blok or nil if no number at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'number no-delimiters (interactive-p)))

(defalias 'ar-escape-number-atpt 'ar-number-escape-atpt)
;;;###autoload
(defun ar-number-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted number at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'number no-delimiters))

(defalias 'ar-doublequote-number-atpt 'ar-number-doublequote-atpt)
;;;###autoload
(defun ar-number-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes number at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'number no-delimiters (interactive-p)))

(defalias 'ar-slash-number-atpt 'ar-number-slash-atpt)
;;;###autoload
(defun ar-number-slash-atpt (&optional no-delimiters) 
  "Doublequotes number at point if any. "
  (interactive "*p")
  (ar-th-slash 'number no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-number-atpt 'ar-number-double-backslash-atpt)
;;;###autoload
(defun ar-number-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around number at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'number no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-number-atpt 'ar-number-doubleslash-atpt)
;;;###autoload
(defun ar-number-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around number at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'number no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-number-atpt 'ar-number-doubleslashparen-atpt)
;;;###autoload
(defun ar-number-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around number at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'number no-delimiters (interactive-p)))

(defalias 'ar-slashparen-number-atpt 'ar-number-slashparen-atpt)
;;;###autoload
(defun ar-number-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around number at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'number no-delimiters (interactive-p)))

(defalias 'ar-dollar-number-atpt 'ar-number-dollar-atpt)
;;;###autoload
(defun ar-number-dollar-atpt (&optional no-delimiters) 
  "Doublequotes number at point if any. "
  (interactive "*p")
  (ar-th-dollar 'number no-delimiters (interactive-p)))

(defalias 'ar-equalize-number-atpt 'ar-number-equalize-atpt)
;;;###autoload
(defun ar-number-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around number at point if any. "
  (interactive "*p")
  (ar-th-equalize 'number no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-number-atpt 'ar-number-greater-angle-atpt)
;;;###autoload
(defun ar-number-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for number after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'number no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-number-atpt 'ar-number-lesser-angle-atpt)
;;;###autoload
(defun ar-number-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for number after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'number no-delimiters (interactive-p)))

(defalias 'ar-backslash-number-atpt 'ar-number-backslash-atpt)
;;;###autoload
(defun ar-number-backslash-atpt (&optional no-delimiters) 
  "Backslash number at point if any. "
  (interactive "*p")
  (ar-th-backslash 'number no-delimiters (interactive-p))) 

(defalias 'ar-brace-number-atpt 'ar-number-brace-atpt)
;;;###autoload
(defun ar-number-brace-atpt (&optional no-delimiters) 
  "Braces number at point if any. "
  (interactive "*p")
  (ar-th-brace 'number no-delimiters (interactive-p)))

(defalias 'ar-bracket-number-atpt 'ar-number-bracket-atpt)
;;;###autoload
(defun ar-number-bracket-atpt (&optional no-delimiters) 
  "Brackets number after point if any. "
  (interactive "*p")
  (ar-th-bracket 'number no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-number-atpt (&optional no-delimiters) 
  "Comments number at point if any. "
  (interactive "*p")
  (ar-th-comment 'number no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-number-atpt (&optional no-delimiters) 
  "Put a comma after number at point if any. "
  (interactive "*p")
  (ar-th-commatize 'number no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-number-atpt (&optional no-delimiters) 
  "Put a singlequote before number at point if any. "
  (interactive "*p")
  (ar-th-quote 'number no-delimiters (interactive-p)))

(defalias 'ar-hyphen-number-atpt 'ar-number-hyphen-atpt)
;;;###autoload
(defun ar-number-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around number at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'number no-delimiters (interactive-p)))

(defalias 'ar-mark-number-atpt 'ar-number-mark-atpt)
;;;###autoload
(defun ar-number-mark-atpt () 
  "Marks number at point if any. "
  (interactive)
  (ar-th-mark 'number))

(defalias 'ar-hide-number-atpt 'ar-number-hide-atpt)
;;;###autoload
(defun ar-number-hide-atpt () 
  "Hides number at point. "
  (interactive)
  (ar-th-hide 'number))

(defalias 'ar-show-number-atpt 'ar-number-show-atpt)
;;;###autoload
(defun ar-number-show-atpt () 
  "Shows hidden number at point. "
  (interactive)
  (ar-th-show 'number))

(defalias 'ar-hide-show-number-atpt 'ar-number-hide-show-atpt)
;;;###autoload
(defun ar-number-hide-show-atpt () 
  "Alternatively hides or shows number at point. "
  (interactive)
  (ar-th-hide-show 'number))

(defalias 'ar-highlight-number-atpt-mode 'ar-number-highlight-atpt-mode)

(defun ar-number-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles number-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'number no-delimiters (interactive-p)))

(defalias 'ar-kill-number-atpt 'ar-number-kill-atpt)
;;;###autoload
(defun ar-number-kill-atpt (&optional no-delimiters) 
  "Kills number at point if any. "
  (interactive "*P")
  (ar-th-kill 'number no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-number-atpt 'ar-number-left-right-singlequote-atpt)
;;;###autoload
(defun ar-number-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'number no-delimiters (interactive-p)))

(defalias 'ar-parentize-number-atpt 'ar-number-parentize-atpt)
;;;###autoload
(defun ar-number-parentize-atpt (&optional no-delimiters) 
  "Parentizes number at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'number no-delimiters (interactive-p)))

(defalias 'ar-separate-number-atpt 'ar-number-separate-atpt)
;;;###autoload
(defun ar-number-separate-atpt (&optional no-delimiters) 
  "Separates number at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'number no-delimiters (interactive-p)))

(defalias 'ar-singlequote-number-atpt 'ar-number-singlequote-atpt)
;;;###autoload
(defun ar-number-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes number at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'number no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-number-atpt 'ar-number-triplequote-dq-atpt)
;;;###autoload
(defun ar-number-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around number. "
  (interactive "*p")
  (ar-th-triplequote-dq 'number no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-number-atpt 'ar-number-triplequote-sq-atpt)
;;;###autoload
(defun ar-number-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around number. "
  (interactive "*p")
  (ar-th-triplequote-sq 'number no-delimiters (interactive-p)))

(defalias 'ar-trim-number-atpt 'ar-number-trim-atpt)
;;;###autoload
(defun ar-number-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'number t t)) 
    (ar-th-trim 'number t t)))

(defalias 'ar-trim-left-number-atpt 'ar-number-left-trim-atpt)
;;;###autoload
(defun ar-number-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'number t nil))
    (ar-th-trim 'number t nil)))

(defalias 'ar-trim-right-number-atpt 'ar-number-right-trim-atpt)
;;;###autoload
(defun ar-number-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'number nil t))
    (ar-th-trim 'number nil t)))

(defalias 'ar-number-underscore-atpt 'ar-underscore-number-atpt)
;;;###autoload
(defun ar-underscore-number-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'number no-delimiters (interactive-p)))

(defalias 'ar-number-whitespace-atpt 'ar-whitespace-number-atpt)
;;;###autoload
(defun ar-whitespace-number-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'number nil t))

(defalias 'ar-forward-number-atpt 'ar-number-forward-atpt)
;;;###autoload
(defun ar-number-forward-atpt (&optional arg) 
  "Moves forward over number at point if any, does nothing otherwise.
Returns end position of number "
  (interactive "p")
  (ar-th-forward 'number arg (interactive-p)))

(defalias 'ar-backward-number-atpt 'ar-number-backward-atpt)
;;;###autoload
(defun ar-number-backward-atpt (&optional arg) 
  "Moves backward over number before point if any, does nothing otherwise.
Returns beginning position of number "
  (interactive "p")
  (ar-th-backward 'number arg (interactive-p)))

(defalias 'ar-transpose-number-atpt 'ar-number-transpose-atpt)
;;;###autoload
(defun ar-number-transpose-atpt (&optional arg) 
  "Transposes number with number before point if any. "
  (interactive "*p")
  (ar-th-transpose 'number arg (interactive-p)))

(defalias 'ar-sort-number-atpt 'ar-number-sort-atpt)
;;;###autoload
(defun ar-number-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts numbers in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'number reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-number-atpt 'ar-number-check-atpt)
;;;###autoload
(defun ar-number-check-atpt () 
  "Return t if a number at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-number-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-number-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-page-atpt (&optional arg no-delimiters) 
  "Returns page at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'page arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-page-atpt 'ar-page-bounds-atpt)
;;;###autoload
(defun ar-page-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of page if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'page no-delimiters (interactive-p)))

;;;###autoload
(defun ar-page-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position page at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'page no-delimiters (interactive-p)))

;;;###autoload
(defun ar-page-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of page at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'page no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-page-atpt 'ar-page-beginning-atpt)
;;;###autoload
(defun ar-page-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class page at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'page no-delimiters (interactive-p)))

(defalias 'ar-end-of-page-atpt 'ar-page-end-atpt)
;;;###autoload
(defun ar-page-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class page at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'page no-delimiters (interactive-p)))

(defalias 'ar-in-page-p-atpt 'ar-page-in-p-atpt)
;;;###autoload
(defun ar-page-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of page at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'page no-delimiters (interactive-p)))

(defalias 'ar-length-of-page-atpt 'ar-page-length-atpt)
;;;###autoload
(defun ar-page-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class page at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'page no-delimiters (interactive-p)))

(defalias 'ar-copy-page-atpt 'ar-page-copy-atpt)
;;;###autoload
(defun ar-page-copy-atpt (&optional no-delimiters) 
  "Returns a copy of page at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'page no-delimiters (interactive-p)))

(defalias 'ar-delete-page-in-region 'ar-page-delete-in-region)
;;;###autoload
(defun ar-page-delete-in-region (beg end) 
  "Deletes page at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'page beg end (interactive-p)))

;;;###autoload
(defun ar-blok-page-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around page.
  Returns blok or nil if no page at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'page no-delimiters (interactive-p)))

(defalias 'ar-escape-page-atpt 'ar-page-escape-atpt)
;;;###autoload
(defun ar-page-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted page at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'page no-delimiters))

(defalias 'ar-doublequote-page-atpt 'ar-page-doublequote-atpt)
;;;###autoload
(defun ar-page-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes page at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'page no-delimiters (interactive-p)))

(defalias 'ar-slash-page-atpt 'ar-page-slash-atpt)
;;;###autoload
(defun ar-page-slash-atpt (&optional no-delimiters) 
  "Doublequotes page at point if any. "
  (interactive "*p")
  (ar-th-slash 'page no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-page-atpt 'ar-page-double-backslash-atpt)
;;;###autoload
(defun ar-page-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around page at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'page no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-page-atpt 'ar-page-doubleslash-atpt)
;;;###autoload
(defun ar-page-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around page at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'page no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-page-atpt 'ar-page-doubleslashparen-atpt)
;;;###autoload
(defun ar-page-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around page at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'page no-delimiters (interactive-p)))

(defalias 'ar-slashparen-page-atpt 'ar-page-slashparen-atpt)
;;;###autoload
(defun ar-page-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around page at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'page no-delimiters (interactive-p)))

(defalias 'ar-dollar-page-atpt 'ar-page-dollar-atpt)
;;;###autoload
(defun ar-page-dollar-atpt (&optional no-delimiters) 
  "Doublequotes page at point if any. "
  (interactive "*p")
  (ar-th-dollar 'page no-delimiters (interactive-p)))

(defalias 'ar-equalize-page-atpt 'ar-page-equalize-atpt)
;;;###autoload
(defun ar-page-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around page at point if any. "
  (interactive "*p")
  (ar-th-equalize 'page no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-page-atpt 'ar-page-greater-angle-atpt)
;;;###autoload
(defun ar-page-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for page after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'page no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-page-atpt 'ar-page-lesser-angle-atpt)
;;;###autoload
(defun ar-page-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for page after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'page no-delimiters (interactive-p)))

(defalias 'ar-backslash-page-atpt 'ar-page-backslash-atpt)
;;;###autoload
(defun ar-page-backslash-atpt (&optional no-delimiters) 
  "Backslash page at point if any. "
  (interactive "*p")
  (ar-th-backslash 'page no-delimiters (interactive-p))) 

(defalias 'ar-brace-page-atpt 'ar-page-brace-atpt)
;;;###autoload
(defun ar-page-brace-atpt (&optional no-delimiters) 
  "Braces page at point if any. "
  (interactive "*p")
  (ar-th-brace 'page no-delimiters (interactive-p)))

(defalias 'ar-bracket-page-atpt 'ar-page-bracket-atpt)
;;;###autoload
(defun ar-page-bracket-atpt (&optional no-delimiters) 
  "Brackets page after point if any. "
  (interactive "*p")
  (ar-th-bracket 'page no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-page-atpt (&optional no-delimiters) 
  "Comments page at point if any. "
  (interactive "*p")
  (ar-th-comment 'page no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-page-atpt (&optional no-delimiters) 
  "Put a comma after page at point if any. "
  (interactive "*p")
  (ar-th-commatize 'page no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-page-atpt (&optional no-delimiters) 
  "Put a singlequote before page at point if any. "
  (interactive "*p")
  (ar-th-quote 'page no-delimiters (interactive-p)))

(defalias 'ar-hyphen-page-atpt 'ar-page-hyphen-atpt)
;;;###autoload
(defun ar-page-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around page at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'page no-delimiters (interactive-p)))

(defalias 'ar-mark-page-atpt 'ar-page-mark-atpt)
;;;###autoload
(defun ar-page-mark-atpt () 
  "Marks page at point if any. "
  (interactive)
  (ar-th-mark 'page))

(defalias 'ar-hide-page-atpt 'ar-page-hide-atpt)
;;;###autoload
(defun ar-page-hide-atpt () 
  "Hides page at point. "
  (interactive)
  (ar-th-hide 'page))

(defalias 'ar-show-page-atpt 'ar-page-show-atpt)
;;;###autoload
(defun ar-page-show-atpt () 
  "Shows hidden page at point. "
  (interactive)
  (ar-th-show 'page))

(defalias 'ar-hide-show-page-atpt 'ar-page-hide-show-atpt)
;;;###autoload
(defun ar-page-hide-show-atpt () 
  "Alternatively hides or shows page at point. "
  (interactive)
  (ar-th-hide-show 'page))

(defalias 'ar-highlight-page-atpt-mode 'ar-page-highlight-atpt-mode)

(defun ar-page-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles page-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'page no-delimiters (interactive-p)))

(defalias 'ar-kill-page-atpt 'ar-page-kill-atpt)
;;;###autoload
(defun ar-page-kill-atpt (&optional no-delimiters) 
  "Kills page at point if any. "
  (interactive "*P")
  (ar-th-kill 'page no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-page-atpt 'ar-page-left-right-singlequote-atpt)
;;;###autoload
(defun ar-page-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'page no-delimiters (interactive-p)))

(defalias 'ar-parentize-page-atpt 'ar-page-parentize-atpt)
;;;###autoload
(defun ar-page-parentize-atpt (&optional no-delimiters) 
  "Parentizes page at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'page no-delimiters (interactive-p)))

(defalias 'ar-separate-page-atpt 'ar-page-separate-atpt)
;;;###autoload
(defun ar-page-separate-atpt (&optional no-delimiters) 
  "Separates page at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'page no-delimiters (interactive-p)))

(defalias 'ar-singlequote-page-atpt 'ar-page-singlequote-atpt)
;;;###autoload
(defun ar-page-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes page at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'page no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-page-atpt 'ar-page-triplequote-dq-atpt)
;;;###autoload
(defun ar-page-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around page. "
  (interactive "*p")
  (ar-th-triplequote-dq 'page no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-page-atpt 'ar-page-triplequote-sq-atpt)
;;;###autoload
(defun ar-page-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around page. "
  (interactive "*p")
  (ar-th-triplequote-sq 'page no-delimiters (interactive-p)))

(defalias 'ar-trim-page-atpt 'ar-page-trim-atpt)
;;;###autoload
(defun ar-page-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'page t t)) 
    (ar-th-trim 'page t t)))

(defalias 'ar-trim-left-page-atpt 'ar-page-left-trim-atpt)
;;;###autoload
(defun ar-page-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'page t nil))
    (ar-th-trim 'page t nil)))

(defalias 'ar-trim-right-page-atpt 'ar-page-right-trim-atpt)
;;;###autoload
(defun ar-page-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'page nil t))
    (ar-th-trim 'page nil t)))

(defalias 'ar-page-underscore-atpt 'ar-underscore-page-atpt)
;;;###autoload
(defun ar-underscore-page-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'page no-delimiters (interactive-p)))

(defalias 'ar-page-whitespace-atpt 'ar-whitespace-page-atpt)
;;;###autoload
(defun ar-whitespace-page-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'page nil t))

(defalias 'ar-forward-page-atpt 'ar-page-forward-atpt)
;;;###autoload
(defun ar-page-forward-atpt (&optional arg) 
  "Moves forward over page at point if any, does nothing otherwise.
Returns end position of page "
  (interactive "p")
  (ar-th-forward 'page arg (interactive-p)))

(defalias 'ar-backward-page-atpt 'ar-page-backward-atpt)
;;;###autoload
(defun ar-page-backward-atpt (&optional arg) 
  "Moves backward over page before point if any, does nothing otherwise.
Returns beginning position of page "
  (interactive "p")
  (ar-th-backward 'page arg (interactive-p)))

(defalias 'ar-transpose-page-atpt 'ar-page-transpose-atpt)
;;;###autoload
(defun ar-page-transpose-atpt (&optional arg) 
  "Transposes page with page before point if any. "
  (interactive "*p")
  (ar-th-transpose 'page arg (interactive-p)))

(defalias 'ar-sort-page-atpt 'ar-page-sort-atpt)
;;;###autoload
(defun ar-page-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts pages in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'page reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-page-atpt 'ar-page-check-atpt)
;;;###autoload
(defun ar-page-check-atpt () 
  "Return t if a page at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-page-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-page-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-paragraph-atpt (&optional arg no-delimiters) 
  "Returns paragraph at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'paragraph arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-paragraph-atpt 'ar-paragraph-bounds-atpt)
;;;###autoload
(defun ar-paragraph-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of paragraph if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'paragraph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-paragraph-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position paragraph at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'paragraph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-paragraph-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of paragraph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-paragraph-atpt 'ar-paragraph-beginning-atpt)
;;;###autoload
(defun ar-paragraph-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class paragraph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-end-of-paragraph-atpt 'ar-paragraph-end-atpt)
;;;###autoload
(defun ar-paragraph-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class paragraph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-in-paragraph-p-atpt 'ar-paragraph-in-p-atpt)
;;;###autoload
(defun ar-paragraph-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of paragraph at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-length-of-paragraph-atpt 'ar-paragraph-length-atpt)
;;;###autoload
(defun ar-paragraph-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class paragraph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-copy-paragraph-atpt 'ar-paragraph-copy-atpt)
;;;###autoload
(defun ar-paragraph-copy-atpt (&optional no-delimiters) 
  "Returns a copy of paragraph at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-delete-paragraph-in-region 'ar-paragraph-delete-in-region)
;;;###autoload
(defun ar-paragraph-delete-in-region (beg end) 
  "Deletes paragraph at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'paragraph beg end (interactive-p)))

;;;###autoload
(defun ar-blok-paragraph-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around paragraph.
  Returns blok or nil if no paragraph at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-escape-paragraph-atpt 'ar-paragraph-escape-atpt)
;;;###autoload
(defun ar-paragraph-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted paragraph at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'paragraph no-delimiters))

(defalias 'ar-doublequote-paragraph-atpt 'ar-paragraph-doublequote-atpt)
;;;###autoload
(defun ar-paragraph-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes paragraph at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-slash-paragraph-atpt 'ar-paragraph-slash-atpt)
;;;###autoload
(defun ar-paragraph-slash-atpt (&optional no-delimiters) 
  "Doublequotes paragraph at point if any. "
  (interactive "*p")
  (ar-th-slash 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-paragraph-atpt 'ar-paragraph-double-backslash-atpt)
;;;###autoload
(defun ar-paragraph-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around paragraph at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-paragraph-atpt 'ar-paragraph-doubleslash-atpt)
;;;###autoload
(defun ar-paragraph-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around paragraph at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-paragraph-atpt 'ar-paragraph-doubleslashparen-atpt)
;;;###autoload
(defun ar-paragraph-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around paragraph at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-slashparen-paragraph-atpt 'ar-paragraph-slashparen-atpt)
;;;###autoload
(defun ar-paragraph-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around paragraph at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-dollar-paragraph-atpt 'ar-paragraph-dollar-atpt)
;;;###autoload
(defun ar-paragraph-dollar-atpt (&optional no-delimiters) 
  "Doublequotes paragraph at point if any. "
  (interactive "*p")
  (ar-th-dollar 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-equalize-paragraph-atpt 'ar-paragraph-equalize-atpt)
;;;###autoload
(defun ar-paragraph-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around paragraph at point if any. "
  (interactive "*p")
  (ar-th-equalize 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-paragraph-atpt 'ar-paragraph-greater-angle-atpt)
;;;###autoload
(defun ar-paragraph-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for paragraph after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-paragraph-atpt 'ar-paragraph-lesser-angle-atpt)
;;;###autoload
(defun ar-paragraph-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for paragraph after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-backslash-paragraph-atpt 'ar-paragraph-backslash-atpt)
;;;###autoload
(defun ar-paragraph-backslash-atpt (&optional no-delimiters) 
  "Backslash paragraph at point if any. "
  (interactive "*p")
  (ar-th-backslash 'paragraph no-delimiters (interactive-p))) 

(defalias 'ar-brace-paragraph-atpt 'ar-paragraph-brace-atpt)
;;;###autoload
(defun ar-paragraph-brace-atpt (&optional no-delimiters) 
  "Braces paragraph at point if any. "
  (interactive "*p")
  (ar-th-brace 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-bracket-paragraph-atpt 'ar-paragraph-bracket-atpt)
;;;###autoload
(defun ar-paragraph-bracket-atpt (&optional no-delimiters) 
  "Brackets paragraph after point if any. "
  (interactive "*p")
  (ar-th-bracket 'paragraph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-paragraph-atpt (&optional no-delimiters) 
  "Comments paragraph at point if any. "
  (interactive "*p")
  (ar-th-comment 'paragraph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-paragraph-atpt (&optional no-delimiters) 
  "Put a comma after paragraph at point if any. "
  (interactive "*p")
  (ar-th-commatize 'paragraph no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-paragraph-atpt (&optional no-delimiters) 
  "Put a singlequote before paragraph at point if any. "
  (interactive "*p")
  (ar-th-quote 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-hyphen-paragraph-atpt 'ar-paragraph-hyphen-atpt)
;;;###autoload
(defun ar-paragraph-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around paragraph at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-mark-paragraph-atpt 'ar-paragraph-mark-atpt)
;;;###autoload
(defun ar-paragraph-mark-atpt () 
  "Marks paragraph at point if any. "
  (interactive)
  (ar-th-mark 'paragraph))

(defalias 'ar-hide-paragraph-atpt 'ar-paragraph-hide-atpt)
;;;###autoload
(defun ar-paragraph-hide-atpt () 
  "Hides paragraph at point. "
  (interactive)
  (ar-th-hide 'paragraph))

(defalias 'ar-show-paragraph-atpt 'ar-paragraph-show-atpt)
;;;###autoload
(defun ar-paragraph-show-atpt () 
  "Shows hidden paragraph at point. "
  (interactive)
  (ar-th-show 'paragraph))

(defalias 'ar-hide-show-paragraph-atpt 'ar-paragraph-hide-show-atpt)
;;;###autoload
(defun ar-paragraph-hide-show-atpt () 
  "Alternatively hides or shows paragraph at point. "
  (interactive)
  (ar-th-hide-show 'paragraph))

(defalias 'ar-highlight-paragraph-atpt-mode 'ar-paragraph-highlight-atpt-mode)

(defun ar-paragraph-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles paragraph-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-kill-paragraph-atpt 'ar-paragraph-kill-atpt)
;;;###autoload
(defun ar-paragraph-kill-atpt (&optional no-delimiters) 
  "Kills paragraph at point if any. "
  (interactive "*P")
  (ar-th-kill 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-paragraph-atpt 'ar-paragraph-left-right-singlequote-atpt)
;;;###autoload
(defun ar-paragraph-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-parentize-paragraph-atpt 'ar-paragraph-parentize-atpt)
;;;###autoload
(defun ar-paragraph-parentize-atpt (&optional no-delimiters) 
  "Parentizes paragraph at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-separate-paragraph-atpt 'ar-paragraph-separate-atpt)
;;;###autoload
(defun ar-paragraph-separate-atpt (&optional no-delimiters) 
  "Separates paragraph at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-singlequote-paragraph-atpt 'ar-paragraph-singlequote-atpt)
;;;###autoload
(defun ar-paragraph-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes paragraph at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-paragraph-atpt 'ar-paragraph-triplequote-dq-atpt)
;;;###autoload
(defun ar-paragraph-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around paragraph. "
  (interactive "*p")
  (ar-th-triplequote-dq 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-paragraph-atpt 'ar-paragraph-triplequote-sq-atpt)
;;;###autoload
(defun ar-paragraph-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around paragraph. "
  (interactive "*p")
  (ar-th-triplequote-sq 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-trim-paragraph-atpt 'ar-paragraph-trim-atpt)
;;;###autoload
(defun ar-paragraph-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paragraph t t)) 
    (ar-th-trim 'paragraph t t)))

(defalias 'ar-trim-left-paragraph-atpt 'ar-paragraph-left-trim-atpt)
;;;###autoload
(defun ar-paragraph-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paragraph t nil))
    (ar-th-trim 'paragraph t nil)))

(defalias 'ar-trim-right-paragraph-atpt 'ar-paragraph-right-trim-atpt)
;;;###autoload
(defun ar-paragraph-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paragraph nil t))
    (ar-th-trim 'paragraph nil t)))

(defalias 'ar-paragraph-underscore-atpt 'ar-underscore-paragraph-atpt)
;;;###autoload
(defun ar-underscore-paragraph-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'paragraph no-delimiters (interactive-p)))

(defalias 'ar-paragraph-whitespace-atpt 'ar-whitespace-paragraph-atpt)
;;;###autoload
(defun ar-whitespace-paragraph-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'paragraph nil t))

(defalias 'ar-forward-paragraph-atpt 'ar-paragraph-forward-atpt)
;;;###autoload
(defun ar-paragraph-forward-atpt (&optional arg) 
  "Moves forward over paragraph at point if any, does nothing otherwise.
Returns end position of paragraph "
  (interactive "p")
  (ar-th-forward 'paragraph arg (interactive-p)))

(defalias 'ar-backward-paragraph-atpt 'ar-paragraph-backward-atpt)
;;;###autoload
(defun ar-paragraph-backward-atpt (&optional arg) 
  "Moves backward over paragraph before point if any, does nothing otherwise.
Returns beginning position of paragraph "
  (interactive "p")
  (ar-th-backward 'paragraph arg (interactive-p)))

(defalias 'ar-transpose-paragraph-atpt 'ar-paragraph-transpose-atpt)
;;;###autoload
(defun ar-paragraph-transpose-atpt (&optional arg) 
  "Transposes paragraph with paragraph before point if any. "
  (interactive "*p")
  (ar-th-transpose 'paragraph arg (interactive-p)))

(defalias 'ar-sort-paragraph-atpt 'ar-paragraph-sort-atpt)
;;;###autoload
(defun ar-paragraph-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts paragraphs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'paragraph reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-paragraph-atpt 'ar-paragraph-check-atpt)
;;;###autoload
(defun ar-paragraph-check-atpt () 
  "Return t if a paragraph at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-paragraph-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-paragraph-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-paren-atpt (&optional arg no-delimiters) 
  "Returns paren at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'paren arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-paren-atpt 'ar-paren-bounds-atpt)
;;;###autoload
(defun ar-paren-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of paren if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'paren no-delimiters (interactive-p)))

;;;###autoload
(defun ar-paren-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position paren at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'paren no-delimiters (interactive-p)))

;;;###autoload
(defun ar-paren-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of paren at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'paren no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-paren-atpt 'ar-paren-beginning-atpt)
;;;###autoload
(defun ar-paren-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class paren at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'paren no-delimiters (interactive-p)))

(defalias 'ar-end-of-paren-atpt 'ar-paren-end-atpt)
;;;###autoload
(defun ar-paren-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class paren at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'paren no-delimiters (interactive-p)))

(defalias 'ar-in-paren-p-atpt 'ar-paren-in-p-atpt)
;;;###autoload
(defun ar-paren-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of paren at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'paren no-delimiters (interactive-p)))

(defalias 'ar-length-of-paren-atpt 'ar-paren-length-atpt)
;;;###autoload
(defun ar-paren-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class paren at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'paren no-delimiters (interactive-p)))

(defalias 'ar-copy-paren-atpt 'ar-paren-copy-atpt)
;;;###autoload
(defun ar-paren-copy-atpt (&optional no-delimiters) 
  "Returns a copy of paren at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'paren no-delimiters (interactive-p)))

(defalias 'ar-delete-paren-in-region 'ar-paren-delete-in-region)
;;;###autoload
(defun ar-paren-delete-in-region (beg end) 
  "Deletes paren at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'paren beg end (interactive-p)))

;;;###autoload
(defun ar-blok-paren-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around paren.
  Returns blok or nil if no paren at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'paren no-delimiters (interactive-p)))

(defalias 'ar-escape-paren-atpt 'ar-paren-escape-atpt)
;;;###autoload
(defun ar-paren-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted paren at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'paren no-delimiters))

(defalias 'ar-doublequote-paren-atpt 'ar-paren-doublequote-atpt)
;;;###autoload
(defun ar-paren-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes paren at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'paren no-delimiters (interactive-p)))

(defalias 'ar-slash-paren-atpt 'ar-paren-slash-atpt)
;;;###autoload
(defun ar-paren-slash-atpt (&optional no-delimiters) 
  "Doublequotes paren at point if any. "
  (interactive "*p")
  (ar-th-slash 'paren no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-paren-atpt 'ar-paren-double-backslash-atpt)
;;;###autoload
(defun ar-paren-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around paren at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'paren no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-paren-atpt 'ar-paren-doubleslash-atpt)
;;;###autoload
(defun ar-paren-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around paren at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'paren no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-paren-atpt 'ar-paren-doubleslashparen-atpt)
;;;###autoload
(defun ar-paren-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around paren at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'paren no-delimiters (interactive-p)))

(defalias 'ar-slashparen-paren-atpt 'ar-paren-slashparen-atpt)
;;;###autoload
(defun ar-paren-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around paren at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'paren no-delimiters (interactive-p)))

(defalias 'ar-dollar-paren-atpt 'ar-paren-dollar-atpt)
;;;###autoload
(defun ar-paren-dollar-atpt (&optional no-delimiters) 
  "Doublequotes paren at point if any. "
  (interactive "*p")
  (ar-th-dollar 'paren no-delimiters (interactive-p)))

(defalias 'ar-equalize-paren-atpt 'ar-paren-equalize-atpt)
;;;###autoload
(defun ar-paren-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around paren at point if any. "
  (interactive "*p")
  (ar-th-equalize 'paren no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-paren-atpt 'ar-paren-greater-angle-atpt)
;;;###autoload
(defun ar-paren-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for paren after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'paren no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-paren-atpt 'ar-paren-lesser-angle-atpt)
;;;###autoload
(defun ar-paren-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for paren after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'paren no-delimiters (interactive-p)))

(defalias 'ar-backslash-paren-atpt 'ar-paren-backslash-atpt)
;;;###autoload
(defun ar-paren-backslash-atpt (&optional no-delimiters) 
  "Backslash paren at point if any. "
  (interactive "*p")
  (ar-th-backslash 'paren no-delimiters (interactive-p))) 

(defalias 'ar-brace-paren-atpt 'ar-paren-brace-atpt)
;;;###autoload
(defun ar-paren-brace-atpt (&optional no-delimiters) 
  "Braces paren at point if any. "
  (interactive "*p")
  (ar-th-brace 'paren no-delimiters (interactive-p)))

(defalias 'ar-bracket-paren-atpt 'ar-paren-bracket-atpt)
;;;###autoload
(defun ar-paren-bracket-atpt (&optional no-delimiters) 
  "Brackets paren after point if any. "
  (interactive "*p")
  (ar-th-bracket 'paren no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-paren-atpt (&optional no-delimiters) 
  "Comments paren at point if any. "
  (interactive "*p")
  (ar-th-comment 'paren no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-paren-atpt (&optional no-delimiters) 
  "Put a comma after paren at point if any. "
  (interactive "*p")
  (ar-th-commatize 'paren no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-paren-atpt (&optional no-delimiters) 
  "Put a singlequote before paren at point if any. "
  (interactive "*p")
  (ar-th-quote 'paren no-delimiters (interactive-p)))

(defalias 'ar-hyphen-paren-atpt 'ar-paren-hyphen-atpt)
;;;###autoload
(defun ar-paren-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around paren at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'paren no-delimiters (interactive-p)))

(defalias 'ar-mark-paren-atpt 'ar-paren-mark-atpt)
;;;###autoload
(defun ar-paren-mark-atpt () 
  "Marks paren at point if any. "
  (interactive)
  (ar-th-mark 'paren))

(defalias 'ar-hide-paren-atpt 'ar-paren-hide-atpt)
;;;###autoload
(defun ar-paren-hide-atpt () 
  "Hides paren at point. "
  (interactive)
  (ar-th-hide 'paren))

(defalias 'ar-show-paren-atpt 'ar-paren-show-atpt)
;;;###autoload
(defun ar-paren-show-atpt () 
  "Shows hidden paren at point. "
  (interactive)
  (ar-th-show 'paren))

(defalias 'ar-hide-show-paren-atpt 'ar-paren-hide-show-atpt)
;;;###autoload
(defun ar-paren-hide-show-atpt () 
  "Alternatively hides or shows paren at point. "
  (interactive)
  (ar-th-hide-show 'paren))

(defalias 'ar-highlight-paren-atpt-mode 'ar-paren-highlight-atpt-mode)

(defun ar-paren-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles paren-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'paren no-delimiters (interactive-p)))

(defalias 'ar-kill-paren-atpt 'ar-paren-kill-atpt)
;;;###autoload
(defun ar-paren-kill-atpt (&optional no-delimiters) 
  "Kills paren at point if any. "
  (interactive "*P")
  (ar-th-kill 'paren no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-paren-atpt 'ar-paren-left-right-singlequote-atpt)
;;;###autoload
(defun ar-paren-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'paren no-delimiters (interactive-p)))

(defalias 'ar-parentize-paren-atpt 'ar-paren-parentize-atpt)
;;;###autoload
(defun ar-paren-parentize-atpt (&optional no-delimiters) 
  "Parentizes paren at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'paren no-delimiters (interactive-p)))

(defalias 'ar-separate-paren-atpt 'ar-paren-separate-atpt)
;;;###autoload
(defun ar-paren-separate-atpt (&optional no-delimiters) 
  "Separates paren at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'paren no-delimiters (interactive-p)))

(defalias 'ar-singlequote-paren-atpt 'ar-paren-singlequote-atpt)
;;;###autoload
(defun ar-paren-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes paren at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'paren no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-paren-atpt 'ar-paren-triplequote-dq-atpt)
;;;###autoload
(defun ar-paren-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around paren. "
  (interactive "*p")
  (ar-th-triplequote-dq 'paren no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-paren-atpt 'ar-paren-triplequote-sq-atpt)
;;;###autoload
(defun ar-paren-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around paren. "
  (interactive "*p")
  (ar-th-triplequote-sq 'paren no-delimiters (interactive-p)))

(defalias 'ar-trim-paren-atpt 'ar-paren-trim-atpt)
;;;###autoload
(defun ar-paren-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paren t t)) 
    (ar-th-trim 'paren t t)))

(defalias 'ar-trim-left-paren-atpt 'ar-paren-left-trim-atpt)
;;;###autoload
(defun ar-paren-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paren t nil))
    (ar-th-trim 'paren t nil)))

(defalias 'ar-trim-right-paren-atpt 'ar-paren-right-trim-atpt)
;;;###autoload
(defun ar-paren-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'paren nil t))
    (ar-th-trim 'paren nil t)))

(defalias 'ar-paren-underscore-atpt 'ar-underscore-paren-atpt)
;;;###autoload
(defun ar-underscore-paren-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'paren no-delimiters (interactive-p)))

(defalias 'ar-paren-whitespace-atpt 'ar-whitespace-paren-atpt)
;;;###autoload
(defun ar-whitespace-paren-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'paren nil t))

(defalias 'ar-forward-paren-atpt 'ar-paren-forward-atpt)
;;;###autoload
(defun ar-paren-forward-atpt (&optional arg) 
  "Moves forward over paren at point if any, does nothing otherwise.
Returns end position of paren "
  (interactive "p")
  (ar-th-forward 'paren arg (interactive-p)))

(defalias 'ar-backward-paren-atpt 'ar-paren-backward-atpt)
;;;###autoload
(defun ar-paren-backward-atpt (&optional arg) 
  "Moves backward over paren before point if any, does nothing otherwise.
Returns beginning position of paren "
  (interactive "p")
  (ar-th-backward 'paren arg (interactive-p)))

(defalias 'ar-transpose-paren-atpt 'ar-paren-transpose-atpt)
;;;###autoload
(defun ar-paren-transpose-atpt (&optional arg) 
  "Transposes paren with paren before point if any. "
  (interactive "*p")
  (ar-th-transpose 'paren arg (interactive-p)))

(defalias 'ar-sort-paren-atpt 'ar-paren-sort-atpt)
;;;###autoload
(defun ar-paren-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts parens in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'paren reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-paren-atpt 'ar-paren-check-atpt)
;;;###autoload
(defun ar-paren-check-atpt () 
  "Return t if a paren at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-paren-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-paren-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-phone-atpt (&optional arg no-delimiters) 
  "Returns phone at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'phone arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-phone-atpt 'ar-phone-bounds-atpt)
;;;###autoload
(defun ar-phone-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of phone if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'phone no-delimiters (interactive-p)))

;;;###autoload
(defun ar-phone-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position phone at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'phone no-delimiters (interactive-p)))

;;;###autoload
(defun ar-phone-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of phone at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'phone no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-phone-atpt 'ar-phone-beginning-atpt)
;;;###autoload
(defun ar-phone-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class phone at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'phone no-delimiters (interactive-p)))

(defalias 'ar-end-of-phone-atpt 'ar-phone-end-atpt)
;;;###autoload
(defun ar-phone-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class phone at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'phone no-delimiters (interactive-p)))

(defalias 'ar-in-phone-p-atpt 'ar-phone-in-p-atpt)
;;;###autoload
(defun ar-phone-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of phone at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'phone no-delimiters (interactive-p)))

(defalias 'ar-length-of-phone-atpt 'ar-phone-length-atpt)
;;;###autoload
(defun ar-phone-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class phone at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'phone no-delimiters (interactive-p)))

(defalias 'ar-copy-phone-atpt 'ar-phone-copy-atpt)
;;;###autoload
(defun ar-phone-copy-atpt (&optional no-delimiters) 
  "Returns a copy of phone at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'phone no-delimiters (interactive-p)))

(defalias 'ar-delete-phone-in-region 'ar-phone-delete-in-region)
;;;###autoload
(defun ar-phone-delete-in-region (beg end) 
  "Deletes phone at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'phone beg end (interactive-p)))

;;;###autoload
(defun ar-blok-phone-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around phone.
  Returns blok or nil if no phone at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'phone no-delimiters (interactive-p)))

(defalias 'ar-escape-phone-atpt 'ar-phone-escape-atpt)
;;;###autoload
(defun ar-phone-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted phone at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'phone no-delimiters))

(defalias 'ar-doublequote-phone-atpt 'ar-phone-doublequote-atpt)
;;;###autoload
(defun ar-phone-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes phone at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'phone no-delimiters (interactive-p)))

(defalias 'ar-slash-phone-atpt 'ar-phone-slash-atpt)
;;;###autoload
(defun ar-phone-slash-atpt (&optional no-delimiters) 
  "Doublequotes phone at point if any. "
  (interactive "*p")
  (ar-th-slash 'phone no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-phone-atpt 'ar-phone-double-backslash-atpt)
;;;###autoload
(defun ar-phone-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around phone at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'phone no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-phone-atpt 'ar-phone-doubleslash-atpt)
;;;###autoload
(defun ar-phone-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around phone at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'phone no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-phone-atpt 'ar-phone-doubleslashparen-atpt)
;;;###autoload
(defun ar-phone-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around phone at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'phone no-delimiters (interactive-p)))

(defalias 'ar-slashparen-phone-atpt 'ar-phone-slashparen-atpt)
;;;###autoload
(defun ar-phone-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around phone at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'phone no-delimiters (interactive-p)))

(defalias 'ar-dollar-phone-atpt 'ar-phone-dollar-atpt)
;;;###autoload
(defun ar-phone-dollar-atpt (&optional no-delimiters) 
  "Doublequotes phone at point if any. "
  (interactive "*p")
  (ar-th-dollar 'phone no-delimiters (interactive-p)))

(defalias 'ar-equalize-phone-atpt 'ar-phone-equalize-atpt)
;;;###autoload
(defun ar-phone-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around phone at point if any. "
  (interactive "*p")
  (ar-th-equalize 'phone no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-phone-atpt 'ar-phone-greater-angle-atpt)
;;;###autoload
(defun ar-phone-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for phone after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'phone no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-phone-atpt 'ar-phone-lesser-angle-atpt)
;;;###autoload
(defun ar-phone-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for phone after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'phone no-delimiters (interactive-p)))

(defalias 'ar-backslash-phone-atpt 'ar-phone-backslash-atpt)
;;;###autoload
(defun ar-phone-backslash-atpt (&optional no-delimiters) 
  "Backslash phone at point if any. "
  (interactive "*p")
  (ar-th-backslash 'phone no-delimiters (interactive-p))) 

(defalias 'ar-brace-phone-atpt 'ar-phone-brace-atpt)
;;;###autoload
(defun ar-phone-brace-atpt (&optional no-delimiters) 
  "Braces phone at point if any. "
  (interactive "*p")
  (ar-th-brace 'phone no-delimiters (interactive-p)))

(defalias 'ar-bracket-phone-atpt 'ar-phone-bracket-atpt)
;;;###autoload
(defun ar-phone-bracket-atpt (&optional no-delimiters) 
  "Brackets phone after point if any. "
  (interactive "*p")
  (ar-th-bracket 'phone no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-phone-atpt (&optional no-delimiters) 
  "Comments phone at point if any. "
  (interactive "*p")
  (ar-th-comment 'phone no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-phone-atpt (&optional no-delimiters) 
  "Put a comma after phone at point if any. "
  (interactive "*p")
  (ar-th-commatize 'phone no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-phone-atpt (&optional no-delimiters) 
  "Put a singlequote before phone at point if any. "
  (interactive "*p")
  (ar-th-quote 'phone no-delimiters (interactive-p)))

(defalias 'ar-hyphen-phone-atpt 'ar-phone-hyphen-atpt)
;;;###autoload
(defun ar-phone-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around phone at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'phone no-delimiters (interactive-p)))

(defalias 'ar-mark-phone-atpt 'ar-phone-mark-atpt)
;;;###autoload
(defun ar-phone-mark-atpt () 
  "Marks phone at point if any. "
  (interactive)
  (ar-th-mark 'phone))

(defalias 'ar-hide-phone-atpt 'ar-phone-hide-atpt)
;;;###autoload
(defun ar-phone-hide-atpt () 
  "Hides phone at point. "
  (interactive)
  (ar-th-hide 'phone))

(defalias 'ar-show-phone-atpt 'ar-phone-show-atpt)
;;;###autoload
(defun ar-phone-show-atpt () 
  "Shows hidden phone at point. "
  (interactive)
  (ar-th-show 'phone))

(defalias 'ar-hide-show-phone-atpt 'ar-phone-hide-show-atpt)
;;;###autoload
(defun ar-phone-hide-show-atpt () 
  "Alternatively hides or shows phone at point. "
  (interactive)
  (ar-th-hide-show 'phone))

(defalias 'ar-highlight-phone-atpt-mode 'ar-phone-highlight-atpt-mode)

(defun ar-phone-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles phone-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'phone no-delimiters (interactive-p)))

(defalias 'ar-kill-phone-atpt 'ar-phone-kill-atpt)
;;;###autoload
(defun ar-phone-kill-atpt (&optional no-delimiters) 
  "Kills phone at point if any. "
  (interactive "*P")
  (ar-th-kill 'phone no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-phone-atpt 'ar-phone-left-right-singlequote-atpt)
;;;###autoload
(defun ar-phone-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'phone no-delimiters (interactive-p)))

(defalias 'ar-parentize-phone-atpt 'ar-phone-parentize-atpt)
;;;###autoload
(defun ar-phone-parentize-atpt (&optional no-delimiters) 
  "Parentizes phone at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'phone no-delimiters (interactive-p)))

(defalias 'ar-separate-phone-atpt 'ar-phone-separate-atpt)
;;;###autoload
(defun ar-phone-separate-atpt (&optional no-delimiters) 
  "Separates phone at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'phone no-delimiters (interactive-p)))

(defalias 'ar-singlequote-phone-atpt 'ar-phone-singlequote-atpt)
;;;###autoload
(defun ar-phone-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes phone at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'phone no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-phone-atpt 'ar-phone-triplequote-dq-atpt)
;;;###autoload
(defun ar-phone-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around phone. "
  (interactive "*p")
  (ar-th-triplequote-dq 'phone no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-phone-atpt 'ar-phone-triplequote-sq-atpt)
;;;###autoload
(defun ar-phone-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around phone. "
  (interactive "*p")
  (ar-th-triplequote-sq 'phone no-delimiters (interactive-p)))

(defalias 'ar-trim-phone-atpt 'ar-phone-trim-atpt)
;;;###autoload
(defun ar-phone-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'phone t t)) 
    (ar-th-trim 'phone t t)))

(defalias 'ar-trim-left-phone-atpt 'ar-phone-left-trim-atpt)
;;;###autoload
(defun ar-phone-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'phone t nil))
    (ar-th-trim 'phone t nil)))

(defalias 'ar-trim-right-phone-atpt 'ar-phone-right-trim-atpt)
;;;###autoload
(defun ar-phone-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'phone nil t))
    (ar-th-trim 'phone nil t)))

(defalias 'ar-phone-underscore-atpt 'ar-underscore-phone-atpt)
;;;###autoload
(defun ar-underscore-phone-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'phone no-delimiters (interactive-p)))

(defalias 'ar-phone-whitespace-atpt 'ar-whitespace-phone-atpt)
;;;###autoload
(defun ar-whitespace-phone-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'phone nil t))

(defalias 'ar-forward-phone-atpt 'ar-phone-forward-atpt)
;;;###autoload
(defun ar-phone-forward-atpt (&optional arg) 
  "Moves forward over phone at point if any, does nothing otherwise.
Returns end position of phone "
  (interactive "p")
  (ar-th-forward 'phone arg (interactive-p)))

(defalias 'ar-backward-phone-atpt 'ar-phone-backward-atpt)
;;;###autoload
(defun ar-phone-backward-atpt (&optional arg) 
  "Moves backward over phone before point if any, does nothing otherwise.
Returns beginning position of phone "
  (interactive "p")
  (ar-th-backward 'phone arg (interactive-p)))

(defalias 'ar-transpose-phone-atpt 'ar-phone-transpose-atpt)
;;;###autoload
(defun ar-phone-transpose-atpt (&optional arg) 
  "Transposes phone with phone before point if any. "
  (interactive "*p")
  (ar-th-transpose 'phone arg (interactive-p)))

(defalias 'ar-sort-phone-atpt 'ar-phone-sort-atpt)
;;;###autoload
(defun ar-phone-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts phones in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'phone reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-phone-atpt 'ar-phone-check-atpt)
;;;###autoload
(defun ar-phone-check-atpt () 
  "Return t if a phone at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-phone-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-phone-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-region-atpt (&optional arg no-delimiters) 
  "Returns region at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'region arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-region-atpt 'ar-region-bounds-atpt)
;;;###autoload
(defun ar-region-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of region if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'region no-delimiters (interactive-p)))

;;;###autoload
(defun ar-region-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position region at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'region no-delimiters (interactive-p)))

;;;###autoload
(defun ar-region-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of region at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'region no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-region-atpt 'ar-region-beginning-atpt)
;;;###autoload
(defun ar-region-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class region at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'region no-delimiters (interactive-p)))

(defalias 'ar-end-of-region-atpt 'ar-region-end-atpt)
;;;###autoload
(defun ar-region-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class region at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'region no-delimiters (interactive-p)))

(defalias 'ar-in-region-p-atpt 'ar-region-in-p-atpt)
;;;###autoload
(defun ar-region-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of region at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'region no-delimiters (interactive-p)))

(defalias 'ar-length-of-region-atpt 'ar-region-length-atpt)
;;;###autoload
(defun ar-region-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class region at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'region no-delimiters (interactive-p)))

(defalias 'ar-copy-region-atpt 'ar-region-copy-atpt)
;;;###autoload
(defun ar-region-copy-atpt (&optional no-delimiters) 
  "Returns a copy of region at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'region no-delimiters (interactive-p)))

(defalias 'ar-delete-region-in-region 'ar-region-delete-in-region)
;;;###autoload
(defun ar-region-delete-in-region (beg end) 
  "Deletes region at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'region beg end (interactive-p)))

;;;###autoload
(defun ar-blok-region-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around region.
  Returns blok or nil if no region at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'region no-delimiters (interactive-p)))

(defalias 'ar-escape-region-atpt 'ar-region-escape-atpt)
;;;###autoload
(defun ar-region-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted region at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'region no-delimiters))

(defalias 'ar-doublequote-region-atpt 'ar-region-doublequote-atpt)
;;;###autoload
(defun ar-region-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes region at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'region no-delimiters (interactive-p)))

(defalias 'ar-slash-region-atpt 'ar-region-slash-atpt)
;;;###autoload
(defun ar-region-slash-atpt (&optional no-delimiters) 
  "Doublequotes region at point if any. "
  (interactive "*p")
  (ar-th-slash 'region no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-region-atpt 'ar-region-double-backslash-atpt)
;;;###autoload
(defun ar-region-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around region at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'region no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-region-atpt 'ar-region-doubleslash-atpt)
;;;###autoload
(defun ar-region-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around region at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'region no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-region-atpt 'ar-region-doubleslashparen-atpt)
;;;###autoload
(defun ar-region-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around region at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'region no-delimiters (interactive-p)))

(defalias 'ar-slashparen-region-atpt 'ar-region-slashparen-atpt)
;;;###autoload
(defun ar-region-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around region at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'region no-delimiters (interactive-p)))

(defalias 'ar-dollar-region-atpt 'ar-region-dollar-atpt)
;;;###autoload
(defun ar-region-dollar-atpt (&optional no-delimiters) 
  "Doublequotes region at point if any. "
  (interactive "*p")
  (ar-th-dollar 'region no-delimiters (interactive-p)))

(defalias 'ar-equalize-region-atpt 'ar-region-equalize-atpt)
;;;###autoload
(defun ar-region-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around region at point if any. "
  (interactive "*p")
  (ar-th-equalize 'region no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-region-atpt 'ar-region-greater-angle-atpt)
;;;###autoload
(defun ar-region-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for region after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'region no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-region-atpt 'ar-region-lesser-angle-atpt)
;;;###autoload
(defun ar-region-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for region after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'region no-delimiters (interactive-p)))

(defalias 'ar-backslash-region-atpt 'ar-region-backslash-atpt)
;;;###autoload
(defun ar-region-backslash-atpt (&optional no-delimiters) 
  "Backslash region at point if any. "
  (interactive "*p")
  (ar-th-backslash 'region no-delimiters (interactive-p))) 

(defalias 'ar-brace-region-atpt 'ar-region-brace-atpt)
;;;###autoload
(defun ar-region-brace-atpt (&optional no-delimiters) 
  "Braces region at point if any. "
  (interactive "*p")
  (ar-th-brace 'region no-delimiters (interactive-p)))

(defalias 'ar-bracket-region-atpt 'ar-region-bracket-atpt)
;;;###autoload
(defun ar-region-bracket-atpt (&optional no-delimiters) 
  "Brackets region after point if any. "
  (interactive "*p")
  (ar-th-bracket 'region no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-region-atpt (&optional no-delimiters) 
  "Comments region at point if any. "
  (interactive "*p")
  (ar-th-comment 'region no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-region-atpt (&optional no-delimiters) 
  "Put a comma after region at point if any. "
  (interactive "*p")
  (ar-th-commatize 'region no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-region-atpt (&optional no-delimiters) 
  "Put a singlequote before region at point if any. "
  (interactive "*p")
  (ar-th-quote 'region no-delimiters (interactive-p)))

(defalias 'ar-hyphen-region-atpt 'ar-region-hyphen-atpt)
;;;###autoload
(defun ar-region-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around region at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'region no-delimiters (interactive-p)))

(defalias 'ar-mark-region-atpt 'ar-region-mark-atpt)
;;;###autoload
(defun ar-region-mark-atpt () 
  "Marks region at point if any. "
  (interactive)
  (ar-th-mark 'region))

(defalias 'ar-hide-region-atpt 'ar-region-hide-atpt)
;;;###autoload
(defun ar-region-hide-atpt () 
  "Hides region at point. "
  (interactive)
  (ar-th-hide 'region))

(defalias 'ar-show-region-atpt 'ar-region-show-atpt)
;;;###autoload
(defun ar-region-show-atpt () 
  "Shows hidden region at point. "
  (interactive)
  (ar-th-show 'region))

(defalias 'ar-hide-show-region-atpt 'ar-region-hide-show-atpt)
;;;###autoload
(defun ar-region-hide-show-atpt () 
  "Alternatively hides or shows region at point. "
  (interactive)
  (ar-th-hide-show 'region))

(defalias 'ar-highlight-region-atpt-mode 'ar-region-highlight-atpt-mode)

(defun ar-region-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles region-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'region no-delimiters (interactive-p)))

(defalias 'ar-kill-region-atpt 'ar-region-kill-atpt)
;;;###autoload
(defun ar-region-kill-atpt (&optional no-delimiters) 
  "Kills region at point if any. "
  (interactive "*P")
  (ar-th-kill 'region no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-region-atpt 'ar-region-left-right-singlequote-atpt)
;;;###autoload
(defun ar-region-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'region no-delimiters (interactive-p)))

(defalias 'ar-parentize-region-atpt 'ar-region-parentize-atpt)
;;;###autoload
(defun ar-region-parentize-atpt (&optional no-delimiters) 
  "Parentizes region at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'region no-delimiters (interactive-p)))

(defalias 'ar-separate-region-atpt 'ar-region-separate-atpt)
;;;###autoload
(defun ar-region-separate-atpt (&optional no-delimiters) 
  "Separates region at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'region no-delimiters (interactive-p)))

(defalias 'ar-singlequote-region-atpt 'ar-region-singlequote-atpt)
;;;###autoload
(defun ar-region-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes region at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'region no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-region-atpt 'ar-region-triplequote-dq-atpt)
;;;###autoload
(defun ar-region-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around region. "
  (interactive "*p")
  (ar-th-triplequote-dq 'region no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-region-atpt 'ar-region-triplequote-sq-atpt)
;;;###autoload
(defun ar-region-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around region. "
  (interactive "*p")
  (ar-th-triplequote-sq 'region no-delimiters (interactive-p)))

(defalias 'ar-trim-region-atpt 'ar-region-trim-atpt)
;;;###autoload
(defun ar-region-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'region t t)) 
    (ar-th-trim 'region t t)))

(defalias 'ar-trim-left-region-atpt 'ar-region-left-trim-atpt)
;;;###autoload
(defun ar-region-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'region t nil))
    (ar-th-trim 'region t nil)))

(defalias 'ar-trim-right-region-atpt 'ar-region-right-trim-atpt)
;;;###autoload
(defun ar-region-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'region nil t))
    (ar-th-trim 'region nil t)))

(defalias 'ar-region-underscore-atpt 'ar-underscore-region-atpt)
;;;###autoload
(defun ar-underscore-region-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'region no-delimiters (interactive-p)))

(defalias 'ar-region-whitespace-atpt 'ar-whitespace-region-atpt)
;;;###autoload
(defun ar-whitespace-region-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'region nil t))

(defalias 'ar-forward-region-atpt 'ar-region-forward-atpt)
;;;###autoload
(defun ar-region-forward-atpt (&optional arg) 
  "Moves forward over region at point if any, does nothing otherwise.
Returns end position of region "
  (interactive "p")
  (ar-th-forward 'region arg (interactive-p)))

(defalias 'ar-backward-region-atpt 'ar-region-backward-atpt)
;;;###autoload
(defun ar-region-backward-atpt (&optional arg) 
  "Moves backward over region before point if any, does nothing otherwise.
Returns beginning position of region "
  (interactive "p")
  (ar-th-backward 'region arg (interactive-p)))

(defalias 'ar-transpose-region-atpt 'ar-region-transpose-atpt)
;;;###autoload
(defun ar-region-transpose-atpt (&optional arg) 
  "Transposes region with region before point if any. "
  (interactive "*p")
  (ar-th-transpose 'region arg (interactive-p)))

(defalias 'ar-sort-region-atpt 'ar-region-sort-atpt)
;;;###autoload
(defun ar-region-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts regions in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'region reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-region-atpt 'ar-region-check-atpt)
;;;###autoload
(defun ar-region-check-atpt () 
  "Return t if a region at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-region-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-region-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-sentence-atpt (&optional arg no-delimiters) 
  "Returns sentence at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'sentence arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-sentence-atpt 'ar-sentence-bounds-atpt)
;;;###autoload
(defun ar-sentence-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of sentence if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'sentence no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sentence-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position sentence at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'sentence no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sentence-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of sentence at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'sentence no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-sentence-atpt 'ar-sentence-beginning-atpt)
;;;###autoload
(defun ar-sentence-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class sentence at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'sentence no-delimiters (interactive-p)))

(defalias 'ar-end-of-sentence-atpt 'ar-sentence-end-atpt)
;;;###autoload
(defun ar-sentence-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class sentence at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'sentence no-delimiters (interactive-p)))

(defalias 'ar-in-sentence-p-atpt 'ar-sentence-in-p-atpt)
;;;###autoload
(defun ar-sentence-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of sentence at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'sentence no-delimiters (interactive-p)))

(defalias 'ar-length-of-sentence-atpt 'ar-sentence-length-atpt)
;;;###autoload
(defun ar-sentence-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class sentence at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'sentence no-delimiters (interactive-p)))

(defalias 'ar-copy-sentence-atpt 'ar-sentence-copy-atpt)
;;;###autoload
(defun ar-sentence-copy-atpt (&optional no-delimiters) 
  "Returns a copy of sentence at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'sentence no-delimiters (interactive-p)))

(defalias 'ar-delete-sentence-in-region 'ar-sentence-delete-in-region)
;;;###autoload
(defun ar-sentence-delete-in-region (beg end) 
  "Deletes sentence at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'sentence beg end (interactive-p)))

;;;###autoload
(defun ar-blok-sentence-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around sentence.
  Returns blok or nil if no sentence at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'sentence no-delimiters (interactive-p)))

(defalias 'ar-escape-sentence-atpt 'ar-sentence-escape-atpt)
;;;###autoload
(defun ar-sentence-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted sentence at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'sentence no-delimiters))

(defalias 'ar-doublequote-sentence-atpt 'ar-sentence-doublequote-atpt)
;;;###autoload
(defun ar-sentence-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes sentence at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'sentence no-delimiters (interactive-p)))

(defalias 'ar-slash-sentence-atpt 'ar-sentence-slash-atpt)
;;;###autoload
(defun ar-sentence-slash-atpt (&optional no-delimiters) 
  "Doublequotes sentence at point if any. "
  (interactive "*p")
  (ar-th-slash 'sentence no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-sentence-atpt 'ar-sentence-double-backslash-atpt)
;;;###autoload
(defun ar-sentence-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around sentence at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'sentence no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-sentence-atpt 'ar-sentence-doubleslash-atpt)
;;;###autoload
(defun ar-sentence-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around sentence at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'sentence no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-sentence-atpt 'ar-sentence-doubleslashparen-atpt)
;;;###autoload
(defun ar-sentence-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around sentence at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'sentence no-delimiters (interactive-p)))

(defalias 'ar-slashparen-sentence-atpt 'ar-sentence-slashparen-atpt)
;;;###autoload
(defun ar-sentence-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around sentence at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'sentence no-delimiters (interactive-p)))

(defalias 'ar-dollar-sentence-atpt 'ar-sentence-dollar-atpt)
;;;###autoload
(defun ar-sentence-dollar-atpt (&optional no-delimiters) 
  "Doublequotes sentence at point if any. "
  (interactive "*p")
  (ar-th-dollar 'sentence no-delimiters (interactive-p)))

(defalias 'ar-equalize-sentence-atpt 'ar-sentence-equalize-atpt)
;;;###autoload
(defun ar-sentence-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around sentence at point if any. "
  (interactive "*p")
  (ar-th-equalize 'sentence no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-sentence-atpt 'ar-sentence-greater-angle-atpt)
;;;###autoload
(defun ar-sentence-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for sentence after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'sentence no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-sentence-atpt 'ar-sentence-lesser-angle-atpt)
;;;###autoload
(defun ar-sentence-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for sentence after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'sentence no-delimiters (interactive-p)))

(defalias 'ar-backslash-sentence-atpt 'ar-sentence-backslash-atpt)
;;;###autoload
(defun ar-sentence-backslash-atpt (&optional no-delimiters) 
  "Backslash sentence at point if any. "
  (interactive "*p")
  (ar-th-backslash 'sentence no-delimiters (interactive-p))) 

(defalias 'ar-brace-sentence-atpt 'ar-sentence-brace-atpt)
;;;###autoload
(defun ar-sentence-brace-atpt (&optional no-delimiters) 
  "Braces sentence at point if any. "
  (interactive "*p")
  (ar-th-brace 'sentence no-delimiters (interactive-p)))

(defalias 'ar-bracket-sentence-atpt 'ar-sentence-bracket-atpt)
;;;###autoload
(defun ar-sentence-bracket-atpt (&optional no-delimiters) 
  "Brackets sentence after point if any. "
  (interactive "*p")
  (ar-th-bracket 'sentence no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-sentence-atpt (&optional no-delimiters) 
  "Comments sentence at point if any. "
  (interactive "*p")
  (ar-th-comment 'sentence no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-sentence-atpt (&optional no-delimiters) 
  "Put a comma after sentence at point if any. "
  (interactive "*p")
  (ar-th-commatize 'sentence no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-sentence-atpt (&optional no-delimiters) 
  "Put a singlequote before sentence at point if any. "
  (interactive "*p")
  (ar-th-quote 'sentence no-delimiters (interactive-p)))

(defalias 'ar-hyphen-sentence-atpt 'ar-sentence-hyphen-atpt)
;;;###autoload
(defun ar-sentence-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around sentence at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'sentence no-delimiters (interactive-p)))

(defalias 'ar-mark-sentence-atpt 'ar-sentence-mark-atpt)
;;;###autoload
(defun ar-sentence-mark-atpt () 
  "Marks sentence at point if any. "
  (interactive)
  (ar-th-mark 'sentence))

(defalias 'ar-hide-sentence-atpt 'ar-sentence-hide-atpt)
;;;###autoload
(defun ar-sentence-hide-atpt () 
  "Hides sentence at point. "
  (interactive)
  (ar-th-hide 'sentence))

(defalias 'ar-show-sentence-atpt 'ar-sentence-show-atpt)
;;;###autoload
(defun ar-sentence-show-atpt () 
  "Shows hidden sentence at point. "
  (interactive)
  (ar-th-show 'sentence))

(defalias 'ar-hide-show-sentence-atpt 'ar-sentence-hide-show-atpt)
;;;###autoload
(defun ar-sentence-hide-show-atpt () 
  "Alternatively hides or shows sentence at point. "
  (interactive)
  (ar-th-hide-show 'sentence))

(defalias 'ar-highlight-sentence-atpt-mode 'ar-sentence-highlight-atpt-mode)

(defun ar-sentence-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles sentence-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'sentence no-delimiters (interactive-p)))

(defalias 'ar-kill-sentence-atpt 'ar-sentence-kill-atpt)
;;;###autoload
(defun ar-sentence-kill-atpt (&optional no-delimiters) 
  "Kills sentence at point if any. "
  (interactive "*P")
  (ar-th-kill 'sentence no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-sentence-atpt 'ar-sentence-left-right-singlequote-atpt)
;;;###autoload
(defun ar-sentence-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'sentence no-delimiters (interactive-p)))

(defalias 'ar-parentize-sentence-atpt 'ar-sentence-parentize-atpt)
;;;###autoload
(defun ar-sentence-parentize-atpt (&optional no-delimiters) 
  "Parentizes sentence at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'sentence no-delimiters (interactive-p)))

(defalias 'ar-separate-sentence-atpt 'ar-sentence-separate-atpt)
;;;###autoload
(defun ar-sentence-separate-atpt (&optional no-delimiters) 
  "Separates sentence at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'sentence no-delimiters (interactive-p)))

(defalias 'ar-singlequote-sentence-atpt 'ar-sentence-singlequote-atpt)
;;;###autoload
(defun ar-sentence-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes sentence at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'sentence no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-sentence-atpt 'ar-sentence-triplequote-dq-atpt)
;;;###autoload
(defun ar-sentence-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around sentence. "
  (interactive "*p")
  (ar-th-triplequote-dq 'sentence no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-sentence-atpt 'ar-sentence-triplequote-sq-atpt)
;;;###autoload
(defun ar-sentence-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around sentence. "
  (interactive "*p")
  (ar-th-triplequote-sq 'sentence no-delimiters (interactive-p)))

(defalias 'ar-trim-sentence-atpt 'ar-sentence-trim-atpt)
;;;###autoload
(defun ar-sentence-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sentence t t)) 
    (ar-th-trim 'sentence t t)))

(defalias 'ar-trim-left-sentence-atpt 'ar-sentence-left-trim-atpt)
;;;###autoload
(defun ar-sentence-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sentence t nil))
    (ar-th-trim 'sentence t nil)))

(defalias 'ar-trim-right-sentence-atpt 'ar-sentence-right-trim-atpt)
;;;###autoload
(defun ar-sentence-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sentence nil t))
    (ar-th-trim 'sentence nil t)))

(defalias 'ar-sentence-underscore-atpt 'ar-underscore-sentence-atpt)
;;;###autoload
(defun ar-underscore-sentence-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'sentence no-delimiters (interactive-p)))

(defalias 'ar-sentence-whitespace-atpt 'ar-whitespace-sentence-atpt)
;;;###autoload
(defun ar-whitespace-sentence-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'sentence nil t))

(defalias 'ar-forward-sentence-atpt 'ar-sentence-forward-atpt)
;;;###autoload
(defun ar-sentence-forward-atpt (&optional arg) 
  "Moves forward over sentence at point if any, does nothing otherwise.
Returns end position of sentence "
  (interactive "p")
  (ar-th-forward 'sentence arg (interactive-p)))

(defalias 'ar-backward-sentence-atpt 'ar-sentence-backward-atpt)
;;;###autoload
(defun ar-sentence-backward-atpt (&optional arg) 
  "Moves backward over sentence before point if any, does nothing otherwise.
Returns beginning position of sentence "
  (interactive "p")
  (ar-th-backward 'sentence arg (interactive-p)))

(defalias 'ar-transpose-sentence-atpt 'ar-sentence-transpose-atpt)
;;;###autoload
(defun ar-sentence-transpose-atpt (&optional arg) 
  "Transposes sentence with sentence before point if any. "
  (interactive "*p")
  (ar-th-transpose 'sentence arg (interactive-p)))

(defalias 'ar-sort-sentence-atpt 'ar-sentence-sort-atpt)
;;;###autoload
(defun ar-sentence-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sentences in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'sentence reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-sentence-atpt 'ar-sentence-check-atpt)
;;;###autoload
(defun ar-sentence-check-atpt () 
  "Return t if a sentence at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-sentence-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-sentence-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-sexp-atpt (&optional arg no-delimiters) 
  "Returns sexp at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'sexp arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-sexp-atpt 'ar-sexp-bounds-atpt)
;;;###autoload
(defun ar-sexp-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of sexp if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'sexp no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sexp-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position sexp at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'sexp no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sexp-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of sexp at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'sexp no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-sexp-atpt 'ar-sexp-beginning-atpt)
;;;###autoload
(defun ar-sexp-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class sexp at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'sexp no-delimiters (interactive-p)))

(defalias 'ar-end-of-sexp-atpt 'ar-sexp-end-atpt)
;;;###autoload
(defun ar-sexp-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class sexp at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'sexp no-delimiters (interactive-p)))

(defalias 'ar-in-sexp-p-atpt 'ar-sexp-in-p-atpt)
;;;###autoload
(defun ar-sexp-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of sexp at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'sexp no-delimiters (interactive-p)))

(defalias 'ar-length-of-sexp-atpt 'ar-sexp-length-atpt)
;;;###autoload
(defun ar-sexp-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class sexp at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'sexp no-delimiters (interactive-p)))

(defalias 'ar-copy-sexp-atpt 'ar-sexp-copy-atpt)
;;;###autoload
(defun ar-sexp-copy-atpt (&optional no-delimiters) 
  "Returns a copy of sexp at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'sexp no-delimiters (interactive-p)))

(defalias 'ar-delete-sexp-in-region 'ar-sexp-delete-in-region)
;;;###autoload
(defun ar-sexp-delete-in-region (beg end) 
  "Deletes sexp at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'sexp beg end (interactive-p)))

;;;###autoload
(defun ar-blok-sexp-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around sexp.
  Returns blok or nil if no sexp at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'sexp no-delimiters (interactive-p)))

(defalias 'ar-escape-sexp-atpt 'ar-sexp-escape-atpt)
;;;###autoload
(defun ar-sexp-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted sexp at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'sexp no-delimiters))

(defalias 'ar-doublequote-sexp-atpt 'ar-sexp-doublequote-atpt)
;;;###autoload
(defun ar-sexp-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes sexp at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'sexp no-delimiters (interactive-p)))

(defalias 'ar-slash-sexp-atpt 'ar-sexp-slash-atpt)
;;;###autoload
(defun ar-sexp-slash-atpt (&optional no-delimiters) 
  "Doublequotes sexp at point if any. "
  (interactive "*p")
  (ar-th-slash 'sexp no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-sexp-atpt 'ar-sexp-double-backslash-atpt)
;;;###autoload
(defun ar-sexp-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around sexp at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'sexp no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-sexp-atpt 'ar-sexp-doubleslash-atpt)
;;;###autoload
(defun ar-sexp-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around sexp at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'sexp no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-sexp-atpt 'ar-sexp-doubleslashparen-atpt)
;;;###autoload
(defun ar-sexp-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around sexp at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'sexp no-delimiters (interactive-p)))

(defalias 'ar-slashparen-sexp-atpt 'ar-sexp-slashparen-atpt)
;;;###autoload
(defun ar-sexp-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around sexp at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'sexp no-delimiters (interactive-p)))

(defalias 'ar-dollar-sexp-atpt 'ar-sexp-dollar-atpt)
;;;###autoload
(defun ar-sexp-dollar-atpt (&optional no-delimiters) 
  "Doublequotes sexp at point if any. "
  (interactive "*p")
  (ar-th-dollar 'sexp no-delimiters (interactive-p)))

(defalias 'ar-equalize-sexp-atpt 'ar-sexp-equalize-atpt)
;;;###autoload
(defun ar-sexp-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around sexp at point if any. "
  (interactive "*p")
  (ar-th-equalize 'sexp no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-sexp-atpt 'ar-sexp-greater-angle-atpt)
;;;###autoload
(defun ar-sexp-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for sexp after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'sexp no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-sexp-atpt 'ar-sexp-lesser-angle-atpt)
;;;###autoload
(defun ar-sexp-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for sexp after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'sexp no-delimiters (interactive-p)))

(defalias 'ar-backslash-sexp-atpt 'ar-sexp-backslash-atpt)
;;;###autoload
(defun ar-sexp-backslash-atpt (&optional no-delimiters) 
  "Backslash sexp at point if any. "
  (interactive "*p")
  (ar-th-backslash 'sexp no-delimiters (interactive-p))) 

(defalias 'ar-brace-sexp-atpt 'ar-sexp-brace-atpt)
;;;###autoload
(defun ar-sexp-brace-atpt (&optional no-delimiters) 
  "Braces sexp at point if any. "
  (interactive "*p")
  (ar-th-brace 'sexp no-delimiters (interactive-p)))

(defalias 'ar-bracket-sexp-atpt 'ar-sexp-bracket-atpt)
;;;###autoload
(defun ar-sexp-bracket-atpt (&optional no-delimiters) 
  "Brackets sexp after point if any. "
  (interactive "*p")
  (ar-th-bracket 'sexp no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-sexp-atpt (&optional no-delimiters) 
  "Comments sexp at point if any. "
  (interactive "*p")
  (ar-th-comment 'sexp no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-sexp-atpt (&optional no-delimiters) 
  "Put a comma after sexp at point if any. "
  (interactive "*p")
  (ar-th-commatize 'sexp no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-sexp-atpt (&optional no-delimiters) 
  "Put a singlequote before sexp at point if any. "
  (interactive "*p")
  (ar-th-quote 'sexp no-delimiters (interactive-p)))

(defalias 'ar-hyphen-sexp-atpt 'ar-sexp-hyphen-atpt)
;;;###autoload
(defun ar-sexp-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around sexp at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'sexp no-delimiters (interactive-p)))

(defalias 'ar-mark-sexp-atpt 'ar-sexp-mark-atpt)
;;;###autoload
(defun ar-sexp-mark-atpt () 
  "Marks sexp at point if any. "
  (interactive)
  (ar-th-mark 'sexp))

(defalias 'ar-hide-sexp-atpt 'ar-sexp-hide-atpt)
;;;###autoload
(defun ar-sexp-hide-atpt () 
  "Hides sexp at point. "
  (interactive)
  (ar-th-hide 'sexp))

(defalias 'ar-show-sexp-atpt 'ar-sexp-show-atpt)
;;;###autoload
(defun ar-sexp-show-atpt () 
  "Shows hidden sexp at point. "
  (interactive)
  (ar-th-show 'sexp))

(defalias 'ar-hide-show-sexp-atpt 'ar-sexp-hide-show-atpt)
;;;###autoload
(defun ar-sexp-hide-show-atpt () 
  "Alternatively hides or shows sexp at point. "
  (interactive)
  (ar-th-hide-show 'sexp))

(defalias 'ar-highlight-sexp-atpt-mode 'ar-sexp-highlight-atpt-mode)

(defun ar-sexp-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles sexp-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'sexp no-delimiters (interactive-p)))

(defalias 'ar-kill-sexp-atpt 'ar-sexp-kill-atpt)
;;;###autoload
(defun ar-sexp-kill-atpt (&optional no-delimiters) 
  "Kills sexp at point if any. "
  (interactive "*P")
  (ar-th-kill 'sexp no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-sexp-atpt 'ar-sexp-left-right-singlequote-atpt)
;;;###autoload
(defun ar-sexp-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'sexp no-delimiters (interactive-p)))

(defalias 'ar-parentize-sexp-atpt 'ar-sexp-parentize-atpt)
;;;###autoload
(defun ar-sexp-parentize-atpt (&optional no-delimiters) 
  "Parentizes sexp at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'sexp no-delimiters (interactive-p)))

(defalias 'ar-separate-sexp-atpt 'ar-sexp-separate-atpt)
;;;###autoload
(defun ar-sexp-separate-atpt (&optional no-delimiters) 
  "Separates sexp at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'sexp no-delimiters (interactive-p)))

(defalias 'ar-singlequote-sexp-atpt 'ar-sexp-singlequote-atpt)
;;;###autoload
(defun ar-sexp-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes sexp at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'sexp no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-sexp-atpt 'ar-sexp-triplequote-dq-atpt)
;;;###autoload
(defun ar-sexp-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around sexp. "
  (interactive "*p")
  (ar-th-triplequote-dq 'sexp no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-sexp-atpt 'ar-sexp-triplequote-sq-atpt)
;;;###autoload
(defun ar-sexp-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around sexp. "
  (interactive "*p")
  (ar-th-triplequote-sq 'sexp no-delimiters (interactive-p)))

(defalias 'ar-trim-sexp-atpt 'ar-sexp-trim-atpt)
;;;###autoload
(defun ar-sexp-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sexp t t)) 
    (ar-th-trim 'sexp t t)))

(defalias 'ar-trim-left-sexp-atpt 'ar-sexp-left-trim-atpt)
;;;###autoload
(defun ar-sexp-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sexp t nil))
    (ar-th-trim 'sexp t nil)))

(defalias 'ar-trim-right-sexp-atpt 'ar-sexp-right-trim-atpt)
;;;###autoload
(defun ar-sexp-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sexp nil t))
    (ar-th-trim 'sexp nil t)))

(defalias 'ar-sexp-underscore-atpt 'ar-underscore-sexp-atpt)
;;;###autoload
(defun ar-underscore-sexp-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'sexp no-delimiters (interactive-p)))

(defalias 'ar-sexp-whitespace-atpt 'ar-whitespace-sexp-atpt)
;;;###autoload
(defun ar-whitespace-sexp-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'sexp nil t))

(defalias 'ar-forward-sexp-atpt 'ar-sexp-forward-atpt)
;;;###autoload
(defun ar-sexp-forward-atpt (&optional arg) 
  "Moves forward over sexp at point if any, does nothing otherwise.
Returns end position of sexp "
  (interactive "p")
  (ar-th-forward 'sexp arg (interactive-p)))

(defalias 'ar-backward-sexp-atpt 'ar-sexp-backward-atpt)
;;;###autoload
(defun ar-sexp-backward-atpt (&optional arg) 
  "Moves backward over sexp before point if any, does nothing otherwise.
Returns beginning position of sexp "
  (interactive "p")
  (ar-th-backward 'sexp arg (interactive-p)))

(defalias 'ar-transpose-sexp-atpt 'ar-sexp-transpose-atpt)
;;;###autoload
(defun ar-sexp-transpose-atpt (&optional arg) 
  "Transposes sexp with sexp before point if any. "
  (interactive "*p")
  (ar-th-transpose 'sexp arg (interactive-p)))

(defalias 'ar-sort-sexp-atpt 'ar-sexp-sort-atpt)
;;;###autoload
(defun ar-sexp-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sexps in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'sexp reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-sexp-atpt 'ar-sexp-check-atpt)
;;;###autoload
(defun ar-sexp-check-atpt () 
  "Return t if a sexp at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-sexp-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-sexp-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-string-atpt (&optional arg no-delimiters) 
  "Returns string at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'string arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-string-atpt 'ar-string-bounds-atpt)
;;;###autoload
(defun ar-string-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of string if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'string no-delimiters (interactive-p)))

;;;###autoload
(defun ar-string-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position string at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'string no-delimiters (interactive-p)))

;;;###autoload
(defun ar-string-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of string at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'string no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-string-atpt 'ar-string-beginning-atpt)
;;;###autoload
(defun ar-string-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class string at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'string no-delimiters (interactive-p)))

(defalias 'ar-end-of-string-atpt 'ar-string-end-atpt)
;;;###autoload
(defun ar-string-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class string at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'string no-delimiters (interactive-p)))

(defalias 'ar-in-string-p-atpt 'ar-string-in-p-atpt)
;;;###autoload
(defun ar-string-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of string at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'string no-delimiters (interactive-p)))

(defalias 'ar-length-of-string-atpt 'ar-string-length-atpt)
;;;###autoload
(defun ar-string-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class string at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'string no-delimiters (interactive-p)))

(defalias 'ar-copy-string-atpt 'ar-string-copy-atpt)
;;;###autoload
(defun ar-string-copy-atpt (&optional no-delimiters) 
  "Returns a copy of string at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'string no-delimiters (interactive-p)))

(defalias 'ar-delete-string-in-region 'ar-string-delete-in-region)
;;;###autoload
(defun ar-string-delete-in-region (beg end) 
  "Deletes string at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'string beg end (interactive-p)))

;;;###autoload
(defun ar-blok-string-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around string.
  Returns blok or nil if no string at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'string no-delimiters (interactive-p)))

(defalias 'ar-escape-string-atpt 'ar-string-escape-atpt)
;;;###autoload
(defun ar-string-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted string at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'string no-delimiters))

(defalias 'ar-doublequote-string-atpt 'ar-string-doublequote-atpt)
;;;###autoload
(defun ar-string-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes string at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'string no-delimiters (interactive-p)))

(defalias 'ar-slash-string-atpt 'ar-string-slash-atpt)
;;;###autoload
(defun ar-string-slash-atpt (&optional no-delimiters) 
  "Doublequotes string at point if any. "
  (interactive "*p")
  (ar-th-slash 'string no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-string-atpt 'ar-string-double-backslash-atpt)
;;;###autoload
(defun ar-string-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around string at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'string no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-string-atpt 'ar-string-doubleslash-atpt)
;;;###autoload
(defun ar-string-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around string at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'string no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-string-atpt 'ar-string-doubleslashparen-atpt)
;;;###autoload
(defun ar-string-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around string at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'string no-delimiters (interactive-p)))

(defalias 'ar-slashparen-string-atpt 'ar-string-slashparen-atpt)
;;;###autoload
(defun ar-string-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around string at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'string no-delimiters (interactive-p)))

(defalias 'ar-dollar-string-atpt 'ar-string-dollar-atpt)
;;;###autoload
(defun ar-string-dollar-atpt (&optional no-delimiters) 
  "Doublequotes string at point if any. "
  (interactive "*p")
  (ar-th-dollar 'string no-delimiters (interactive-p)))

(defalias 'ar-equalize-string-atpt 'ar-string-equalize-atpt)
;;;###autoload
(defun ar-string-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around string at point if any. "
  (interactive "*p")
  (ar-th-equalize 'string no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-string-atpt 'ar-string-greater-angle-atpt)
;;;###autoload
(defun ar-string-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for string after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'string no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-string-atpt 'ar-string-lesser-angle-atpt)
;;;###autoload
(defun ar-string-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for string after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'string no-delimiters (interactive-p)))

(defalias 'ar-backslash-string-atpt 'ar-string-backslash-atpt)
;;;###autoload
(defun ar-string-backslash-atpt (&optional no-delimiters) 
  "Backslash string at point if any. "
  (interactive "*p")
  (ar-th-backslash 'string no-delimiters (interactive-p))) 

(defalias 'ar-brace-string-atpt 'ar-string-brace-atpt)
;;;###autoload
(defun ar-string-brace-atpt (&optional no-delimiters) 
  "Braces string at point if any. "
  (interactive "*p")
  (ar-th-brace 'string no-delimiters (interactive-p)))

(defalias 'ar-bracket-string-atpt 'ar-string-bracket-atpt)
;;;###autoload
(defun ar-string-bracket-atpt (&optional no-delimiters) 
  "Brackets string after point if any. "
  (interactive "*p")
  (ar-th-bracket 'string no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-string-atpt (&optional no-delimiters) 
  "Comments string at point if any. "
  (interactive "*p")
  (ar-th-comment 'string no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-string-atpt (&optional no-delimiters) 
  "Put a comma after string at point if any. "
  (interactive "*p")
  (ar-th-commatize 'string no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-string-atpt (&optional no-delimiters) 
  "Put a singlequote before string at point if any. "
  (interactive "*p")
  (ar-th-quote 'string no-delimiters (interactive-p)))

(defalias 'ar-hyphen-string-atpt 'ar-string-hyphen-atpt)
;;;###autoload
(defun ar-string-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around string at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'string no-delimiters (interactive-p)))

(defalias 'ar-mark-string-atpt 'ar-string-mark-atpt)
;;;###autoload
(defun ar-string-mark-atpt () 
  "Marks string at point if any. "
  (interactive)
  (ar-th-mark 'string))

(defalias 'ar-hide-string-atpt 'ar-string-hide-atpt)
;;;###autoload
(defun ar-string-hide-atpt () 
  "Hides string at point. "
  (interactive)
  (ar-th-hide 'string))

(defalias 'ar-show-string-atpt 'ar-string-show-atpt)
;;;###autoload
(defun ar-string-show-atpt () 
  "Shows hidden string at point. "
  (interactive)
  (ar-th-show 'string))

(defalias 'ar-hide-show-string-atpt 'ar-string-hide-show-atpt)
;;;###autoload
(defun ar-string-hide-show-atpt () 
  "Alternatively hides or shows string at point. "
  (interactive)
  (ar-th-hide-show 'string))

(defalias 'ar-highlight-string-atpt-mode 'ar-string-highlight-atpt-mode)

(defun ar-string-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles string-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'string no-delimiters (interactive-p)))

(defalias 'ar-kill-string-atpt 'ar-string-kill-atpt)
;;;###autoload
(defun ar-string-kill-atpt (&optional no-delimiters) 
  "Kills string at point if any. "
  (interactive "*P")
  (ar-th-kill 'string no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-string-atpt 'ar-string-left-right-singlequote-atpt)
;;;###autoload
(defun ar-string-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'string no-delimiters (interactive-p)))

(defalias 'ar-parentize-string-atpt 'ar-string-parentize-atpt)
;;;###autoload
(defun ar-string-parentize-atpt (&optional no-delimiters) 
  "Parentizes string at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'string no-delimiters (interactive-p)))

(defalias 'ar-separate-string-atpt 'ar-string-separate-atpt)
;;;###autoload
(defun ar-string-separate-atpt (&optional no-delimiters) 
  "Separates string at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'string no-delimiters (interactive-p)))

(defalias 'ar-singlequote-string-atpt 'ar-string-singlequote-atpt)
;;;###autoload
(defun ar-string-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes string at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'string no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-string-atpt 'ar-string-triplequote-dq-atpt)
;;;###autoload
(defun ar-string-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around string. "
  (interactive "*p")
  (ar-th-triplequote-dq 'string no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-string-atpt 'ar-string-triplequote-sq-atpt)
;;;###autoload
(defun ar-string-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around string. "
  (interactive "*p")
  (ar-th-triplequote-sq 'string no-delimiters (interactive-p)))

(defalias 'ar-trim-string-atpt 'ar-string-trim-atpt)
;;;###autoload
(defun ar-string-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'string t t)) 
    (ar-th-trim 'string t t)))

(defalias 'ar-trim-left-string-atpt 'ar-string-left-trim-atpt)
;;;###autoload
(defun ar-string-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'string t nil))
    (ar-th-trim 'string t nil)))

(defalias 'ar-trim-right-string-atpt 'ar-string-right-trim-atpt)
;;;###autoload
(defun ar-string-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'string nil t))
    (ar-th-trim 'string nil t)))

(defalias 'ar-string-underscore-atpt 'ar-underscore-string-atpt)
;;;###autoload
(defun ar-underscore-string-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'string no-delimiters (interactive-p)))

(defalias 'ar-string-whitespace-atpt 'ar-whitespace-string-atpt)
;;;###autoload
(defun ar-whitespace-string-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'string nil t))

(defalias 'ar-forward-string-atpt 'ar-string-forward-atpt)
;;;###autoload
(defun ar-string-forward-atpt (&optional arg) 
  "Moves forward over string at point if any, does nothing otherwise.
Returns end position of string "
  (interactive "p")
  (ar-th-forward 'string arg (interactive-p)))

(defalias 'ar-backward-string-atpt 'ar-string-backward-atpt)
;;;###autoload
(defun ar-string-backward-atpt (&optional arg) 
  "Moves backward over string before point if any, does nothing otherwise.
Returns beginning position of string "
  (interactive "p")
  (ar-th-backward 'string arg (interactive-p)))

(defalias 'ar-transpose-string-atpt 'ar-string-transpose-atpt)
;;;###autoload
(defun ar-string-transpose-atpt (&optional arg) 
  "Transposes string with string before point if any. "
  (interactive "*p")
  (ar-th-transpose 'string arg (interactive-p)))

(defalias 'ar-sort-string-atpt 'ar-string-sort-atpt)
;;;###autoload
(defun ar-string-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts strings in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'string reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-string-atpt 'ar-string-check-atpt)
;;;###autoload
(defun ar-string-check-atpt () 
  "Return t if a string at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-string-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-string-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-sh-struct-atpt (&optional arg no-delimiters) 
  "Returns sh-struct at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'sh-struct arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-sh-struct-atpt 'ar-sh-struct-bounds-atpt)
;;;###autoload
(defun ar-sh-struct-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of sh-struct if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'sh-struct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sh-struct-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position sh-struct at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'sh-struct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-sh-struct-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of sh-struct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-sh-struct-atpt 'ar-sh-struct-beginning-atpt)
;;;###autoload
(defun ar-sh-struct-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class sh-struct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-end-of-sh-struct-atpt 'ar-sh-struct-end-atpt)
;;;###autoload
(defun ar-sh-struct-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class sh-struct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-in-sh-struct-p-atpt 'ar-sh-struct-in-p-atpt)
;;;###autoload
(defun ar-sh-struct-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of sh-struct at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-length-of-sh-struct-atpt 'ar-sh-struct-length-atpt)
;;;###autoload
(defun ar-sh-struct-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class sh-struct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-copy-sh-struct-atpt 'ar-sh-struct-copy-atpt)
;;;###autoload
(defun ar-sh-struct-copy-atpt (&optional no-delimiters) 
  "Returns a copy of sh-struct at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-delete-sh-struct-in-region 'ar-sh-struct-delete-in-region)
;;;###autoload
(defun ar-sh-struct-delete-in-region (beg end) 
  "Deletes sh-struct at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'sh-struct beg end (interactive-p)))

;;;###autoload
(defun ar-blok-sh-struct-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around sh-struct.
  Returns blok or nil if no sh-struct at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-escape-sh-struct-atpt 'ar-sh-struct-escape-atpt)
;;;###autoload
(defun ar-sh-struct-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted sh-struct at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'sh-struct no-delimiters))

(defalias 'ar-doublequote-sh-struct-atpt 'ar-sh-struct-doublequote-atpt)
;;;###autoload
(defun ar-sh-struct-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes sh-struct at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-slash-sh-struct-atpt 'ar-sh-struct-slash-atpt)
;;;###autoload
(defun ar-sh-struct-slash-atpt (&optional no-delimiters) 
  "Doublequotes sh-struct at point if any. "
  (interactive "*p")
  (ar-th-slash 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-sh-struct-atpt 'ar-sh-struct-double-backslash-atpt)
;;;###autoload
(defun ar-sh-struct-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-sh-struct-atpt 'ar-sh-struct-doubleslash-atpt)
;;;###autoload
(defun ar-sh-struct-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-sh-struct-atpt 'ar-sh-struct-doubleslashparen-atpt)
;;;###autoload
(defun ar-sh-struct-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-slashparen-sh-struct-atpt 'ar-sh-struct-slashparen-atpt)
;;;###autoload
(defun ar-sh-struct-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-dollar-sh-struct-atpt 'ar-sh-struct-dollar-atpt)
;;;###autoload
(defun ar-sh-struct-dollar-atpt (&optional no-delimiters) 
  "Doublequotes sh-struct at point if any. "
  (interactive "*p")
  (ar-th-dollar 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-equalize-sh-struct-atpt 'ar-sh-struct-equalize-atpt)
;;;###autoload
(defun ar-sh-struct-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-equalize 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-sh-struct-atpt 'ar-sh-struct-greater-angle-atpt)
;;;###autoload
(defun ar-sh-struct-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for sh-struct after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-sh-struct-atpt 'ar-sh-struct-lesser-angle-atpt)
;;;###autoload
(defun ar-sh-struct-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for sh-struct after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-backslash-sh-struct-atpt 'ar-sh-struct-backslash-atpt)
;;;###autoload
(defun ar-sh-struct-backslash-atpt (&optional no-delimiters) 
  "Backslash sh-struct at point if any. "
  (interactive "*p")
  (ar-th-backslash 'sh-struct no-delimiters (interactive-p))) 

(defalias 'ar-brace-sh-struct-atpt 'ar-sh-struct-brace-atpt)
;;;###autoload
(defun ar-sh-struct-brace-atpt (&optional no-delimiters) 
  "Braces sh-struct at point if any. "
  (interactive "*p")
  (ar-th-brace 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-bracket-sh-struct-atpt 'ar-sh-struct-bracket-atpt)
;;;###autoload
(defun ar-sh-struct-bracket-atpt (&optional no-delimiters) 
  "Brackets sh-struct after point if any. "
  (interactive "*p")
  (ar-th-bracket 'sh-struct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-sh-struct-atpt (&optional no-delimiters) 
  "Comments sh-struct at point if any. "
  (interactive "*p")
  (ar-th-comment 'sh-struct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-sh-struct-atpt (&optional no-delimiters) 
  "Put a comma after sh-struct at point if any. "
  (interactive "*p")
  (ar-th-commatize 'sh-struct no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-sh-struct-atpt (&optional no-delimiters) 
  "Put a singlequote before sh-struct at point if any. "
  (interactive "*p")
  (ar-th-quote 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-hyphen-sh-struct-atpt 'ar-sh-struct-hyphen-atpt)
;;;###autoload
(defun ar-sh-struct-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around sh-struct at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-mark-sh-struct-atpt 'ar-sh-struct-mark-atpt)
;;;###autoload
(defun ar-sh-struct-mark-atpt () 
  "Marks sh-struct at point if any. "
  (interactive)
  (ar-th-mark 'sh-struct))

(defalias 'ar-hide-sh-struct-atpt 'ar-sh-struct-hide-atpt)
;;;###autoload
(defun ar-sh-struct-hide-atpt () 
  "Hides sh-struct at point. "
  (interactive)
  (ar-th-hide 'sh-struct))

(defalias 'ar-show-sh-struct-atpt 'ar-sh-struct-show-atpt)
;;;###autoload
(defun ar-sh-struct-show-atpt () 
  "Shows hidden sh-struct at point. "
  (interactive)
  (ar-th-show 'sh-struct))

(defalias 'ar-hide-show-sh-struct-atpt 'ar-sh-struct-hide-show-atpt)
;;;###autoload
(defun ar-sh-struct-hide-show-atpt () 
  "Alternatively hides or shows sh-struct at point. "
  (interactive)
  (ar-th-hide-show 'sh-struct))

(defalias 'ar-highlight-sh-struct-atpt-mode 'ar-sh-struct-highlight-atpt-mode)

(defun ar-sh-struct-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles sh-struct-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-kill-sh-struct-atpt 'ar-sh-struct-kill-atpt)
;;;###autoload
(defun ar-sh-struct-kill-atpt (&optional no-delimiters) 
  "Kills sh-struct at point if any. "
  (interactive "*P")
  (ar-th-kill 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-sh-struct-atpt 'ar-sh-struct-left-right-singlequote-atpt)
;;;###autoload
(defun ar-sh-struct-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-parentize-sh-struct-atpt 'ar-sh-struct-parentize-atpt)
;;;###autoload
(defun ar-sh-struct-parentize-atpt (&optional no-delimiters) 
  "Parentizes sh-struct at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-separate-sh-struct-atpt 'ar-sh-struct-separate-atpt)
;;;###autoload
(defun ar-sh-struct-separate-atpt (&optional no-delimiters) 
  "Separates sh-struct at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-singlequote-sh-struct-atpt 'ar-sh-struct-singlequote-atpt)
;;;###autoload
(defun ar-sh-struct-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes sh-struct at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-sh-struct-atpt 'ar-sh-struct-triplequote-dq-atpt)
;;;###autoload
(defun ar-sh-struct-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around sh-struct. "
  (interactive "*p")
  (ar-th-triplequote-dq 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-sh-struct-atpt 'ar-sh-struct-triplequote-sq-atpt)
;;;###autoload
(defun ar-sh-struct-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around sh-struct. "
  (interactive "*p")
  (ar-th-triplequote-sq 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-trim-sh-struct-atpt 'ar-sh-struct-trim-atpt)
;;;###autoload
(defun ar-sh-struct-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sh-struct t t)) 
    (ar-th-trim 'sh-struct t t)))

(defalias 'ar-trim-left-sh-struct-atpt 'ar-sh-struct-left-trim-atpt)
;;;###autoload
(defun ar-sh-struct-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sh-struct t nil))
    (ar-th-trim 'sh-struct t nil)))

(defalias 'ar-trim-right-sh-struct-atpt 'ar-sh-struct-right-trim-atpt)
;;;###autoload
(defun ar-sh-struct-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'sh-struct nil t))
    (ar-th-trim 'sh-struct nil t)))

(defalias 'ar-sh-struct-underscore-atpt 'ar-underscore-sh-struct-atpt)
;;;###autoload
(defun ar-underscore-sh-struct-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'sh-struct no-delimiters (interactive-p)))

(defalias 'ar-sh-struct-whitespace-atpt 'ar-whitespace-sh-struct-atpt)
;;;###autoload
(defun ar-whitespace-sh-struct-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'sh-struct nil t))

(defalias 'ar-forward-sh-struct-atpt 'ar-sh-struct-forward-atpt)
;;;###autoload
(defun ar-sh-struct-forward-atpt (&optional arg) 
  "Moves forward over sh-struct at point if any, does nothing otherwise.
Returns end position of sh-struct "
  (interactive "p")
  (ar-th-forward 'sh-struct arg (interactive-p)))

(defalias 'ar-backward-sh-struct-atpt 'ar-sh-struct-backward-atpt)
;;;###autoload
(defun ar-sh-struct-backward-atpt (&optional arg) 
  "Moves backward over sh-struct before point if any, does nothing otherwise.
Returns beginning position of sh-struct "
  (interactive "p")
  (ar-th-backward 'sh-struct arg (interactive-p)))

(defalias 'ar-transpose-sh-struct-atpt 'ar-sh-struct-transpose-atpt)
;;;###autoload
(defun ar-sh-struct-transpose-atpt (&optional arg) 
  "Transposes sh-struct with sh-struct before point if any. "
  (interactive "*p")
  (ar-th-transpose 'sh-struct arg (interactive-p)))

(defalias 'ar-sort-sh-struct-atpt 'ar-sh-struct-sort-atpt)
;;;###autoload
(defun ar-sh-struct-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts sh-structs in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'sh-struct reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-sh-struct-atpt 'ar-sh-struct-check-atpt)
;;;###autoload
(defun ar-sh-struct-check-atpt () 
  "Return t if a sh-struct at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-sh-struct-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-sh-struct-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-symbol-atpt (&optional arg no-delimiters) 
  "Returns symbol at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'symbol arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-symbol-atpt 'ar-symbol-bounds-atpt)
;;;###autoload
(defun ar-symbol-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of symbol if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'symbol no-delimiters (interactive-p)))

;;;###autoload
(defun ar-symbol-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position symbol at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'symbol no-delimiters (interactive-p)))

;;;###autoload
(defun ar-symbol-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of symbol at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'symbol no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-symbol-atpt 'ar-symbol-beginning-atpt)
;;;###autoload
(defun ar-symbol-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class symbol at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'symbol no-delimiters (interactive-p)))

(defalias 'ar-end-of-symbol-atpt 'ar-symbol-end-atpt)
;;;###autoload
(defun ar-symbol-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class symbol at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'symbol no-delimiters (interactive-p)))

(defalias 'ar-in-symbol-p-atpt 'ar-symbol-in-p-atpt)
;;;###autoload
(defun ar-symbol-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of symbol at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'symbol no-delimiters (interactive-p)))

(defalias 'ar-length-of-symbol-atpt 'ar-symbol-length-atpt)
;;;###autoload
(defun ar-symbol-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class symbol at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'symbol no-delimiters (interactive-p)))

(defalias 'ar-copy-symbol-atpt 'ar-symbol-copy-atpt)
;;;###autoload
(defun ar-symbol-copy-atpt (&optional no-delimiters) 
  "Returns a copy of symbol at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'symbol no-delimiters (interactive-p)))

(defalias 'ar-delete-symbol-in-region 'ar-symbol-delete-in-region)
;;;###autoload
(defun ar-symbol-delete-in-region (beg end) 
  "Deletes symbol at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'symbol beg end (interactive-p)))

;;;###autoload
(defun ar-blok-symbol-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around symbol.
  Returns blok or nil if no symbol at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'symbol no-delimiters (interactive-p)))

(defalias 'ar-escape-symbol-atpt 'ar-symbol-escape-atpt)
;;;###autoload
(defun ar-symbol-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted symbol at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'symbol no-delimiters))

(defalias 'ar-doublequote-symbol-atpt 'ar-symbol-doublequote-atpt)
;;;###autoload
(defun ar-symbol-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes symbol at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'symbol no-delimiters (interactive-p)))

(defalias 'ar-slash-symbol-atpt 'ar-symbol-slash-atpt)
;;;###autoload
(defun ar-symbol-slash-atpt (&optional no-delimiters) 
  "Doublequotes symbol at point if any. "
  (interactive "*p")
  (ar-th-slash 'symbol no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-symbol-atpt 'ar-symbol-double-backslash-atpt)
;;;###autoload
(defun ar-symbol-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around symbol at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'symbol no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-symbol-atpt 'ar-symbol-doubleslash-atpt)
;;;###autoload
(defun ar-symbol-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around symbol at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'symbol no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-symbol-atpt 'ar-symbol-doubleslashparen-atpt)
;;;###autoload
(defun ar-symbol-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around symbol at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'symbol no-delimiters (interactive-p)))

(defalias 'ar-slashparen-symbol-atpt 'ar-symbol-slashparen-atpt)
;;;###autoload
(defun ar-symbol-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around symbol at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'symbol no-delimiters (interactive-p)))

(defalias 'ar-dollar-symbol-atpt 'ar-symbol-dollar-atpt)
;;;###autoload
(defun ar-symbol-dollar-atpt (&optional no-delimiters) 
  "Doublequotes symbol at point if any. "
  (interactive "*p")
  (ar-th-dollar 'symbol no-delimiters (interactive-p)))

(defalias 'ar-equalize-symbol-atpt 'ar-symbol-equalize-atpt)
;;;###autoload
(defun ar-symbol-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around symbol at point if any. "
  (interactive "*p")
  (ar-th-equalize 'symbol no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-symbol-atpt 'ar-symbol-greater-angle-atpt)
;;;###autoload
(defun ar-symbol-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for symbol after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'symbol no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-symbol-atpt 'ar-symbol-lesser-angle-atpt)
;;;###autoload
(defun ar-symbol-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for symbol after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'symbol no-delimiters (interactive-p)))

(defalias 'ar-backslash-symbol-atpt 'ar-symbol-backslash-atpt)
;;;###autoload
(defun ar-symbol-backslash-atpt (&optional no-delimiters) 
  "Backslash symbol at point if any. "
  (interactive "*p")
  (ar-th-backslash 'symbol no-delimiters (interactive-p))) 

(defalias 'ar-brace-symbol-atpt 'ar-symbol-brace-atpt)
;;;###autoload
(defun ar-symbol-brace-atpt (&optional no-delimiters) 
  "Braces symbol at point if any. "
  (interactive "*p")
  (ar-th-brace 'symbol no-delimiters (interactive-p)))

(defalias 'ar-bracket-symbol-atpt 'ar-symbol-bracket-atpt)
;;;###autoload
(defun ar-symbol-bracket-atpt (&optional no-delimiters) 
  "Brackets symbol after point if any. "
  (interactive "*p")
  (ar-th-bracket 'symbol no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-symbol-atpt (&optional no-delimiters) 
  "Comments symbol at point if any. "
  (interactive "*p")
  (ar-th-comment 'symbol no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-symbol-atpt (&optional no-delimiters) 
  "Put a comma after symbol at point if any. "
  (interactive "*p")
  (ar-th-commatize 'symbol no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-symbol-atpt (&optional no-delimiters) 
  "Put a singlequote before symbol at point if any. "
  (interactive "*p")
  (ar-th-quote 'symbol no-delimiters (interactive-p)))

(defalias 'ar-hyphen-symbol-atpt 'ar-symbol-hyphen-atpt)
;;;###autoload
(defun ar-symbol-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around symbol at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'symbol no-delimiters (interactive-p)))

(defalias 'ar-mark-symbol-atpt 'ar-symbol-mark-atpt)
;;;###autoload
(defun ar-symbol-mark-atpt () 
  "Marks symbol at point if any. "
  (interactive)
  (ar-th-mark 'symbol))

(defalias 'ar-hide-symbol-atpt 'ar-symbol-hide-atpt)
;;;###autoload
(defun ar-symbol-hide-atpt () 
  "Hides symbol at point. "
  (interactive)
  (ar-th-hide 'symbol))

(defalias 'ar-show-symbol-atpt 'ar-symbol-show-atpt)
;;;###autoload
(defun ar-symbol-show-atpt () 
  "Shows hidden symbol at point. "
  (interactive)
  (ar-th-show 'symbol))

(defalias 'ar-hide-show-symbol-atpt 'ar-symbol-hide-show-atpt)
;;;###autoload
(defun ar-symbol-hide-show-atpt () 
  "Alternatively hides or shows symbol at point. "
  (interactive)
  (ar-th-hide-show 'symbol))

(defalias 'ar-highlight-symbol-atpt-mode 'ar-symbol-highlight-atpt-mode)

(defun ar-symbol-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles symbol-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'symbol no-delimiters (interactive-p)))

(defalias 'ar-kill-symbol-atpt 'ar-symbol-kill-atpt)
;;;###autoload
(defun ar-symbol-kill-atpt (&optional no-delimiters) 
  "Kills symbol at point if any. "
  (interactive "*P")
  (ar-th-kill 'symbol no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-symbol-atpt 'ar-symbol-left-right-singlequote-atpt)
;;;###autoload
(defun ar-symbol-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'symbol no-delimiters (interactive-p)))

(defalias 'ar-parentize-symbol-atpt 'ar-symbol-parentize-atpt)
;;;###autoload
(defun ar-symbol-parentize-atpt (&optional no-delimiters) 
  "Parentizes symbol at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'symbol no-delimiters (interactive-p)))

(defalias 'ar-separate-symbol-atpt 'ar-symbol-separate-atpt)
;;;###autoload
(defun ar-symbol-separate-atpt (&optional no-delimiters) 
  "Separates symbol at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'symbol no-delimiters (interactive-p)))

(defalias 'ar-singlequote-symbol-atpt 'ar-symbol-singlequote-atpt)
;;;###autoload
(defun ar-symbol-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes symbol at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'symbol no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-symbol-atpt 'ar-symbol-triplequote-dq-atpt)
;;;###autoload
(defun ar-symbol-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around symbol. "
  (interactive "*p")
  (ar-th-triplequote-dq 'symbol no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-symbol-atpt 'ar-symbol-triplequote-sq-atpt)
;;;###autoload
(defun ar-symbol-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around symbol. "
  (interactive "*p")
  (ar-th-triplequote-sq 'symbol no-delimiters (interactive-p)))

(defalias 'ar-trim-symbol-atpt 'ar-symbol-trim-atpt)
;;;###autoload
(defun ar-symbol-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'symbol t t)) 
    (ar-th-trim 'symbol t t)))

(defalias 'ar-trim-left-symbol-atpt 'ar-symbol-left-trim-atpt)
;;;###autoload
(defun ar-symbol-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'symbol t nil))
    (ar-th-trim 'symbol t nil)))

(defalias 'ar-trim-right-symbol-atpt 'ar-symbol-right-trim-atpt)
;;;###autoload
(defun ar-symbol-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'symbol nil t))
    (ar-th-trim 'symbol nil t)))

(defalias 'ar-symbol-underscore-atpt 'ar-underscore-symbol-atpt)
;;;###autoload
(defun ar-underscore-symbol-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'symbol no-delimiters (interactive-p)))

(defalias 'ar-symbol-whitespace-atpt 'ar-whitespace-symbol-atpt)
;;;###autoload
(defun ar-whitespace-symbol-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'symbol nil t))

(defalias 'ar-forward-symbol-atpt 'ar-symbol-forward-atpt)
;;;###autoload
(defun ar-symbol-forward-atpt (&optional arg) 
  "Moves forward over symbol at point if any, does nothing otherwise.
Returns end position of symbol "
  (interactive "p")
  (ar-th-forward 'symbol arg (interactive-p)))

(defalias 'ar-backward-symbol-atpt 'ar-symbol-backward-atpt)
;;;###autoload
(defun ar-symbol-backward-atpt (&optional arg) 
  "Moves backward over symbol before point if any, does nothing otherwise.
Returns beginning position of symbol "
  (interactive "p")
  (ar-th-backward 'symbol arg (interactive-p)))

(defalias 'ar-transpose-symbol-atpt 'ar-symbol-transpose-atpt)
;;;###autoload
(defun ar-symbol-transpose-atpt (&optional arg) 
  "Transposes symbol with symbol before point if any. "
  (interactive "*p")
  (ar-th-transpose 'symbol arg (interactive-p)))

(defalias 'ar-sort-symbol-atpt 'ar-symbol-sort-atpt)
;;;###autoload
(defun ar-symbol-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts symbols in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'symbol reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-symbol-atpt 'ar-symbol-check-atpt)
;;;###autoload
(defun ar-symbol-check-atpt () 
  "Return t if a symbol at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-symbol-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-symbol-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-url-atpt (&optional arg no-delimiters) 
  "Returns url at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'url arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-url-atpt 'ar-url-bounds-atpt)
;;;###autoload
(defun ar-url-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of url if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'url no-delimiters (interactive-p)))

;;;###autoload
(defun ar-url-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position url at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'url no-delimiters (interactive-p)))

;;;###autoload
(defun ar-url-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of url at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'url no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-url-atpt 'ar-url-beginning-atpt)
;;;###autoload
(defun ar-url-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class url at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'url no-delimiters (interactive-p)))

(defalias 'ar-end-of-url-atpt 'ar-url-end-atpt)
;;;###autoload
(defun ar-url-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class url at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'url no-delimiters (interactive-p)))

(defalias 'ar-in-url-p-atpt 'ar-url-in-p-atpt)
;;;###autoload
(defun ar-url-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of url at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'url no-delimiters (interactive-p)))

(defalias 'ar-length-of-url-atpt 'ar-url-length-atpt)
;;;###autoload
(defun ar-url-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class url at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'url no-delimiters (interactive-p)))

(defalias 'ar-copy-url-atpt 'ar-url-copy-atpt)
;;;###autoload
(defun ar-url-copy-atpt (&optional no-delimiters) 
  "Returns a copy of url at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'url no-delimiters (interactive-p)))

(defalias 'ar-delete-url-in-region 'ar-url-delete-in-region)
;;;###autoload
(defun ar-url-delete-in-region (beg end) 
  "Deletes url at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'url beg end (interactive-p)))

;;;###autoload
(defun ar-blok-url-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around url.
  Returns blok or nil if no url at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'url no-delimiters (interactive-p)))

(defalias 'ar-escape-url-atpt 'ar-url-escape-atpt)
;;;###autoload
(defun ar-url-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted url at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'url no-delimiters))

(defalias 'ar-doublequote-url-atpt 'ar-url-doublequote-atpt)
;;;###autoload
(defun ar-url-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes url at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'url no-delimiters (interactive-p)))

(defalias 'ar-slash-url-atpt 'ar-url-slash-atpt)
;;;###autoload
(defun ar-url-slash-atpt (&optional no-delimiters) 
  "Doublequotes url at point if any. "
  (interactive "*p")
  (ar-th-slash 'url no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-url-atpt 'ar-url-double-backslash-atpt)
;;;###autoload
(defun ar-url-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around url at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'url no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-url-atpt 'ar-url-doubleslash-atpt)
;;;###autoload
(defun ar-url-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around url at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'url no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-url-atpt 'ar-url-doubleslashparen-atpt)
;;;###autoload
(defun ar-url-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around url at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'url no-delimiters (interactive-p)))

(defalias 'ar-slashparen-url-atpt 'ar-url-slashparen-atpt)
;;;###autoload
(defun ar-url-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around url at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'url no-delimiters (interactive-p)))

(defalias 'ar-dollar-url-atpt 'ar-url-dollar-atpt)
;;;###autoload
(defun ar-url-dollar-atpt (&optional no-delimiters) 
  "Doublequotes url at point if any. "
  (interactive "*p")
  (ar-th-dollar 'url no-delimiters (interactive-p)))

(defalias 'ar-equalize-url-atpt 'ar-url-equalize-atpt)
;;;###autoload
(defun ar-url-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around url at point if any. "
  (interactive "*p")
  (ar-th-equalize 'url no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-url-atpt 'ar-url-greater-angle-atpt)
;;;###autoload
(defun ar-url-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for url after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'url no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-url-atpt 'ar-url-lesser-angle-atpt)
;;;###autoload
(defun ar-url-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for url after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'url no-delimiters (interactive-p)))

(defalias 'ar-backslash-url-atpt 'ar-url-backslash-atpt)
;;;###autoload
(defun ar-url-backslash-atpt (&optional no-delimiters) 
  "Backslash url at point if any. "
  (interactive "*p")
  (ar-th-backslash 'url no-delimiters (interactive-p))) 

(defalias 'ar-brace-url-atpt 'ar-url-brace-atpt)
;;;###autoload
(defun ar-url-brace-atpt (&optional no-delimiters) 
  "Braces url at point if any. "
  (interactive "*p")
  (ar-th-brace 'url no-delimiters (interactive-p)))

(defalias 'ar-bracket-url-atpt 'ar-url-bracket-atpt)
;;;###autoload
(defun ar-url-bracket-atpt (&optional no-delimiters) 
  "Brackets url after point if any. "
  (interactive "*p")
  (ar-th-bracket 'url no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-url-atpt (&optional no-delimiters) 
  "Comments url at point if any. "
  (interactive "*p")
  (ar-th-comment 'url no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-url-atpt (&optional no-delimiters) 
  "Put a comma after url at point if any. "
  (interactive "*p")
  (ar-th-commatize 'url no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-url-atpt (&optional no-delimiters) 
  "Put a singlequote before url at point if any. "
  (interactive "*p")
  (ar-th-quote 'url no-delimiters (interactive-p)))

(defalias 'ar-hyphen-url-atpt 'ar-url-hyphen-atpt)
;;;###autoload
(defun ar-url-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around url at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'url no-delimiters (interactive-p)))

(defalias 'ar-mark-url-atpt 'ar-url-mark-atpt)
;;;###autoload
(defun ar-url-mark-atpt () 
  "Marks url at point if any. "
  (interactive)
  (ar-th-mark 'url))

(defalias 'ar-hide-url-atpt 'ar-url-hide-atpt)
;;;###autoload
(defun ar-url-hide-atpt () 
  "Hides url at point. "
  (interactive)
  (ar-th-hide 'url))

(defalias 'ar-show-url-atpt 'ar-url-show-atpt)
;;;###autoload
(defun ar-url-show-atpt () 
  "Shows hidden url at point. "
  (interactive)
  (ar-th-show 'url))

(defalias 'ar-hide-show-url-atpt 'ar-url-hide-show-atpt)
;;;###autoload
(defun ar-url-hide-show-atpt () 
  "Alternatively hides or shows url at point. "
  (interactive)
  (ar-th-hide-show 'url))

(defalias 'ar-highlight-url-atpt-mode 'ar-url-highlight-atpt-mode)

(defun ar-url-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles url-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'url no-delimiters (interactive-p)))

(defalias 'ar-kill-url-atpt 'ar-url-kill-atpt)
;;;###autoload
(defun ar-url-kill-atpt (&optional no-delimiters) 
  "Kills url at point if any. "
  (interactive "*P")
  (ar-th-kill 'url no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-url-atpt 'ar-url-left-right-singlequote-atpt)
;;;###autoload
(defun ar-url-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'url no-delimiters (interactive-p)))

(defalias 'ar-parentize-url-atpt 'ar-url-parentize-atpt)
;;;###autoload
(defun ar-url-parentize-atpt (&optional no-delimiters) 
  "Parentizes url at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'url no-delimiters (interactive-p)))

(defalias 'ar-separate-url-atpt 'ar-url-separate-atpt)
;;;###autoload
(defun ar-url-separate-atpt (&optional no-delimiters) 
  "Separates url at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'url no-delimiters (interactive-p)))

(defalias 'ar-singlequote-url-atpt 'ar-url-singlequote-atpt)
;;;###autoload
(defun ar-url-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes url at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'url no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-url-atpt 'ar-url-triplequote-dq-atpt)
;;;###autoload
(defun ar-url-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around url. "
  (interactive "*p")
  (ar-th-triplequote-dq 'url no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-url-atpt 'ar-url-triplequote-sq-atpt)
;;;###autoload
(defun ar-url-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around url. "
  (interactive "*p")
  (ar-th-triplequote-sq 'url no-delimiters (interactive-p)))

(defalias 'ar-trim-url-atpt 'ar-url-trim-atpt)
;;;###autoload
(defun ar-url-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'url t t)) 
    (ar-th-trim 'url t t)))

(defalias 'ar-trim-left-url-atpt 'ar-url-left-trim-atpt)
;;;###autoload
(defun ar-url-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'url t nil))
    (ar-th-trim 'url t nil)))

(defalias 'ar-trim-right-url-atpt 'ar-url-right-trim-atpt)
;;;###autoload
(defun ar-url-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'url nil t))
    (ar-th-trim 'url nil t)))

(defalias 'ar-url-underscore-atpt 'ar-underscore-url-atpt)
;;;###autoload
(defun ar-underscore-url-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'url no-delimiters (interactive-p)))

(defalias 'ar-url-whitespace-atpt 'ar-whitespace-url-atpt)
;;;###autoload
(defun ar-whitespace-url-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'url nil t))

(defalias 'ar-forward-url-atpt 'ar-url-forward-atpt)
;;;###autoload
(defun ar-url-forward-atpt (&optional arg) 
  "Moves forward over url at point if any, does nothing otherwise.
Returns end position of url "
  (interactive "p")
  (ar-th-forward 'url arg (interactive-p)))

(defalias 'ar-backward-url-atpt 'ar-url-backward-atpt)
;;;###autoload
(defun ar-url-backward-atpt (&optional arg) 
  "Moves backward over url before point if any, does nothing otherwise.
Returns beginning position of url "
  (interactive "p")
  (ar-th-backward 'url arg (interactive-p)))

(defalias 'ar-transpose-url-atpt 'ar-url-transpose-atpt)
;;;###autoload
(defun ar-url-transpose-atpt (&optional arg) 
  "Transposes url with url before point if any. "
  (interactive "*p")
  (ar-th-transpose 'url arg (interactive-p)))

(defalias 'ar-sort-url-atpt 'ar-url-sort-atpt)
;;;###autoload
(defun ar-url-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts urls in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'url reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-url-atpt 'ar-url-check-atpt)
;;;###autoload
(defun ar-url-check-atpt () 
  "Return t if a url at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-url-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-url-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-word-atpt (&optional arg no-delimiters) 
  "Returns word at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'word arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-word-atpt 'ar-word-bounds-atpt)
;;;###autoload
(defun ar-word-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of word if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'word no-delimiters (interactive-p)))

;;;###autoload
(defun ar-word-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position word at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'word no-delimiters (interactive-p)))

;;;###autoload
(defun ar-word-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of word at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'word no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-word-atpt 'ar-word-beginning-atpt)
;;;###autoload
(defun ar-word-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class word at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'word no-delimiters (interactive-p)))

(defalias 'ar-end-of-word-atpt 'ar-word-end-atpt)
;;;###autoload
(defun ar-word-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class word at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'word no-delimiters (interactive-p)))

(defalias 'ar-in-word-p-atpt 'ar-word-in-p-atpt)
;;;###autoload
(defun ar-word-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of word at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'word no-delimiters (interactive-p)))

(defalias 'ar-length-of-word-atpt 'ar-word-length-atpt)
;;;###autoload
(defun ar-word-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class word at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'word no-delimiters (interactive-p)))

(defalias 'ar-copy-word-atpt 'ar-word-copy-atpt)
;;;###autoload
(defun ar-word-copy-atpt (&optional no-delimiters) 
  "Returns a copy of word at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'word no-delimiters (interactive-p)))

(defalias 'ar-delete-word-in-region 'ar-word-delete-in-region)
;;;###autoload
(defun ar-word-delete-in-region (beg end) 
  "Deletes word at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'word beg end (interactive-p)))

;;;###autoload
(defun ar-blok-word-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around word.
  Returns blok or nil if no word at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'word no-delimiters (interactive-p)))

(defalias 'ar-escape-word-atpt 'ar-word-escape-atpt)
;;;###autoload
(defun ar-word-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted word at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'word no-delimiters))

(defalias 'ar-doublequote-word-atpt 'ar-word-doublequote-atpt)
;;;###autoload
(defun ar-word-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes word at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'word no-delimiters (interactive-p)))

(defalias 'ar-slash-word-atpt 'ar-word-slash-atpt)
;;;###autoload
(defun ar-word-slash-atpt (&optional no-delimiters) 
  "Doublequotes word at point if any. "
  (interactive "*p")
  (ar-th-slash 'word no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-word-atpt 'ar-word-double-backslash-atpt)
;;;###autoload
(defun ar-word-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around word at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'word no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-word-atpt 'ar-word-doubleslash-atpt)
;;;###autoload
(defun ar-word-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around word at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'word no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-word-atpt 'ar-word-doubleslashparen-atpt)
;;;###autoload
(defun ar-word-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around word at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'word no-delimiters (interactive-p)))

(defalias 'ar-slashparen-word-atpt 'ar-word-slashparen-atpt)
;;;###autoload
(defun ar-word-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around word at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'word no-delimiters (interactive-p)))

(defalias 'ar-dollar-word-atpt 'ar-word-dollar-atpt)
;;;###autoload
(defun ar-word-dollar-atpt (&optional no-delimiters) 
  "Doublequotes word at point if any. "
  (interactive "*p")
  (ar-th-dollar 'word no-delimiters (interactive-p)))

(defalias 'ar-equalize-word-atpt 'ar-word-equalize-atpt)
;;;###autoload
(defun ar-word-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around word at point if any. "
  (interactive "*p")
  (ar-th-equalize 'word no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-word-atpt 'ar-word-greater-angle-atpt)
;;;###autoload
(defun ar-word-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for word after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'word no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-word-atpt 'ar-word-lesser-angle-atpt)
;;;###autoload
(defun ar-word-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for word after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'word no-delimiters (interactive-p)))

(defalias 'ar-backslash-word-atpt 'ar-word-backslash-atpt)
;;;###autoload
(defun ar-word-backslash-atpt (&optional no-delimiters) 
  "Backslash word at point if any. "
  (interactive "*p")
  (ar-th-backslash 'word no-delimiters (interactive-p))) 

(defalias 'ar-brace-word-atpt 'ar-word-brace-atpt)
;;;###autoload
(defun ar-word-brace-atpt (&optional no-delimiters) 
  "Braces word at point if any. "
  (interactive "*p")
  (ar-th-brace 'word no-delimiters (interactive-p)))

(defalias 'ar-bracket-word-atpt 'ar-word-bracket-atpt)
;;;###autoload
(defun ar-word-bracket-atpt (&optional no-delimiters) 
  "Brackets word after point if any. "
  (interactive "*p")
  (ar-th-bracket 'word no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-word-atpt (&optional no-delimiters) 
  "Comments word at point if any. "
  (interactive "*p")
  (ar-th-comment 'word no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-word-atpt (&optional no-delimiters) 
  "Put a comma after word at point if any. "
  (interactive "*p")
  (ar-th-commatize 'word no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-word-atpt (&optional no-delimiters) 
  "Put a singlequote before word at point if any. "
  (interactive "*p")
  (ar-th-quote 'word no-delimiters (interactive-p)))

(defalias 'ar-hyphen-word-atpt 'ar-word-hyphen-atpt)
;;;###autoload
(defun ar-word-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around word at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'word no-delimiters (interactive-p)))

(defalias 'ar-mark-word-atpt 'ar-word-mark-atpt)
;;;###autoload
(defun ar-word-mark-atpt () 
  "Marks word at point if any. "
  (interactive)
  (ar-th-mark 'word))

(defalias 'ar-hide-word-atpt 'ar-word-hide-atpt)
;;;###autoload
(defun ar-word-hide-atpt () 
  "Hides word at point. "
  (interactive)
  (ar-th-hide 'word))

(defalias 'ar-show-word-atpt 'ar-word-show-atpt)
;;;###autoload
(defun ar-word-show-atpt () 
  "Shows hidden word at point. "
  (interactive)
  (ar-th-show 'word))

(defalias 'ar-hide-show-word-atpt 'ar-word-hide-show-atpt)
;;;###autoload
(defun ar-word-hide-show-atpt () 
  "Alternatively hides or shows word at point. "
  (interactive)
  (ar-th-hide-show 'word))

(defalias 'ar-highlight-word-atpt-mode 'ar-word-highlight-atpt-mode)

(defun ar-word-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles word-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'word no-delimiters (interactive-p)))

(defalias 'ar-kill-word-atpt 'ar-word-kill-atpt)
;;;###autoload
(defun ar-word-kill-atpt (&optional no-delimiters) 
  "Kills word at point if any. "
  (interactive "*P")
  (ar-th-kill 'word no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-word-atpt 'ar-word-left-right-singlequote-atpt)
;;;###autoload
(defun ar-word-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'word no-delimiters (interactive-p)))

(defalias 'ar-parentize-word-atpt 'ar-word-parentize-atpt)
;;;###autoload
(defun ar-word-parentize-atpt (&optional no-delimiters) 
  "Parentizes word at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'word no-delimiters (interactive-p)))

(defalias 'ar-separate-word-atpt 'ar-word-separate-atpt)
;;;###autoload
(defun ar-word-separate-atpt (&optional no-delimiters) 
  "Separates word at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'word no-delimiters (interactive-p)))

(defalias 'ar-singlequote-word-atpt 'ar-word-singlequote-atpt)
;;;###autoload
(defun ar-word-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes word at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'word no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-word-atpt 'ar-word-triplequote-dq-atpt)
;;;###autoload
(defun ar-word-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around word. "
  (interactive "*p")
  (ar-th-triplequote-dq 'word no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-word-atpt 'ar-word-triplequote-sq-atpt)
;;;###autoload
(defun ar-word-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around word. "
  (interactive "*p")
  (ar-th-triplequote-sq 'word no-delimiters (interactive-p)))

(defalias 'ar-trim-word-atpt 'ar-word-trim-atpt)
;;;###autoload
(defun ar-word-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word t t)) 
    (ar-th-trim 'word t t)))

(defalias 'ar-trim-left-word-atpt 'ar-word-left-trim-atpt)
;;;###autoload
(defun ar-word-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word t nil))
    (ar-th-trim 'word t nil)))

(defalias 'ar-trim-right-word-atpt 'ar-word-right-trim-atpt)
;;;###autoload
(defun ar-word-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word nil t))
    (ar-th-trim 'word nil t)))

(defalias 'ar-word-underscore-atpt 'ar-underscore-word-atpt)
;;;###autoload
(defun ar-underscore-word-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'word no-delimiters (interactive-p)))

(defalias 'ar-word-whitespace-atpt 'ar-whitespace-word-atpt)
;;;###autoload
(defun ar-whitespace-word-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'word nil t))

(defalias 'ar-forward-word-atpt 'ar-word-forward-atpt)
;;;###autoload
(defun ar-word-forward-atpt (&optional arg) 
  "Moves forward over word at point if any, does nothing otherwise.
Returns end position of word "
  (interactive "p")
  (ar-th-forward 'word arg (interactive-p)))

(defalias 'ar-backward-word-atpt 'ar-word-backward-atpt)
;;;###autoload
(defun ar-word-backward-atpt (&optional arg) 
  "Moves backward over word before point if any, does nothing otherwise.
Returns beginning position of word "
  (interactive "p")
  (ar-th-backward 'word arg (interactive-p)))

(defalias 'ar-transpose-word-atpt 'ar-word-transpose-atpt)
;;;###autoload
(defun ar-word-transpose-atpt (&optional arg) 
  "Transposes word with word before point if any. "
  (interactive "*p")
  (ar-th-transpose 'word arg (interactive-p)))

(defalias 'ar-sort-word-atpt 'ar-word-sort-atpt)
;;;###autoload
(defun ar-word-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts words in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'word reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-word-atpt 'ar-word-check-atpt)
;;;###autoload
(defun ar-word-check-atpt () 
  "Return t if a word at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-word-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-word-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;;;###autoload
(defun ar-word-alpha-only-atpt (&optional arg no-delimiters) 
  "Returns word-alpha-only at point if any, nil otherwise. Optional NO-DELIMITERS trims THING, i.e. returns delimited objects like `brackteted', `braced' etc. without delimiters. "
  (interactive "p\nP")
  (ar-th 'word-alpha-only arg no-delimiters (interactive-p)))

(defalias 'ar-bounds-of-word-alpha-only-atpt 'ar-word-alpha-only-bounds-atpt)
;;;###autoload
(defun ar-word-alpha-only-bounds-atpt (&optional no-delimiters) 
  "Returns a list, borders of word-alpha-only if any, nil otherwise. "
  (interactive "P")
  (ar-th-bounds 'word-alpha-only no-delimiters (interactive-p)))

;;;###autoload
(defun ar-word-alpha-only-beginning-position-atpt (&optional no-delimiters) 
  "Returns a number, beginning position word-alpha-only at point if any, nil otherwise.  "
  (interactive "P")
  (ar-th-beg 'word-alpha-only no-delimiters (interactive-p)))

;;;###autoload
(defun ar-word-alpha-only-end-position-atpt (&optional no-delimiters) 
  "Returns a number, end position of word-alpha-only at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-end 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-beginning-of-word-alpha-only-atpt 'ar-word-alpha-only-beginning-atpt)
;;;###autoload
(defun ar-word-alpha-only-beginning-atpt (&optional no-delimiters) 
  "Goto beginning of symbol or char-class word-alpha-only at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotobeg 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-end-of-word-alpha-only-atpt 'ar-word-alpha-only-end-atpt)
;;;###autoload
(defun ar-word-alpha-only-end-atpt (&optional no-delimiters) 
  "Goto end of symbol or char-class word-alpha-only at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-gotoend 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-in-word-alpha-only-p-atpt 'ar-word-alpha-only-in-p-atpt)
;;;###autoload
(defun ar-word-alpha-only-in-p-atpt (&optional no-delimiters) 
  "If `t', returns beginning position of word-alpha-only at point, nil otherwise. "
  (interactive "P")
  (ar-th-beg 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-length-of-word-alpha-only-atpt 'ar-word-alpha-only-length-atpt)
;;;###autoload
(defun ar-word-alpha-only-length-atpt (&optional no-delimiters) 
  "Returns beginning of symbol or char-class word-alpha-only at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-length 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-copy-word-alpha-only-atpt 'ar-word-alpha-only-copy-atpt)
;;;###autoload
(defun ar-word-alpha-only-copy-atpt (&optional no-delimiters) 
  "Returns a copy of word-alpha-only at point if any, nil otherwise. "
  (interactive "P")
  (ar-th-copy 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-delete-word-alpha-only-in-region 'ar-word-alpha-only-delete-in-region)
;;;###autoload
(defun ar-word-alpha-only-delete-in-region (beg end) 
  "Deletes word-alpha-only at point if any. "
  (interactive "*r")
  (ar-th-delete-in-region 'word-alpha-only beg end (interactive-p)))

;;;###autoload
(defun ar-blok-word-alpha-only-atpt (&optional no-delimiters) 
  "Puts `blok-startstring-atpt', `blok-endstring-atpt' around word-alpha-only.
  Returns blok or nil if no word-alpha-only at cursor-position. "
  (interactive "*p")
  (ar-th-blok 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-escape-word-alpha-only-atpt 'ar-word-alpha-only-escape-atpt)
;;;###autoload
(defun ar-word-alpha-only-escape-atpt (&optional no-delimiters) 
  "Returns regexp-quoted word-alpha-only at point if any, nil otherwise "
  (interactive "*p")
  (ar-th-escape 'word-alpha-only no-delimiters))

(defalias 'ar-doublequote-word-alpha-only-atpt 'ar-word-alpha-only-doublequote-atpt)
;;;###autoload
(defun ar-word-alpha-only-doublequote-atpt (&optional no-delimiters) 
  "Doublequotes word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-doublequote 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-slash-word-alpha-only-atpt 'ar-word-alpha-only-slash-atpt)
;;;###autoload
(defun ar-word-alpha-only-slash-atpt (&optional no-delimiters) 
  "Doublequotes word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-slash 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-double-backslash-word-alpha-only-atpt 'ar-word-alpha-only-double-backslash-atpt)
;;;###autoload
(defun ar-word-alpha-only-double-backslash-atpt (&optional no-delimiters) 
  "Puts doubled backslashes around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-double-backslash 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-doubleslash-word-alpha-only-atpt 'ar-word-alpha-only-doubleslash-atpt)
;;;###autoload
(defun ar-word-alpha-only-doubleslash-atpt (&optional no-delimiters) 
  "Puts doubled slashes around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-doubleslash 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-doubleslashparen-word-alpha-only-atpt 'ar-word-alpha-only-doubleslashparen-atpt)
;;;###autoload
(defun ar-word-alpha-only-doubleslashparen-atpt (&optional no-delimiters) 
  "Provides doubleslashed parentheses around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-doubleslashparen 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-slashparen-word-alpha-only-atpt 'ar-word-alpha-only-slashparen-atpt)
;;;###autoload
(defun ar-word-alpha-only-slashparen-atpt (&optional no-delimiters) 
  "Provides slashed parentheses around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-slashparen 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-dollar-word-alpha-only-atpt 'ar-word-alpha-only-dollar-atpt)
;;;###autoload
(defun ar-word-alpha-only-dollar-atpt (&optional no-delimiters) 
  "Doublequotes word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-dollar 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-equalize-word-alpha-only-atpt 'ar-word-alpha-only-equalize-atpt)
;;;###autoload
(defun ar-word-alpha-only-equalize-atpt (&optional no-delimiters) 
  "Puts equal signs `=' around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-equalize 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-greater-angle-word-alpha-only-atpt 'ar-word-alpha-only-greater-angle-atpt)
;;;###autoload
(defun ar-word-alpha-only-greater-angle-atpt (&optional no-delimiters) 
  "Sets angles for word-alpha-only after point if any. "
  (interactive "*p")
  (ar-th-greater-angle 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-lesser-angle-word-alpha-only-atpt 'ar-word-alpha-only-lesser-angle-atpt)
;;;###autoload
(defun ar-word-alpha-only-lesser-angle-atpt (&optional no-delimiters) 
  "Sets angles for word-alpha-only after point if any. "
  (interactive "*p")
  (ar-th-lesser-angle 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-backslash-word-alpha-only-atpt 'ar-word-alpha-only-backslash-atpt)
;;;###autoload
(defun ar-word-alpha-only-backslash-atpt (&optional no-delimiters) 
  "Backslash word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-backslash 'word-alpha-only no-delimiters (interactive-p))) 

(defalias 'ar-brace-word-alpha-only-atpt 'ar-word-alpha-only-brace-atpt)
;;;###autoload
(defun ar-word-alpha-only-brace-atpt (&optional no-delimiters) 
  "Braces word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-brace 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-bracket-word-alpha-only-atpt 'ar-word-alpha-only-bracket-atpt)
;;;###autoload
(defun ar-word-alpha-only-bracket-atpt (&optional no-delimiters) 
  "Brackets word-alpha-only after point if any. "
  (interactive "*p")
  (ar-th-bracket 'word-alpha-only no-delimiters (interactive-p)))

;;;###autoload
(defun ar-comment-word-alpha-only-atpt (&optional no-delimiters) 
  "Comments word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-comment 'word-alpha-only no-delimiters (interactive-p)))

;;;###autoload
(defun ar-commatize-word-alpha-only-atpt (&optional no-delimiters) 
  "Put a comma after word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-commatize 'word-alpha-only no-delimiters (interactive-p)))

;;;###autoload
(defun ar-quote-word-alpha-only-atpt (&optional no-delimiters) 
  "Put a singlequote before word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-quote 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-hyphen-word-alpha-only-atpt 'ar-word-alpha-only-hyphen-atpt)
;;;###autoload
(defun ar-word-alpha-only-hyphen-atpt (&optional no-delimiters) 
  "Puts hyphens around word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-hyphen 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-mark-word-alpha-only-atpt 'ar-word-alpha-only-mark-atpt)
;;;###autoload
(defun ar-word-alpha-only-mark-atpt () 
  "Marks word-alpha-only at point if any. "
  (interactive)
  (ar-th-mark 'word-alpha-only))

(defalias 'ar-hide-word-alpha-only-atpt 'ar-word-alpha-only-hide-atpt)
;;;###autoload
(defun ar-word-alpha-only-hide-atpt () 
  "Hides word-alpha-only at point. "
  (interactive)
  (ar-th-hide 'word-alpha-only))

(defalias 'ar-show-word-alpha-only-atpt 'ar-word-alpha-only-show-atpt)
;;;###autoload
(defun ar-word-alpha-only-show-atpt () 
  "Shows hidden word-alpha-only at point. "
  (interactive)
  (ar-th-show 'word-alpha-only))

(defalias 'ar-hide-show-word-alpha-only-atpt 'ar-word-alpha-only-hide-show-atpt)
;;;###autoload
(defun ar-word-alpha-only-hide-show-atpt () 
  "Alternatively hides or shows word-alpha-only at point. "
  (interactive)
  (ar-th-hide-show 'word-alpha-only))

(defalias 'ar-highlight-word-alpha-only-atpt-mode 'ar-word-alpha-only-highlight-atpt-mode)

(defun ar-word-alpha-only-highlight-atpt-mode (&optional no-delimiters) 
  "Toggles word-alpha-only-highlight-atpt-mode "
  (interactive "P")
  (ar-th-highlight 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-kill-word-alpha-only-atpt 'ar-word-alpha-only-kill-atpt)
;;;###autoload
(defun ar-word-alpha-only-kill-atpt (&optional no-delimiters) 
  "Kills word-alpha-only at point if any. "
  (interactive "*P")
  (ar-th-kill 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-left-right-singlequote-word-alpha-only-atpt 'ar-word-alpha-only-left-right-singlequote-atpt)
;;;###autoload
(defun ar-word-alpha-only-left-right-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes alnum at point if any. "
  (interactive "*p")
  (ar-th-left-right-singlequote 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-parentize-word-alpha-only-atpt 'ar-word-alpha-only-parentize-atpt)
;;;###autoload
(defun ar-word-alpha-only-parentize-atpt (&optional no-delimiters) 
  "Parentizes word-alpha-only at point if any, does nothing otherwise"
  (interactive "*p")
  (ar-th-parentize 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-separate-word-alpha-only-atpt 'ar-word-alpha-only-separate-atpt)
;;;###autoload
(defun ar-word-alpha-only-separate-atpt (&optional no-delimiters) 
  "Separates word-alpha-only at point if any, does nothing otherwise
inserts newlines, borders are the beginning or the end of buffer "
  (interactive "*p")
  (ar-th-separate 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-singlequote-word-alpha-only-atpt 'ar-word-alpha-only-singlequote-atpt)
;;;###autoload
(defun ar-word-alpha-only-singlequote-atpt (&optional no-delimiters) 
  "Singlequotes word-alpha-only at point if any. "
  (interactive "*p")
  (ar-th-singlequote 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-triplequote-dq-word-alpha-only-atpt 'ar-word-alpha-only-triplequote-dq-atpt)
;;;###autoload
(defun ar-word-alpha-only-triplequote-dq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of doublequotes around word-alpha-only. "
  (interactive "*p")
  (ar-th-triplequote-dq 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-triplequote-sq-word-alpha-only-atpt 'ar-word-alpha-only-triplequote-sq-atpt)
;;;###autoload
(defun ar-word-alpha-only-triplequote-sq-atpt (&optional no-delimiters) 
  "Put triplequotes composed of singlequotes around word-alpha-only. "
  (interactive "*p")
  (ar-th-triplequote-sq 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-trim-word-alpha-only-atpt 'ar-word-alpha-only-trim-atpt)
;;;###autoload
(defun ar-word-alpha-only-trim-atpt (&optional no-delimiters) 
  "Removes leading and trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word-alpha-only t t)) 
    (ar-th-trim 'word-alpha-only t t)))

(defalias 'ar-trim-left-word-alpha-only-atpt 'ar-word-alpha-only-left-trim-atpt)
;;;###autoload
(defun ar-word-alpha-only-left-trim-atpt (&optional no-delimiters)
  "Removes leading char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word-alpha-only t nil))
    (ar-th-trim 'word-alpha-only t nil)))

(defalias 'ar-trim-right-word-alpha-only-atpt 'ar-word-alpha-only-right-trim-atpt)
;;;###autoload
(defun ar-word-alpha-only-right-trim-atpt (&optional no-delimiters)
  "Removes trailing char. "
  (interactive "*p")
  (if no-delimiters
      (save-excursion (ar-th-trim 'word-alpha-only nil t))
    (ar-th-trim 'word-alpha-only nil t)))

(defalias 'ar-word-alpha-only-underscore-atpt 'ar-underscore-word-alpha-only-atpt)
;;;###autoload
(defun ar-underscore-word-alpha-only-atpt (&optional no-delimiters)
  "Put underscore char around elt. "
  (interactive "*p")
  (ar-th-underscore 'word-alpha-only no-delimiters (interactive-p)))

(defalias 'ar-word-alpha-only-whitespace-atpt 'ar-whitespace-word-alpha-only-atpt)
;;;###autoload
(defun ar-whitespace-word-alpha-only-atpt (&optional no-delimiters)
  "Put whitespace char around elt. "
  (interactive "*p")
  (ar-th-whitespace 'word-alpha-only nil t))

(defalias 'ar-forward-word-alpha-only-atpt 'ar-word-alpha-only-forward-atpt)
;;;###autoload
(defun ar-word-alpha-only-forward-atpt (&optional arg) 
  "Moves forward over word-alpha-only at point if any, does nothing otherwise.
Returns end position of word-alpha-only "
  (interactive "p")
  (ar-th-forward 'word-alpha-only arg (interactive-p)))

(defalias 'ar-backward-word-alpha-only-atpt 'ar-word-alpha-only-backward-atpt)
;;;###autoload
(defun ar-word-alpha-only-backward-atpt (&optional arg) 
  "Moves backward over word-alpha-only before point if any, does nothing otherwise.
Returns beginning position of word-alpha-only "
  (interactive "p")
  (ar-th-backward 'word-alpha-only arg (interactive-p)))

(defalias 'ar-transpose-word-alpha-only-atpt 'ar-word-alpha-only-transpose-atpt)
;;;###autoload
(defun ar-word-alpha-only-transpose-atpt (&optional arg) 
  "Transposes word-alpha-only with word-alpha-only before point if any. "
  (interactive "*p")
  (ar-th-transpose 'word-alpha-only arg (interactive-p)))

(defalias 'ar-sort-word-alpha-only-atpt 'ar-word-alpha-only-sort-atpt)
;;;###autoload
(defun ar-word-alpha-only-sort-atpt (reverse beg end &optional startkeyfun endkeyfun predicate) 
  "Sorts word-alpha-onlys in region, with ARG in reverse order.
STARTKEYFUN may be replaced by a function which stops at an alternative beginning.
ENDKEYFUN might be a function specifying THING's end when sorting.  
With PREDICATE define a the function to compare. Defaults are `<' for numbers, otherwise `string<'.
See doku from `sort-subr', for details.
  "
  (interactive "*P\nr")
  (let ((reverse (when reverse)) startkeyfun endkeyfun predicate)
    (unless (region-active-p) (message "%s" "Region must be active!"))
    (ar-th-sort 'word-alpha-only reverse beg end startkeyfun endkeyfun predicate)))

(defalias 'ar-check-word-alpha-only-atpt 'ar-word-alpha-only-check-atpt)
;;;###autoload
(defun ar-word-alpha-only-check-atpt () 
  "Return t if a word-alpha-only at point exists, nil otherwise "
  (interactive)
  (let* ((beg (funcall (intern-soft (concat "ar-word-alpha-only-beginning-position-atpt"))))
         (end (funcall (intern-soft (concat "ar-word-alpha-only-end-position-atpt"))))
         (erg (ignore-errors (< beg end))))
    (when (interactive-p) (message "%s" erg))
    erg))

;; ar-thing-at-point-utils-core: ar-atpt-rest-list end
(defun ar-triplequote-dq-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with triplequote-dq(s),
  otherwise copy triplequote-dq(ed) at point.
  With NO-DELIMITERS, copy triplequote-dq(ed) without delimiters. 
  With negative argument kill triplequote-dq(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'triplequote-dq no-delimiters (interactive-p)))

(defun ar-triplequote-sq-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with triplequote-sq(s),
  otherwise copy triplequote-sq(ed) at point.
  With NO-DELIMITERS, copy triplequote-sq(ed) without delimiters. 
  With negative argument kill triplequote-sq(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'triplequote-sq no-delimiters (interactive-p)))

(defun ar-backslash-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with backslash(s),
  otherwise copy backslash(ed) at point.
  With NO-DELIMITERS, copy backslash(ed) without delimiters. 
  With negative argument kill backslash(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'backslash no-delimiters (interactive-p)))

(defun ar-dollar-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with dollar(s),
  otherwise copy dollar(ed) at point.
  With NO-DELIMITERS, copy dollar(ed) without delimiters. 
  With negative argument kill dollar(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'dollar no-delimiters (interactive-p)))

(defun ar-doublequote-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with doublequote(s),
  otherwise copy doublequote(ed) at point.
  With NO-DELIMITERS, copy doublequote(ed) without delimiters. 
  With negative argument kill doublequote(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'doublequote no-delimiters (interactive-p)))

(defun ar-equalize-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with equalize(s),
  otherwise copy equalize(ed) at point.
  With NO-DELIMITERS, copy equalize(ed) without delimiters. 
  With negative argument kill equalize(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'equalize no-delimiters (interactive-p)))

(defun ar-hyphen-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with hyphen(s),
  otherwise copy hyphen(ed) at point.
  With NO-DELIMITERS, copy hyphen(ed) without delimiters. 
  With negative argument kill hyphen(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'hyphen no-delimiters (interactive-p)))

(defun ar-singlequote-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with singlequote(s),
  otherwise copy singlequote(ed) at point.
  With NO-DELIMITERS, copy singlequote(ed) without delimiters. 
  With negative argument kill singlequote(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'singlequote no-delimiters (interactive-p)))

(defun ar-slash-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with slash(s),
  otherwise copy slash(ed) at point.
  With NO-DELIMITERS, copy slash(ed) without delimiters. 
  With negative argument kill slash(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'slash no-delimiters (interactive-p)))

(defun ar-underscore-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with underscore(s),
  otherwise copy underscore(ed) at point.
  With NO-DELIMITERS, copy underscore(ed) without delimiters. 
  With negative argument kill underscore(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'underscore no-delimiters (interactive-p)))

(defun ar-whitespace-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with whitespace(s),
  otherwise copy whitespace(ed) at point.
  With NO-DELIMITERS, copy whitespace(ed) without delimiters. 
  With negative argument kill whitespace(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'whitespace no-delimiters (interactive-p)))

(defun ar-brace-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with brace(s),
  otherwise copy brace(ed) at point.
  With NO-DELIMITERS, copy brace(ed) without delimiters. 
  With negative argument kill brace(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'brace no-delimiters (interactive-p)))

(defun ar-bracket-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with bracket(s),
  otherwise copy bracket(ed) at point.
  With NO-DELIMITERS, copy bracket(ed) without delimiters. 
  With negative argument kill bracket(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'bracket no-delimiters (interactive-p)))

(defun ar-lesser-angle-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with lesser-angle(s),
  otherwise copy lesser-angle(ed) at point.
  With NO-DELIMITERS, copy lesser-angle(ed) without delimiters. 
  With negative argument kill lesser-angle(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'lesser-angle no-delimiters (interactive-p)))

(defun ar-greater-angle-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with greater-angle(s),
  otherwise copy greater-angle(ed) at point.
  With NO-DELIMITERS, copy greater-angle(ed) without delimiters. 
  With negative argument kill greater-angle(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'greater-angle no-delimiters (interactive-p)))

(defun ar-left-right-singlequote-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with left-right-singlequote(s),
  otherwise copy left-right-singlequote(ed) at point.
  With NO-DELIMITERS, copy left-right-singlequote(ed) without delimiters. 
  With negative argument kill left-right-singlequote(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'left-right-singlequote no-delimiters (interactive-p)))

(defun ar-parentize-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with parentize(s),
  otherwise copy parentize(ed) at point.
  With NO-DELIMITERS, copy parentize(ed) without delimiters. 
  With negative argument kill parentize(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'parentize no-delimiters (interactive-p)))

(defun ar-braced-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with braced(s),
  otherwise copy braced(ed) at point.
  With NO-DELIMITERS, copy braced(ed) without delimiters. 
  With negative argument kill braced(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'braced no-delimiters (interactive-p)))

(defun ar-bracketed-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with bracketed(s),
  otherwise copy bracketed(ed) at point.
  With NO-DELIMITERS, copy bracketed(ed) without delimiters. 
  With negative argument kill bracketed(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'bracketed no-delimiters (interactive-p)))

(defun ar-lesser-angled-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with lesser-angled(s),
  otherwise copy lesser-angled(ed) at point.
  With NO-DELIMITERS, copy lesser-angled(ed) without delimiters. 
  With negative argument kill lesser-angled(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'lesser-angled no-delimiters (interactive-p)))

(defun ar-greater-angled-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with greater-angled(s),
  otherwise copy greater-angled(ed) at point.
  With NO-DELIMITERS, copy greater-angled(ed) without delimiters. 
  With negative argument kill greater-angled(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'greater-angled no-delimiters (interactive-p)))

(defun ar-left-right-singlequoted-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with left-right-singlequoted(s),
  otherwise copy left-right-singlequoted(ed) at point.
  With NO-DELIMITERS, copy left-right-singlequoted(ed) without delimiters. 
  With negative argument kill left-right-singlequoted(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'left-right-singlequoted no-delimiters (interactive-p)))

(defun ar-parentized-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with parentized(s),
  otherwise copy parentized(ed) at point.
  With NO-DELIMITERS, copy parentized(ed) without delimiters. 
  With negative argument kill parentized(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'parentized no-delimiters (interactive-p)))

(defun ar-abbrev-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with abbrev(s),
  otherwise copy abbrev(ed) at point.
  With NO-DELIMITERS, copy abbrev(ed) without delimiters. 
  With negative argument kill abbrev(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'abbrev no-delimiters (interactive-p)))

(defun ar-acronym-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with acronym(s),
  otherwise copy acronym(ed) at point.
  With NO-DELIMITERS, copy acronym(ed) without delimiters. 
  With negative argument kill acronym(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'acronym no-delimiters (interactive-p)))

(defun ar-angled-no-nest-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with angled-no-nest(s),
  otherwise copy angled-no-nest(ed) at point.
  With NO-DELIMITERS, copy angled-no-nest(ed) without delimiters. 
  With negative argument kill angled-no-nest(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'angled-no-nest no-delimiters (interactive-p)))

(defun ar-greater-angled-nested-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with greater-angled-nested(s),
  otherwise copy greater-angled-nested(ed) at point.
  With NO-DELIMITERS, copy greater-angled-nested(ed) without delimiters. 
  With negative argument kill greater-angled-nested(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'greater-angled-nested no-delimiters (interactive-p)))

(defun ar-lesser-angled-nested-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with lesser-angled-nested(s),
  otherwise copy lesser-angled-nested(ed) at point.
  With NO-DELIMITERS, copy lesser-angled-nested(ed) without delimiters. 
  With negative argument kill lesser-angled-nested(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'lesser-angled-nested no-delimiters (interactive-p)))

(defun ar-buffer-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with buffer(s),
  otherwise copy buffer(ed) at point.
  With NO-DELIMITERS, copy buffer(ed) without delimiters. 
  With negative argument kill buffer(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'buffer no-delimiters (interactive-p)))

(defun ar-comment-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with comment(s),
  otherwise copy comment(ed) at point.
  With NO-DELIMITERS, copy comment(ed) without delimiters. 
  With negative argument kill comment(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'comment no-delimiters (interactive-p)))

(defun ar-csv-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with csv(s),
  otherwise copy csv(ed) at point.
  With NO-DELIMITERS, copy csv(ed) without delimiters. 
  With negative argument kill csv(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'csv no-delimiters (interactive-p)))

(defun ar-date-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with date(s),
  otherwise copy date(ed) at point.
  With NO-DELIMITERS, copy date(ed) without delimiters. 
  With negative argument kill date(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'date no-delimiters (interactive-p)))

(defun ar-defun-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with defun(s),
  otherwise copy defun(ed) at point.
  With NO-DELIMITERS, copy defun(ed) without delimiters. 
  With negative argument kill defun(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'defun no-delimiters (interactive-p)))

(defun ar-delimited-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with delimited(s),
  otherwise copy delimited(ed) at point.
  With NO-DELIMITERS, copy delimited(ed) without delimiters. 
  With negative argument kill delimited(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'delimited no-delimiters (interactive-p)))

(defun ar-email-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with email(s),
  otherwise copy email(ed) at point.
  With NO-DELIMITERS, copy email(ed) without delimiters. 
  With negative argument kill email(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'email no-delimiters (interactive-p)))

(defun ar-filename-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with filename(s),
  otherwise copy filename(ed) at point.
  With NO-DELIMITERS, copy filename(ed) without delimiters. 
  With negative argument kill filename(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'filename no-delimiters (interactive-p)))

(defun ar-float-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with float(s),
  otherwise copy float(ed) at point.
  With NO-DELIMITERS, copy float(ed) without delimiters. 
  With negative argument kill float(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'float no-delimiters (interactive-p)))

(defun ar-function-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with function(s),
  otherwise copy function(ed) at point.
  With NO-DELIMITERS, copy function(ed) without delimiters. 
  With negative argument kill function(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'function no-delimiters (interactive-p)))

(defun ar-ip-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with ip(s),
  otherwise copy ip(ed) at point.
  With NO-DELIMITERS, copy ip(ed) without delimiters. 
  With negative argument kill ip(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'ip no-delimiters (interactive-p)))

(defun ar-isbn-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with isbn(s),
  otherwise copy isbn(ed) at point.
  With NO-DELIMITERS, copy isbn(ed) without delimiters. 
  With negative argument kill isbn(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'isbn no-delimiters (interactive-p)))

(defun ar-line-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with line(s),
  otherwise copy line(ed) at point.
  With NO-DELIMITERS, copy line(ed) without delimiters. 
  With negative argument kill line(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'line no-delimiters (interactive-p)))

(defun ar-name-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with name(s),
  otherwise copy name(ed) at point.
  With NO-DELIMITERS, copy name(ed) without delimiters. 
  With negative argument kill name(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'name no-delimiters (interactive-p)))

(defun ar-number-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with number(s),
  otherwise copy number(ed) at point.
  With NO-DELIMITERS, copy number(ed) without delimiters. 
  With negative argument kill number(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'number no-delimiters (interactive-p)))

(defun ar-page-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with page(s),
  otherwise copy page(ed) at point.
  With NO-DELIMITERS, copy page(ed) without delimiters. 
  With negative argument kill page(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'page no-delimiters (interactive-p)))

(defun ar-paragraph-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with paragraph(s),
  otherwise copy paragraph(ed) at point.
  With NO-DELIMITERS, copy paragraph(ed) without delimiters. 
  With negative argument kill paragraph(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'paragraph no-delimiters (interactive-p)))

(defun ar-paren-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with paren(s),
  otherwise copy paren(ed) at point.
  With NO-DELIMITERS, copy paren(ed) without delimiters. 
  With negative argument kill paren(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'paren no-delimiters (interactive-p)))

(defun ar-phone-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with phone(s),
  otherwise copy phone(ed) at point.
  With NO-DELIMITERS, copy phone(ed) without delimiters. 
  With negative argument kill phone(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'phone no-delimiters (interactive-p)))

(defun ar-region-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with region(s),
  otherwise copy region(ed) at point.
  With NO-DELIMITERS, copy region(ed) without delimiters. 
  With negative argument kill region(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'region no-delimiters (interactive-p)))

(defun ar-sentence-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with sentence(s),
  otherwise copy sentence(ed) at point.
  With NO-DELIMITERS, copy sentence(ed) without delimiters. 
  With negative argument kill sentence(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'sentence no-delimiters (interactive-p)))

(defun ar-sexp-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with sexp(s),
  otherwise copy sexp(ed) at point.
  With NO-DELIMITERS, copy sexp(ed) without delimiters. 
  With negative argument kill sexp(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'sexp no-delimiters (interactive-p)))

(defun ar-string-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with string(s),
  otherwise copy string(ed) at point.
  With NO-DELIMITERS, copy string(ed) without delimiters. 
  With negative argument kill string(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'string no-delimiters (interactive-p)))

(defun ar-sh-struct-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with sh-struct(s),
  otherwise copy sh-struct(ed) at point.
  With NO-DELIMITERS, copy sh-struct(ed) without delimiters. 
  With negative argument kill sh-struct(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'sh-struct no-delimiters (interactive-p)))

(defun ar-symbol-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with symbol(s),
  otherwise copy symbol(ed) at point.
  With NO-DELIMITERS, copy symbol(ed) without delimiters. 
  With negative argument kill symbol(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'symbol no-delimiters (interactive-p)))

(defun ar-url-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with url(s),
  otherwise copy url(ed) at point.
  With NO-DELIMITERS, copy url(ed) without delimiters. 
  With negative argument kill url(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'url no-delimiters (interactive-p)))

(defun ar-word-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with word(s),
  otherwise copy word(ed) at point.
  With NO-DELIMITERS, copy word(ed) without delimiters. 
  With negative argument kill word(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'word no-delimiters (interactive-p)))

(defun ar-word-alpha-only-or-copy-atpt (&optional no-delimiters) 
  "If region is highlighted, provide THING at point with word-alpha-only(s),
  otherwise copy word-alpha-only(ed) at point.
  With NO-DELIMITERS, copy word-alpha-only(ed) without delimiters. 
  With negative argument kill word-alpha-only(ed) at point. "
  (interactive "p")
  (ar-th-base-copy-or 'word-alpha-only no-delimiters (interactive-p)))




(provide 'thing-at-point-utils)
;;; thing-at-point-utils.el ends here
